#include "parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1378
#define LARGE_STATE_COUNT 405
#define SYMBOL_COUNT 320
#define ALIAS_COUNT 1
#define TOKEN_COUNT 138
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 40
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define PRODUCTION_ID_COUNT 208

enum ts_symbol_identifiers {
  sym_identifier = 1,
  sym_decimal_integer_literal = 2,
  sym_hex_integer_literal = 3,
  sym_octal_integer_literal = 4,
  sym_binary_integer_literal = 5,
  sym_decimal_floating_point_literal = 6,
  sym_hex_floating_point_literal = 7,
  sym_true = 8,
  sym_false = 9,
  sym_character_literal = 10,
  anon_sym_DQUOTE = 11,
  anon_sym_DQUOTE_DQUOTE_DQUOTE = 12,
  sym_string_fragment = 13,
  aux_sym__multiline_string_fragment_token1 = 14,
  aux_sym__multiline_string_fragment_token2 = 15,
  anon_sym_BSLASH_LBRACE = 16,
  anon_sym_RBRACE = 17,
  aux_sym__escape_sequence_token1 = 18,
  sym_escape_sequence = 19,
  sym_null_literal = 20,
  anon_sym_LPAREN = 21,
  anon_sym_RPAREN = 22,
  anon_sym_AMP = 23,
  anon_sym_EQ = 24,
  anon_sym_PLUS_EQ = 25,
  anon_sym_DASH_EQ = 26,
  anon_sym_STAR_EQ = 27,
  anon_sym_SLASH_EQ = 28,
  anon_sym_AMP_EQ = 29,
  anon_sym_PIPE_EQ = 30,
  anon_sym_CARET_EQ = 31,
  anon_sym_PERCENT_EQ = 32,
  anon_sym_LT_LT_EQ = 33,
  anon_sym_GT_GT_EQ = 34,
  anon_sym_GT_GT_GT_EQ = 35,
  anon_sym_GT = 36,
  anon_sym_LT = 37,
  anon_sym_GT_EQ = 38,
  anon_sym_LT_EQ = 39,
  anon_sym_EQ_EQ = 40,
  anon_sym_BANG_EQ = 41,
  anon_sym_AMP_AMP = 42,
  anon_sym_PIPE_PIPE = 43,
  anon_sym_PLUS = 44,
  anon_sym_DASH = 45,
  anon_sym_STAR = 46,
  anon_sym_SLASH = 47,
  anon_sym_PIPE = 48,
  anon_sym_CARET = 49,
  anon_sym_PERCENT = 50,
  anon_sym_LT_LT = 51,
  anon_sym_GT_GT = 52,
  anon_sym_GT_GT_GT = 53,
  anon_sym_instanceof = 54,
  anon_sym_final = 55,
  anon_sym_DASH_GT = 56,
  anon_sym_COMMA = 57,
  anon_sym_QMARK = 58,
  anon_sym_COLON = 59,
  anon_sym_BANG = 60,
  anon_sym_TILDE = 61,
  anon_sym_PLUS_PLUS = 62,
  anon_sym_DASH_DASH = 63,
  anon_sym_new = 64,
  anon_sym_LBRACK = 65,
  anon_sym_RBRACK = 66,
  anon_sym_DOT = 67,
  anon_sym_class = 68,
  anon_sym_COLON_COLON = 69,
  anon_sym_extends = 70,
  anon_sym_switch = 71,
  anon_sym_LBRACE = 72,
  anon_sym_case = 73,
  anon_sym_default = 74,
  sym_underscore_pattern = 75,
  anon_sym_when = 76,
  anon_sym_SEMI = 77,
  anon_sym_assert = 78,
  anon_sym_do = 79,
  anon_sym_while = 80,
  anon_sym_break = 81,
  anon_sym_continue = 82,
  anon_sym_return = 83,
  anon_sym_yield = 84,
  anon_sym_synchronized = 85,
  anon_sym_throw = 86,
  anon_sym_try = 87,
  anon_sym_catch = 88,
  anon_sym_finally = 89,
  anon_sym_if = 90,
  anon_sym_else = 91,
  anon_sym_for = 92,
  anon_sym_AT = 93,
  anon_sym_open = 94,
  anon_sym_module = 95,
  anon_sym_requires = 96,
  anon_sym_transitive = 97,
  anon_sym_static = 98,
  anon_sym_exports = 99,
  anon_sym_to = 100,
  anon_sym_opens = 101,
  anon_sym_uses = 102,
  anon_sym_provides = 103,
  anon_sym_with = 104,
  anon_sym_package = 105,
  anon_sym_import = 106,
  anon_sym_enum = 107,
  anon_sym_public = 108,
  anon_sym_protected = 109,
  anon_sym_private = 110,
  anon_sym_abstract = 111,
  anon_sym_strictfp = 112,
  anon_sym_native = 113,
  anon_sym_transient = 114,
  anon_sym_volatile = 115,
  anon_sym_sealed = 116,
  anon_sym_non_DASHsealed = 117,
  anon_sym_implements = 118,
  anon_sym_permits = 119,
  anon_sym_record = 120,
  anon_sym_ATinterface = 121,
  anon_sym_interface = 122,
  anon_sym_byte = 123,
  anon_sym_short = 124,
  anon_sym_int = 125,
  anon_sym_long = 126,
  anon_sym_char = 127,
  anon_sym_float = 128,
  anon_sym_double = 129,
  sym_boolean_type = 130,
  sym_void_type = 131,
  anon_sym_DOT_DOT_DOT = 132,
  anon_sym_throws = 133,
  sym_this = 134,
  sym_super = 135,
  sym_line_comment = 136,
  sym_block_comment = 137,
  sym_program = 138,
  sym__toplevel_statement = 139,
  sym__literal = 140,
  sym_string_literal = 141,
  sym__string_literal = 142,
  sym__multiline_string_literal = 143,
  sym__multiline_string_fragment = 144,
  sym_string_interpolation = 145,
  sym__escape_sequence = 146,
  sym_expression = 147,
  sym_cast_expression = 148,
  sym_assignment_expression = 149,
  sym_binary_expression = 150,
  sym_instanceof_expression = 151,
  sym_lambda_expression = 152,
  sym_inferred_parameters = 153,
  sym_ternary_expression = 154,
  sym_unary_expression = 155,
  sym_update_expression = 156,
  sym_primary_expression = 157,
  sym_array_creation_expression = 158,
  sym_dimensions_expr = 159,
  sym_parenthesized_expression = 160,
  sym_class_literal = 161,
  sym_object_creation_expression = 162,
  sym__unqualified_object_creation_expression = 163,
  sym_field_access = 164,
  sym_template_expression = 165,
  sym_array_access = 166,
  sym_method_invocation = 167,
  sym_argument_list = 168,
  sym_method_reference = 169,
  sym_type_arguments = 170,
  sym_wildcard = 171,
  sym__wildcard_bounds = 172,
  sym_dimensions = 173,
  sym_switch_expression = 174,
  sym_switch_block = 175,
  sym_switch_block_statement_group = 176,
  sym_switch_rule = 177,
  sym_switch_label = 178,
  sym_pattern = 179,
  sym_type_pattern = 180,
  sym_record_pattern = 181,
  sym_record_pattern_body = 182,
  sym_record_pattern_component = 183,
  sym_guard = 184,
  sym_statement = 185,
  sym_block = 186,
  sym_expression_statement = 187,
  sym_labeled_statement = 188,
  sym_assert_statement = 189,
  sym_do_statement = 190,
  sym_break_statement = 191,
  sym_continue_statement = 192,
  sym_return_statement = 193,
  sym_yield_statement = 194,
  sym_synchronized_statement = 195,
  sym_throw_statement = 196,
  sym_try_statement = 197,
  sym_catch_clause = 198,
  sym_catch_formal_parameter = 199,
  sym_catch_type = 200,
  sym_finally_clause = 201,
  sym_try_with_resources_statement = 202,
  sym_resource_specification = 203,
  sym_resource = 204,
  sym_if_statement = 205,
  sym_while_statement = 206,
  sym_for_statement = 207,
  sym_enhanced_for_statement = 208,
  sym__annotation = 209,
  sym_marker_annotation = 210,
  sym_annotation = 211,
  sym_annotation_argument_list = 212,
  sym_element_value_pair = 213,
  sym__element_value = 214,
  sym_element_value_array_initializer = 215,
  sym_declaration = 216,
  sym_module_declaration = 217,
  sym_module_body = 218,
  sym_module_directive = 219,
  sym_requires_module_directive = 220,
  sym_requires_modifier = 221,
  sym_exports_module_directive = 222,
  sym_opens_module_directive = 223,
  sym_uses_module_directive = 224,
  sym_provides_module_directive = 225,
  sym_package_declaration = 226,
  sym_import_declaration = 227,
  sym_asterisk = 228,
  sym_enum_declaration = 229,
  sym_enum_body = 230,
  sym_enum_body_declarations = 231,
  sym_enum_constant = 232,
  sym_class_declaration = 233,
  sym_modifiers = 234,
  sym_type_parameters = 235,
  sym_type_parameter = 236,
  sym_type_bound = 237,
  sym_superclass = 238,
  sym_super_interfaces = 239,
  sym_type_list = 240,
  sym_permits = 241,
  sym_class_body = 242,
  sym_static_initializer = 243,
  sym_constructor_declaration = 244,
  sym__constructor_declarator = 245,
  sym_constructor_body = 246,
  sym_explicit_constructor_invocation = 247,
  sym_scoped_identifier = 248,
  sym_field_declaration = 249,
  sym_record_declaration = 250,
  sym_annotation_type_declaration = 251,
  sym_annotation_type_body = 252,
  sym_annotation_type_element_declaration = 253,
  sym__default_value = 254,
  sym_interface_declaration = 255,
  sym_extends_interfaces = 256,
  sym_interface_body = 257,
  sym_constant_declaration = 258,
  sym__variable_declarator_list = 259,
  sym_variable_declarator = 260,
  sym__variable_declarator_id = 261,
  sym_array_initializer = 262,
  sym__type = 263,
  sym__unannotated_type = 264,
  sym_annotated_type = 265,
  sym_scoped_type_identifier = 266,
  sym_generic_type = 267,
  sym_array_type = 268,
  sym_integral_type = 269,
  sym_floating_point_type = 270,
  sym__method_header = 271,
  sym__method_declarator = 272,
  sym_formal_parameters = 273,
  sym_formal_parameter = 274,
  sym_receiver_parameter = 275,
  sym_spread_parameter = 276,
  sym_throws = 277,
  sym_local_variable_declaration = 278,
  sym_method_declaration = 279,
  sym_compact_constructor_declaration = 280,
  sym__reserved_identifier = 281,
  aux_sym_program_repeat1 = 282,
  aux_sym__string_literal_repeat1 = 283,
  aux_sym__multiline_string_literal_repeat1 = 284,
  aux_sym_cast_expression_repeat1 = 285,
  aux_sym_inferred_parameters_repeat1 = 286,
  aux_sym_array_creation_expression_repeat1 = 287,
  aux_sym_array_creation_expression_repeat2 = 288,
  aux_sym_argument_list_repeat1 = 289,
  aux_sym_type_arguments_repeat1 = 290,
  aux_sym_dimensions_repeat1 = 291,
  aux_sym_switch_block_repeat1 = 292,
  aux_sym_switch_block_repeat2 = 293,
  aux_sym_switch_block_statement_group_repeat1 = 294,
  aux_sym_switch_block_statement_group_repeat2 = 295,
  aux_sym_record_pattern_body_repeat1 = 296,
  aux_sym_try_statement_repeat1 = 297,
  aux_sym_catch_type_repeat1 = 298,
  aux_sym_resource_specification_repeat1 = 299,
  aux_sym_for_statement_repeat1 = 300,
  aux_sym_for_statement_repeat2 = 301,
  aux_sym_annotation_argument_list_repeat1 = 302,
  aux_sym_element_value_array_initializer_repeat1 = 303,
  aux_sym_module_body_repeat1 = 304,
  aux_sym_requires_module_directive_repeat1 = 305,
  aux_sym_exports_module_directive_repeat1 = 306,
  aux_sym_provides_module_directive_repeat1 = 307,
  aux_sym_enum_body_repeat1 = 308,
  aux_sym_enum_body_declarations_repeat1 = 309,
  aux_sym_modifiers_repeat1 = 310,
  aux_sym_type_parameters_repeat1 = 311,
  aux_sym_type_bound_repeat1 = 312,
  aux_sym_type_list_repeat1 = 313,
  aux_sym_annotation_type_body_repeat1 = 314,
  aux_sym_interface_body_repeat1 = 315,
  aux_sym__variable_declarator_list_repeat1 = 316,
  aux_sym_array_initializer_repeat1 = 317,
  aux_sym_formal_parameters_repeat1 = 318,
  aux_sym_receiver_parameter_repeat1 = 319,
  alias_sym_type_identifier = 320,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [sym_decimal_integer_literal] = "decimal_integer_literal",
  [sym_hex_integer_literal] = "hex_integer_literal",
  [sym_octal_integer_literal] = "octal_integer_literal",
  [sym_binary_integer_literal] = "binary_integer_literal",
  [sym_decimal_floating_point_literal] = "decimal_floating_point_literal",
  [sym_hex_floating_point_literal] = "hex_floating_point_literal",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_character_literal] = "character_literal",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = "\"\"\"",
  [sym_string_fragment] = "string_fragment",
  [aux_sym__multiline_string_fragment_token1] = "_multiline_string_fragment_token1",
  [aux_sym__multiline_string_fragment_token2] = "_multiline_string_fragment_token2",
  [anon_sym_BSLASH_LBRACE] = "\\{",
  [anon_sym_RBRACE] = "}",
  [aux_sym__escape_sequence_token1] = "_escape_sequence_token1",
  [sym_escape_sequence] = "escape_sequence",
  [sym_null_literal] = "null_literal",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_GT] = ">",
  [anon_sym_LT] = "<",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_PERCENT] = "%",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_instanceof] = "instanceof",
  [anon_sym_final] = "final",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_COMMA] = ",",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_new] = "new",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT] = ".",
  [anon_sym_class] = "class",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_extends] = "extends",
  [anon_sym_switch] = "switch",
  [anon_sym_LBRACE] = "{",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [sym_underscore_pattern] = "underscore_pattern",
  [anon_sym_when] = "when",
  [anon_sym_SEMI] = ";",
  [anon_sym_assert] = "assert",
  [anon_sym_do] = "do",
  [anon_sym_while] = "while",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_return] = "return",
  [anon_sym_yield] = "yield",
  [anon_sym_synchronized] = "synchronized",
  [anon_sym_throw] = "throw",
  [anon_sym_try] = "try",
  [anon_sym_catch] = "catch",
  [anon_sym_finally] = "finally",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_for] = "for",
  [anon_sym_AT] = "@",
  [anon_sym_open] = "open",
  [anon_sym_module] = "module",
  [anon_sym_requires] = "requires",
  [anon_sym_transitive] = "transitive",
  [anon_sym_static] = "static",
  [anon_sym_exports] = "exports",
  [anon_sym_to] = "to",
  [anon_sym_opens] = "opens",
  [anon_sym_uses] = "uses",
  [anon_sym_provides] = "provides",
  [anon_sym_with] = "with",
  [anon_sym_package] = "package",
  [anon_sym_import] = "import",
  [anon_sym_enum] = "enum",
  [anon_sym_public] = "public",
  [anon_sym_protected] = "protected",
  [anon_sym_private] = "private",
  [anon_sym_abstract] = "abstract",
  [anon_sym_strictfp] = "strictfp",
  [anon_sym_native] = "native",
  [anon_sym_transient] = "transient",
  [anon_sym_volatile] = "volatile",
  [anon_sym_sealed] = "sealed",
  [anon_sym_non_DASHsealed] = "non-sealed",
  [anon_sym_implements] = "implements",
  [anon_sym_permits] = "permits",
  [anon_sym_record] = "record",
  [anon_sym_ATinterface] = "@interface",
  [anon_sym_interface] = "interface",
  [anon_sym_byte] = "byte",
  [anon_sym_short] = "short",
  [anon_sym_int] = "int",
  [anon_sym_long] = "long",
  [anon_sym_char] = "char",
  [anon_sym_float] = "float",
  [anon_sym_double] = "double",
  [sym_boolean_type] = "boolean_type",
  [sym_void_type] = "void_type",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_throws] = "throws",
  [sym_this] = "this",
  [sym_super] = "super",
  [sym_line_comment] = "line_comment",
  [sym_block_comment] = "block_comment",
  [sym_program] = "program",
  [sym__toplevel_statement] = "_toplevel_statement",
  [sym__literal] = "_literal",
  [sym_string_literal] = "string_literal",
  [sym__string_literal] = "_string_literal",
  [sym__multiline_string_literal] = "_multiline_string_literal",
  [sym__multiline_string_fragment] = "multiline_string_fragment",
  [sym_string_interpolation] = "string_interpolation",
  [sym__escape_sequence] = "_escape_sequence",
  [sym_expression] = "expression",
  [sym_cast_expression] = "cast_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_instanceof_expression] = "instanceof_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_inferred_parameters] = "inferred_parameters",
  [sym_ternary_expression] = "ternary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_update_expression] = "update_expression",
  [sym_primary_expression] = "primary_expression",
  [sym_array_creation_expression] = "array_creation_expression",
  [sym_dimensions_expr] = "dimensions_expr",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_class_literal] = "class_literal",
  [sym_object_creation_expression] = "object_creation_expression",
  [sym__unqualified_object_creation_expression] = "_unqualified_object_creation_expression",
  [sym_field_access] = "field_access",
  [sym_template_expression] = "template_expression",
  [sym_array_access] = "array_access",
  [sym_method_invocation] = "method_invocation",
  [sym_argument_list] = "argument_list",
  [sym_method_reference] = "method_reference",
  [sym_type_arguments] = "type_arguments",
  [sym_wildcard] = "wildcard",
  [sym__wildcard_bounds] = "_wildcard_bounds",
  [sym_dimensions] = "dimensions",
  [sym_switch_expression] = "switch_expression",
  [sym_switch_block] = "switch_block",
  [sym_switch_block_statement_group] = "switch_block_statement_group",
  [sym_switch_rule] = "switch_rule",
  [sym_switch_label] = "switch_label",
  [sym_pattern] = "pattern",
  [sym_type_pattern] = "type_pattern",
  [sym_record_pattern] = "record_pattern",
  [sym_record_pattern_body] = "record_pattern_body",
  [sym_record_pattern_component] = "record_pattern_component",
  [sym_guard] = "guard",
  [sym_statement] = "statement",
  [sym_block] = "block",
  [sym_expression_statement] = "expression_statement",
  [sym_labeled_statement] = "labeled_statement",
  [sym_assert_statement] = "assert_statement",
  [sym_do_statement] = "do_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_return_statement] = "return_statement",
  [sym_yield_statement] = "yield_statement",
  [sym_synchronized_statement] = "synchronized_statement",
  [sym_throw_statement] = "throw_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_catch_formal_parameter] = "catch_formal_parameter",
  [sym_catch_type] = "catch_type",
  [sym_finally_clause] = "finally_clause",
  [sym_try_with_resources_statement] = "try_with_resources_statement",
  [sym_resource_specification] = "resource_specification",
  [sym_resource] = "resource",
  [sym_if_statement] = "if_statement",
  [sym_while_statement] = "while_statement",
  [sym_for_statement] = "for_statement",
  [sym_enhanced_for_statement] = "enhanced_for_statement",
  [sym__annotation] = "_annotation",
  [sym_marker_annotation] = "marker_annotation",
  [sym_annotation] = "annotation",
  [sym_annotation_argument_list] = "annotation_argument_list",
  [sym_element_value_pair] = "element_value_pair",
  [sym__element_value] = "_element_value",
  [sym_element_value_array_initializer] = "element_value_array_initializer",
  [sym_declaration] = "declaration",
  [sym_module_declaration] = "module_declaration",
  [sym_module_body] = "module_body",
  [sym_module_directive] = "module_directive",
  [sym_requires_module_directive] = "requires_module_directive",
  [sym_requires_modifier] = "requires_modifier",
  [sym_exports_module_directive] = "exports_module_directive",
  [sym_opens_module_directive] = "opens_module_directive",
  [sym_uses_module_directive] = "uses_module_directive",
  [sym_provides_module_directive] = "provides_module_directive",
  [sym_package_declaration] = "package_declaration",
  [sym_import_declaration] = "import_declaration",
  [sym_asterisk] = "asterisk",
  [sym_enum_declaration] = "enum_declaration",
  [sym_enum_body] = "enum_body",
  [sym_enum_body_declarations] = "enum_body_declarations",
  [sym_enum_constant] = "enum_constant",
  [sym_class_declaration] = "class_declaration",
  [sym_modifiers] = "modifiers",
  [sym_type_parameters] = "type_parameters",
  [sym_type_parameter] = "type_parameter",
  [sym_type_bound] = "type_bound",
  [sym_superclass] = "superclass",
  [sym_super_interfaces] = "super_interfaces",
  [sym_type_list] = "type_list",
  [sym_permits] = "permits",
  [sym_class_body] = "class_body",
  [sym_static_initializer] = "static_initializer",
  [sym_constructor_declaration] = "constructor_declaration",
  [sym__constructor_declarator] = "_constructor_declarator",
  [sym_constructor_body] = "constructor_body",
  [sym_explicit_constructor_invocation] = "explicit_constructor_invocation",
  [sym_scoped_identifier] = "scoped_identifier",
  [sym_field_declaration] = "field_declaration",
  [sym_record_declaration] = "record_declaration",
  [sym_annotation_type_declaration] = "annotation_type_declaration",
  [sym_annotation_type_body] = "annotation_type_body",
  [sym_annotation_type_element_declaration] = "annotation_type_element_declaration",
  [sym__default_value] = "_default_value",
  [sym_interface_declaration] = "interface_declaration",
  [sym_extends_interfaces] = "extends_interfaces",
  [sym_interface_body] = "interface_body",
  [sym_constant_declaration] = "constant_declaration",
  [sym__variable_declarator_list] = "_variable_declarator_list",
  [sym_variable_declarator] = "variable_declarator",
  [sym__variable_declarator_id] = "_variable_declarator_id",
  [sym_array_initializer] = "array_initializer",
  [sym__type] = "_type",
  [sym__unannotated_type] = "_unannotated_type",
  [sym_annotated_type] = "annotated_type",
  [sym_scoped_type_identifier] = "scoped_type_identifier",
  [sym_generic_type] = "generic_type",
  [sym_array_type] = "array_type",
  [sym_integral_type] = "integral_type",
  [sym_floating_point_type] = "floating_point_type",
  [sym__method_header] = "_method_header",
  [sym__method_declarator] = "_method_declarator",
  [sym_formal_parameters] = "formal_parameters",
  [sym_formal_parameter] = "formal_parameter",
  [sym_receiver_parameter] = "receiver_parameter",
  [sym_spread_parameter] = "spread_parameter",
  [sym_throws] = "throws",
  [sym_local_variable_declaration] = "local_variable_declaration",
  [sym_method_declaration] = "method_declaration",
  [sym_compact_constructor_declaration] = "compact_constructor_declaration",
  [sym__reserved_identifier] = "_reserved_identifier",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym__string_literal_repeat1] = "_string_literal_repeat1",
  [aux_sym__multiline_string_literal_repeat1] = "_multiline_string_literal_repeat1",
  [aux_sym_cast_expression_repeat1] = "cast_expression_repeat1",
  [aux_sym_inferred_parameters_repeat1] = "inferred_parameters_repeat1",
  [aux_sym_array_creation_expression_repeat1] = "array_creation_expression_repeat1",
  [aux_sym_array_creation_expression_repeat2] = "array_creation_expression_repeat2",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_type_arguments_repeat1] = "type_arguments_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_switch_block_repeat1] = "switch_block_repeat1",
  [aux_sym_switch_block_repeat2] = "switch_block_repeat2",
  [aux_sym_switch_block_statement_group_repeat1] = "switch_block_statement_group_repeat1",
  [aux_sym_switch_block_statement_group_repeat2] = "switch_block_statement_group_repeat2",
  [aux_sym_record_pattern_body_repeat1] = "record_pattern_body_repeat1",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym_catch_type_repeat1] = "catch_type_repeat1",
  [aux_sym_resource_specification_repeat1] = "resource_specification_repeat1",
  [aux_sym_for_statement_repeat1] = "for_statement_repeat1",
  [aux_sym_for_statement_repeat2] = "for_statement_repeat2",
  [aux_sym_annotation_argument_list_repeat1] = "annotation_argument_list_repeat1",
  [aux_sym_element_value_array_initializer_repeat1] = "element_value_array_initializer_repeat1",
  [aux_sym_module_body_repeat1] = "module_body_repeat1",
  [aux_sym_requires_module_directive_repeat1] = "requires_module_directive_repeat1",
  [aux_sym_exports_module_directive_repeat1] = "exports_module_directive_repeat1",
  [aux_sym_provides_module_directive_repeat1] = "provides_module_directive_repeat1",
  [aux_sym_enum_body_repeat1] = "enum_body_repeat1",
  [aux_sym_enum_body_declarations_repeat1] = "enum_body_declarations_repeat1",
  [aux_sym_modifiers_repeat1] = "modifiers_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym_type_bound_repeat1] = "type_bound_repeat1",
  [aux_sym_type_list_repeat1] = "type_list_repeat1",
  [aux_sym_annotation_type_body_repeat1] = "annotation_type_body_repeat1",
  [aux_sym_interface_body_repeat1] = "interface_body_repeat1",
  [aux_sym__variable_declarator_list_repeat1] = "_variable_declarator_list_repeat1",
  [aux_sym_array_initializer_repeat1] = "array_initializer_repeat1",
  [aux_sym_formal_parameters_repeat1] = "formal_parameters_repeat1",
  [aux_sym_receiver_parameter_repeat1] = "receiver_parameter_repeat1",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [sym_decimal_integer_literal] = sym_decimal_integer_literal,
  [sym_hex_integer_literal] = sym_hex_integer_literal,
  [sym_octal_integer_literal] = sym_octal_integer_literal,
  [sym_binary_integer_literal] = sym_binary_integer_literal,
  [sym_decimal_floating_point_literal] = sym_decimal_floating_point_literal,
  [sym_hex_floating_point_literal] = sym_hex_floating_point_literal,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_character_literal] = sym_character_literal,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [sym_string_fragment] = sym_string_fragment,
  [aux_sym__multiline_string_fragment_token1] = aux_sym__multiline_string_fragment_token1,
  [aux_sym__multiline_string_fragment_token2] = aux_sym__multiline_string_fragment_token2,
  [anon_sym_BSLASH_LBRACE] = anon_sym_BSLASH_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym__escape_sequence_token1] = aux_sym__escape_sequence_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_null_literal] = sym_null_literal,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_instanceof] = anon_sym_instanceof,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [sym_underscore_pattern] = sym_underscore_pattern,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_yield] = anon_sym_yield,
  [anon_sym_synchronized] = anon_sym_synchronized,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_open] = anon_sym_open,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_requires] = anon_sym_requires,
  [anon_sym_transitive] = anon_sym_transitive,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_exports] = anon_sym_exports,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_opens] = anon_sym_opens,
  [anon_sym_uses] = anon_sym_uses,
  [anon_sym_provides] = anon_sym_provides,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_strictfp] = anon_sym_strictfp,
  [anon_sym_native] = anon_sym_native,
  [anon_sym_transient] = anon_sym_transient,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_sealed] = anon_sym_sealed,
  [anon_sym_non_DASHsealed] = anon_sym_non_DASHsealed,
  [anon_sym_implements] = anon_sym_implements,
  [anon_sym_permits] = anon_sym_permits,
  [anon_sym_record] = anon_sym_record,
  [anon_sym_ATinterface] = anon_sym_ATinterface,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_byte] = anon_sym_byte,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_char] = anon_sym_char,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_double] = anon_sym_double,
  [sym_boolean_type] = sym_boolean_type,
  [sym_void_type] = sym_void_type,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_throws] = anon_sym_throws,
  [sym_this] = sym_this,
  [sym_super] = sym_super,
  [sym_line_comment] = sym_line_comment,
  [sym_block_comment] = sym_block_comment,
  [sym_program] = sym_program,
  [sym__toplevel_statement] = sym__toplevel_statement,
  [sym__literal] = sym__literal,
  [sym_string_literal] = sym_string_literal,
  [sym__string_literal] = sym__string_literal,
  [sym__multiline_string_literal] = sym__multiline_string_literal,
  [sym__multiline_string_fragment] = sym__multiline_string_fragment,
  [sym_string_interpolation] = sym_string_interpolation,
  [sym__escape_sequence] = sym__escape_sequence,
  [sym_expression] = sym_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_instanceof_expression] = sym_instanceof_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_inferred_parameters] = sym_inferred_parameters,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_primary_expression] = sym_primary_expression,
  [sym_array_creation_expression] = sym_array_creation_expression,
  [sym_dimensions_expr] = sym_dimensions_expr,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_class_literal] = sym_class_literal,
  [sym_object_creation_expression] = sym_object_creation_expression,
  [sym__unqualified_object_creation_expression] = sym__unqualified_object_creation_expression,
  [sym_field_access] = sym_field_access,
  [sym_template_expression] = sym_template_expression,
  [sym_array_access] = sym_array_access,
  [sym_method_invocation] = sym_method_invocation,
  [sym_argument_list] = sym_argument_list,
  [sym_method_reference] = sym_method_reference,
  [sym_type_arguments] = sym_type_arguments,
  [sym_wildcard] = sym_wildcard,
  [sym__wildcard_bounds] = sym__wildcard_bounds,
  [sym_dimensions] = sym_dimensions,
  [sym_switch_expression] = sym_switch_expression,
  [sym_switch_block] = sym_switch_block,
  [sym_switch_block_statement_group] = sym_switch_block_statement_group,
  [sym_switch_rule] = sym_switch_rule,
  [sym_switch_label] = sym_switch_label,
  [sym_pattern] = sym_pattern,
  [sym_type_pattern] = sym_type_pattern,
  [sym_record_pattern] = sym_record_pattern,
  [sym_record_pattern_body] = sym_record_pattern_body,
  [sym_record_pattern_component] = sym_record_pattern_component,
  [sym_guard] = sym_guard,
  [sym_statement] = sym_statement,
  [sym_block] = sym_block,
  [sym_expression_statement] = sym_expression_statement,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym_assert_statement] = sym_assert_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_yield_statement] = sym_yield_statement,
  [sym_synchronized_statement] = sym_synchronized_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_catch_formal_parameter] = sym_catch_formal_parameter,
  [sym_catch_type] = sym_catch_type,
  [sym_finally_clause] = sym_finally_clause,
  [sym_try_with_resources_statement] = sym_try_with_resources_statement,
  [sym_resource_specification] = sym_resource_specification,
  [sym_resource] = sym_resource,
  [sym_if_statement] = sym_if_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_enhanced_for_statement] = sym_enhanced_for_statement,
  [sym__annotation] = sym__annotation,
  [sym_marker_annotation] = sym_marker_annotation,
  [sym_annotation] = sym_annotation,
  [sym_annotation_argument_list] = sym_annotation_argument_list,
  [sym_element_value_pair] = sym_element_value_pair,
  [sym__element_value] = sym__element_value,
  [sym_element_value_array_initializer] = sym_element_value_array_initializer,
  [sym_declaration] = sym_declaration,
  [sym_module_declaration] = sym_module_declaration,
  [sym_module_body] = sym_module_body,
  [sym_module_directive] = sym_module_directive,
  [sym_requires_module_directive] = sym_requires_module_directive,
  [sym_requires_modifier] = sym_requires_modifier,
  [sym_exports_module_directive] = sym_exports_module_directive,
  [sym_opens_module_directive] = sym_opens_module_directive,
  [sym_uses_module_directive] = sym_uses_module_directive,
  [sym_provides_module_directive] = sym_provides_module_directive,
  [sym_package_declaration] = sym_package_declaration,
  [sym_import_declaration] = sym_import_declaration,
  [sym_asterisk] = sym_asterisk,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_body_declarations] = sym_enum_body_declarations,
  [sym_enum_constant] = sym_enum_constant,
  [sym_class_declaration] = sym_class_declaration,
  [sym_modifiers] = sym_modifiers,
  [sym_type_parameters] = sym_type_parameters,
  [sym_type_parameter] = sym_type_parameter,
  [sym_type_bound] = sym_type_bound,
  [sym_superclass] = sym_superclass,
  [sym_super_interfaces] = sym_super_interfaces,
  [sym_type_list] = sym_type_list,
  [sym_permits] = sym_permits,
  [sym_class_body] = sym_class_body,
  [sym_static_initializer] = sym_static_initializer,
  [sym_constructor_declaration] = sym_constructor_declaration,
  [sym__constructor_declarator] = sym__constructor_declarator,
  [sym_constructor_body] = sym_constructor_body,
  [sym_explicit_constructor_invocation] = sym_explicit_constructor_invocation,
  [sym_scoped_identifier] = sym_scoped_identifier,
  [sym_field_declaration] = sym_field_declaration,
  [sym_record_declaration] = sym_record_declaration,
  [sym_annotation_type_declaration] = sym_annotation_type_declaration,
  [sym_annotation_type_body] = sym_annotation_type_body,
  [sym_annotation_type_element_declaration] = sym_annotation_type_element_declaration,
  [sym__default_value] = sym__default_value,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_extends_interfaces] = sym_extends_interfaces,
  [sym_interface_body] = sym_interface_body,
  [sym_constant_declaration] = sym_constant_declaration,
  [sym__variable_declarator_list] = sym__variable_declarator_list,
  [sym_variable_declarator] = sym_variable_declarator,
  [sym__variable_declarator_id] = sym__variable_declarator_id,
  [sym_array_initializer] = sym_array_initializer,
  [sym__type] = sym__type,
  [sym__unannotated_type] = sym__unannotated_type,
  [sym_annotated_type] = sym_annotated_type,
  [sym_scoped_type_identifier] = sym_scoped_type_identifier,
  [sym_generic_type] = sym_generic_type,
  [sym_array_type] = sym_array_type,
  [sym_integral_type] = sym_integral_type,
  [sym_floating_point_type] = sym_floating_point_type,
  [sym__method_header] = sym__method_header,
  [sym__method_declarator] = sym__method_declarator,
  [sym_formal_parameters] = sym_formal_parameters,
  [sym_formal_parameter] = sym_formal_parameter,
  [sym_receiver_parameter] = sym_receiver_parameter,
  [sym_spread_parameter] = sym_spread_parameter,
  [sym_throws] = sym_throws,
  [sym_local_variable_declaration] = sym_local_variable_declaration,
  [sym_method_declaration] = sym_method_declaration,
  [sym_compact_constructor_declaration] = sym_compact_constructor_declaration,
  [sym__reserved_identifier] = sym__reserved_identifier,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym__string_literal_repeat1] = aux_sym__string_literal_repeat1,
  [aux_sym__multiline_string_literal_repeat1] = aux_sym__multiline_string_literal_repeat1,
  [aux_sym_cast_expression_repeat1] = aux_sym_cast_expression_repeat1,
  [aux_sym_inferred_parameters_repeat1] = aux_sym_inferred_parameters_repeat1,
  [aux_sym_array_creation_expression_repeat1] = aux_sym_array_creation_expression_repeat1,
  [aux_sym_array_creation_expression_repeat2] = aux_sym_array_creation_expression_repeat2,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_type_arguments_repeat1] = aux_sym_type_arguments_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_switch_block_repeat1] = aux_sym_switch_block_repeat1,
  [aux_sym_switch_block_repeat2] = aux_sym_switch_block_repeat2,
  [aux_sym_switch_block_statement_group_repeat1] = aux_sym_switch_block_statement_group_repeat1,
  [aux_sym_switch_block_statement_group_repeat2] = aux_sym_switch_block_statement_group_repeat2,
  [aux_sym_record_pattern_body_repeat1] = aux_sym_record_pattern_body_repeat1,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym_catch_type_repeat1] = aux_sym_catch_type_repeat1,
  [aux_sym_resource_specification_repeat1] = aux_sym_resource_specification_repeat1,
  [aux_sym_for_statement_repeat1] = aux_sym_for_statement_repeat1,
  [aux_sym_for_statement_repeat2] = aux_sym_for_statement_repeat2,
  [aux_sym_annotation_argument_list_repeat1] = aux_sym_annotation_argument_list_repeat1,
  [aux_sym_element_value_array_initializer_repeat1] = aux_sym_element_value_array_initializer_repeat1,
  [aux_sym_module_body_repeat1] = aux_sym_module_body_repeat1,
  [aux_sym_requires_module_directive_repeat1] = aux_sym_requires_module_directive_repeat1,
  [aux_sym_exports_module_directive_repeat1] = aux_sym_exports_module_directive_repeat1,
  [aux_sym_provides_module_directive_repeat1] = aux_sym_provides_module_directive_repeat1,
  [aux_sym_enum_body_repeat1] = aux_sym_enum_body_repeat1,
  [aux_sym_enum_body_declarations_repeat1] = aux_sym_enum_body_declarations_repeat1,
  [aux_sym_modifiers_repeat1] = aux_sym_modifiers_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym_type_bound_repeat1] = aux_sym_type_bound_repeat1,
  [aux_sym_type_list_repeat1] = aux_sym_type_list_repeat1,
  [aux_sym_annotation_type_body_repeat1] = aux_sym_annotation_type_body_repeat1,
  [aux_sym_interface_body_repeat1] = aux_sym_interface_body_repeat1,
  [aux_sym__variable_declarator_list_repeat1] = aux_sym__variable_declarator_list_repeat1,
  [aux_sym_array_initializer_repeat1] = aux_sym_array_initializer_repeat1,
  [aux_sym_formal_parameters_repeat1] = aux_sym_formal_parameters_repeat1,
  [aux_sym_receiver_parameter_repeat1] = aux_sym_receiver_parameter_repeat1,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hex_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_octal_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal_floating_point_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hex_floating_point_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_character_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_string_fragment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__multiline_string_fragment_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__multiline_string_fragment_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_null_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_instanceof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [sym_underscore_pattern] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_synchronized] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_open] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_requires] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transitive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exports] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_opens] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uses] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_provides] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strictfp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_native] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transient] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sealed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_non_DASHsealed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_permits] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_record] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATinterface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_byte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_char] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [sym_boolean_type] = {
    .visible = true,
    .named = true,
  },
  [sym_void_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throws] = {
    .visible = true,
    .named = false,
  },
  [sym_this] = {
    .visible = true,
    .named = true,
  },
  [sym_super] = {
    .visible = true,
    .named = true,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_block_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym__toplevel_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__multiline_string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__multiline_string_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_string_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym__escape_sequence] = {
    .visible = false,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instanceof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_inferred_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_array_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_class_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_object_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__unqualified_object_creation_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_field_access] = {
    .visible = true,
    .named = true,
  },
  [sym_template_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_access] = {
    .visible = true,
    .named = true,
  },
  [sym_method_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_method_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym__wildcard_bounds] = {
    .visible = false,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_block] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_block_statement_group] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_label] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_type_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_record_pattern_body] = {
    .visible = true,
    .named = true,
  },
  [sym_record_pattern_component] = {
    .visible = true,
    .named = true,
  },
  [sym_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_yield_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_synchronized_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_formal_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_type] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_with_resources_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_resource_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_resource] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_enhanced_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__annotation] = {
    .visible = false,
    .named = true,
  },
  [sym_marker_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_element_value_pair] = {
    .visible = true,
    .named = true,
  },
  [sym__element_value] = {
    .visible = false,
    .named = true,
  },
  [sym_element_value_array_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_module_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_module_body] = {
    .visible = true,
    .named = true,
  },
  [sym_module_directive] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_requires_module_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_requires_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_exports_module_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_opens_module_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_uses_module_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_provides_module_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_package_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_asterisk] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body_declarations] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_modifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_type_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_superclass] = {
    .visible = true,
    .named = true,
  },
  [sym_super_interfaces] = {
    .visible = true,
    .named = true,
  },
  [sym_type_list] = {
    .visible = true,
    .named = true,
  },
  [sym_permits] = {
    .visible = true,
    .named = true,
  },
  [sym_class_body] = {
    .visible = true,
    .named = true,
  },
  [sym_static_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__constructor_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_constructor_body] = {
    .visible = true,
    .named = true,
  },
  [sym_explicit_constructor_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym_scoped_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_record_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_type_body] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_type_element_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__default_value] = {
    .visible = false,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_interfaces] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_body] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_declarator_list] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_declarator_id] = {
    .visible = false,
    .named = true,
  },
  [sym_array_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__unannotated_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_annotated_type] = {
    .visible = true,
    .named = true,
  },
  [sym_scoped_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_integral_type] = {
    .visible = true,
    .named = true,
  },
  [sym_floating_point_type] = {
    .visible = true,
    .named = true,
  },
  [sym__method_header] = {
    .visible = false,
    .named = true,
  },
  [sym__method_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_formal_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_receiver_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_throws] = {
    .visible = true,
    .named = true,
  },
  [sym_local_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_method_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_compact_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__reserved_identifier] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__multiline_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_cast_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inferred_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_creation_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_creation_expression_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_block_statement_group_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_block_statement_group_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_pattern_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_catch_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_resource_specification_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_annotation_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_element_value_array_initializer_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_requires_module_directive_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_exports_module_directive_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_provides_module_directive_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_declarations_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_bound_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_annotation_type_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__variable_declarator_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_initializer_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_formal_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_receiver_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_arguments = 2,
  field_array = 3,
  field_body = 4,
  field_condition = 5,
  field_consequence = 6,
  field_constructor = 7,
  field_declarator = 8,
  field_dimensions = 9,
  field_element = 10,
  field_field = 11,
  field_index = 12,
  field_init = 13,
  field_interfaces = 14,
  field_key = 15,
  field_left = 16,
  field_modifiers = 17,
  field_module = 18,
  field_modules = 19,
  field_name = 20,
  field_object = 21,
  field_operand = 22,
  field_operator = 23,
  field_package = 24,
  field_parameters = 25,
  field_pattern = 26,
  field_permits = 27,
  field_provided = 28,
  field_provider = 29,
  field_resources = 30,
  field_right = 31,
  field_scope = 32,
  field_superclass = 33,
  field_template_argument = 34,
  field_template_processor = 35,
  field_type = 36,
  field_type_arguments = 37,
  field_type_parameters = 38,
  field_update = 39,
  field_value = 40,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_arguments] = "arguments",
  [field_array] = "array",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_constructor] = "constructor",
  [field_declarator] = "declarator",
  [field_dimensions] = "dimensions",
  [field_element] = "element",
  [field_field] = "field",
  [field_index] = "index",
  [field_init] = "init",
  [field_interfaces] = "interfaces",
  [field_key] = "key",
  [field_left] = "left",
  [field_modifiers] = "modifiers",
  [field_module] = "module",
  [field_modules] = "modules",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_package] = "package",
  [field_parameters] = "parameters",
  [field_pattern] = "pattern",
  [field_permits] = "permits",
  [field_provided] = "provided",
  [field_provider] = "provider",
  [field_resources] = "resources",
  [field_right] = "right",
  [field_scope] = "scope",
  [field_superclass] = "superclass",
  [field_template_argument] = "template_argument",
  [field_template_processor] = "template_processor",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [3] = {.index = 0, .length = 3},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 6, .length = 2},
  [7] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 1},
  [10] = {.index = 12, .length = 2},
  [11] = {.index = 14, .length = 4},
  [12] = {.index = 18, .length = 5},
  [13] = {.index = 23, .length = 6},
  [14] = {.index = 29, .length = 3},
  [16] = {.index = 32, .length = 2},
  [17] = {.index = 34, .length = 2},
  [18] = {.index = 32, .length = 2},
  [19] = {.index = 34, .length = 2},
  [20] = {.index = 36, .length = 2},
  [21] = {.index = 38, .length = 2},
  [22] = {.index = 40, .length = 1},
  [23] = {.index = 41, .length = 1},
  [24] = {.index = 42, .length = 2},
  [25] = {.index = 44, .length = 2},
  [26] = {.index = 46, .length = 2},
  [27] = {.index = 48, .length = 2},
  [28] = {.index = 50, .length = 3},
  [29] = {.index = 53, .length = 2},
  [31] = {.index = 55, .length = 2},
  [32] = {.index = 57, .length = 2},
  [33] = {.index = 59, .length = 2},
  [34] = {.index = 61, .length = 3},
  [35] = {.index = 64, .length = 5},
  [36] = {.index = 69, .length = 6},
  [37] = {.index = 75, .length = 5},
  [38] = {.index = 80, .length = 2},
  [39] = {.index = 82, .length = 2},
  [40] = {.index = 84, .length = 2},
  [41] = {.index = 86, .length = 2},
  [43] = {.index = 88, .length = 3},
  [44] = {.index = 91, .length = 2},
  [45] = {.index = 93, .length = 1},
  [46] = {.index = 94, .length = 2},
  [47] = {.index = 96, .length = 3},
  [48] = {.index = 99, .length = 3},
  [49] = {.index = 96, .length = 3},
  [50] = {.index = 99, .length = 3},
  [51] = {.index = 102, .length = 3},
  [52] = {.index = 102, .length = 3},
  [53] = {.index = 105, .length = 2},
  [54] = {.index = 107, .length = 2},
  [55] = {.index = 105, .length = 2},
  [56] = {.index = 107, .length = 2},
  [57] = {.index = 109, .length = 3},
  [58] = {.index = 112, .length = 3},
  [59] = {.index = 115, .length = 3},
  [60] = {.index = 118, .length = 3},
  [61] = {.index = 121, .length = 2},
  [62] = {.index = 123, .length = 2},
  [63] = {.index = 125, .length = 3},
  [64] = {.index = 128, .length = 2},
  [65] = {.index = 130, .length = 3},
  [67] = {.index = 133, .length = 2},
  [68] = {.index = 135, .length = 2},
  [69] = {.index = 137, .length = 3},
  [70] = {.index = 140, .length = 2},
  [71] = {.index = 142, .length = 2},
  [72] = {.index = 144, .length = 5},
  [73] = {.index = 149, .length = 3},
  [74] = {.index = 152, .length = 1},
  [75] = {.index = 153, .length = 2},
  [76] = {.index = 155, .length = 3},
  [78] = {.index = 158, .length = 3},
  [79] = {.index = 161, .length = 3},
  [80] = {.index = 161, .length = 3},
  [81] = {.index = 164, .length = 3},
  [82] = {.index = 167, .length = 3},
  [83] = {.index = 164, .length = 3},
  [84] = {.index = 167, .length = 3},
  [85] = {.index = 170, .length = 3},
  [86] = {.index = 170, .length = 3},
  [87] = {.index = 173, .length = 2},
  [88] = {.index = 175, .length = 4},
  [89] = {.index = 179, .length = 4},
  [90] = {.index = 183, .length = 4},
  [91] = {.index = 187, .length = 4},
  [92] = {.index = 191, .length = 4},
  [93] = {.index = 195, .length = 4},
  [94] = {.index = 199, .length = 4},
  [95] = {.index = 203, .length = 2},
  [96] = {.index = 205, .length = 3},
  [97] = {.index = 208, .length = 1},
  [98] = {.index = 209, .length = 2},
  [99] = {.index = 211, .length = 1},
  [100] = {.index = 212, .length = 4},
  [101] = {.index = 216, .length = 4},
  [102] = {.index = 220, .length = 3},
  [103] = {.index = 223, .length = 3},
  [104] = {.index = 226, .length = 2},
  [105] = {.index = 228, .length = 4},
  [106] = {.index = 232, .length = 3},
  [107] = {.index = 235, .length = 3},
  [108] = {.index = 238, .length = 3},
  [109] = {.index = 241, .length = 3},
  [110] = {.index = 244, .length = 3},
  [111] = {.index = 247, .length = 3},
  [112] = {.index = 250, .length = 3},
  [113] = {.index = 253, .length = 2},
  [114] = {.index = 255, .length = 2},
  [115] = {.index = 257, .length = 3},
  [116] = {.index = 257, .length = 3},
  [117] = {.index = 260, .length = 4},
  [118] = {.index = 264, .length = 3},
  [119] = {.index = 267, .length = 4},
  [120] = {.index = 271, .length = 5},
  [121] = {.index = 276, .length = 5},
  [122] = {.index = 281, .length = 5},
  [123] = {.index = 286, .length = 5},
  [124] = {.index = 291, .length = 4},
  [125] = {.index = 295, .length = 2},
  [126] = {.index = 297, .length = 1},
  [127] = {.index = 298, .length = 2},
  [128] = {.index = 300, .length = 2},
  [129] = {.index = 302, .length = 1},
  [130] = {.index = 303, .length = 2},
  [131] = {.index = 305, .length = 1},
  [132] = {.index = 306, .length = 3},
  [133] = {.index = 309, .length = 5},
  [134] = {.index = 314, .length = 4},
  [135] = {.index = 318, .length = 3},
  [136] = {.index = 321, .length = 4},
  [137] = {.index = 325, .length = 4},
  [138] = {.index = 329, .length = 4},
  [139] = {.index = 333, .length = 4},
  [140] = {.index = 337, .length = 4},
  [141] = {.index = 341, .length = 4},
  [142] = {.index = 345, .length = 4},
  [143] = {.index = 349, .length = 4},
  [144] = {.index = 353, .length = 3},
  [145] = {.index = 356, .length = 3},
  [146] = {.index = 359, .length = 4},
  [147] = {.index = 363, .length = 6},
  [148] = {.index = 369, .length = 4},
  [149] = {.index = 373, .length = 1},
  [150] = {.index = 374, .length = 2},
  [151] = {.index = 376, .length = 2},
  [152] = {.index = 378, .length = 1},
  [153] = {.index = 379, .length = 2},
  [154] = {.index = 381, .length = 2},
  [155] = {.index = 383, .length = 2},
  [156] = {.index = 385, .length = 3},
  [157] = {.index = 388, .length = 3},
  [158] = {.index = 391, .length = 2},
  [159] = {.index = 393, .length = 3},
  [160] = {.index = 396, .length = 4},
  [161] = {.index = 400, .length = 5},
  [162] = {.index = 405, .length = 5},
  [163] = {.index = 410, .length = 5},
  [164] = {.index = 415, .length = 5},
  [165] = {.index = 420, .length = 5},
  [166] = {.index = 425, .length = 4},
  [167] = {.index = 429, .length = 2},
  [168] = {.index = 431, .length = 3},
  [169] = {.index = 434, .length = 3},
  [170] = {.index = 437, .length = 3},
  [171] = {.index = 440, .length = 3},
  [172] = {.index = 443, .length = 3},
  [173] = {.index = 446, .length = 5},
  [174] = {.index = 451, .length = 4},
  [175] = {.index = 455, .length = 4},
  [176] = {.index = 459, .length = 2},
  [177] = {.index = 461, .length = 1},
  [178] = {.index = 462, .length = 2},
  [179] = {.index = 464, .length = 6},
  [180] = {.index = 470, .length = 3},
  [181] = {.index = 473, .length = 4},
  [182] = {.index = 477, .length = 4},
  [183] = {.index = 481, .length = 4},
  [184] = {.index = 485, .length = 4},
  [185] = {.index = 489, .length = 4},
  [186] = {.index = 493, .length = 5},
  [187] = {.index = 498, .length = 5},
  [188] = {.index = 503, .length = 1},
  [189] = {.index = 504, .length = 3},
  [190] = {.index = 507, .length = 2},
  [191] = {.index = 509, .length = 1},
  [192] = {.index = 510, .length = 2},
  [193] = {.index = 512, .length = 2},
  [194] = {.index = 514, .length = 2},
  [195] = {.index = 516, .length = 1},
  [196] = {.index = 517, .length = 3},
  [197] = {.index = 520, .length = 3},
  [198] = {.index = 523, .length = 3},
  [199] = {.index = 526, .length = 5},
  [200] = {.index = 531, .length = 5},
  [201] = {.index = 536, .length = 5},
  [202] = {.index = 541, .length = 3},
  [203] = {.index = 544, .length = 3},
  [204] = {.index = 547, .length = 4},
  [205] = {.index = 551, .length = 4},
  [206] = {.index = 555, .length = 6},
  [207] = {.index = 561, .length = 4},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_arguments, 0, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type_arguments, 0, .inherited = true},
  [3] =
    {field_operand, 1},
    {field_operator, 0},
  [5] =
    {field_name, 1},
  [6] =
    {field_arguments, 1},
    {field_name, 0},
  [8] =
    {field_name, 0},
  [9] =
    {field_dimensions, 1},
    {field_element, 0},
  [11] =
    {field_declarator, 0},
  [12] =
    {field_dimensions, 0, .inherited = true},
    {field_name, 0, .inherited = true},
  [14] =
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type, 0},
  [18] =
    {field_dimensions, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [23] =
    {field_body, 1},
    {field_dimensions, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [29] =
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 0},
  [32] =
    {field_arguments, 2},
    {field_type, 1},
  [34] =
    {field_dimensions, 2},
    {field_type, 1},
  [36] =
    {field_body, 2},
    {field_name, 1},
  [38] =
    {field_body, 2},
    {field_condition, 1},
  [40] =
    {field_body, 2},
  [41] =
    {field_body, 1},
  [42] =
    {field_body, 2},
    {field_resources, 1},
  [44] =
    {field_condition, 1},
    {field_consequence, 2},
  [46] =
    {field_arguments, 2},
    {field_name, 1},
  [48] =
    {field_field, 2},
    {field_object, 0},
  [50] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [53] =
    {field_body, 2},
    {field_parameters, 0},
  [55] =
    {field_left, 0},
    {field_pattern, 2},
  [57] =
    {field_left, 0},
    {field_right, 2},
  [59] =
    {field_template_argument, 2},
    {field_template_processor, 0},
  [61] =
    {field_arguments, 2, .inherited = true},
    {field_type, 2, .inherited = true},
    {field_type_arguments, 2, .inherited = true},
  [64] =
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [69] =
    {field_body, 2},
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [75] =
    {field_dimensions, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_type, 1},
    {field_type_parameters, 0},
  [80] =
    {field_dimensions, 1},
    {field_name, 0},
  [82] =
    {field_name, 0},
    {field_parameters, 1},
  [84] =
    {field_declarator, 1, .inherited = true},
    {field_type, 0},
  [86] =
    {field_declarator, 0},
    {field_declarator, 1, .inherited = true},
  [88] =
    {field_dimensions, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 1},
  [91] =
    {field_type, 1},
    {field_value, 3},
  [93] =
    {field_type, 1},
  [94] =
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [96] =
    {field_dimensions, 2},
    {field_type, 1},
    {field_value, 3},
  [99] =
    {field_dimensions, 2},
    {field_dimensions, 3},
    {field_type, 1},
  [102] =
    {field_arguments, 3},
    {field_type, 2},
    {field_type_arguments, 1},
  [105] =
    {field_arguments, 3},
    {field_type, 2},
  [107] =
    {field_dimensions, 3},
    {field_type, 2},
  [109] =
    {field_body, 3},
    {field_name, 1},
    {field_type_parameters, 2},
  [112] =
    {field_body, 3},
    {field_name, 1},
    {field_superclass, 2},
  [115] =
    {field_body, 3},
    {field_interfaces, 2},
    {field_name, 1},
  [118] =
    {field_body, 3},
    {field_name, 1},
    {field_permits, 2},
  [121] =
    {field_name, 2},
    {field_scope, 0},
  [123] =
    {field_body, 3},
    {field_name, 2},
  [125] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2},
  [128] =
    {field_body, 3},
    {field_name, 1},
  [130] =
    {field_arguments, 3},
    {field_name, 2},
    {field_object, 0},
  [133] =
    {field_left, 0},
    {field_pattern, 3},
  [135] =
    {field_left, 0},
    {field_right, 3},
  [137] =
    {field_left, 0},
    {field_name, 3},
    {field_right, 2},
  [140] =
    {field_array, 0},
    {field_index, 2},
  [142] =
    {field_declarator, 2, .inherited = true},
    {field_type, 1},
  [144] =
    {field_dimensions, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_type, 2},
    {field_type_parameters, 0},
  [149] =
    {field_dimensions, 2},
    {field_name, 0},
    {field_parameters, 1},
  [152] =
    {field_declarator, 1},
  [153] =
    {field_declarator, 0, .inherited = true},
    {field_declarator, 1, .inherited = true},
  [155] =
    {field_dimensions, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_value, 2},
  [158] =
    {field_type, 1},
    {field_type, 2, .inherited = true},
    {field_value, 4},
  [161] =
    {field_arguments, 4},
    {field_type, 3},
    {field_type_arguments, 1},
  [164] =
    {field_dimensions, 3},
    {field_type, 2},
    {field_value, 4},
  [167] =
    {field_dimensions, 3},
    {field_dimensions, 4},
    {field_type, 2},
  [170] =
    {field_arguments, 4},
    {field_type, 3},
    {field_type_arguments, 2},
  [173] =
    {field_body, 1},
    {field_name, 0},
  [175] =
    {field_body, 1},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [179] =
    {field_body, 4},
    {field_name, 1},
    {field_superclass, 3},
    {field_type_parameters, 2},
  [183] =
    {field_body, 4},
    {field_interfaces, 3},
    {field_name, 1},
    {field_type_parameters, 2},
  [187] =
    {field_body, 4},
    {field_name, 1},
    {field_permits, 3},
    {field_type_parameters, 2},
  [191] =
    {field_body, 4},
    {field_interfaces, 3},
    {field_name, 1},
    {field_superclass, 2},
  [195] =
    {field_body, 4},
    {field_name, 1},
    {field_permits, 3},
    {field_superclass, 2},
  [199] =
    {field_body, 4},
    {field_interfaces, 2},
    {field_name, 1},
    {field_permits, 3},
  [203] =
    {field_body, 1},
    {field_condition, 3},
  [205] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 2},
  [208] =
    {field_init, 1},
  [209] =
    {field_init, 0, .inherited = true},
    {field_init, 1, .inherited = true},
  [211] =
    {field_modifiers, 0},
  [212] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [216] =
    {field_body, 4},
    {field_interfaces, 3},
    {field_name, 1},
    {field_parameters, 2},
  [220] =
    {field_body, 4},
    {field_name, 1},
    {field_type_parameters, 2},
  [223] =
    {field_body, 4},
    {field_name, 1},
    {field_permits, 3},
  [226] =
    {field_field, 4},
    {field_object, 0},
  [228] =
    {field_arguments, 4},
    {field_name, 3},
    {field_object, 0},
    {field_type_arguments, 2},
  [232] =
    {field_left, 0},
    {field_name, 4},
    {field_right, 3},
  [235] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [238] =
    {field_body, 4},
    {field_name, 2},
    {field_type_parameters, 3},
  [241] =
    {field_body, 4},
    {field_name, 2},
    {field_superclass, 3},
  [244] =
    {field_body, 4},
    {field_interfaces, 3},
    {field_name, 2},
  [247] =
    {field_body, 4},
    {field_name, 2},
    {field_permits, 3},
  [250] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
  [253] =
    {field_body, 4},
    {field_name, 2},
  [255] =
    {field_body, 4},
    {field_name, 3},
  [257] =
    {field_arguments, 5},
    {field_type, 4},
    {field_type_arguments, 2},
  [260] =
    {field_body, 2},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [264] =
    {field_name, 1},
    {field_parameters, 2},
    {field_type_parameters, 0},
  [267] =
    {field_body, 2},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [271] =
    {field_body, 5},
    {field_interfaces, 4},
    {field_name, 1},
    {field_superclass, 3},
    {field_type_parameters, 2},
  [276] =
    {field_body, 5},
    {field_name, 1},
    {field_permits, 4},
    {field_superclass, 3},
    {field_type_parameters, 2},
  [281] =
    {field_body, 5},
    {field_interfaces, 3},
    {field_name, 1},
    {field_permits, 4},
    {field_type_parameters, 2},
  [286] =
    {field_body, 5},
    {field_interfaces, 3},
    {field_name, 1},
    {field_permits, 4},
    {field_superclass, 2},
  [291] =
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 0},
    {field_value, 3},
  [295] =
    {field_dimensions, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [297] =
    {field_body, 5},
  [298] =
    {field_body, 5},
    {field_init, 2},
  [300] =
    {field_key, 0},
    {field_value, 2},
  [302] =
    {field_module, 1},
  [303] =
    {field_modifiers, 0, .inherited = true},
    {field_modifiers, 1, .inherited = true},
  [305] =
    {field_package, 1},
  [306] =
    {field_arguments, 1},
    {field_body, 2},
    {field_name, 0},
  [309] =
    {field_body, 5},
    {field_interfaces, 4},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [314] =
    {field_body, 5},
    {field_name, 1},
    {field_permits, 4},
    {field_type_parameters, 2},
  [318] =
    {field_arguments, 5},
    {field_name, 4},
    {field_object, 0},
  [321] =
    {field_body, 5},
    {field_name, 2},
    {field_superclass, 4},
    {field_type_parameters, 3},
  [325] =
    {field_body, 5},
    {field_interfaces, 4},
    {field_name, 2},
    {field_type_parameters, 3},
  [329] =
    {field_body, 5},
    {field_name, 2},
    {field_permits, 4},
    {field_type_parameters, 3},
  [333] =
    {field_body, 5},
    {field_interfaces, 4},
    {field_name, 2},
    {field_superclass, 3},
  [337] =
    {field_body, 5},
    {field_name, 2},
    {field_permits, 4},
    {field_superclass, 3},
  [341] =
    {field_body, 5},
    {field_interfaces, 3},
    {field_name, 2},
    {field_permits, 4},
  [345] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [349] =
    {field_body, 5},
    {field_interfaces, 4},
    {field_name, 2},
    {field_parameters, 3},
  [353] =
    {field_body, 5},
    {field_name, 2},
    {field_type_parameters, 3},
  [356] =
    {field_body, 5},
    {field_name, 2},
    {field_permits, 4},
  [359] =
    {field_body, 3},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [363] =
    {field_body, 6},
    {field_interfaces, 4},
    {field_name, 1},
    {field_permits, 5},
    {field_superclass, 3},
    {field_type_parameters, 2},
  [369] =
    {field_dimensions, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 1},
    {field_value, 4},
  [373] =
    {field_body, 4},
  [374] =
    {field_dimensions, 2, .inherited = true},
    {field_name, 2, .inherited = true},
  [376] =
    {field_body, 6},
    {field_update, 4},
  [378] =
    {field_update, 1},
  [379] =
    {field_update, 0, .inherited = true},
    {field_update, 1, .inherited = true},
  [381] =
    {field_body, 6},
    {field_condition, 3},
  [383] =
    {field_body, 6},
    {field_init, 2},
  [385] =
    {field_body, 6},
    {field_init, 2},
    {field_update, 4},
  [388] =
    {field_body, 6},
    {field_condition, 3},
    {field_init, 2},
  [391] =
    {field_modifiers, 1, .inherited = true},
    {field_module, 2},
  [393] =
    {field_arguments, 2},
    {field_body, 3},
    {field_name, 1},
  [396] =
    {field_arguments, 6},
    {field_name, 5},
    {field_object, 0},
    {field_type_arguments, 4},
  [400] =
    {field_body, 6},
    {field_interfaces, 5},
    {field_name, 2},
    {field_superclass, 4},
    {field_type_parameters, 3},
  [405] =
    {field_body, 6},
    {field_name, 2},
    {field_permits, 5},
    {field_superclass, 4},
    {field_type_parameters, 3},
  [410] =
    {field_body, 6},
    {field_interfaces, 4},
    {field_name, 2},
    {field_permits, 5},
    {field_type_parameters, 3},
  [415] =
    {field_body, 6},
    {field_interfaces, 4},
    {field_name, 2},
    {field_permits, 5},
    {field_superclass, 3},
  [420] =
    {field_body, 6},
    {field_interfaces, 5},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [425] =
    {field_body, 6},
    {field_name, 2},
    {field_permits, 5},
    {field_type_parameters, 3},
  [429] =
    {field_arguments, 1},
    {field_constructor, 0},
  [431] =
    {field_body, 7},
    {field_update, 4},
    {field_update, 5, .inherited = true},
  [434] =
    {field_body, 7},
    {field_condition, 3},
    {field_update, 5},
  [437] =
    {field_body, 7},
    {field_init, 2},
    {field_update, 5},
  [440] =
    {field_body, 7},
    {field_condition, 4},
    {field_init, 2},
  [443] =
    {field_body, 7},
    {field_init, 2},
    {field_init, 3, .inherited = true},
  [446] =
    {field_body, 7},
    {field_dimensions, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type, 2},
    {field_value, 5},
  [451] =
    {field_body, 7},
    {field_init, 2},
    {field_update, 4},
    {field_update, 5, .inherited = true},
  [455] =
    {field_body, 7},
    {field_condition, 3},
    {field_init, 2},
    {field_update, 5},
  [459] =
    {field_modules, 3},
    {field_package, 1},
  [461] =
    {field_provided, 1},
  [462] =
    {field_name, 1},
    {field_type, 0},
  [464] =
    {field_body, 7},
    {field_interfaces, 5},
    {field_name, 2},
    {field_permits, 6},
    {field_superclass, 4},
    {field_type_parameters, 3},
  [470] =
    {field_arguments, 2},
    {field_constructor, 1},
    {field_type_arguments, 0},
  [473] =
    {field_body, 8},
    {field_condition, 3},
    {field_update, 5},
    {field_update, 6, .inherited = true},
  [477] =
    {field_body, 8},
    {field_init, 2},
    {field_update, 5},
    {field_update, 6, .inherited = true},
  [481] =
    {field_body, 8},
    {field_condition, 4},
    {field_init, 2},
    {field_update, 6},
  [485] =
    {field_body, 8},
    {field_init, 2},
    {field_init, 3, .inherited = true},
    {field_update, 6},
  [489] =
    {field_body, 8},
    {field_condition, 5},
    {field_init, 2},
    {field_init, 3, .inherited = true},
  [493] =
    {field_body, 8},
    {field_dimensions, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type, 3},
    {field_value, 6},
  [498] =
    {field_body, 8},
    {field_condition, 3},
    {field_init, 2},
    {field_update, 5},
    {field_update, 6, .inherited = true},
  [503] =
    {field_modules, 1},
  [504] =
    {field_modules, 3},
    {field_modules, 4, .inherited = true},
    {field_package, 1},
  [507] =
    {field_modules, 0, .inherited = true},
    {field_modules, 1, .inherited = true},
  [509] =
    {field_provider, 1},
  [510] =
    {field_provided, 1},
    {field_provider, 4, .inherited = true},
  [512] =
    {field_provider, 0, .inherited = true},
    {field_provider, 1, .inherited = true},
  [514] =
    {field_name, 2},
    {field_type, 1},
  [516] =
    {field_value, 1},
  [517] =
    {field_dimensions, 4},
    {field_name, 1},
    {field_type, 0},
  [520] =
    {field_name, 1},
    {field_type, 0},
    {field_value, 4, .inherited = true},
  [523] =
    {field_arguments, 3},
    {field_constructor, 2},
    {field_object, 0},
  [526] =
    {field_body, 9},
    {field_condition, 4},
    {field_init, 2},
    {field_update, 6},
    {field_update, 7, .inherited = true},
  [531] =
    {field_body, 9},
    {field_init, 2},
    {field_init, 3, .inherited = true},
    {field_update, 6},
    {field_update, 7, .inherited = true},
  [536] =
    {field_body, 9},
    {field_condition, 5},
    {field_init, 2},
    {field_init, 3, .inherited = true},
    {field_update, 7},
  [541] =
    {field_dimensions, 5},
    {field_name, 2},
    {field_type, 1},
  [544] =
    {field_name, 2},
    {field_type, 1},
    {field_value, 5, .inherited = true},
  [547] =
    {field_dimensions, 4},
    {field_name, 1},
    {field_type, 0},
    {field_value, 5, .inherited = true},
  [551] =
    {field_arguments, 4},
    {field_constructor, 3},
    {field_object, 0},
    {field_type_arguments, 2},
  [555] =
    {field_body, 10},
    {field_condition, 5},
    {field_init, 2},
    {field_init, 3, .inherited = true},
    {field_update, 7},
    {field_update, 8, .inherited = true},
  [561] =
    {field_dimensions, 5},
    {field_name, 2},
    {field_type, 1},
    {field_value, 6, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [2] = {
    [0] = alias_sym_type_identifier,
  },
  [15] = {
    [1] = alias_sym_type_identifier,
  },
  [18] = {
    [1] = alias_sym_type_identifier,
  },
  [19] = {
    [1] = alias_sym_type_identifier,
  },
  [30] = {
    [0] = alias_sym_type_identifier,
    [2] = alias_sym_type_identifier,
  },
  [42] = {
    [2] = alias_sym_type_identifier,
  },
  [49] = {
    [1] = alias_sym_type_identifier,
  },
  [50] = {
    [1] = alias_sym_type_identifier,
  },
  [52] = {
    [2] = alias_sym_type_identifier,
  },
  [55] = {
    [2] = alias_sym_type_identifier,
  },
  [56] = {
    [2] = alias_sym_type_identifier,
  },
  [66] = {
    [0] = alias_sym_type_identifier,
    [3] = alias_sym_type_identifier,
  },
  [77] = {
    [3] = alias_sym_type_identifier,
  },
  [80] = {
    [3] = alias_sym_type_identifier,
  },
  [83] = {
    [2] = alias_sym_type_identifier,
  },
  [84] = {
    [2] = alias_sym_type_identifier,
  },
  [86] = {
    [3] = alias_sym_type_identifier,
  },
  [116] = {
    [4] = alias_sym_type_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 10,
  [13] = 11,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 15,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 28,
  [41] = 26,
  [42] = 22,
  [43] = 21,
  [44] = 20,
  [45] = 45,
  [46] = 19,
  [47] = 47,
  [48] = 18,
  [49] = 49,
  [50] = 17,
  [51] = 47,
  [52] = 49,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 39,
  [57] = 45,
  [58] = 16,
  [59] = 38,
  [60] = 60,
  [61] = 36,
  [62] = 60,
  [63] = 45,
  [64] = 39,
  [65] = 53,
  [66] = 37,
  [67] = 55,
  [68] = 54,
  [69] = 53,
  [70] = 49,
  [71] = 60,
  [72] = 35,
  [73] = 47,
  [74] = 17,
  [75] = 18,
  [76] = 23,
  [77] = 19,
  [78] = 20,
  [79] = 21,
  [80] = 22,
  [81] = 26,
  [82] = 28,
  [83] = 33,
  [84] = 16,
  [85] = 38,
  [86] = 54,
  [87] = 36,
  [88] = 35,
  [89] = 37,
  [90] = 33,
  [91] = 34,
  [92] = 15,
  [93] = 25,
  [94] = 30,
  [95] = 27,
  [96] = 29,
  [97] = 29,
  [98] = 27,
  [99] = 30,
  [100] = 55,
  [101] = 34,
  [102] = 25,
  [103] = 32,
  [104] = 23,
  [105] = 32,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 115,
  [118] = 118,
  [119] = 118,
  [120] = 118,
  [121] = 121,
  [122] = 121,
  [123] = 123,
  [124] = 124,
  [125] = 124,
  [126] = 126,
  [127] = 124,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 128,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 139,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 143,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 149,
  [151] = 147,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 153,
  [156] = 156,
  [157] = 157,
  [158] = 149,
  [159] = 154,
  [160] = 160,
  [161] = 156,
  [162] = 162,
  [163] = 163,
  [164] = 162,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 167,
  [170] = 166,
  [171] = 168,
  [172] = 162,
  [173] = 166,
  [174] = 174,
  [175] = 156,
  [176] = 174,
  [177] = 160,
  [178] = 163,
  [179] = 179,
  [180] = 148,
  [181] = 146,
  [182] = 154,
  [183] = 163,
  [184] = 153,
  [185] = 185,
  [186] = 167,
  [187] = 174,
  [188] = 147,
  [189] = 160,
  [190] = 148,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 196,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 201,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 208,
  [223] = 194,
  [224] = 218,
  [225] = 213,
  [226] = 204,
  [227] = 193,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 230,
  [232] = 216,
  [233] = 229,
  [234] = 215,
  [235] = 228,
  [236] = 202,
  [237] = 191,
  [238] = 219,
  [239] = 192,
  [240] = 220,
  [241] = 191,
  [242] = 203,
  [243] = 221,
  [244] = 202,
  [245] = 200,
  [246] = 199,
  [247] = 247,
  [248] = 248,
  [249] = 110,
  [250] = 111,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 390,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 400,
  [402] = 400,
  [403] = 403,
  [404] = 403,
  [405] = 138,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 412,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 415,
  [419] = 419,
  [420] = 415,
  [421] = 419,
  [422] = 419,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 411,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 438,
  [441] = 441,
  [442] = 438,
  [443] = 428,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 439,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 309,
  [469] = 469,
  [470] = 470,
  [471] = 355,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 427,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 429,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 452,
  [504] = 455,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 451,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 434,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 433,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 542,
  [543] = 481,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 435,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 574,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 579,
  [580] = 487,
  [581] = 431,
  [582] = 430,
  [583] = 583,
  [584] = 584,
  [585] = 585,
  [586] = 586,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 509,
  [625] = 625,
  [626] = 502,
  [627] = 484,
  [628] = 625,
  [629] = 614,
  [630] = 470,
  [631] = 617,
  [632] = 613,
  [633] = 621,
  [634] = 620,
  [635] = 619,
  [636] = 622,
  [637] = 615,
  [638] = 462,
  [639] = 616,
  [640] = 610,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 641,
  [645] = 612,
  [646] = 618,
  [647] = 611,
  [648] = 453,
  [649] = 649,
  [650] = 567,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 121,
  [658] = 655,
  [659] = 656,
  [660] = 653,
  [661] = 661,
  [662] = 662,
  [663] = 522,
  [664] = 655,
  [665] = 665,
  [666] = 666,
  [667] = 662,
  [668] = 661,
  [669] = 563,
  [670] = 661,
  [671] = 665,
  [672] = 656,
  [673] = 673,
  [674] = 665,
  [675] = 666,
  [676] = 654,
  [677] = 653,
  [678] = 654,
  [679] = 651,
  [680] = 680,
  [681] = 651,
  [682] = 682,
  [683] = 662,
  [684] = 684,
  [685] = 652,
  [686] = 666,
  [687] = 687,
  [688] = 544,
  [689] = 689,
  [690] = 467,
  [691] = 691,
  [692] = 692,
  [693] = 469,
  [694] = 694,
  [695] = 456,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 460,
  [701] = 701,
  [702] = 534,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 472,
  [707] = 465,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 459,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 709,
  [722] = 722,
  [723] = 713,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 717,
  [728] = 476,
  [729] = 474,
  [730] = 710,
  [731] = 716,
  [732] = 720,
  [733] = 733,
  [734] = 710,
  [735] = 715,
  [736] = 736,
  [737] = 736,
  [738] = 713,
  [739] = 739,
  [740] = 708,
  [741] = 720,
  [742] = 742,
  [743] = 743,
  [744] = 742,
  [745] = 461,
  [746] = 746,
  [747] = 747,
  [748] = 709,
  [749] = 717,
  [750] = 750,
  [751] = 736,
  [752] = 484,
  [753] = 753,
  [754] = 754,
  [755] = 475,
  [756] = 756,
  [757] = 473,
  [758] = 463,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 138,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 765,
  [770] = 470,
  [771] = 765,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 774,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 781,
  [789] = 787,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 567,
  [794] = 794,
  [795] = 544,
  [796] = 563,
  [797] = 797,
  [798] = 798,
  [799] = 522,
  [800] = 800,
  [801] = 797,
  [802] = 797,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 807,
  [814] = 814,
  [815] = 815,
  [816] = 456,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 432,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 463,
  [828] = 828,
  [829] = 437,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 832,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 832,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 841,
  [843] = 838,
  [844] = 840,
  [845] = 839,
  [846] = 846,
  [847] = 445,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 446,
  [853] = 853,
  [854] = 854,
  [855] = 851,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 856,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 448,
  [866] = 449,
  [867] = 867,
  [868] = 862,
  [869] = 869,
  [870] = 446,
  [871] = 450,
  [872] = 863,
  [873] = 447,
  [874] = 864,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 877,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 482,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 904,
  [918] = 904,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 792,
  [949] = 949,
  [950] = 950,
  [951] = 941,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 949,
  [965] = 937,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 956,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 939,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 971,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 963,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 982,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 960,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1040,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1040,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1041,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1025,
  [1057] = 1041,
  [1058] = 1058,
  [1059] = 1059,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 1067,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1069,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1082,
  [1085] = 1085,
  [1086] = 1083,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1088,
  [1095] = 1093,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1096,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1069,
  [1109] = 1082,
  [1110] = 1110,
  [1111] = 1083,
  [1112] = 1088,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1093,
  [1117] = 1117,
  [1118] = 1096,
  [1119] = 1099,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1104,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1099,
  [1127] = 1104,
  [1128] = 1091,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1067,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1147,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1145,
  [1166] = 1145,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 1044,
  [1170] = 1138,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1105,
  [1174] = 1147,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1184,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1183,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1240,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1179,
  [1265] = 1183,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1268,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 390,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1291,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1179,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1308,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1311,
  [1312] = 1312,
  [1313] = 1313,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 1316,
  [1317] = 1317,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1320,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1300,
  [1325] = 1322,
  [1326] = 1326,
  [1327] = 1327,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1334,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1342,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1340,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1338,
  [1352] = 1322,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1307,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1362,
  [1363] = 1347,
  [1364] = 1364,
  [1365] = 1309,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1370,
  [1372] = 1372,
  [1373] = 1370,
  [1374] = 1305,
  [1375] = 1300,
  [1376] = 1376,
  [1377] = 1377,
};

static inline bool sym_identifier_character_set_1(int32_t c) {
  return (c < 43514
    ? (c < 4193
      ? (c < 2707
        ? (c < 1994
          ? (c < 931
            ? (c < 748
              ? (c < 192
                ? (c < 170
                  ? (c < 'a'
                    ? (c >= '$' && c <= '_')
                    : c <= 'z')
                  : (c <= 170 || (c < 186
                    ? c == 181
                    : c <= 186)))
                : (c <= 214 || (c < 710
                  ? (c < 248
                    ? (c >= 216 && c <= 246)
                    : c <= 705)
                  : (c <= 721 || (c >= 736 && c <= 740)))))
              : (c <= 748 || (c < 895
                ? (c < 886
                  ? (c < 880
                    ? c == 750
                    : c <= 884)
                  : (c <= 887 || (c >= 891 && c <= 893)))
                : (c <= 895 || (c < 908
                  ? (c < 904
                    ? c == 902
                    : c <= 906)
                  : (c <= 908 || (c >= 910 && c <= 929)))))))
            : (c <= 1013 || (c < 1649
              ? (c < 1376
                ? (c < 1329
                  ? (c < 1162
                    ? (c >= 1015 && c <= 1153)
                    : c <= 1327)
                  : (c <= 1366 || c == 1369))
                : (c <= 1416 || (c < 1568
                  ? (c < 1519
                    ? (c >= 1488 && c <= 1514)
                    : c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))))
              : (c <= 1747 || (c < 1791
                ? (c < 1774
                  ? (c < 1765
                    ? c == 1749
                    : c <= 1766)
                  : (c <= 1775 || (c >= 1786 && c <= 1788)))
                : (c <= 1791 || (c < 1869
                  ? (c < 1810
                    ? c == 1808
                    : c <= 1839)
                  : (c <= 1957 || c == 1969))))))))
          : (c <= 2026 || (c < 2482
            ? (c < 2208
              ? (c < 2088
                ? (c < 2048
                  ? (c < 2042
                    ? (c >= 2036 && c <= 2037)
                    : c <= 2042)
                  : (c <= 2069 || (c < 2084
                    ? c == 2074
                    : c <= 2084)))
                : (c <= 2088 || (c < 2160
                  ? (c < 2144
                    ? (c >= 2112 && c <= 2136)
                    : c <= 2154)
                  : (c <= 2183 || (c >= 2185 && c <= 2190)))))
              : (c <= 2249 || (c < 2417
                ? (c < 2384
                  ? (c < 2365
                    ? (c >= 2308 && c <= 2361)
                    : c <= 2365)
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2451
                  ? (c < 2447
                    ? (c >= 2437 && c <= 2444)
                    : c <= 2448)
                  : (c <= 2472 || (c >= 2474 && c <= 2480)))))))
            : (c <= 2482 || (c < 2579
              ? (c < 2527
                ? (c < 2510
                  ? (c < 2493
                    ? (c >= 2486 && c <= 2489)
                    : c <= 2493)
                  : (c <= 2510 || (c >= 2524 && c <= 2525)))
                : (c <= 2529 || (c < 2565
                  ? (c < 2556
                    ? (c >= 2544 && c <= 2545)
                    : c <= 2556)
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))))
              : (c <= 2600 || (c < 2649
                ? (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c >= 2616 && c <= 2617)))
                : (c <= 2652 || (c < 2693
                  ? (c < 2674
                    ? c == 2654
                    : c <= 2676)
                  : (c <= 2701 || (c >= 2703 && c <= 2705)))))))))))
        : (c <= 2728 || (c < 3242
          ? (c < 2962
            ? (c < 2858
              ? (c < 2784
                ? (c < 2741
                  ? (c < 2738
                    ? (c >= 2730 && c <= 2736)
                    : c <= 2739)
                  : (c <= 2745 || (c < 2768
                    ? c == 2749
                    : c <= 2768)))
                : (c <= 2785 || (c < 2831
                  ? (c < 2821
                    ? c == 2809
                    : c <= 2828)
                  : (c <= 2832 || (c >= 2835 && c <= 2856)))))
              : (c <= 2864 || (c < 2911
                ? (c < 2877
                  ? (c < 2869
                    ? (c >= 2866 && c <= 2867)
                    : c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2949
                  ? (c < 2947
                    ? c == 2929
                    : c <= 2947)
                  : (c <= 2954 || (c >= 2958 && c <= 2960)))))))
            : (c <= 2965 || (c < 3090
              ? (c < 2984
                ? (c < 2974
                  ? (c < 2972
                    ? (c >= 2969 && c <= 2970)
                    : c <= 2972)
                  : (c <= 2975 || (c >= 2979 && c <= 2980)))
                : (c <= 2986 || (c < 3077
                  ? (c < 3024
                    ? (c >= 2990 && c <= 3001)
                    : c <= 3024)
                  : (c <= 3084 || (c >= 3086 && c <= 3088)))))
              : (c <= 3112 || (c < 3168
                ? (c < 3160
                  ? (c < 3133
                    ? (c >= 3114 && c <= 3129)
                    : c <= 3133)
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3214
                  ? (c < 3205
                    ? c == 3200
                    : c <= 3212)
                  : (c <= 3216 || (c >= 3218 && c <= 3240)))))))))
          : (c <= 3251 || (c < 3648
            ? (c < 3412
              ? (c < 3332
                ? (c < 3293
                  ? (c < 3261
                    ? (c >= 3253 && c <= 3257)
                    : c <= 3261)
                  : (c <= 3294 || (c < 3313
                    ? (c >= 3296 && c <= 3297)
                    : c <= 3314)))
                : (c <= 3340 || (c < 3389
                  ? (c < 3346
                    ? (c >= 3342 && c <= 3344)
                    : c <= 3386)
                  : (c <= 3389 || c == 3406))))
              : (c <= 3414 || (c < 3507
                ? (c < 3461
                  ? (c < 3450
                    ? (c >= 3423 && c <= 3425)
                    : c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3585
                  ? (c < 3520
                    ? c == 3517
                    : c <= 3526)
                  : (c <= 3632 || c == 3634))))))
            : (c <= 3654 || (c < 3782
              ? (c < 3749
                ? (c < 3718
                  ? (c < 3716
                    ? (c >= 3713 && c <= 3714)
                    : c <= 3716)
                  : (c <= 3722 || (c >= 3724 && c <= 3747)))
                : (c <= 3749 || (c < 3773
                  ? (c < 3762
                    ? (c >= 3751 && c <= 3760)
                    : c <= 3762)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))))
              : (c <= 3782 || (c < 3976
                ? (c < 3904
                  ? (c < 3840
                    ? (c >= 3804 && c <= 3807)
                    : c <= 3840)
                  : (c <= 3911 || (c >= 3913 && c <= 3948)))
                : (c <= 3980 || (c < 4176
                  ? (c < 4159
                    ? (c >= 4096 && c <= 4138)
                    : c <= 4159)
                  : (c <= 4181 || (c >= 4186 && c <= 4189)))))))))))))
      : (c <= 4193 || (c < 8134
        ? (c < 6176
          ? (c < 4808
            ? (c < 4688
              ? (c < 4295
                ? (c < 4213
                  ? (c < 4206
                    ? (c >= 4197 && c <= 4198)
                    : c <= 4208)
                  : (c <= 4225 || (c < 4256
                    ? c == 4238
                    : c <= 4293)))
                : (c <= 4295 || (c < 4348
                  ? (c < 4304
                    ? c == 4301
                    : c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))))
              : (c <= 4694 || (c < 4752
                ? (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c >= 4802 && c <= 4805)))))))
            : (c <= 4822 || (c < 5792
              ? (c < 5024
                ? (c < 4888
                  ? (c < 4882
                    ? (c >= 4824 && c <= 4880)
                    : c <= 4885)
                  : (c <= 4954 || (c >= 4992 && c <= 5007)))
                : (c <= 5109 || (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c >= 5761 && c <= 5786)))))
              : (c <= 5866 || (c < 5984
                ? (c < 5919
                  ? (c < 5888
                    ? (c >= 5870 && c <= 5880)
                    : c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6103
                  ? (c < 6016
                    ? (c >= 5998 && c <= 6000)
                    : c <= 6067)
                  : (c <= 6103 || c == 6108))))))))
          : (c <= 6264 || (c < 7312
            ? (c < 6823
              ? (c < 6512
                ? (c < 6320
                  ? (c < 6314
                    ? (c >= 6272 && c <= 6312)
                    : c <= 6314)
                  : (c <= 6389 || (c < 6480
                    ? (c >= 6400 && c <= 6430)
                    : c <= 6509)))
                : (c <= 6516 || (c < 6656
                  ? (c < 6576
                    ? (c >= 6528 && c <= 6571)
                    : c <= 6601)
                  : (c <= 6678 || (c >= 6688 && c <= 6740)))))
              : (c <= 6823 || (c < 7098
                ? (c < 7043
                  ? (c < 6981
                    ? (c >= 6917 && c <= 6963)
                    : c <= 6988)
                  : (c <= 7072 || (c >= 7086 && c <= 7087)))
                : (c <= 7141 || (c < 7258
                  ? (c < 7245
                    ? (c >= 7168 && c <= 7203)
                    : c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))))))
            : (c <= 7354 || (c < 8008
              ? (c < 7418
                ? (c < 7406
                  ? (c < 7401
                    ? (c >= 7357 && c <= 7359)
                    : c <= 7404)
                  : (c <= 7411 || (c >= 7413 && c <= 7414)))
                : (c <= 7418 || (c < 7960
                  ? (c < 7680
                    ? (c >= 7424 && c <= 7615)
                    : c <= 7957)
                  : (c <= 7965 || (c >= 7968 && c <= 8005)))))
              : (c <= 8013 || (c < 8031
                ? (c < 8027
                  ? (c < 8025
                    ? (c >= 8016 && c <= 8023)
                    : c <= 8025)
                  : (c <= 8027 || c == 8029))
                : (c <= 8061 || (c < 8126
                  ? (c < 8118
                    ? (c >= 8064 && c <= 8116)
                    : c <= 8124)
                  : (c <= 8126 || (c >= 8130 && c <= 8132)))))))))))
        : (c <= 8140 || (c < 12337
          ? (c < 8544
            ? (c < 8458
              ? (c < 8305
                ? (c < 8160
                  ? (c < 8150
                    ? (c >= 8144 && c <= 8147)
                    : c <= 8155)
                  : (c <= 8172 || (c < 8182
                    ? (c >= 8178 && c <= 8180)
                    : c <= 8188)))
                : (c <= 8305 || (c < 8450
                  ? (c < 8336
                    ? c == 8319
                    : c <= 8348)
                  : (c <= 8450 || c == 8455))))
              : (c <= 8467 || (c < 8488
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || c == 8486))
                : (c <= 8488 || (c < 8517
                  ? (c < 8508
                    ? (c >= 8490 && c <= 8505)
                    : c <= 8511)
                  : (c <= 8521 || c == 8526))))))
            : (c <= 8584 || (c < 11680
              ? (c < 11559
                ? (c < 11506
                  ? (c < 11499
                    ? (c >= 11264 && c <= 11492)
                    : c <= 11502)
                  : (c <= 11507 || (c >= 11520 && c <= 11557)))
                : (c <= 11559 || (c < 11631
                  ? (c < 11568
                    ? c == 11565
                    : c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))))
              : (c <= 11686 || (c < 11720
                ? (c < 11704
                  ? (c < 11696
                    ? (c >= 11688 && c <= 11694)
                    : c <= 11702)
                  : (c <= 11710 || (c >= 11712 && c <= 11718)))
                : (c <= 11726 || (c < 12293
                  ? (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)
                  : (c <= 12295 || (c >= 12321 && c <= 12329)))))))))
          : (c <= 12341 || (c < 42891
            ? (c < 19968
              ? (c < 12549
                ? (c < 12445
                  ? (c < 12353
                    ? (c >= 12344 && c <= 12348)
                    : c <= 12438)
                  : (c <= 12447 || (c < 12540
                    ? (c >= 12449 && c <= 12538)
                    : c <= 12543)))
                : (c <= 12591 || (c < 12784
                  ? (c < 12704
                    ? (c >= 12593 && c <= 12686)
                    : c <= 12735)
                  : (c <= 12799 || (c >= 13312 && c <= 19903)))))
              : (c <= 42124 || (c < 42560
                ? (c < 42512
                  ? (c < 42240
                    ? (c >= 42192 && c <= 42237)
                    : c <= 42508)
                  : (c <= 42527 || (c >= 42538 && c <= 42539)))
                : (c <= 42606 || (c < 42775
                  ? (c < 42656
                    ? (c >= 42623 && c <= 42653)
                    : c <= 42735)
                  : (c <= 42783 || (c >= 42786 && c <= 42888)))))))
            : (c <= 42954 || (c < 43250
              ? (c < 43011
                ? (c < 42965
                  ? (c < 42963
                    ? (c >= 42960 && c <= 42961)
                    : c <= 42963)
                  : (c <= 42969 || (c >= 42994 && c <= 43009)))
                : (c <= 43013 || (c < 43072
                  ? (c < 43020
                    ? (c >= 43015 && c <= 43018)
                    : c <= 43042)
                  : (c <= 43123 || (c >= 43138 && c <= 43187)))))
              : (c <= 43255 || (c < 43360
                ? (c < 43274
                  ? (c < 43261
                    ? c == 43259
                    : c <= 43262)
                  : (c <= 43301 || (c >= 43312 && c <= 43334)))
                : (c <= 43388 || (c < 43488
                  ? (c < 43471
                    ? (c >= 43396 && c <= 43442)
                    : c <= 43471)
                  : (c <= 43492 || (c >= 43494 && c <= 43503)))))))))))))))
    : (c <= 43518 || (c < 70727
      ? (c < 66956
        ? (c < 64914
          ? (c < 43868
            ? (c < 43714
              ? (c < 43646
                ? (c < 43588
                  ? (c < 43584
                    ? (c >= 43520 && c <= 43560)
                    : c <= 43586)
                  : (c <= 43595 || (c < 43642
                    ? (c >= 43616 && c <= 43638)
                    : c <= 43642)))
                : (c <= 43695 || (c < 43705
                  ? (c < 43701
                    ? c == 43697
                    : c <= 43702)
                  : (c <= 43709 || c == 43712))))
              : (c <= 43714 || (c < 43785
                ? (c < 43762
                  ? (c < 43744
                    ? (c >= 43739 && c <= 43741)
                    : c <= 43754)
                  : (c <= 43764 || (c >= 43777 && c <= 43782)))
                : (c <= 43790 || (c < 43816
                  ? (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)
                  : (c <= 43822 || (c >= 43824 && c <= 43866)))))))
            : (c <= 43881 || (c < 64287
              ? (c < 63744
                ? (c < 55216
                  ? (c < 44032
                    ? (c >= 43888 && c <= 44002)
                    : c <= 55203)
                  : (c <= 55238 || (c >= 55243 && c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || c == 64285))))
              : (c <= 64296 || (c < 64323
                ? (c < 64318
                  ? (c < 64312
                    ? (c >= 64298 && c <= 64310)
                    : c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65599
            ? (c < 65382
              ? (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))))
              : (c <= 65437 || (c < 65498
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))))))
            : (c <= 65613 || (c < 66464
              ? (c < 66208
                ? (c < 65856
                  ? (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)
                  : (c <= 65908 || (c >= 66176 && c <= 66204)))
                : (c <= 66256 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))))
              : (c <= 66499 || (c < 66776
                ? (c < 66560
                  ? (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)
                  : (c <= 66717 || (c >= 66736 && c <= 66771)))
                : (c <= 66811 || (c < 66928
                  ? (c < 66864
                    ? (c >= 66816 && c <= 66855)
                    : c <= 66915)
                  : (c <= 66938 || (c >= 66940 && c <= 66954)))))))))))
        : (c <= 66962 || (c < 68864
          ? (c < 67828
            ? (c < 67506
              ? (c < 67072
                ? (c < 66979
                  ? (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)
                  : (c <= 66993 || (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)))
                : (c <= 67382 || (c < 67456
                  ? (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)
                  : (c <= 67461 || (c >= 67463 && c <= 67504)))))
              : (c <= 67514 || (c < 67644
                ? (c < 67594
                  ? (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)
                  : (c <= 67637 || (c >= 67639 && c <= 67640)))
                : (c <= 67644 || (c < 67712
                  ? (c < 67680
                    ? (c >= 67647 && c <= 67669)
                    : c <= 67702)
                  : (c <= 67742 || (c >= 67808 && c <= 67826)))))))
            : (c <= 67829 || (c < 68224
              ? (c < 68096
                ? (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c >= 68030 && c <= 68031)))
                : (c <= 68096 || (c < 68121
                  ? (c < 68117
                    ? (c >= 68112 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c >= 68192 && c <= 68220)))))
              : (c <= 68252 || (c < 68448
                ? (c < 68352
                  ? (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68324)
                  : (c <= 68405 || (c >= 68416 && c <= 68437)))
                : (c <= 68466 || (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c >= 68800 && c <= 68850)))))))))
          : (c <= 68899 || (c < 70106
            ? (c < 69749
              ? (c < 69488
                ? (c < 69376
                  ? (c < 69296
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69297)
                  : (c <= 69404 || (c < 69424
                    ? c == 69415
                    : c <= 69445)))
                : (c <= 69505 || (c < 69635
                  ? (c < 69600
                    ? (c >= 69552 && c <= 69572)
                    : c <= 69622)
                  : (c <= 69687 || (c >= 69745 && c <= 69746)))))
              : (c <= 69749 || (c < 69959
                ? (c < 69891
                  ? (c < 69840
                    ? (c >= 69763 && c <= 69807)
                    : c <= 69864)
                  : (c <= 69926 || c == 69956))
                : (c <= 69959 || (c < 70019
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70002)
                    : c <= 70006)
                  : (c <= 70066 || (c >= 70081 && c <= 70084)))))))
            : (c <= 70106 || (c < 70405
              ? (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70187 || (c >= 70272 && c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70366)))))
              : (c <= 70412 || (c < 70453
                ? (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))
                : (c <= 70457 || (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))))))))))))
      : (c <= 70730 || (c < 119894
        ? (c < 73056
          ? (c < 72001
            ? (c < 71424
              ? (c < 71128
                ? (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || (c < 71040
                    ? c == 70855
                    : c <= 71086)))
                : (c <= 71131 || (c < 71296
                  ? (c < 71236
                    ? (c >= 71168 && c <= 71215)
                    : c <= 71236)
                  : (c <= 71338 || c == 71352))))
              : (c <= 71450 || (c < 71945
                ? (c < 71840
                  ? (c < 71680
                    ? (c >= 71488 && c <= 71494)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))))))
            : (c <= 72001 || (c < 72349
              ? (c < 72192
                ? (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))
                : (c <= 72192 || (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))))
              : (c <= 72349 || (c < 72818
                ? (c < 72714
                  ? (c < 72704
                    ? (c >= 72368 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))
                : (c <= 72847 || (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))))))))
          : (c <= 73061 || (c < 93952
            ? (c < 82944
              ? (c < 73728
                ? (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c < 73648
                    ? (c >= 73440 && c <= 73458)
                    : c <= 73648)))
                : (c <= 74649 || (c < 77712
                  ? (c < 74880
                    ? (c >= 74752 && c <= 74862)
                    : c <= 75075)
                  : (c <= 77808 || (c >= 77824 && c <= 78894)))))
              : (c <= 83526 || (c < 92928
                ? (c < 92784
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92862 || (c >= 92880 && c <= 92909)))
                : (c <= 92975 || (c < 93053
                  ? (c < 93027
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93047)
                  : (c <= 93071 || (c >= 93760 && c <= 93823)))))))
            : (c <= 94026 || (c < 110589
              ? (c < 94208
                ? (c < 94176
                  ? (c < 94099
                    ? c == 94032
                    : c <= 94111)
                  : (c <= 94177 || c == 94179))
                : (c <= 100343 || (c < 110576
                  ? (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)
                  : (c <= 110579 || (c >= 110581 && c <= 110587)))))
              : (c <= 110590 || (c < 113664
                ? (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110882)
                    : c <= 110930)
                  : (c <= 110951 || (c >= 110960 && c <= 111355)))
                : (c <= 113770 || (c < 113808
                  ? (c < 113792
                    ? (c >= 113776 && c <= 113788)
                    : c <= 113800)
                  : (c <= 113817 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 125259
          ? (c < 120572
            ? (c < 120086
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c >= 120077 && c <= 120084)))))
              : (c <= 120092 || (c < 120138
                ? (c < 120128
                  ? (c < 120123
                    ? (c >= 120094 && c <= 120121)
                    : c <= 120126)
                  : (c <= 120132 || c == 120134))
                : (c <= 120144 || (c < 120514
                  ? (c < 120488
                    ? (c >= 120146 && c <= 120485)
                    : c <= 120512)
                  : (c <= 120538 || (c >= 120540 && c <= 120570)))))))
            : (c <= 120596 || (c < 123191
              ? (c < 120714
                ? (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c >= 120688 && c <= 120712)))
                : (c <= 120744 || (c < 122624
                  ? (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)
                  : (c <= 122654 || (c >= 123136 && c <= 123180)))))
              : (c <= 123197 || (c < 124904
                ? (c < 123584
                  ? (c < 123536
                    ? c == 123214
                    : c <= 123565)
                  : (c <= 123627 || (c >= 124896 && c <= 124902)))
                : (c <= 124907 || (c < 124928
                  ? (c < 124912
                    ? (c >= 124909 && c <= 124910)
                    : c <= 124926)
                  : (c <= 125124 || (c >= 125184 && c <= 125251)))))))))
          : (c <= 125259 || (c < 126559
            ? (c < 126535
              ? (c < 126505
                ? (c < 126497
                  ? (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)
                  : (c <= 126498 || (c < 126503
                    ? c == 126500
                    : c <= 126503)))
                : (c <= 126514 || (c < 126523
                  ? (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)
                  : (c <= 126523 || c == 126530))))
              : (c <= 126535 || (c < 126548
                ? (c < 126541
                  ? (c < 126539
                    ? c == 126537
                    : c <= 126539)
                  : (c <= 126543 || (c >= 126545 && c <= 126546)))
                : (c <= 126548 || (c < 126555
                  ? (c < 126553
                    ? c == 126551
                    : c <= 126553)
                  : (c <= 126555 || c == 126557))))))
            : (c <= 126559 || (c < 126625
              ? (c < 126580
                ? (c < 126567
                  ? (c < 126564
                    ? (c >= 126561 && c <= 126562)
                    : c <= 126564)
                  : (c <= 126570 || (c >= 126572 && c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c >= 126603 && c <= 126619)))))
              : (c <= 126627 || (c < 177984
                ? (c < 131072
                  ? (c < 126635
                    ? (c >= 126629 && c <= 126633)
                    : c <= 126651)
                  : (c <= 173791 || (c >= 173824 && c <= 177976)))
                : (c <= 178205 || (c < 194560
                  ? (c < 183984
                    ? (c >= 178208 && c <= 183969)
                    : c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_2(int32_t c) {
  return (c < 43514
    ? (c < 4193
      ? (c < 2707
        ? (c < 1994
          ? (c < 910
            ? (c < 736
              ? (c < 186
                ? (c < 'a'
                  ? (c < '_'
                    ? (c >= '$' && c <= 'Z')
                    : c <= '_')
                  : (c <= 'z' || (c < 181
                    ? c == 170
                    : c <= 181)))
                : (c <= 186 || (c < 248
                  ? (c < 216
                    ? (c >= 192 && c <= 214)
                    : c <= 246)
                  : (c <= 705 || (c >= 710 && c <= 721)))))
              : (c <= 740 || (c < 891
                ? (c < 880
                  ? (c < 750
                    ? c == 748
                    : c <= 750)
                  : (c <= 884 || (c >= 886 && c <= 887)))
                : (c <= 893 || (c < 904
                  ? (c < 902
                    ? c == 895
                    : c <= 902)
                  : (c <= 906 || c == 908))))))
            : (c <= 929 || (c < 1649
              ? (c < 1376
                ? (c < 1162
                  ? (c < 1015
                    ? (c >= 931 && c <= 1013)
                    : c <= 1153)
                  : (c <= 1327 || (c < 1369
                    ? (c >= 1329 && c <= 1366)
                    : c <= 1369)))
                : (c <= 1416 || (c < 1568
                  ? (c < 1519
                    ? (c >= 1488 && c <= 1514)
                    : c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))))
              : (c <= 1747 || (c < 1791
                ? (c < 1774
                  ? (c < 1765
                    ? c == 1749
                    : c <= 1766)
                  : (c <= 1775 || (c >= 1786 && c <= 1788)))
                : (c <= 1791 || (c < 1869
                  ? (c < 1810
                    ? c == 1808
                    : c <= 1839)
                  : (c <= 1957 || c == 1969))))))))
          : (c <= 2026 || (c < 2482
            ? (c < 2208
              ? (c < 2088
                ? (c < 2048
                  ? (c < 2042
                    ? (c >= 2036 && c <= 2037)
                    : c <= 2042)
                  : (c <= 2069 || (c < 2084
                    ? c == 2074
                    : c <= 2084)))
                : (c <= 2088 || (c < 2160
                  ? (c < 2144
                    ? (c >= 2112 && c <= 2136)
                    : c <= 2154)
                  : (c <= 2183 || (c >= 2185 && c <= 2190)))))
              : (c <= 2249 || (c < 2417
                ? (c < 2384
                  ? (c < 2365
                    ? (c >= 2308 && c <= 2361)
                    : c <= 2365)
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2451
                  ? (c < 2447
                    ? (c >= 2437 && c <= 2444)
                    : c <= 2448)
                  : (c <= 2472 || (c >= 2474 && c <= 2480)))))))
            : (c <= 2482 || (c < 2579
              ? (c < 2527
                ? (c < 2510
                  ? (c < 2493
                    ? (c >= 2486 && c <= 2489)
                    : c <= 2493)
                  : (c <= 2510 || (c >= 2524 && c <= 2525)))
                : (c <= 2529 || (c < 2565
                  ? (c < 2556
                    ? (c >= 2544 && c <= 2545)
                    : c <= 2556)
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))))
              : (c <= 2600 || (c < 2649
                ? (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c >= 2616 && c <= 2617)))
                : (c <= 2652 || (c < 2693
                  ? (c < 2674
                    ? c == 2654
                    : c <= 2676)
                  : (c <= 2701 || (c >= 2703 && c <= 2705)))))))))))
        : (c <= 2728 || (c < 3242
          ? (c < 2962
            ? (c < 2858
              ? (c < 2784
                ? (c < 2741
                  ? (c < 2738
                    ? (c >= 2730 && c <= 2736)
                    : c <= 2739)
                  : (c <= 2745 || (c < 2768
                    ? c == 2749
                    : c <= 2768)))
                : (c <= 2785 || (c < 2831
                  ? (c < 2821
                    ? c == 2809
                    : c <= 2828)
                  : (c <= 2832 || (c >= 2835 && c <= 2856)))))
              : (c <= 2864 || (c < 2911
                ? (c < 2877
                  ? (c < 2869
                    ? (c >= 2866 && c <= 2867)
                    : c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2949
                  ? (c < 2947
                    ? c == 2929
                    : c <= 2947)
                  : (c <= 2954 || (c >= 2958 && c <= 2960)))))))
            : (c <= 2965 || (c < 3090
              ? (c < 2984
                ? (c < 2974
                  ? (c < 2972
                    ? (c >= 2969 && c <= 2970)
                    : c <= 2972)
                  : (c <= 2975 || (c >= 2979 && c <= 2980)))
                : (c <= 2986 || (c < 3077
                  ? (c < 3024
                    ? (c >= 2990 && c <= 3001)
                    : c <= 3024)
                  : (c <= 3084 || (c >= 3086 && c <= 3088)))))
              : (c <= 3112 || (c < 3168
                ? (c < 3160
                  ? (c < 3133
                    ? (c >= 3114 && c <= 3129)
                    : c <= 3133)
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3214
                  ? (c < 3205
                    ? c == 3200
                    : c <= 3212)
                  : (c <= 3216 || (c >= 3218 && c <= 3240)))))))))
          : (c <= 3251 || (c < 3648
            ? (c < 3412
              ? (c < 3332
                ? (c < 3293
                  ? (c < 3261
                    ? (c >= 3253 && c <= 3257)
                    : c <= 3261)
                  : (c <= 3294 || (c < 3313
                    ? (c >= 3296 && c <= 3297)
                    : c <= 3314)))
                : (c <= 3340 || (c < 3389
                  ? (c < 3346
                    ? (c >= 3342 && c <= 3344)
                    : c <= 3386)
                  : (c <= 3389 || c == 3406))))
              : (c <= 3414 || (c < 3507
                ? (c < 3461
                  ? (c < 3450
                    ? (c >= 3423 && c <= 3425)
                    : c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3585
                  ? (c < 3520
                    ? c == 3517
                    : c <= 3526)
                  : (c <= 3632 || c == 3634))))))
            : (c <= 3654 || (c < 3782
              ? (c < 3749
                ? (c < 3718
                  ? (c < 3716
                    ? (c >= 3713 && c <= 3714)
                    : c <= 3716)
                  : (c <= 3722 || (c >= 3724 && c <= 3747)))
                : (c <= 3749 || (c < 3773
                  ? (c < 3762
                    ? (c >= 3751 && c <= 3760)
                    : c <= 3762)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))))
              : (c <= 3782 || (c < 3976
                ? (c < 3904
                  ? (c < 3840
                    ? (c >= 3804 && c <= 3807)
                    : c <= 3840)
                  : (c <= 3911 || (c >= 3913 && c <= 3948)))
                : (c <= 3980 || (c < 4176
                  ? (c < 4159
                    ? (c >= 4096 && c <= 4138)
                    : c <= 4159)
                  : (c <= 4181 || (c >= 4186 && c <= 4189)))))))))))))
      : (c <= 4193 || (c < 8134
        ? (c < 6176
          ? (c < 4808
            ? (c < 4688
              ? (c < 4295
                ? (c < 4213
                  ? (c < 4206
                    ? (c >= 4197 && c <= 4198)
                    : c <= 4208)
                  : (c <= 4225 || (c < 4256
                    ? c == 4238
                    : c <= 4293)))
                : (c <= 4295 || (c < 4348
                  ? (c < 4304
                    ? c == 4301
                    : c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))))
              : (c <= 4694 || (c < 4752
                ? (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c >= 4802 && c <= 4805)))))))
            : (c <= 4822 || (c < 5792
              ? (c < 5024
                ? (c < 4888
                  ? (c < 4882
                    ? (c >= 4824 && c <= 4880)
                    : c <= 4885)
                  : (c <= 4954 || (c >= 4992 && c <= 5007)))
                : (c <= 5109 || (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c >= 5761 && c <= 5786)))))
              : (c <= 5866 || (c < 5984
                ? (c < 5919
                  ? (c < 5888
                    ? (c >= 5870 && c <= 5880)
                    : c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6103
                  ? (c < 6016
                    ? (c >= 5998 && c <= 6000)
                    : c <= 6067)
                  : (c <= 6103 || c == 6108))))))))
          : (c <= 6264 || (c < 7312
            ? (c < 6823
              ? (c < 6512
                ? (c < 6320
                  ? (c < 6314
                    ? (c >= 6272 && c <= 6312)
                    : c <= 6314)
                  : (c <= 6389 || (c < 6480
                    ? (c >= 6400 && c <= 6430)
                    : c <= 6509)))
                : (c <= 6516 || (c < 6656
                  ? (c < 6576
                    ? (c >= 6528 && c <= 6571)
                    : c <= 6601)
                  : (c <= 6678 || (c >= 6688 && c <= 6740)))))
              : (c <= 6823 || (c < 7098
                ? (c < 7043
                  ? (c < 6981
                    ? (c >= 6917 && c <= 6963)
                    : c <= 6988)
                  : (c <= 7072 || (c >= 7086 && c <= 7087)))
                : (c <= 7141 || (c < 7258
                  ? (c < 7245
                    ? (c >= 7168 && c <= 7203)
                    : c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))))))
            : (c <= 7354 || (c < 8008
              ? (c < 7418
                ? (c < 7406
                  ? (c < 7401
                    ? (c >= 7357 && c <= 7359)
                    : c <= 7404)
                  : (c <= 7411 || (c >= 7413 && c <= 7414)))
                : (c <= 7418 || (c < 7960
                  ? (c < 7680
                    ? (c >= 7424 && c <= 7615)
                    : c <= 7957)
                  : (c <= 7965 || (c >= 7968 && c <= 8005)))))
              : (c <= 8013 || (c < 8031
                ? (c < 8027
                  ? (c < 8025
                    ? (c >= 8016 && c <= 8023)
                    : c <= 8025)
                  : (c <= 8027 || c == 8029))
                : (c <= 8061 || (c < 8126
                  ? (c < 8118
                    ? (c >= 8064 && c <= 8116)
                    : c <= 8124)
                  : (c <= 8126 || (c >= 8130 && c <= 8132)))))))))))
        : (c <= 8140 || (c < 12337
          ? (c < 8544
            ? (c < 8458
              ? (c < 8305
                ? (c < 8160
                  ? (c < 8150
                    ? (c >= 8144 && c <= 8147)
                    : c <= 8155)
                  : (c <= 8172 || (c < 8182
                    ? (c >= 8178 && c <= 8180)
                    : c <= 8188)))
                : (c <= 8305 || (c < 8450
                  ? (c < 8336
                    ? c == 8319
                    : c <= 8348)
                  : (c <= 8450 || c == 8455))))
              : (c <= 8467 || (c < 8488
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || c == 8486))
                : (c <= 8488 || (c < 8517
                  ? (c < 8508
                    ? (c >= 8490 && c <= 8505)
                    : c <= 8511)
                  : (c <= 8521 || c == 8526))))))
            : (c <= 8584 || (c < 11680
              ? (c < 11559
                ? (c < 11506
                  ? (c < 11499
                    ? (c >= 11264 && c <= 11492)
                    : c <= 11502)
                  : (c <= 11507 || (c >= 11520 && c <= 11557)))
                : (c <= 11559 || (c < 11631
                  ? (c < 11568
                    ? c == 11565
                    : c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))))
              : (c <= 11686 || (c < 11720
                ? (c < 11704
                  ? (c < 11696
                    ? (c >= 11688 && c <= 11694)
                    : c <= 11702)
                  : (c <= 11710 || (c >= 11712 && c <= 11718)))
                : (c <= 11726 || (c < 12293
                  ? (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)
                  : (c <= 12295 || (c >= 12321 && c <= 12329)))))))))
          : (c <= 12341 || (c < 42891
            ? (c < 19968
              ? (c < 12549
                ? (c < 12445
                  ? (c < 12353
                    ? (c >= 12344 && c <= 12348)
                    : c <= 12438)
                  : (c <= 12447 || (c < 12540
                    ? (c >= 12449 && c <= 12538)
                    : c <= 12543)))
                : (c <= 12591 || (c < 12784
                  ? (c < 12704
                    ? (c >= 12593 && c <= 12686)
                    : c <= 12735)
                  : (c <= 12799 || (c >= 13312 && c <= 19903)))))
              : (c <= 42124 || (c < 42560
                ? (c < 42512
                  ? (c < 42240
                    ? (c >= 42192 && c <= 42237)
                    : c <= 42508)
                  : (c <= 42527 || (c >= 42538 && c <= 42539)))
                : (c <= 42606 || (c < 42775
                  ? (c < 42656
                    ? (c >= 42623 && c <= 42653)
                    : c <= 42735)
                  : (c <= 42783 || (c >= 42786 && c <= 42888)))))))
            : (c <= 42954 || (c < 43250
              ? (c < 43011
                ? (c < 42965
                  ? (c < 42963
                    ? (c >= 42960 && c <= 42961)
                    : c <= 42963)
                  : (c <= 42969 || (c >= 42994 && c <= 43009)))
                : (c <= 43013 || (c < 43072
                  ? (c < 43020
                    ? (c >= 43015 && c <= 43018)
                    : c <= 43042)
                  : (c <= 43123 || (c >= 43138 && c <= 43187)))))
              : (c <= 43255 || (c < 43360
                ? (c < 43274
                  ? (c < 43261
                    ? c == 43259
                    : c <= 43262)
                  : (c <= 43301 || (c >= 43312 && c <= 43334)))
                : (c <= 43388 || (c < 43488
                  ? (c < 43471
                    ? (c >= 43396 && c <= 43442)
                    : c <= 43471)
                  : (c <= 43492 || (c >= 43494 && c <= 43503)))))))))))))))
    : (c <= 43518 || (c < 70727
      ? (c < 66956
        ? (c < 64914
          ? (c < 43868
            ? (c < 43714
              ? (c < 43646
                ? (c < 43588
                  ? (c < 43584
                    ? (c >= 43520 && c <= 43560)
                    : c <= 43586)
                  : (c <= 43595 || (c < 43642
                    ? (c >= 43616 && c <= 43638)
                    : c <= 43642)))
                : (c <= 43695 || (c < 43705
                  ? (c < 43701
                    ? c == 43697
                    : c <= 43702)
                  : (c <= 43709 || c == 43712))))
              : (c <= 43714 || (c < 43785
                ? (c < 43762
                  ? (c < 43744
                    ? (c >= 43739 && c <= 43741)
                    : c <= 43754)
                  : (c <= 43764 || (c >= 43777 && c <= 43782)))
                : (c <= 43790 || (c < 43816
                  ? (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)
                  : (c <= 43822 || (c >= 43824 && c <= 43866)))))))
            : (c <= 43881 || (c < 64287
              ? (c < 63744
                ? (c < 55216
                  ? (c < 44032
                    ? (c >= 43888 && c <= 44002)
                    : c <= 55203)
                  : (c <= 55238 || (c >= 55243 && c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || c == 64285))))
              : (c <= 64296 || (c < 64323
                ? (c < 64318
                  ? (c < 64312
                    ? (c >= 64298 && c <= 64310)
                    : c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65599
            ? (c < 65382
              ? (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))))
              : (c <= 65437 || (c < 65498
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))))))
            : (c <= 65613 || (c < 66464
              ? (c < 66208
                ? (c < 65856
                  ? (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)
                  : (c <= 65908 || (c >= 66176 && c <= 66204)))
                : (c <= 66256 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))))
              : (c <= 66499 || (c < 66776
                ? (c < 66560
                  ? (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)
                  : (c <= 66717 || (c >= 66736 && c <= 66771)))
                : (c <= 66811 || (c < 66928
                  ? (c < 66864
                    ? (c >= 66816 && c <= 66855)
                    : c <= 66915)
                  : (c <= 66938 || (c >= 66940 && c <= 66954)))))))))))
        : (c <= 66962 || (c < 68864
          ? (c < 67828
            ? (c < 67506
              ? (c < 67072
                ? (c < 66979
                  ? (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)
                  : (c <= 66993 || (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)))
                : (c <= 67382 || (c < 67456
                  ? (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)
                  : (c <= 67461 || (c >= 67463 && c <= 67504)))))
              : (c <= 67514 || (c < 67644
                ? (c < 67594
                  ? (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)
                  : (c <= 67637 || (c >= 67639 && c <= 67640)))
                : (c <= 67644 || (c < 67712
                  ? (c < 67680
                    ? (c >= 67647 && c <= 67669)
                    : c <= 67702)
                  : (c <= 67742 || (c >= 67808 && c <= 67826)))))))
            : (c <= 67829 || (c < 68224
              ? (c < 68096
                ? (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c >= 68030 && c <= 68031)))
                : (c <= 68096 || (c < 68121
                  ? (c < 68117
                    ? (c >= 68112 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c >= 68192 && c <= 68220)))))
              : (c <= 68252 || (c < 68448
                ? (c < 68352
                  ? (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68324)
                  : (c <= 68405 || (c >= 68416 && c <= 68437)))
                : (c <= 68466 || (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c >= 68800 && c <= 68850)))))))))
          : (c <= 68899 || (c < 70106
            ? (c < 69749
              ? (c < 69488
                ? (c < 69376
                  ? (c < 69296
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69297)
                  : (c <= 69404 || (c < 69424
                    ? c == 69415
                    : c <= 69445)))
                : (c <= 69505 || (c < 69635
                  ? (c < 69600
                    ? (c >= 69552 && c <= 69572)
                    : c <= 69622)
                  : (c <= 69687 || (c >= 69745 && c <= 69746)))))
              : (c <= 69749 || (c < 69959
                ? (c < 69891
                  ? (c < 69840
                    ? (c >= 69763 && c <= 69807)
                    : c <= 69864)
                  : (c <= 69926 || c == 69956))
                : (c <= 69959 || (c < 70019
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70002)
                    : c <= 70006)
                  : (c <= 70066 || (c >= 70081 && c <= 70084)))))))
            : (c <= 70106 || (c < 70405
              ? (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70187 || (c >= 70272 && c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70366)))))
              : (c <= 70412 || (c < 70453
                ? (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))
                : (c <= 70457 || (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))))))))))))
      : (c <= 70730 || (c < 119894
        ? (c < 73056
          ? (c < 72001
            ? (c < 71424
              ? (c < 71128
                ? (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || (c < 71040
                    ? c == 70855
                    : c <= 71086)))
                : (c <= 71131 || (c < 71296
                  ? (c < 71236
                    ? (c >= 71168 && c <= 71215)
                    : c <= 71236)
                  : (c <= 71338 || c == 71352))))
              : (c <= 71450 || (c < 71945
                ? (c < 71840
                  ? (c < 71680
                    ? (c >= 71488 && c <= 71494)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))))))
            : (c <= 72001 || (c < 72349
              ? (c < 72192
                ? (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))
                : (c <= 72192 || (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))))
              : (c <= 72349 || (c < 72818
                ? (c < 72714
                  ? (c < 72704
                    ? (c >= 72368 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))
                : (c <= 72847 || (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))))))))
          : (c <= 73061 || (c < 93952
            ? (c < 82944
              ? (c < 73728
                ? (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c < 73648
                    ? (c >= 73440 && c <= 73458)
                    : c <= 73648)))
                : (c <= 74649 || (c < 77712
                  ? (c < 74880
                    ? (c >= 74752 && c <= 74862)
                    : c <= 75075)
                  : (c <= 77808 || (c >= 77824 && c <= 78894)))))
              : (c <= 83526 || (c < 92928
                ? (c < 92784
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92862 || (c >= 92880 && c <= 92909)))
                : (c <= 92975 || (c < 93053
                  ? (c < 93027
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93047)
                  : (c <= 93071 || (c >= 93760 && c <= 93823)))))))
            : (c <= 94026 || (c < 110589
              ? (c < 94208
                ? (c < 94176
                  ? (c < 94099
                    ? c == 94032
                    : c <= 94111)
                  : (c <= 94177 || c == 94179))
                : (c <= 100343 || (c < 110576
                  ? (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)
                  : (c <= 110579 || (c >= 110581 && c <= 110587)))))
              : (c <= 110590 || (c < 113664
                ? (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110882)
                    : c <= 110930)
                  : (c <= 110951 || (c >= 110960 && c <= 111355)))
                : (c <= 113770 || (c < 113808
                  ? (c < 113792
                    ? (c >= 113776 && c <= 113788)
                    : c <= 113800)
                  : (c <= 113817 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 125259
          ? (c < 120572
            ? (c < 120086
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c >= 120077 && c <= 120084)))))
              : (c <= 120092 || (c < 120138
                ? (c < 120128
                  ? (c < 120123
                    ? (c >= 120094 && c <= 120121)
                    : c <= 120126)
                  : (c <= 120132 || c == 120134))
                : (c <= 120144 || (c < 120514
                  ? (c < 120488
                    ? (c >= 120146 && c <= 120485)
                    : c <= 120512)
                  : (c <= 120538 || (c >= 120540 && c <= 120570)))))))
            : (c <= 120596 || (c < 123191
              ? (c < 120714
                ? (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c >= 120688 && c <= 120712)))
                : (c <= 120744 || (c < 122624
                  ? (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)
                  : (c <= 122654 || (c >= 123136 && c <= 123180)))))
              : (c <= 123197 || (c < 124904
                ? (c < 123584
                  ? (c < 123536
                    ? c == 123214
                    : c <= 123565)
                  : (c <= 123627 || (c >= 124896 && c <= 124902)))
                : (c <= 124907 || (c < 124928
                  ? (c < 124912
                    ? (c >= 124909 && c <= 124910)
                    : c <= 124926)
                  : (c <= 125124 || (c >= 125184 && c <= 125251)))))))))
          : (c <= 125259 || (c < 126559
            ? (c < 126535
              ? (c < 126505
                ? (c < 126497
                  ? (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)
                  : (c <= 126498 || (c < 126503
                    ? c == 126500
                    : c <= 126503)))
                : (c <= 126514 || (c < 126523
                  ? (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)
                  : (c <= 126523 || c == 126530))))
              : (c <= 126535 || (c < 126548
                ? (c < 126541
                  ? (c < 126539
                    ? c == 126537
                    : c <= 126539)
                  : (c <= 126543 || (c >= 126545 && c <= 126546)))
                : (c <= 126548 || (c < 126555
                  ? (c < 126553
                    ? c == 126551
                    : c <= 126553)
                  : (c <= 126555 || c == 126557))))))
            : (c <= 126559 || (c < 126625
              ? (c < 126580
                ? (c < 126567
                  ? (c < 126564
                    ? (c >= 126561 && c <= 126562)
                    : c <= 126564)
                  : (c <= 126570 || (c >= 126572 && c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c >= 126603 && c <= 126619)))))
              : (c <= 126627 || (c < 177984
                ? (c < 131072
                  ? (c < 126635
                    ? (c >= 126629 && c <= 126633)
                    : c <= 126651)
                  : (c <= 173791 || (c >= 173824 && c <= 177976)))
                : (c <= 178205 || (c < 194560
                  ? (c < 183984
                    ? (c >= 178208 && c <= 183969)
                    : c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_3(int32_t c) {
  return (c < 43494
    ? (c < 4186
      ? (c < 2703
        ? (c < 1969
          ? (c < 908
            ? (c < 710
              ? (c < 181
                ? (c < '_'
                  ? (c < 'A'
                    ? c == '$'
                    : c <= 'Z')
                  : (c <= '_' || (c < 170
                    ? (c >= 'a' && c <= 'z')
                    : c <= 170)))
                : (c <= 181 || (c < 216
                  ? (c < 192
                    ? c == 186
                    : c <= 214)
                  : (c <= 246 || (c >= 248 && c <= 705)))))
              : (c <= 721 || (c < 886
                ? (c < 750
                  ? (c < 748
                    ? (c >= 736 && c <= 740)
                    : c <= 748)
                  : (c <= 750 || (c >= 880 && c <= 884)))
                : (c <= 887 || (c < 902
                  ? (c < 895
                    ? (c >= 891 && c <= 893)
                    : c <= 895)
                  : (c <= 902 || (c >= 904 && c <= 906)))))))
            : (c <= 908 || (c < 1646
              ? (c < 1369
                ? (c < 1015
                  ? (c < 931
                    ? (c >= 910 && c <= 929)
                    : c <= 1013)
                  : (c <= 1153 || (c < 1329
                    ? (c >= 1162 && c <= 1327)
                    : c <= 1366)))
                : (c <= 1369 || (c < 1519
                  ? (c < 1488
                    ? (c >= 1376 && c <= 1416)
                    : c <= 1514)
                  : (c <= 1522 || (c >= 1568 && c <= 1610)))))
              : (c <= 1647 || (c < 1786
                ? (c < 1765
                  ? (c < 1749
                    ? (c >= 1649 && c <= 1747)
                    : c <= 1749)
                  : (c <= 1766 || (c >= 1774 && c <= 1775)))
                : (c <= 1788 || (c < 1810
                  ? (c < 1808
                    ? c == 1791
                    : c <= 1808)
                  : (c <= 1839 || (c >= 1869 && c <= 1957)))))))))
          : (c <= 1969 || (c < 2474
            ? (c < 2185
              ? (c < 2084
                ? (c < 2042
                  ? (c < 2036
                    ? (c >= 1994 && c <= 2026)
                    : c <= 2037)
                  : (c <= 2042 || (c < 2074
                    ? (c >= 2048 && c <= 2069)
                    : c <= 2074)))
                : (c <= 2084 || (c < 2144
                  ? (c < 2112
                    ? c == 2088
                    : c <= 2136)
                  : (c <= 2154 || (c >= 2160 && c <= 2183)))))
              : (c <= 2190 || (c < 2392
                ? (c < 2365
                  ? (c < 2308
                    ? (c >= 2208 && c <= 2249)
                    : c <= 2361)
                  : (c <= 2365 || c == 2384))
                : (c <= 2401 || (c < 2447
                  ? (c < 2437
                    ? (c >= 2417 && c <= 2432)
                    : c <= 2444)
                  : (c <= 2448 || (c >= 2451 && c <= 2472)))))))
            : (c <= 2480 || (c < 2575
              ? (c < 2524
                ? (c < 2493
                  ? (c < 2486
                    ? c == 2482
                    : c <= 2489)
                  : (c <= 2493 || c == 2510))
                : (c <= 2525 || (c < 2556
                  ? (c < 2544
                    ? (c >= 2527 && c <= 2529)
                    : c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))))
              : (c <= 2576 || (c < 2616
                ? (c < 2610
                  ? (c < 2602
                    ? (c >= 2579 && c <= 2600)
                    : c <= 2608)
                  : (c <= 2611 || (c >= 2613 && c <= 2614)))
                : (c <= 2617 || (c < 2674
                  ? (c < 2654
                    ? (c >= 2649 && c <= 2652)
                    : c <= 2654)
                  : (c <= 2676 || (c >= 2693 && c <= 2701)))))))))))
        : (c <= 2705 || (c < 3218
          ? (c < 2958
            ? (c < 2835
              ? (c < 2768
                ? (c < 2738
                  ? (c < 2730
                    ? (c >= 2707 && c <= 2728)
                    : c <= 2736)
                  : (c <= 2739 || (c < 2749
                    ? (c >= 2741 && c <= 2745)
                    : c <= 2749)))
                : (c <= 2768 || (c < 2821
                  ? (c < 2809
                    ? (c >= 2784 && c <= 2785)
                    : c <= 2809)
                  : (c <= 2828 || (c >= 2831 && c <= 2832)))))
              : (c <= 2856 || (c < 2908
                ? (c < 2869
                  ? (c < 2866
                    ? (c >= 2858 && c <= 2864)
                    : c <= 2867)
                  : (c <= 2873 || c == 2877))
                : (c <= 2909 || (c < 2947
                  ? (c < 2929
                    ? (c >= 2911 && c <= 2913)
                    : c <= 2929)
                  : (c <= 2947 || (c >= 2949 && c <= 2954)))))))
            : (c <= 2960 || (c < 3086
              ? (c < 2979
                ? (c < 2972
                  ? (c < 2969
                    ? (c >= 2962 && c <= 2965)
                    : c <= 2970)
                  : (c <= 2972 || (c >= 2974 && c <= 2975)))
                : (c <= 2980 || (c < 3024
                  ? (c < 2990
                    ? (c >= 2984 && c <= 2986)
                    : c <= 3001)
                  : (c <= 3024 || (c >= 3077 && c <= 3084)))))
              : (c <= 3088 || (c < 3165
                ? (c < 3133
                  ? (c < 3114
                    ? (c >= 3090 && c <= 3112)
                    : c <= 3129)
                  : (c <= 3133 || (c >= 3160 && c <= 3162)))
                : (c <= 3165 || (c < 3205
                  ? (c < 3200
                    ? (c >= 3168 && c <= 3169)
                    : c <= 3200)
                  : (c <= 3212 || (c >= 3214 && c <= 3216)))))))))
          : (c <= 3240 || (c < 3634
            ? (c < 3406
              ? (c < 3313
                ? (c < 3261
                  ? (c < 3253
                    ? (c >= 3242 && c <= 3251)
                    : c <= 3257)
                  : (c <= 3261 || (c < 3296
                    ? (c >= 3293 && c <= 3294)
                    : c <= 3297)))
                : (c <= 3314 || (c < 3346
                  ? (c < 3342
                    ? (c >= 3332 && c <= 3340)
                    : c <= 3344)
                  : (c <= 3386 || c == 3389))))
              : (c <= 3406 || (c < 3482
                ? (c < 3450
                  ? (c < 3423
                    ? (c >= 3412 && c <= 3414)
                    : c <= 3425)
                  : (c <= 3455 || (c >= 3461 && c <= 3478)))
                : (c <= 3505 || (c < 3520
                  ? (c < 3517
                    ? (c >= 3507 && c <= 3515)
                    : c <= 3517)
                  : (c <= 3526 || (c >= 3585 && c <= 3632)))))))
            : (c <= 3634 || (c < 3776
              ? (c < 3724
                ? (c < 3716
                  ? (c < 3713
                    ? (c >= 3648 && c <= 3654)
                    : c <= 3714)
                  : (c <= 3716 || (c >= 3718 && c <= 3722)))
                : (c <= 3747 || (c < 3762
                  ? (c < 3751
                    ? c == 3749
                    : c <= 3760)
                  : (c <= 3762 || c == 3773))))
              : (c <= 3780 || (c < 3913
                ? (c < 3840
                  ? (c < 3804
                    ? c == 3782
                    : c <= 3807)
                  : (c <= 3840 || (c >= 3904 && c <= 3911)))
                : (c <= 3948 || (c < 4159
                  ? (c < 4096
                    ? (c >= 3976 && c <= 3980)
                    : c <= 4138)
                  : (c <= 4159 || (c >= 4176 && c <= 4181)))))))))))))
      : (c <= 4189 || (c < 8130
        ? (c < 6108
          ? (c < 4802
            ? (c < 4682
              ? (c < 4256
                ? (c < 4206
                  ? (c < 4197
                    ? c == 4193
                    : c <= 4198)
                  : (c <= 4208 || (c < 4238
                    ? (c >= 4213 && c <= 4225)
                    : c <= 4238)))
                : (c <= 4293 || (c < 4304
                  ? (c < 4301
                    ? c == 4295
                    : c <= 4301)
                  : (c <= 4346 || (c >= 4348 && c <= 4680)))))
              : (c <= 4685 || (c < 4746
                ? (c < 4698
                  ? (c < 4696
                    ? (c >= 4688 && c <= 4694)
                    : c <= 4696)
                  : (c <= 4701 || (c >= 4704 && c <= 4744)))
                : (c <= 4749 || (c < 4792
                  ? (c < 4786
                    ? (c >= 4752 && c <= 4784)
                    : c <= 4789)
                  : (c <= 4798 || c == 4800))))))
            : (c <= 4805 || (c < 5761
              ? (c < 4992
                ? (c < 4882
                  ? (c < 4824
                    ? (c >= 4808 && c <= 4822)
                    : c <= 4880)
                  : (c <= 4885 || (c >= 4888 && c <= 4954)))
                : (c <= 5007 || (c < 5121
                  ? (c < 5112
                    ? (c >= 5024 && c <= 5109)
                    : c <= 5117)
                  : (c <= 5740 || (c >= 5743 && c <= 5759)))))
              : (c <= 5786 || (c < 5952
                ? (c < 5888
                  ? (c < 5870
                    ? (c >= 5792 && c <= 5866)
                    : c <= 5880)
                  : (c <= 5905 || (c >= 5919 && c <= 5937)))
                : (c <= 5969 || (c < 6016
                  ? (c < 5998
                    ? (c >= 5984 && c <= 5996)
                    : c <= 6000)
                  : (c <= 6067 || c == 6103))))))))
          : (c <= 6108 || (c < 7296
            ? (c < 6688
              ? (c < 6480
                ? (c < 6314
                  ? (c < 6272
                    ? (c >= 6176 && c <= 6264)
                    : c <= 6312)
                  : (c <= 6314 || (c < 6400
                    ? (c >= 6320 && c <= 6389)
                    : c <= 6430)))
                : (c <= 6509 || (c < 6576
                  ? (c < 6528
                    ? (c >= 6512 && c <= 6516)
                    : c <= 6571)
                  : (c <= 6601 || (c >= 6656 && c <= 6678)))))
              : (c <= 6740 || (c < 7086
                ? (c < 6981
                  ? (c < 6917
                    ? c == 6823
                    : c <= 6963)
                  : (c <= 6988 || (c >= 7043 && c <= 7072)))
                : (c <= 7087 || (c < 7245
                  ? (c < 7168
                    ? (c >= 7098 && c <= 7141)
                    : c <= 7203)
                  : (c <= 7247 || (c >= 7258 && c <= 7293)))))))
            : (c <= 7304 || (c < 7968
              ? (c < 7413
                ? (c < 7401
                  ? (c < 7357
                    ? (c >= 7312 && c <= 7354)
                    : c <= 7359)
                  : (c <= 7404 || (c >= 7406 && c <= 7411)))
                : (c <= 7414 || (c < 7680
                  ? (c < 7424
                    ? c == 7418
                    : c <= 7615)
                  : (c <= 7957 || (c >= 7960 && c <= 7965)))))
              : (c <= 8005 || (c < 8029
                ? (c < 8025
                  ? (c < 8016
                    ? (c >= 8008 && c <= 8013)
                    : c <= 8023)
                  : (c <= 8025 || c == 8027))
                : (c <= 8029 || (c < 8118
                  ? (c < 8064
                    ? (c >= 8031 && c <= 8061)
                    : c <= 8116)
                  : (c <= 8124 || c == 8126))))))))))
        : (c <= 8132 || (c < 12321
          ? (c < 8526
            ? (c < 8455
              ? (c < 8182
                ? (c < 8150
                  ? (c < 8144
                    ? (c >= 8134 && c <= 8140)
                    : c <= 8147)
                  : (c <= 8155 || (c < 8178
                    ? (c >= 8160 && c <= 8172)
                    : c <= 8180)))
                : (c <= 8188 || (c < 8336
                  ? (c < 8319
                    ? c == 8305
                    : c <= 8319)
                  : (c <= 8348 || c == 8450))))
              : (c <= 8455 || (c < 8486
                ? (c < 8472
                  ? (c < 8469
                    ? (c >= 8458 && c <= 8467)
                    : c <= 8469)
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8508
                  ? (c < 8490
                    ? c == 8488
                    : c <= 8505)
                  : (c <= 8511 || (c >= 8517 && c <= 8521)))))))
            : (c <= 8526 || (c < 11648
              ? (c < 11520
                ? (c < 11499
                  ? (c < 11264
                    ? (c >= 8544 && c <= 8584)
                    : c <= 11492)
                  : (c <= 11502 || (c >= 11506 && c <= 11507)))
                : (c <= 11557 || (c < 11568
                  ? (c < 11565
                    ? c == 11559
                    : c <= 11565)
                  : (c <= 11623 || c == 11631))))
              : (c <= 11670 || (c < 11712
                ? (c < 11696
                  ? (c < 11688
                    ? (c >= 11680 && c <= 11686)
                    : c <= 11694)
                  : (c <= 11702 || (c >= 11704 && c <= 11710)))
                : (c <= 11718 || (c < 11736
                  ? (c < 11728
                    ? (c >= 11720 && c <= 11726)
                    : c <= 11734)
                  : (c <= 11742 || (c >= 12293 && c <= 12295)))))))))
          : (c <= 12329 || (c < 42786
            ? (c < 13312
              ? (c < 12540
                ? (c < 12353
                  ? (c < 12344
                    ? (c >= 12337 && c <= 12341)
                    : c <= 12348)
                  : (c <= 12438 || (c < 12449
                    ? (c >= 12445 && c <= 12447)
                    : c <= 12538)))
                : (c <= 12543 || (c < 12704
                  ? (c < 12593
                    ? (c >= 12549 && c <= 12591)
                    : c <= 12686)
                  : (c <= 12735 || (c >= 12784 && c <= 12799)))))
              : (c <= 19903 || (c < 42538
                ? (c < 42240
                  ? (c < 42192
                    ? (c >= 19968 && c <= 42124)
                    : c <= 42237)
                  : (c <= 42508 || (c >= 42512 && c <= 42527)))
                : (c <= 42539 || (c < 42656
                  ? (c < 42623
                    ? (c >= 42560 && c <= 42606)
                    : c <= 42653)
                  : (c <= 42735 || (c >= 42775 && c <= 42783)))))))
            : (c <= 42888 || (c < 43138
              ? (c < 42994
                ? (c < 42963
                  ? (c < 42960
                    ? (c >= 42891 && c <= 42954)
                    : c <= 42961)
                  : (c <= 42963 || (c >= 42965 && c <= 42969)))
                : (c <= 43009 || (c < 43020
                  ? (c < 43015
                    ? (c >= 43011 && c <= 43013)
                    : c <= 43018)
                  : (c <= 43042 || (c >= 43072 && c <= 43123)))))
              : (c <= 43187 || (c < 43312
                ? (c < 43261
                  ? (c < 43259
                    ? (c >= 43250 && c <= 43255)
                    : c <= 43259)
                  : (c <= 43262 || (c >= 43274 && c <= 43301)))
                : (c <= 43334 || (c < 43471
                  ? (c < 43396
                    ? (c >= 43360 && c <= 43388)
                    : c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))))))))))))))
    : (c <= 43503 || (c < 70727
      ? (c < 66956
        ? (c < 64914
          ? (c < 43824
            ? (c < 43712
              ? (c < 43642
                ? (c < 43584
                  ? (c < 43520
                    ? (c >= 43514 && c <= 43518)
                    : c <= 43560)
                  : (c <= 43586 || (c < 43616
                    ? (c >= 43588 && c <= 43595)
                    : c <= 43638)))
                : (c <= 43642 || (c < 43701
                  ? (c < 43697
                    ? (c >= 43646 && c <= 43695)
                    : c <= 43697)
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))))
              : (c <= 43712 || (c < 43777
                ? (c < 43744
                  ? (c < 43739
                    ? c == 43714
                    : c <= 43741)
                  : (c <= 43754 || (c >= 43762 && c <= 43764)))
                : (c <= 43782 || (c < 43808
                  ? (c < 43793
                    ? (c >= 43785 && c <= 43790)
                    : c <= 43798)
                  : (c <= 43814 || (c >= 43816 && c <= 43822)))))))
            : (c <= 43866 || (c < 64287
              ? (c < 63744
                ? (c < 44032
                  ? (c < 43888
                    ? (c >= 43868 && c <= 43881)
                    : c <= 44002)
                  : (c <= 55203 || (c < 55243
                    ? (c >= 55216 && c <= 55238)
                    : c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || c == 64285))))
              : (c <= 64296 || (c < 64323
                ? (c < 64318
                  ? (c < 64312
                    ? (c >= 64298 && c <= 64310)
                    : c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65599
            ? (c < 65382
              ? (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))))
              : (c <= 65437 || (c < 65498
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))))))
            : (c <= 65613 || (c < 66464
              ? (c < 66208
                ? (c < 65856
                  ? (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)
                  : (c <= 65908 || (c >= 66176 && c <= 66204)))
                : (c <= 66256 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))))
              : (c <= 66499 || (c < 66776
                ? (c < 66560
                  ? (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)
                  : (c <= 66717 || (c >= 66736 && c <= 66771)))
                : (c <= 66811 || (c < 66928
                  ? (c < 66864
                    ? (c >= 66816 && c <= 66855)
                    : c <= 66915)
                  : (c <= 66938 || (c >= 66940 && c <= 66954)))))))))))
        : (c <= 66962 || (c < 68864
          ? (c < 67828
            ? (c < 67506
              ? (c < 67072
                ? (c < 66979
                  ? (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)
                  : (c <= 66993 || (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)))
                : (c <= 67382 || (c < 67456
                  ? (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)
                  : (c <= 67461 || (c >= 67463 && c <= 67504)))))
              : (c <= 67514 || (c < 67644
                ? (c < 67594
                  ? (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)
                  : (c <= 67637 || (c >= 67639 && c <= 67640)))
                : (c <= 67644 || (c < 67712
                  ? (c < 67680
                    ? (c >= 67647 && c <= 67669)
                    : c <= 67702)
                  : (c <= 67742 || (c >= 67808 && c <= 67826)))))))
            : (c <= 67829 || (c < 68224
              ? (c < 68096
                ? (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c >= 68030 && c <= 68031)))
                : (c <= 68096 || (c < 68121
                  ? (c < 68117
                    ? (c >= 68112 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c >= 68192 && c <= 68220)))))
              : (c <= 68252 || (c < 68448
                ? (c < 68352
                  ? (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68324)
                  : (c <= 68405 || (c >= 68416 && c <= 68437)))
                : (c <= 68466 || (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c >= 68800 && c <= 68850)))))))))
          : (c <= 68899 || (c < 70106
            ? (c < 69749
              ? (c < 69488
                ? (c < 69376
                  ? (c < 69296
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69297)
                  : (c <= 69404 || (c < 69424
                    ? c == 69415
                    : c <= 69445)))
                : (c <= 69505 || (c < 69635
                  ? (c < 69600
                    ? (c >= 69552 && c <= 69572)
                    : c <= 69622)
                  : (c <= 69687 || (c >= 69745 && c <= 69746)))))
              : (c <= 69749 || (c < 69959
                ? (c < 69891
                  ? (c < 69840
                    ? (c >= 69763 && c <= 69807)
                    : c <= 69864)
                  : (c <= 69926 || c == 69956))
                : (c <= 69959 || (c < 70019
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70002)
                    : c <= 70006)
                  : (c <= 70066 || (c >= 70081 && c <= 70084)))))))
            : (c <= 70106 || (c < 70405
              ? (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70187 || (c >= 70272 && c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70366)))))
              : (c <= 70412 || (c < 70453
                ? (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))
                : (c <= 70457 || (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))))))))))))
      : (c <= 70730 || (c < 119894
        ? (c < 73056
          ? (c < 72001
            ? (c < 71424
              ? (c < 71128
                ? (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || (c < 71040
                    ? c == 70855
                    : c <= 71086)))
                : (c <= 71131 || (c < 71296
                  ? (c < 71236
                    ? (c >= 71168 && c <= 71215)
                    : c <= 71236)
                  : (c <= 71338 || c == 71352))))
              : (c <= 71450 || (c < 71945
                ? (c < 71840
                  ? (c < 71680
                    ? (c >= 71488 && c <= 71494)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))))))
            : (c <= 72001 || (c < 72349
              ? (c < 72192
                ? (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))
                : (c <= 72192 || (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))))
              : (c <= 72349 || (c < 72818
                ? (c < 72714
                  ? (c < 72704
                    ? (c >= 72368 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))
                : (c <= 72847 || (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))))))))
          : (c <= 73061 || (c < 93952
            ? (c < 82944
              ? (c < 73728
                ? (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c < 73648
                    ? (c >= 73440 && c <= 73458)
                    : c <= 73648)))
                : (c <= 74649 || (c < 77712
                  ? (c < 74880
                    ? (c >= 74752 && c <= 74862)
                    : c <= 75075)
                  : (c <= 77808 || (c >= 77824 && c <= 78894)))))
              : (c <= 83526 || (c < 92928
                ? (c < 92784
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92862 || (c >= 92880 && c <= 92909)))
                : (c <= 92975 || (c < 93053
                  ? (c < 93027
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93047)
                  : (c <= 93071 || (c >= 93760 && c <= 93823)))))))
            : (c <= 94026 || (c < 110589
              ? (c < 94208
                ? (c < 94176
                  ? (c < 94099
                    ? c == 94032
                    : c <= 94111)
                  : (c <= 94177 || c == 94179))
                : (c <= 100343 || (c < 110576
                  ? (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)
                  : (c <= 110579 || (c >= 110581 && c <= 110587)))))
              : (c <= 110590 || (c < 113664
                ? (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110882)
                    : c <= 110930)
                  : (c <= 110951 || (c >= 110960 && c <= 111355)))
                : (c <= 113770 || (c < 113808
                  ? (c < 113792
                    ? (c >= 113776 && c <= 113788)
                    : c <= 113800)
                  : (c <= 113817 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 125259
          ? (c < 120572
            ? (c < 120086
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c >= 120077 && c <= 120084)))))
              : (c <= 120092 || (c < 120138
                ? (c < 120128
                  ? (c < 120123
                    ? (c >= 120094 && c <= 120121)
                    : c <= 120126)
                  : (c <= 120132 || c == 120134))
                : (c <= 120144 || (c < 120514
                  ? (c < 120488
                    ? (c >= 120146 && c <= 120485)
                    : c <= 120512)
                  : (c <= 120538 || (c >= 120540 && c <= 120570)))))))
            : (c <= 120596 || (c < 123191
              ? (c < 120714
                ? (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c >= 120688 && c <= 120712)))
                : (c <= 120744 || (c < 122624
                  ? (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)
                  : (c <= 122654 || (c >= 123136 && c <= 123180)))))
              : (c <= 123197 || (c < 124904
                ? (c < 123584
                  ? (c < 123536
                    ? c == 123214
                    : c <= 123565)
                  : (c <= 123627 || (c >= 124896 && c <= 124902)))
                : (c <= 124907 || (c < 124928
                  ? (c < 124912
                    ? (c >= 124909 && c <= 124910)
                    : c <= 124926)
                  : (c <= 125124 || (c >= 125184 && c <= 125251)))))))))
          : (c <= 125259 || (c < 126559
            ? (c < 126535
              ? (c < 126505
                ? (c < 126497
                  ? (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)
                  : (c <= 126498 || (c < 126503
                    ? c == 126500
                    : c <= 126503)))
                : (c <= 126514 || (c < 126523
                  ? (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)
                  : (c <= 126523 || c == 126530))))
              : (c <= 126535 || (c < 126548
                ? (c < 126541
                  ? (c < 126539
                    ? c == 126537
                    : c <= 126539)
                  : (c <= 126543 || (c >= 126545 && c <= 126546)))
                : (c <= 126548 || (c < 126555
                  ? (c < 126553
                    ? c == 126551
                    : c <= 126553)
                  : (c <= 126555 || c == 126557))))))
            : (c <= 126559 || (c < 126625
              ? (c < 126580
                ? (c < 126567
                  ? (c < 126564
                    ? (c >= 126561 && c <= 126562)
                    : c <= 126564)
                  : (c <= 126570 || (c >= 126572 && c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c >= 126603 && c <= 126619)))))
              : (c <= 126627 || (c < 177984
                ? (c < 131072
                  ? (c < 126635
                    ? (c >= 126629 && c <= 126633)
                    : c <= 126651)
                  : (c <= 173791 || (c >= 173824 && c <= 177976)))
                : (c <= 178205 || (c < 194560
                  ? (c < 183984
                    ? (c >= 178208 && c <= 183969)
                    : c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_4(int32_t c) {
  return (c < 43600
    ? (c < 3776
      ? (c < 2738
        ? (c < 1984
          ? (c < 910
            ? (c < 216
              ? (c < 162
                ? (c < 'A'
                  ? (c < '0'
                    ? c == '$'
                    : c <= '9')
                  : (c <= 'Z' || (c < 'a'
                    ? c == '_'
                    : c <= 'z')))
                : (c <= 162 || (c < 183
                  ? (c < 181
                    ? c == 170
                    : c <= 181)
                  : (c <= 183 || (c < 192
                    ? c == 186
                    : c <= 214)))))
              : (c <= 246 || (c < 768
                ? (c < 736
                  ? (c < 710
                    ? (c >= 248 && c <= 705)
                    : c <= 721)
                  : (c <= 740 || (c < 750
                    ? c == 748
                    : c <= 750)))
                : (c <= 884 || (c < 895
                  ? (c < 891
                    ? (c >= 886 && c <= 887)
                    : c <= 893)
                  : (c <= 895 || (c < 908
                    ? (c >= 902 && c <= 906)
                    : c <= 908)))))))
            : (c <= 929 || (c < 1479
              ? (c < 1369
                ? (c < 1155
                  ? (c < 1015
                    ? (c >= 931 && c <= 1013)
                    : c <= 1153)
                  : (c <= 1159 || (c < 1329
                    ? (c >= 1162 && c <= 1327)
                    : c <= 1366)))
                : (c <= 1369 || (c < 1471
                  ? (c < 1425
                    ? (c >= 1376 && c <= 1416)
                    : c <= 1469)
                  : (c <= 1471 || (c < 1476
                    ? (c >= 1473 && c <= 1474)
                    : c <= 1477)))))
              : (c <= 1479 || (c < 1749
                ? (c < 1552
                  ? (c < 1519
                    ? (c >= 1488 && c <= 1514)
                    : c <= 1522)
                  : (c <= 1562 || (c < 1646
                    ? (c >= 1568 && c <= 1641)
                    : c <= 1747)))
                : (c <= 1756 || (c < 1791
                  ? (c < 1770
                    ? (c >= 1759 && c <= 1768)
                    : c <= 1788)
                  : (c <= 1791 || (c < 1869
                    ? (c >= 1808 && c <= 1866)
                    : c <= 1969)))))))))
          : (c <= 2037 || (c < 2534
            ? (c < 2437
              ? (c < 2160
                ? (c < 2048
                  ? (c < 2045
                    ? c == 2042
                    : c <= 2045)
                  : (c <= 2093 || (c < 2144
                    ? (c >= 2112 && c <= 2139)
                    : c <= 2154)))
                : (c <= 2183 || (c < 2275
                  ? (c < 2200
                    ? (c >= 2185 && c <= 2190)
                    : c <= 2273)
                  : (c <= 2403 || (c < 2417
                    ? (c >= 2406 && c <= 2415)
                    : c <= 2435)))))
              : (c <= 2444 || (c < 2492
                ? (c < 2474
                  ? (c < 2451
                    ? (c >= 2447 && c <= 2448)
                    : c <= 2472)
                  : (c <= 2480 || (c < 2486
                    ? c == 2482
                    : c <= 2489)))
                : (c <= 2500 || (c < 2519
                  ? (c < 2507
                    ? (c >= 2503 && c <= 2504)
                    : c <= 2510)
                  : (c <= 2519 || (c < 2527
                    ? (c >= 2524 && c <= 2525)
                    : c <= 2531)))))))
            : (c <= 2545 || (c < 2622
              ? (c < 2579
                ? (c < 2561
                  ? (c < 2558
                    ? c == 2556
                    : c <= 2558)
                  : (c <= 2563 || (c < 2575
                    ? (c >= 2565 && c <= 2570)
                    : c <= 2576)))
                : (c <= 2600 || (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c < 2620
                    ? (c >= 2616 && c <= 2617)
                    : c <= 2620)))))
              : (c <= 2626 || (c < 2662
                ? (c < 2641
                  ? (c < 2635
                    ? (c >= 2631 && c <= 2632)
                    : c <= 2637)
                  : (c <= 2641 || (c < 2654
                    ? (c >= 2649 && c <= 2652)
                    : c <= 2654)))
                : (c <= 2677 || (c < 2703
                  ? (c < 2693
                    ? (c >= 2689 && c <= 2691)
                    : c <= 2701)
                  : (c <= 2705 || (c < 2730
                    ? (c >= 2707 && c <= 2728)
                    : c <= 2736)))))))))))
        : (c <= 2739 || (c < 3160
          ? (c < 2946
            ? (c < 2835
              ? (c < 2784
                ? (c < 2759
                  ? (c < 2748
                    ? (c >= 2741 && c <= 2745)
                    : c <= 2757)
                  : (c <= 2761 || (c < 2768
                    ? (c >= 2763 && c <= 2765)
                    : c <= 2768)))
                : (c <= 2787 || (c < 2817
                  ? (c < 2809
                    ? (c >= 2790 && c <= 2799)
                    : c <= 2815)
                  : (c <= 2819 || (c < 2831
                    ? (c >= 2821 && c <= 2828)
                    : c <= 2832)))))
              : (c <= 2856 || (c < 2891
                ? (c < 2869
                  ? (c < 2866
                    ? (c >= 2858 && c <= 2864)
                    : c <= 2867)
                  : (c <= 2873 || (c < 2887
                    ? (c >= 2876 && c <= 2884)
                    : c <= 2888)))
                : (c <= 2893 || (c < 2911
                  ? (c < 2908
                    ? (c >= 2901 && c <= 2903)
                    : c <= 2909)
                  : (c <= 2915 || (c < 2929
                    ? (c >= 2918 && c <= 2927)
                    : c <= 2929)))))))
            : (c <= 2947 || (c < 3018
              ? (c < 2974
                ? (c < 2962
                  ? (c < 2958
                    ? (c >= 2949 && c <= 2954)
                    : c <= 2960)
                  : (c <= 2965 || (c < 2972
                    ? (c >= 2969 && c <= 2970)
                    : c <= 2972)))
                : (c <= 2975 || (c < 2990
                  ? (c < 2984
                    ? (c >= 2979 && c <= 2980)
                    : c <= 2986)
                  : (c <= 3001 || (c < 3014
                    ? (c >= 3006 && c <= 3010)
                    : c <= 3016)))))
              : (c <= 3021 || (c < 3090
                ? (c < 3046
                  ? (c < 3031
                    ? c == 3024
                    : c <= 3031)
                  : (c <= 3055 || (c < 3086
                    ? (c >= 3072 && c <= 3084)
                    : c <= 3088)))
                : (c <= 3112 || (c < 3142
                  ? (c < 3132
                    ? (c >= 3114 && c <= 3129)
                    : c <= 3140)
                  : (c <= 3144 || (c < 3157
                    ? (c >= 3146 && c <= 3149)
                    : c <= 3158)))))))))
          : (c <= 3162 || (c < 3423
            ? (c < 3274
              ? (c < 3214
                ? (c < 3174
                  ? (c < 3168
                    ? c == 3165
                    : c <= 3171)
                  : (c <= 3183 || (c < 3205
                    ? (c >= 3200 && c <= 3203)
                    : c <= 3212)))
                : (c <= 3216 || (c < 3253
                  ? (c < 3242
                    ? (c >= 3218 && c <= 3240)
                    : c <= 3251)
                  : (c <= 3257 || (c < 3270
                    ? (c >= 3260 && c <= 3268)
                    : c <= 3272)))))
              : (c <= 3277 || (c < 3328
                ? (c < 3296
                  ? (c < 3293
                    ? (c >= 3285 && c <= 3286)
                    : c <= 3294)
                  : (c <= 3299 || (c < 3313
                    ? (c >= 3302 && c <= 3311)
                    : c <= 3314)))
                : (c <= 3340 || (c < 3398
                  ? (c < 3346
                    ? (c >= 3342 && c <= 3344)
                    : c <= 3396)
                  : (c <= 3400 || (c < 3412
                    ? (c >= 3402 && c <= 3406)
                    : c <= 3415)))))))
            : (c <= 3427 || (c < 3544
              ? (c < 3507
                ? (c < 3457
                  ? (c < 3450
                    ? (c >= 3430 && c <= 3439)
                    : c <= 3455)
                  : (c <= 3459 || (c < 3482
                    ? (c >= 3461 && c <= 3478)
                    : c <= 3505)))
                : (c <= 3515 || (c < 3530
                  ? (c < 3520
                    ? c == 3517
                    : c <= 3526)
                  : (c <= 3530 || (c < 3542
                    ? (c >= 3535 && c <= 3540)
                    : c <= 3542)))))
              : (c <= 3551 || (c < 3713
                ? (c < 3585
                  ? (c < 3570
                    ? (c >= 3558 && c <= 3567)
                    : c <= 3571)
                  : (c <= 3642 || (c < 3664
                    ? (c >= 3648 && c <= 3662)
                    : c <= 3673)))
                : (c <= 3714 || (c < 3724
                  ? (c < 3718
                    ? c == 3716
                    : c <= 3722)
                  : (c <= 3747 || (c < 3751
                    ? c == 3749
                    : c <= 3773)))))))))))))
      : (c <= 3780 || (c < 8016
        ? (c < 5870
          ? (c < 4682
            ? (c < 3913
              ? (c < 3864
                ? (c < 3792
                  ? (c < 3784
                    ? c == 3782
                    : c <= 3789)
                  : (c <= 3801 || (c < 3840
                    ? (c >= 3804 && c <= 3807)
                    : c <= 3840)))
                : (c <= 3865 || (c < 3895
                  ? (c < 3893
                    ? (c >= 3872 && c <= 3881)
                    : c <= 3893)
                  : (c <= 3895 || (c < 3902
                    ? c == 3897
                    : c <= 3911)))))
              : (c <= 3948 || (c < 4176
                ? (c < 3993
                  ? (c < 3974
                    ? (c >= 3953 && c <= 3972)
                    : c <= 3991)
                  : (c <= 4028 || (c < 4096
                    ? c == 4038
                    : c <= 4169)))
                : (c <= 4253 || (c < 4301
                  ? (c < 4295
                    ? (c >= 4256 && c <= 4293)
                    : c <= 4295)
                  : (c <= 4301 || (c < 4348
                    ? (c >= 4304 && c <= 4346)
                    : c <= 4680)))))))
            : (c <= 4685 || (c < 4824
              ? (c < 4752
                ? (c < 4698
                  ? (c < 4696
                    ? (c >= 4688 && c <= 4694)
                    : c <= 4696)
                  : (c <= 4701 || (c < 4746
                    ? (c >= 4704 && c <= 4744)
                    : c <= 4749)))
                : (c <= 4784 || (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c < 4808
                    ? (c >= 4802 && c <= 4805)
                    : c <= 4822)))))
              : (c <= 4880 || (c < 5024
                ? (c < 4957
                  ? (c < 4888
                    ? (c >= 4882 && c <= 4885)
                    : c <= 4954)
                  : (c <= 4959 || (c < 4992
                    ? (c >= 4969 && c <= 4977)
                    : c <= 5007)))
                : (c <= 5109 || (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c < 5792
                    ? (c >= 5761 && c <= 5786)
                    : c <= 5866)))))))))
          : (c <= 5880 || (c < 6656
            ? (c < 6159
              ? (c < 6002
                ? (c < 5952
                  ? (c < 5919
                    ? (c >= 5888 && c <= 5909)
                    : c <= 5940)
                  : (c <= 5971 || (c < 5998
                    ? (c >= 5984 && c <= 5996)
                    : c <= 6000)))
                : (c <= 6003 || (c < 6108
                  ? (c < 6103
                    ? (c >= 6016 && c <= 6099)
                    : c <= 6103)
                  : (c <= 6109 || (c < 6155
                    ? (c >= 6112 && c <= 6121)
                    : c <= 6157)))))
              : (c <= 6169 || (c < 6448
                ? (c < 6320
                  ? (c < 6272
                    ? (c >= 6176 && c <= 6264)
                    : c <= 6314)
                  : (c <= 6389 || (c < 6432
                    ? (c >= 6400 && c <= 6430)
                    : c <= 6443)))
                : (c <= 6459 || (c < 6528
                  ? (c < 6512
                    ? (c >= 6470 && c <= 6509)
                    : c <= 6516)
                  : (c <= 6571 || (c < 6608
                    ? (c >= 6576 && c <= 6601)
                    : c <= 6618)))))))
            : (c <= 6683 || (c < 7168
              ? (c < 6832
                ? (c < 6783
                  ? (c < 6752
                    ? (c >= 6688 && c <= 6750)
                    : c <= 6780)
                  : (c <= 6793 || (c < 6823
                    ? (c >= 6800 && c <= 6809)
                    : c <= 6823)))
                : (c <= 6845 || (c < 6992
                  ? (c < 6912
                    ? (c >= 6847 && c <= 6862)
                    : c <= 6988)
                  : (c <= 7001 || (c < 7040
                    ? (c >= 7019 && c <= 7027)
                    : c <= 7155)))))
              : (c <= 7223 || (c < 7376
                ? (c < 7296
                  ? (c < 7245
                    ? (c >= 7232 && c <= 7241)
                    : c <= 7293)
                  : (c <= 7304 || (c < 7357
                    ? (c >= 7312 && c <= 7354)
                    : c <= 7359)))
                : (c <= 7378 || (c < 7960
                  ? (c < 7424
                    ? (c >= 7380 && c <= 7418)
                    : c <= 7957)
                  : (c <= 7965 || (c < 8008
                    ? (c >= 7968 && c <= 8005)
                    : c <= 8013)))))))))))
        : (c <= 8023 || (c < 11712
          ? (c < 8455
            ? (c < 8160
              ? (c < 8118
                ? (c < 8029
                  ? (c < 8027
                    ? c == 8025
                    : c <= 8027)
                  : (c <= 8029 || (c < 8064
                    ? (c >= 8031 && c <= 8061)
                    : c <= 8116)))
                : (c <= 8124 || (c < 8134
                  ? (c < 8130
                    ? c == 8126
                    : c <= 8132)
                  : (c <= 8140 || (c < 8150
                    ? (c >= 8144 && c <= 8147)
                    : c <= 8155)))))
              : (c <= 8172 || (c < 8319
                ? (c < 8255
                  ? (c < 8182
                    ? (c >= 8178 && c <= 8180)
                    : c <= 8188)
                  : (c <= 8256 || (c < 8305
                    ? c == 8276
                    : c <= 8305)))
                : (c <= 8319 || (c < 8417
                  ? (c < 8400
                    ? (c >= 8336 && c <= 8348)
                    : c <= 8412)
                  : (c <= 8417 || (c < 8450
                    ? (c >= 8421 && c <= 8432)
                    : c <= 8450)))))))
            : (c <= 8455 || (c < 11264
              ? (c < 8488
                ? (c < 8472
                  ? (c < 8469
                    ? (c >= 8458 && c <= 8467)
                    : c <= 8469)
                  : (c <= 8477 || (c < 8486
                    ? c == 8484
                    : c <= 8486)))
                : (c <= 8488 || (c < 8517
                  ? (c < 8508
                    ? (c >= 8490 && c <= 8505)
                    : c <= 8511)
                  : (c <= 8521 || (c < 8544
                    ? c == 8526
                    : c <= 8584)))))
              : (c <= 11492 || (c < 11631
                ? (c < 11559
                  ? (c < 11520
                    ? (c >= 11499 && c <= 11507)
                    : c <= 11557)
                  : (c <= 11559 || (c < 11568
                    ? c == 11565
                    : c <= 11623)))
                : (c <= 11631 || (c < 11688
                  ? (c < 11680
                    ? (c >= 11647 && c <= 11670)
                    : c <= 11686)
                  : (c <= 11694 || (c < 11704
                    ? (c >= 11696 && c <= 11702)
                    : c <= 11710)))))))))
          : (c <= 11718 || (c < 42612
            ? (c < 12449
              ? (c < 12321
                ? (c < 11736
                  ? (c < 11728
                    ? (c >= 11720 && c <= 11726)
                    : c <= 11734)
                  : (c <= 11742 || (c < 12293
                    ? (c >= 11744 && c <= 11775)
                    : c <= 12295)))
                : (c <= 12335 || (c < 12353
                  ? (c < 12344
                    ? (c >= 12337 && c <= 12341)
                    : c <= 12348)
                  : (c <= 12438 || (c < 12445
                    ? (c >= 12441 && c <= 12442)
                    : c <= 12447)))))
              : (c <= 12538 || (c < 13312
                ? (c < 12593
                  ? (c < 12549
                    ? (c >= 12540 && c <= 12543)
                    : c <= 12591)
                  : (c <= 12686 || (c < 12784
                    ? (c >= 12704 && c <= 12735)
                    : c <= 12799)))
                : (c <= 19903 || (c < 42240
                  ? (c < 42192
                    ? (c >= 19968 && c <= 42124)
                    : c <= 42237)
                  : (c <= 42508 || (c < 42560
                    ? (c >= 42512 && c <= 42539)
                    : c <= 42607)))))))
            : (c <= 42621 || (c < 43216
              ? (c < 42963
                ? (c < 42786
                  ? (c < 42775
                    ? (c >= 42623 && c <= 42737)
                    : c <= 42783)
                  : (c <= 42888 || (c < 42960
                    ? (c >= 42891 && c <= 42954)
                    : c <= 42961)))
                : (c <= 42963 || (c < 43052
                  ? (c < 42994
                    ? (c >= 42965 && c <= 42969)
                    : c <= 43047)
                  : (c <= 43052 || (c < 43136
                    ? (c >= 43072 && c <= 43123)
                    : c <= 43205)))))
              : (c <= 43225 || (c < 43392
                ? (c < 43261
                  ? (c < 43259
                    ? (c >= 43232 && c <= 43255)
                    : c <= 43259)
                  : (c <= 43309 || (c < 43360
                    ? (c >= 43312 && c <= 43347)
                    : c <= 43388)))
                : (c <= 43456 || (c < 43520
                  ? (c < 43488
                    ? (c >= 43471 && c <= 43481)
                    : c <= 43518)
                  : (c <= 43574 || (c >= 43584 && c <= 43597)))))))))))))))
    : (c <= 43609 || (c < 71453
      ? (c < 67594
        ? (c < 65343
          ? (c < 64298
            ? (c < 43868
              ? (c < 43777
                ? (c < 43739
                  ? (c < 43642
                    ? (c >= 43616 && c <= 43638)
                    : c <= 43714)
                  : (c <= 43741 || (c < 43762
                    ? (c >= 43744 && c <= 43759)
                    : c <= 43766)))
                : (c <= 43782 || (c < 43808
                  ? (c < 43793
                    ? (c >= 43785 && c <= 43790)
                    : c <= 43798)
                  : (c <= 43814 || (c < 43824
                    ? (c >= 43816 && c <= 43822)
                    : c <= 43866)))))
              : (c <= 43881 || (c < 55243
                ? (c < 44016
                  ? (c < 44012
                    ? (c >= 43888 && c <= 44010)
                    : c <= 44013)
                  : (c <= 44025 || (c < 55216
                    ? (c >= 44032 && c <= 55203)
                    : c <= 55238)))
                : (c <= 55291 || (c < 64256
                  ? (c < 64112
                    ? (c >= 63744 && c <= 64109)
                    : c <= 64217)
                  : (c <= 64262 || (c < 64285
                    ? (c >= 64275 && c <= 64279)
                    : c <= 64296)))))))
            : (c <= 64310 || (c < 65056
              ? (c < 64467
                ? (c < 64320
                  ? (c < 64318
                    ? (c >= 64312 && c <= 64316)
                    : c <= 64318)
                  : (c <= 64321 || (c < 64326
                    ? (c >= 64323 && c <= 64324)
                    : c <= 64433)))
                : (c <= 64605 || (c < 64914
                  ? (c < 64848
                    ? (c >= 64612 && c <= 64829)
                    : c <= 64911)
                  : (c <= 64967 || (c < 65024
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65039)))))
              : (c <= 65071 || (c < 65145
                ? (c < 65137
                  ? (c < 65101
                    ? (c >= 65075 && c <= 65076)
                    : c <= 65103)
                  : (c <= 65137 || (c < 65143
                    ? c == 65139
                    : c <= 65143)))
                : (c <= 65145 || (c < 65151
                  ? (c < 65149
                    ? c == 65147
                    : c <= 65149)
                  : (c <= 65276 || (c < 65313
                    ? (c >= 65296 && c <= 65305)
                    : c <= 65338)))))))))
          : (c <= 65343 || (c < 66504
            ? (c < 65616
              ? (c < 65498
                ? (c < 65474
                  ? (c < 65382
                    ? (c >= 65345 && c <= 65370)
                    : c <= 65470)
                  : (c <= 65479 || (c < 65490
                    ? (c >= 65482 && c <= 65487)
                    : c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c < 65599
                    ? (c >= 65596 && c <= 65597)
                    : c <= 65613)))))
              : (c <= 65629 || (c < 66272
                ? (c < 66045
                  ? (c < 65856
                    ? (c >= 65664 && c <= 65786)
                    : c <= 65908)
                  : (c <= 66045 || (c < 66208
                    ? (c >= 66176 && c <= 66204)
                    : c <= 66256)))
                : (c <= 66272 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66426 || (c < 66464
                    ? (c >= 66432 && c <= 66461)
                    : c <= 66499)))))))
            : (c <= 66511 || (c < 66967
              ? (c < 66816
                ? (c < 66720
                  ? (c < 66560
                    ? (c >= 66513 && c <= 66517)
                    : c <= 66717)
                  : (c <= 66729 || (c < 66776
                    ? (c >= 66736 && c <= 66771)
                    : c <= 66811)))
                : (c <= 66855 || (c < 66940
                  ? (c < 66928
                    ? (c >= 66864 && c <= 66915)
                    : c <= 66938)
                  : (c <= 66954 || (c < 66964
                    ? (c >= 66956 && c <= 66962)
                    : c <= 66965)))))
              : (c <= 66977 || (c < 67424
                ? (c < 67003
                  ? (c < 66995
                    ? (c >= 66979 && c <= 66993)
                    : c <= 67001)
                  : (c <= 67004 || (c < 67392
                    ? (c >= 67072 && c <= 67382)
                    : c <= 67413)))
                : (c <= 67431 || (c < 67506
                  ? (c < 67463
                    ? (c >= 67456 && c <= 67461)
                    : c <= 67504)
                  : (c <= 67514 || (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)))))))))))
        : (c <= 67637 || (c < 69942
          ? (c < 68416
            ? (c < 68096
              ? (c < 67808
                ? (c < 67647
                  ? (c < 67644
                    ? (c >= 67639 && c <= 67640)
                    : c <= 67644)
                  : (c <= 67669 || (c < 67712
                    ? (c >= 67680 && c <= 67702)
                    : c <= 67742)))
                : (c <= 67826 || (c < 67872
                  ? (c < 67840
                    ? (c >= 67828 && c <= 67829)
                    : c <= 67861)
                  : (c <= 67897 || (c < 68030
                    ? (c >= 67968 && c <= 68023)
                    : c <= 68031)))))
              : (c <= 68099 || (c < 68159
                ? (c < 68117
                  ? (c < 68108
                    ? (c >= 68101 && c <= 68102)
                    : c <= 68115)
                  : (c <= 68119 || (c < 68152
                    ? (c >= 68121 && c <= 68149)
                    : c <= 68154)))
                : (c <= 68159 || (c < 68288
                  ? (c < 68224
                    ? (c >= 68192 && c <= 68220)
                    : c <= 68252)
                  : (c <= 68295 || (c < 68352
                    ? (c >= 68297 && c <= 68326)
                    : c <= 68405)))))))
            : (c <= 68437 || (c < 69415
              ? (c < 68864
                ? (c < 68608
                  ? (c < 68480
                    ? (c >= 68448 && c <= 68466)
                    : c <= 68497)
                  : (c <= 68680 || (c < 68800
                    ? (c >= 68736 && c <= 68786)
                    : c <= 68850)))
                : (c <= 68903 || (c < 69291
                  ? (c < 69248
                    ? (c >= 68912 && c <= 68921)
                    : c <= 69289)
                  : (c <= 69292 || (c < 69376
                    ? (c >= 69296 && c <= 69297)
                    : c <= 69404)))))
              : (c <= 69415 || (c < 69734
                ? (c < 69552
                  ? (c < 69488
                    ? (c >= 69424 && c <= 69456)
                    : c <= 69509)
                  : (c <= 69572 || (c < 69632
                    ? (c >= 69600 && c <= 69622)
                    : c <= 69702)))
                : (c <= 69749 || (c < 69840
                  ? (c < 69826
                    ? (c >= 69759 && c <= 69818)
                    : c <= 69826)
                  : (c <= 69864 || (c < 69888
                    ? (c >= 69872 && c <= 69881)
                    : c <= 69940)))))))))
          : (c <= 69951 || (c < 70453
            ? (c < 70280
              ? (c < 70094
                ? (c < 70006
                  ? (c < 69968
                    ? (c >= 69956 && c <= 69959)
                    : c <= 70003)
                  : (c <= 70006 || (c < 70089
                    ? (c >= 70016 && c <= 70084)
                    : c <= 70092)))
                : (c <= 70106 || (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70199 || (c < 70272
                    ? c == 70206
                    : c <= 70278)))))
              : (c <= 70280 || (c < 70400
                ? (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c < 70384
                    ? (c >= 70320 && c <= 70378)
                    : c <= 70393)))
                : (c <= 70403 || (c < 70419
                  ? (c < 70415
                    ? (c >= 70405 && c <= 70412)
                    : c <= 70416)
                  : (c <= 70440 || (c < 70450
                    ? (c >= 70442 && c <= 70448)
                    : c <= 70451)))))))
            : (c <= 70457 || (c < 70784
              ? (c < 70493
                ? (c < 70475
                  ? (c < 70471
                    ? (c >= 70459 && c <= 70468)
                    : c <= 70472)
                  : (c <= 70477 || (c < 70487
                    ? c == 70480
                    : c <= 70487)))
                : (c <= 70499 || (c < 70656
                  ? (c < 70512
                    ? (c >= 70502 && c <= 70508)
                    : c <= 70516)
                  : (c <= 70730 || (c < 70750
                    ? (c >= 70736 && c <= 70745)
                    : c <= 70753)))))
              : (c <= 70853 || (c < 71168
                ? (c < 71040
                  ? (c < 70864
                    ? c == 70855
                    : c <= 70873)
                  : (c <= 71093 || (c < 71128
                    ? (c >= 71096 && c <= 71104)
                    : c <= 71133)))
                : (c <= 71232 || (c < 71296
                  ? (c < 71248
                    ? c == 71236
                    : c <= 71257)
                  : (c <= 71352 || (c < 71424
                    ? (c >= 71360 && c <= 71369)
                    : c <= 71450)))))))))))))
      : (c <= 71467 || (c < 119973
        ? (c < 77824
          ? (c < 72760
            ? (c < 72016
              ? (c < 71945
                ? (c < 71680
                  ? (c < 71488
                    ? (c >= 71472 && c <= 71481)
                    : c <= 71494)
                  : (c <= 71738 || (c < 71935
                    ? (c >= 71840 && c <= 71913)
                    : c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71989 || (c < 71995
                    ? (c >= 71991 && c <= 71992)
                    : c <= 72003)))))
              : (c <= 72025 || (c < 72263
                ? (c < 72154
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72151)
                  : (c <= 72161 || (c < 72192
                    ? (c >= 72163 && c <= 72164)
                    : c <= 72254)))
                : (c <= 72263 || (c < 72368
                  ? (c < 72349
                    ? (c >= 72272 && c <= 72345)
                    : c <= 72349)
                  : (c <= 72440 || (c < 72714
                    ? (c >= 72704 && c <= 72712)
                    : c <= 72758)))))))
            : (c <= 72768 || (c < 73056
              ? (c < 72968
                ? (c < 72850
                  ? (c < 72818
                    ? (c >= 72784 && c <= 72793)
                    : c <= 72847)
                  : (c <= 72871 || (c < 72960
                    ? (c >= 72873 && c <= 72886)
                    : c <= 72966)))
                : (c <= 72969 || (c < 73020
                  ? (c < 73018
                    ? (c >= 72971 && c <= 73014)
                    : c <= 73018)
                  : (c <= 73021 || (c < 73040
                    ? (c >= 73023 && c <= 73031)
                    : c <= 73049)))))
              : (c <= 73061 || (c < 73440
                ? (c < 73104
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73102)
                  : (c <= 73105 || (c < 73120
                    ? (c >= 73107 && c <= 73112)
                    : c <= 73129)))
                : (c <= 73462 || (c < 74752
                  ? (c < 73728
                    ? c == 73648
                    : c <= 74649)
                  : (c <= 74862 || (c < 77712
                    ? (c >= 74880 && c <= 75075)
                    : c <= 77808)))))))))
          : (c <= 78894 || (c < 110576
            ? (c < 93027
              ? (c < 92864
                ? (c < 92736
                  ? (c < 92160
                    ? (c >= 82944 && c <= 83526)
                    : c <= 92728)
                  : (c <= 92766 || (c < 92784
                    ? (c >= 92768 && c <= 92777)
                    : c <= 92862)))
                : (c <= 92873 || (c < 92928
                  ? (c < 92912
                    ? (c >= 92880 && c <= 92909)
                    : c <= 92916)
                  : (c <= 92982 || (c < 93008
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93017)))))
              : (c <= 93047 || (c < 94176
                ? (c < 93952
                  ? (c < 93760
                    ? (c >= 93053 && c <= 93071)
                    : c <= 93823)
                  : (c <= 94026 || (c < 94095
                    ? (c >= 94031 && c <= 94087)
                    : c <= 94111)))
                : (c <= 94177 || (c < 94208
                  ? (c < 94192
                    ? (c >= 94179 && c <= 94180)
                    : c <= 94193)
                  : (c <= 100343 || (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)))))))
            : (c <= 110579 || (c < 118528
              ? (c < 110960
                ? (c < 110592
                  ? (c < 110589
                    ? (c >= 110581 && c <= 110587)
                    : c <= 110590)
                  : (c <= 110882 || (c < 110948
                    ? (c >= 110928 && c <= 110930)
                    : c <= 110951)))
                : (c <= 111355 || (c < 113792
                  ? (c < 113776
                    ? (c >= 113664 && c <= 113770)
                    : c <= 113788)
                  : (c <= 113800 || (c < 113821
                    ? (c >= 113808 && c <= 113817)
                    : c <= 113822)))))
              : (c <= 118573 || (c < 119210
                ? (c < 119149
                  ? (c < 119141
                    ? (c >= 118576 && c <= 118598)
                    : c <= 119145)
                  : (c <= 119154 || (c < 119173
                    ? (c >= 119163 && c <= 119170)
                    : c <= 119179)))
                : (c <= 119213 || (c < 119894
                  ? (c < 119808
                    ? (c >= 119362 && c <= 119364)
                    : c <= 119892)
                  : (c <= 119964 || (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)))))))))))
        : (c <= 119974 || (c < 124912
          ? (c < 120746
            ? (c < 120134
              ? (c < 120071
                ? (c < 119995
                  ? (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)
                  : (c <= 119995 || (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)))
                : (c <= 120074 || (c < 120094
                  ? (c < 120086
                    ? (c >= 120077 && c <= 120084)
                    : c <= 120092)
                  : (c <= 120121 || (c < 120128
                    ? (c >= 120123 && c <= 120126)
                    : c <= 120132)))))
              : (c <= 120134 || (c < 120572
                ? (c < 120488
                  ? (c < 120146
                    ? (c >= 120138 && c <= 120144)
                    : c <= 120485)
                  : (c <= 120512 || (c < 120540
                    ? (c >= 120514 && c <= 120538)
                    : c <= 120570)))
                : (c <= 120596 || (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c < 120714
                    ? (c >= 120688 && c <= 120712)
                    : c <= 120744)))))))
            : (c <= 120770 || (c < 122907
              ? (c < 121476
                ? (c < 121344
                  ? (c < 120782
                    ? (c >= 120772 && c <= 120779)
                    : c <= 120831)
                  : (c <= 121398 || (c < 121461
                    ? (c >= 121403 && c <= 121452)
                    : c <= 121461)))
                : (c <= 121476 || (c < 122624
                  ? (c < 121505
                    ? (c >= 121499 && c <= 121503)
                    : c <= 121519)
                  : (c <= 122654 || (c < 122888
                    ? (c >= 122880 && c <= 122886)
                    : c <= 122904)))))
              : (c <= 122913 || (c < 123214
                ? (c < 123136
                  ? (c < 122918
                    ? (c >= 122915 && c <= 122916)
                    : c <= 122922)
                  : (c <= 123180 || (c < 123200
                    ? (c >= 123184 && c <= 123197)
                    : c <= 123209)))
                : (c <= 123214 || (c < 124896
                  ? (c < 123584
                    ? (c >= 123536 && c <= 123566)
                    : c <= 123641)
                  : (c <= 124902 || (c < 124909
                    ? (c >= 124904 && c <= 124907)
                    : c <= 124910)))))))))
          : (c <= 124926 || (c < 126557
            ? (c < 126521
              ? (c < 126469
                ? (c < 125184
                  ? (c < 125136
                    ? (c >= 124928 && c <= 125124)
                    : c <= 125142)
                  : (c <= 125259 || (c < 126464
                    ? (c >= 125264 && c <= 125273)
                    : c <= 126467)))
                : (c <= 126495 || (c < 126503
                  ? (c < 126500
                    ? (c >= 126497 && c <= 126498)
                    : c <= 126500)
                  : (c <= 126503 || (c < 126516
                    ? (c >= 126505 && c <= 126514)
                    : c <= 126519)))))
              : (c <= 126521 || (c < 126541
                ? (c < 126535
                  ? (c < 126530
                    ? c == 126523
                    : c <= 126530)
                  : (c <= 126535 || (c < 126539
                    ? c == 126537
                    : c <= 126539)))
                : (c <= 126543 || (c < 126551
                  ? (c < 126548
                    ? (c >= 126545 && c <= 126546)
                    : c <= 126548)
                  : (c <= 126551 || (c < 126555
                    ? c == 126553
                    : c <= 126555)))))))
            : (c <= 126557 || (c < 126629
              ? (c < 126580
                ? (c < 126564
                  ? (c < 126561
                    ? c == 126559
                    : c <= 126562)
                  : (c <= 126564 || (c < 126572
                    ? (c >= 126567 && c <= 126570)
                    : c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c < 126625
                    ? (c >= 126603 && c <= 126619)
                    : c <= 126627)))))
              : (c <= 126633 || (c < 178208
                ? (c < 131072
                  ? (c < 130032
                    ? (c >= 126635 && c <= 126651)
                    : c <= 130041)
                  : (c <= 173791 || (c < 177984
                    ? (c >= 173824 && c <= 177976)
                    : c <= 178205)))
                : (c <= 183969 || (c < 196608
                  ? (c < 194560
                    ? (c >= 183984 && c <= 191456)
                    : c <= 195101)
                  : (c <= 201546 || (c >= 917760 && c <= 917999)))))))))))))))));
}

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(69);
      if (lookahead == '!') ADVANCE(182);
      if (lookahead == '"') ADVANCE(102);
      if (lookahead == '%') ADVANCE(171);
      if (lookahead == '&') ADVANCE(131);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(162);
      if (lookahead == '+') ADVANCE(158);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(190);
      if (lookahead == '/') ADVANCE(164);
      if (lookahead == '0') ADVANCE(71);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(149);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(146);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(196);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == '\\') ADVANCE(43);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(169);
      if (lookahead == 'n') ADVANCE(202);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(166);
      if (lookahead == '}') ADVANCE(119);
      if (lookahead == '~') ADVANCE(183);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(203);
      END_STATE();
    case 1:
      if (lookahead == '!') ADVANCE(182);
      if (lookahead == '"') ADVANCE(102);
      if (lookahead == '%') ADVANCE(171);
      if (lookahead == '&') ADVANCE(131);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(162);
      if (lookahead == '+') ADVANCE(158);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(190);
      if (lookahead == '/') ADVANCE(164);
      if (lookahead == '0') ADVANCE(71);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(149);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(146);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(195);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(169);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(166);
      if (lookahead == '}') ADVANCE(119);
      if (lookahead == '~') ADVANCE(183);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(203);
      END_STATE();
    case 2:
      if (lookahead == '!') ADVANCE(182);
      if (lookahead == '"') ADVANCE(102);
      if (lookahead == '%') ADVANCE(171);
      if (lookahead == '&') ADVANCE(131);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(162);
      if (lookahead == '+') ADVANCE(158);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(191);
      if (lookahead == '/') ADVANCE(164);
      if (lookahead == '0') ADVANCE(71);
      if (lookahead == ':') ADVANCE(19);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(149);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(146);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(195);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == '^') ADVANCE(169);
      if (lookahead == 'n') ADVANCE(202);
      if (lookahead == '|') ADVANCE(166);
      if (lookahead == '}') ADVANCE(119);
      if (lookahead == '~') ADVANCE(183);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(203);
      END_STATE();
    case 3:
      if (lookahead == '!') ADVANCE(20);
      if (lookahead == '%') ADVANCE(170);
      if (lookahead == '&') ADVANCE(130);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead == '+') ADVANCE(157);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '.') ADVANCE(188);
      if (lookahead == '/') ADVANCE(163);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(150);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(147);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(195);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(168);
      if (lookahead == 'n') ADVANCE(202);
      if (lookahead == '|') ADVANCE(167);
      if (lookahead == '}') ADVANCE(119);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3)
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(203);
      END_STATE();
    case 4:
      if (lookahead == '!') ADVANCE(20);
      if (lookahead == '%') ADVANCE(170);
      if (lookahead == '&') ADVANCE(130);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead == '+') ADVANCE(157);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '.') ADVANCE(188);
      if (lookahead == '/') ADVANCE(163);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(150);
      if (lookahead == '=') ADVANCE(21);
      if (lookahead == '>') ADVANCE(147);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(195);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(168);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(167);
      if (lookahead == '}') ADVANCE(119);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4)
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(203);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(103);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(116);
      if (lookahead == '/') ADVANCE(111);
      if (lookahead == '\\') ADVANCE(43);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(114);
      if (lookahead != 0) ADVANCE(115);
      END_STATE();
    case 7:
      if (lookahead == '"') ADVANCE(117);
      END_STATE();
    case 8:
      if (lookahead == '"') ADVANCE(101);
      if (lookahead == '/') ADVANCE(105);
      if (lookahead == '\\') ADVANCE(44);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(108);
      if (lookahead != 0) ADVANCE(109);
      END_STATE();
    case 9:
      if (lookahead == '&') ADVANCE(129);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '.') ADVANCE(189);
      if (lookahead == '/') ADVANCE(11);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(148);
      if (lookahead == '=') ADVANCE(132);
      if (lookahead == '>') ADVANCE(145);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(195);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(165);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9)
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(203);
      END_STATE();
    case 10:
      if (lookahead == '\'') ADVANCE(100);
      if (lookahead == '\\') ADVANCE(66);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(10);
      END_STATE();
    case 11:
      if (lookahead == '*') ADVANCE(13);
      if (lookahead == '/') ADVANCE(204);
      END_STATE();
    case 12:
      if (lookahead == '*') ADVANCE(12);
      if (lookahead == '/') ADVANCE(205);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 13:
      if (lookahead == '*') ADVANCE(12);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == '_') ADVANCE(54);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(14);
      END_STATE();
    case 15:
      if (lookahead == '.') ADVANCE(199);
      END_STATE();
    case 16:
      if (lookahead == '.') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 17:
      if (lookahead == '/') ADVANCE(11);
      if (lookahead == '<') ADVANCE(148);
      if (lookahead == '@') ADVANCE(37);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17)
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(203);
      END_STATE();
    case 18:
      if (lookahead == '0') ADVANCE(99);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(96);
      END_STATE();
    case 19:
      if (lookahead == ':') ADVANCE(192);
      END_STATE();
    case 20:
      if (lookahead == '=') ADVANCE(154);
      END_STATE();
    case 21:
      if (lookahead == '=') ADVANCE(153);
      END_STATE();
    case 22:
      if (lookahead == '\\') ADVANCE(66);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(10);
      END_STATE();
    case 23:
      if (lookahead == '_') ADVANCE(23);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(74);
      END_STATE();
    case 24:
      if (lookahead == '_') ADVANCE(23);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(72);
      END_STATE();
    case 25:
      if (lookahead == '_') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(77);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 26:
      if (lookahead == '_') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(95);
      END_STATE();
    case 27:
      if (lookahead == '_') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(94);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(38);
      END_STATE();
    case 29:
      if (lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 30:
      if (lookahead == 'c') ADVANCE(35);
      END_STATE();
    case 31:
      if (lookahead == 'd') ADVANCE(197);
      END_STATE();
    case 32:
      if (lookahead == 'e') ADVANCE(40);
      END_STATE();
    case 33:
      if (lookahead == 'e') ADVANCE(28);
      END_STATE();
    case 34:
      if (lookahead == 'e') ADVANCE(31);
      END_STATE();
    case 35:
      if (lookahead == 'e') ADVANCE(198);
      END_STATE();
    case 36:
      if (lookahead == 'f') ADVANCE(29);
      END_STATE();
    case 37:
      if (lookahead == 'i') ADVANCE(39);
      END_STATE();
    case 38:
      if (lookahead == 'l') ADVANCE(34);
      END_STATE();
    case 39:
      if (lookahead == 'n') ADVANCE(42);
      END_STATE();
    case 40:
      if (lookahead == 'r') ADVANCE(36);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(33);
      END_STATE();
    case 42:
      if (lookahead == 't') ADVANCE(32);
      END_STATE();
    case 43:
      if (lookahead == 'u') ADVANCE(121);
      if (lookahead == 'x') ADVANCE(123);
      if (lookahead == '{') ADVANCE(118);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(122);
      if (lookahead == '"' ||
          lookahead == '\'' ||
          lookahead == '\\' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          ('r' <= lookahead && lookahead <= 't')) ADVANCE(124);
      if (lookahead != 0) ADVANCE(120);
      END_STATE();
    case 44:
      if (lookahead == 'u') ADVANCE(46);
      if (lookahead == 'x') ADVANCE(64);
      if (lookahead == '{') ADVANCE(118);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(126);
      if (lookahead != 0) ADVANCE(124);
      END_STATE();
    case 45:
      if (lookahead == '{') ADVANCE(118);
      END_STATE();
    case 46:
      if (lookahead == '{') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(65);
      END_STATE();
    case 47:
      if (lookahead == '}') ADVANCE(124);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(47);
      END_STATE();
    case 48:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(18);
      if (lookahead == '0') ADVANCE(99);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(96);
      END_STATE();
    case 49:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 50:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(85);
      END_STATE();
    case 51:
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(14);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(82);
      END_STATE();
    case 52:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(83);
      END_STATE();
    case 53:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 54:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(14);
      END_STATE();
    case 55:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 56:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(72);
      END_STATE();
    case 57:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(77);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 58:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(95);
      END_STATE();
    case 59:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(94);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 60:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(124);
      END_STATE();
    case 61:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 62:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 63:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(47);
      END_STATE();
    case 64:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(60);
      END_STATE();
    case 65:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(64);
      END_STATE();
    case 66:
      if (lookahead != 0) ADVANCE(10);
      END_STATE();
    case 67:
      if (eof) ADVANCE(69);
      if (lookahead == '!') ADVANCE(182);
      if (lookahead == '"') ADVANCE(102);
      if (lookahead == '%') ADVANCE(171);
      if (lookahead == '&') ADVANCE(131);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(162);
      if (lookahead == '+') ADVANCE(158);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(190);
      if (lookahead == '/') ADVANCE(164);
      if (lookahead == '0') ADVANCE(71);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(149);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(146);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(196);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(169);
      if (lookahead == 'n') ADVANCE(202);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(166);
      if (lookahead == '}') ADVANCE(119);
      if (lookahead == '~') ADVANCE(183);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(203);
      END_STATE();
    case 68:
      if (eof) ADVANCE(69);
      if (lookahead == '!') ADVANCE(182);
      if (lookahead == '"') ADVANCE(102);
      if (lookahead == '%') ADVANCE(170);
      if (lookahead == '&') ADVANCE(130);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(127);
      if (lookahead == ')') ADVANCE(128);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead == '+') ADVANCE(157);
      if (lookahead == ',') ADVANCE(179);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '.') ADVANCE(191);
      if (lookahead == '/') ADVANCE(163);
      if (lookahead == '0') ADVANCE(71);
      if (lookahead == ':') ADVANCE(181);
      if (lookahead == ';') ADVANCE(194);
      if (lookahead == '<') ADVANCE(150);
      if (lookahead == '=') ADVANCE(21);
      if (lookahead == '>') ADVANCE(147);
      if (lookahead == '?') ADVANCE(180);
      if (lookahead == '@') ADVANCE(196);
      if (lookahead == '[') ADVANCE(186);
      if (lookahead == ']') ADVANCE(187);
      if (lookahead == '^') ADVANCE(168);
      if (lookahead == 'n') ADVANCE(202);
      if (lookahead == '{') ADVANCE(193);
      if (lookahead == '|') ADVANCE(167);
      if (lookahead == '}') ADVANCE(119);
      if (lookahead == '~') ADVANCE(183);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(203);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_decimal_integer_literal);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_decimal_integer_literal);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(50);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(70);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(52);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(16);
      if (lookahead == '_') ADVANCE(54);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(49);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(14);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(82);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_decimal_integer_literal);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(70);
      if (lookahead == '_') ADVANCE(24);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(49);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(72);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_decimal_integer_literal);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(70);
      if (lookahead == '_') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(49);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(72);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_decimal_integer_literal);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(70);
      if (lookahead == '_') ADVANCE(23);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(49);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      if (lookahead == '.') ADVANCE(98);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      if (lookahead == '_') ADVANCE(57);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(79);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(77);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      if (lookahead == '.') ADVANCE(98);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      if (lookahead == '_') ADVANCE(25);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(79);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(77);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      if (lookahead == '.') ADVANCE(98);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(79);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      if (lookahead == '.') ADVANCE(98);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(sym_hex_integer_literal);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(18);
      if (lookahead == '.') ADVANCE(98);
      if (lookahead == '0') ADVANCE(78);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(75);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(80);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(76);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(79);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_octal_integer_literal);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_octal_integer_literal);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(81);
      if (lookahead == '_') ADVANCE(51);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(14);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(82);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(sym_octal_integer_literal);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(81);
      if (lookahead == '_') ADVANCE(52);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(83);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_binary_integer_literal);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_binary_integer_literal);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(84);
      if (lookahead == '_') ADVANCE(50);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(85);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_decimal_floating_point_literal);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_decimal_floating_point_literal);
      if (lookahead == '_') ADVANCE(53);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_decimal_floating_point_literal);
      if (lookahead == '_') ADVANCE(55);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_decimal_floating_point_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(49);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(62);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(92);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(62);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(59);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      if (('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(94);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(27);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      if (('A' <= lookahead && lookahead <= 'C') ||
          ('a' <= lookahead && lookahead <= 'c')) ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(94);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(26);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(95);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '_') ADVANCE(58);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(95);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(18);
      if (lookahead == '0') ADVANCE(91);
      if (lookahead == '_') ADVANCE(62);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(93);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(48);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(92);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(sym_hex_floating_point_literal);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(90);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(sym_character_literal);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(5);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE_DQUOTE);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead == '\n') ADVANCE(109);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(104);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead == '*') ADVANCE(107);
      if (lookahead == '/') ADVANCE(104);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(109);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead == '*') ADVANCE(106);
      if (lookahead == '/') ADVANCE(109);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(107);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead == '*') ADVANCE(106);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(107);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead == '/') ADVANCE(105);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(108);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(109);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(109);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead == '\n') ADVANCE(115);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(204);
      if (lookahead != 0) ADVANCE(110);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead == '*') ADVANCE(113);
      if (lookahead == '/') ADVANCE(110);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(115);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead == '*') ADVANCE(112);
      if (lookahead == '/') ADVANCE(115);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(13);
      if (lookahead != 0) ADVANCE(113);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead == '*') ADVANCE(112);
      if (lookahead == '"' ||
          lookahead == '\\') ADVANCE(13);
      if (lookahead != 0) ADVANCE(113);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead == '/') ADVANCE(111);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(114);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(115);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(115);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token2);
      if (lookahead == '"') ADVANCE(5);
      if (lookahead == '\\') ADVANCE(7);
      if (lookahead != 0) ADVANCE(117);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(aux_sym__multiline_string_fragment_token2);
      if (lookahead == '\\') ADVANCE(7);
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(117);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_BSLASH_LBRACE);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      if (lookahead == '{') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(65);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(125);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(60);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(124);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(125);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(155);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(155);
      if (lookahead == '=') ADVANCE(138);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(153);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(151);
      if (lookahead == '>') ADVANCE(174);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(151);
      if (lookahead == '>') ADVANCE(175);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(173);
      if (lookahead == '=') ADVANCE(152);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(172);
      if (lookahead == '=') ADVANCE(152);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(184);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(184);
      if (lookahead == '=') ADVANCE(134);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(185);
      if (lookahead == '=') ADVANCE(135);
      if (lookahead == '>') ADVANCE(178);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(185);
      if (lookahead == '>') ADVANCE(178);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(136);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(13);
      if (lookahead == '/') ADVANCE(204);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(13);
      if (lookahead == '/') ADVANCE(204);
      if (lookahead == '=') ADVANCE(137);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(139);
      if (lookahead == '|') ADVANCE(156);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(156);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(141);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(142);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(143);
      if (lookahead == '>') ADVANCE(177);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(176);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(144);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(192);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(154);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(15);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(87);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == 'i') ADVANCE(39);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_non_DASHsealed);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_ATinterface);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(41);
      if (sym_identifier_character_set_4(lookahead)) ADVANCE(203);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(200);
      if (sym_identifier_character_set_4(lookahead)) ADVANCE(203);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(201);
      if (sym_identifier_character_set_4(lookahead)) ADVANCE(203);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_identifier);
      if (sym_identifier_character_set_4(lookahead)) ADVANCE(203);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(204);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_block_comment);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == '_') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(2);
      if (lookahead == 'b') ADVANCE(3);
      if (lookahead == 'c') ADVANCE(4);
      if (lookahead == 'd') ADVANCE(5);
      if (lookahead == 'e') ADVANCE(6);
      if (lookahead == 'f') ADVANCE(7);
      if (lookahead == 'i') ADVANCE(8);
      if (lookahead == 'l') ADVANCE(9);
      if (lookahead == 'm') ADVANCE(10);
      if (lookahead == 'n') ADVANCE(11);
      if (lookahead == 'o') ADVANCE(12);
      if (lookahead == 'p') ADVANCE(13);
      if (lookahead == 'r') ADVANCE(14);
      if (lookahead == 's') ADVANCE(15);
      if (lookahead == 't') ADVANCE(16);
      if (lookahead == 'u') ADVANCE(17);
      if (lookahead == 'v') ADVANCE(18);
      if (lookahead == 'w') ADVANCE(19);
      if (lookahead == 'y') ADVANCE(20);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0)
      END_STATE();
    case 1:
      ACCEPT_TOKEN(sym_underscore_pattern);
      END_STATE();
    case 2:
      if (lookahead == 'b') ADVANCE(21);
      if (lookahead == 's') ADVANCE(22);
      END_STATE();
    case 3:
      if (lookahead == 'o') ADVANCE(23);
      if (lookahead == 'r') ADVANCE(24);
      if (lookahead == 'y') ADVANCE(25);
      END_STATE();
    case 4:
      if (lookahead == 'a') ADVANCE(26);
      if (lookahead == 'h') ADVANCE(27);
      if (lookahead == 'l') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(29);
      END_STATE();
    case 5:
      if (lookahead == 'e') ADVANCE(30);
      if (lookahead == 'o') ADVANCE(31);
      END_STATE();
    case 6:
      if (lookahead == 'l') ADVANCE(32);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'x') ADVANCE(34);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(35);
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'l') ADVANCE(37);
      if (lookahead == 'o') ADVANCE(38);
      END_STATE();
    case 8:
      if (lookahead == 'f') ADVANCE(39);
      if (lookahead == 'm') ADVANCE(40);
      if (lookahead == 'n') ADVANCE(41);
      END_STATE();
    case 9:
      if (lookahead == 'o') ADVANCE(42);
      END_STATE();
    case 10:
      if (lookahead == 'o') ADVANCE(43);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(44);
      if (lookahead == 'e') ADVANCE(45);
      if (lookahead == 'u') ADVANCE(46);
      END_STATE();
    case 12:
      if (lookahead == 'p') ADVANCE(47);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(48);
      if (lookahead == 'e') ADVANCE(49);
      if (lookahead == 'r') ADVANCE(50);
      if (lookahead == 'u') ADVANCE(51);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(52);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(53);
      if (lookahead == 'h') ADVANCE(54);
      if (lookahead == 't') ADVANCE(55);
      if (lookahead == 'u') ADVANCE(56);
      if (lookahead == 'w') ADVANCE(57);
      if (lookahead == 'y') ADVANCE(58);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(59);
      if (lookahead == 'o') ADVANCE(60);
      if (lookahead == 'r') ADVANCE(61);
      END_STATE();
    case 17:
      if (lookahead == 's') ADVANCE(62);
      END_STATE();
    case 18:
      if (lookahead == 'o') ADVANCE(63);
      END_STATE();
    case 19:
      if (lookahead == 'h') ADVANCE(64);
      if (lookahead == 'i') ADVANCE(65);
      END_STATE();
    case 20:
      if (lookahead == 'i') ADVANCE(66);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(67);
      END_STATE();
    case 22:
      if (lookahead == 's') ADVANCE(68);
      END_STATE();
    case 23:
      if (lookahead == 'o') ADVANCE(69);
      END_STATE();
    case 24:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(71);
      END_STATE();
    case 26:
      if (lookahead == 's') ADVANCE(72);
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 27:
      if (lookahead == 'a') ADVANCE(74);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(75);
      END_STATE();
    case 29:
      if (lookahead == 'n') ADVANCE(76);
      END_STATE();
    case 30:
      if (lookahead == 'f') ADVANCE(77);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_do);
      if (lookahead == 'u') ADVANCE(78);
      END_STATE();
    case 32:
      if (lookahead == 's') ADVANCE(79);
      END_STATE();
    case 33:
      if (lookahead == 'u') ADVANCE(80);
      END_STATE();
    case 34:
      if (lookahead == 'p') ADVANCE(81);
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 35:
      if (lookahead == 'l') ADVANCE(83);
      END_STATE();
    case 36:
      if (lookahead == 'n') ADVANCE(84);
      END_STATE();
    case 37:
      if (lookahead == 'o') ADVANCE(85);
      END_STATE();
    case 38:
      if (lookahead == 'r') ADVANCE(86);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 40:
      if (lookahead == 'p') ADVANCE(87);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(88);
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 42:
      if (lookahead == 'n') ADVANCE(90);
      END_STATE();
    case 43:
      if (lookahead == 'd') ADVANCE(91);
      END_STATE();
    case 44:
      if (lookahead == 't') ADVANCE(92);
      END_STATE();
    case 45:
      if (lookahead == 'w') ADVANCE(93);
      END_STATE();
    case 46:
      if (lookahead == 'l') ADVANCE(94);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(95);
      END_STATE();
    case 48:
      if (lookahead == 'c') ADVANCE(96);
      END_STATE();
    case 49:
      if (lookahead == 'r') ADVANCE(97);
      END_STATE();
    case 50:
      if (lookahead == 'i') ADVANCE(98);
      if (lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 51:
      if (lookahead == 'b') ADVANCE(100);
      END_STATE();
    case 52:
      if (lookahead == 'c') ADVANCE(101);
      if (lookahead == 'q') ADVANCE(102);
      if (lookahead == 't') ADVANCE(103);
      END_STATE();
    case 53:
      if (lookahead == 'a') ADVANCE(104);
      END_STATE();
    case 54:
      if (lookahead == 'o') ADVANCE(105);
      END_STATE();
    case 55:
      if (lookahead == 'a') ADVANCE(106);
      if (lookahead == 'r') ADVANCE(107);
      END_STATE();
    case 56:
      if (lookahead == 'p') ADVANCE(108);
      END_STATE();
    case 57:
      if (lookahead == 'i') ADVANCE(109);
      END_STATE();
    case 58:
      if (lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 59:
      if (lookahead == 'i') ADVANCE(111);
      if (lookahead == 'r') ADVANCE(112);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 61:
      if (lookahead == 'a') ADVANCE(113);
      if (lookahead == 'u') ADVANCE(114);
      if (lookahead == 'y') ADVANCE(115);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(117);
      if (lookahead == 'l') ADVANCE(118);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(119);
      if (lookahead == 'i') ADVANCE(120);
      END_STATE();
    case 65:
      if (lookahead == 't') ADVANCE(121);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(122);
      END_STATE();
    case 67:
      if (lookahead == 't') ADVANCE(123);
      END_STATE();
    case 68:
      if (lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 69:
      if (lookahead == 'l') ADVANCE(125);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(126);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(127);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(128);
      END_STATE();
    case 73:
      if (lookahead == 'c') ADVANCE(129);
      END_STATE();
    case 74:
      if (lookahead == 'r') ADVANCE(130);
      END_STATE();
    case 75:
      if (lookahead == 's') ADVANCE(131);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(132);
      END_STATE();
    case 77:
      if (lookahead == 'a') ADVANCE(133);
      END_STATE();
    case 78:
      if (lookahead == 'b') ADVANCE(134);
      END_STATE();
    case 79:
      if (lookahead == 'e') ADVANCE(135);
      END_STATE();
    case 80:
      if (lookahead == 'm') ADVANCE(136);
      END_STATE();
    case 81:
      if (lookahead == 'o') ADVANCE(137);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 83:
      if (lookahead == 's') ADVANCE(139);
      END_STATE();
    case 84:
      if (lookahead == 'a') ADVANCE(140);
      END_STATE();
    case 85:
      if (lookahead == 'a') ADVANCE(141);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 'o') ADVANCE(143);
      END_STATE();
    case 88:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == 'e') ADVANCE(145);
      END_STATE();
    case 90:
      if (lookahead == 'g') ADVANCE(146);
      END_STATE();
    case 91:
      if (lookahead == 'u') ADVANCE(147);
      END_STATE();
    case 92:
      if (lookahead == 'i') ADVANCE(148);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 94:
      if (lookahead == 'l') ADVANCE(149);
      END_STATE();
    case 95:
      if (lookahead == 'n') ADVANCE(150);
      END_STATE();
    case 96:
      if (lookahead == 'k') ADVANCE(151);
      END_STATE();
    case 97:
      if (lookahead == 'm') ADVANCE(152);
      END_STATE();
    case 98:
      if (lookahead == 'v') ADVANCE(153);
      END_STATE();
    case 99:
      if (lookahead == 't') ADVANCE(154);
      if (lookahead == 'v') ADVANCE(155);
      END_STATE();
    case 100:
      if (lookahead == 'l') ADVANCE(156);
      END_STATE();
    case 101:
      if (lookahead == 'o') ADVANCE(157);
      END_STATE();
    case 102:
      if (lookahead == 'u') ADVANCE(158);
      END_STATE();
    case 103:
      if (lookahead == 'u') ADVANCE(159);
      END_STATE();
    case 104:
      if (lookahead == 'l') ADVANCE(160);
      END_STATE();
    case 105:
      if (lookahead == 'r') ADVANCE(161);
      END_STATE();
    case 106:
      if (lookahead == 't') ADVANCE(162);
      END_STATE();
    case 107:
      if (lookahead == 'i') ADVANCE(163);
      END_STATE();
    case 108:
      if (lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 109:
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 110:
      if (lookahead == 'c') ADVANCE(166);
      END_STATE();
    case 111:
      if (lookahead == 's') ADVANCE(167);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(168);
      END_STATE();
    case 113:
      if (lookahead == 'n') ADVANCE(169);
      END_STATE();
    case 114:
      if (lookahead == 'e') ADVANCE(170);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 116:
      if (lookahead == 's') ADVANCE(171);
      END_STATE();
    case 117:
      if (lookahead == 'd') ADVANCE(172);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(173);
      END_STATE();
    case 119:
      if (lookahead == 'n') ADVANCE(174);
      END_STATE();
    case 120:
      if (lookahead == 'l') ADVANCE(175);
      END_STATE();
    case 121:
      if (lookahead == 'h') ADVANCE(176);
      END_STATE();
    case 122:
      if (lookahead == 'l') ADVANCE(177);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(178);
      END_STATE();
    case 124:
      if (lookahead == 'r') ADVANCE(179);
      END_STATE();
    case 125:
      if (lookahead == 'e') ADVANCE(180);
      END_STATE();
    case 126:
      if (lookahead == 'k') ADVANCE(181);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_byte);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 129:
      if (lookahead == 'h') ADVANCE(182);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_char);
      END_STATE();
    case 131:
      if (lookahead == 's') ADVANCE(183);
      END_STATE();
    case 132:
      if (lookahead == 'i') ADVANCE(184);
      END_STATE();
    case 133:
      if (lookahead == 'u') ADVANCE(185);
      END_STATE();
    case 134:
      if (lookahead == 'l') ADVANCE(186);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 137:
      if (lookahead == 'r') ADVANCE(187);
      END_STATE();
    case 138:
      if (lookahead == 'n') ADVANCE(188);
      END_STATE();
    case 139:
      if (lookahead == 'e') ADVANCE(189);
      END_STATE();
    case 140:
      if (lookahead == 'l') ADVANCE(190);
      END_STATE();
    case 141:
      if (lookahead == 't') ADVANCE(191);
      END_STATE();
    case 142:
      if (lookahead == 'e') ADVANCE(192);
      END_STATE();
    case 143:
      if (lookahead == 'r') ADVANCE(193);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(194);
      END_STATE();
    case 145:
      if (lookahead == 'r') ADVANCE(195);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 147:
      if (lookahead == 'l') ADVANCE(196);
      END_STATE();
    case 148:
      if (lookahead == 'v') ADVANCE(197);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym_null_literal);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_open);
      if (lookahead == 's') ADVANCE(198);
      END_STATE();
    case 151:
      if (lookahead == 'a') ADVANCE(199);
      END_STATE();
    case 152:
      if (lookahead == 'i') ADVANCE(200);
      END_STATE();
    case 153:
      if (lookahead == 'a') ADVANCE(201);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 155:
      if (lookahead == 'i') ADVANCE(203);
      END_STATE();
    case 156:
      if (lookahead == 'i') ADVANCE(204);
      END_STATE();
    case 157:
      if (lookahead == 'r') ADVANCE(205);
      END_STATE();
    case 158:
      if (lookahead == 'i') ADVANCE(206);
      END_STATE();
    case 159:
      if (lookahead == 'r') ADVANCE(207);
      END_STATE();
    case 160:
      if (lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 161:
      if (lookahead == 't') ADVANCE(209);
      END_STATE();
    case 162:
      if (lookahead == 'i') ADVANCE(210);
      END_STATE();
    case 163:
      if (lookahead == 'c') ADVANCE(211);
      END_STATE();
    case 164:
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 165:
      if (lookahead == 'c') ADVANCE(213);
      END_STATE();
    case 166:
      if (lookahead == 'h') ADVANCE(214);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_this);
      END_STATE();
    case 168:
      if (lookahead == 'w') ADVANCE(215);
      END_STATE();
    case 169:
      if (lookahead == 's') ADVANCE(216);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_uses);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_void_type);
      END_STATE();
    case 173:
      if (lookahead == 't') ADVANCE(217);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 175:
      if (lookahead == 'e') ADVANCE(218);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 177:
      if (lookahead == 'd') ADVANCE(219);
      END_STATE();
    case 178:
      if (lookahead == 'a') ADVANCE(220);
      END_STATE();
    case 179:
      if (lookahead == 't') ADVANCE(221);
      END_STATE();
    case 180:
      if (lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 184:
      if (lookahead == 'n') ADVANCE(223);
      END_STATE();
    case 185:
      if (lookahead == 'l') ADVANCE(224);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(225);
      END_STATE();
    case 187:
      if (lookahead == 't') ADVANCE(226);
      END_STATE();
    case 188:
      if (lookahead == 'd') ADVANCE(227);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_final);
      if (lookahead == 'l') ADVANCE(228);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 192:
      if (lookahead == 'm') ADVANCE(229);
      END_STATE();
    case 193:
      if (lookahead == 't') ADVANCE(230);
      END_STATE();
    case 194:
      if (lookahead == 'n') ADVANCE(231);
      END_STATE();
    case 195:
      if (lookahead == 'f') ADVANCE(232);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(234);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_opens);
      END_STATE();
    case 199:
      if (lookahead == 'g') ADVANCE(235);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(236);
      END_STATE();
    case 201:
      if (lookahead == 't') ADVANCE(237);
      END_STATE();
    case 202:
      if (lookahead == 'c') ADVANCE(238);
      END_STATE();
    case 203:
      if (lookahead == 'd') ADVANCE(239);
      END_STATE();
    case 204:
      if (lookahead == 'c') ADVANCE(240);
      END_STATE();
    case 205:
      if (lookahead == 'd') ADVANCE(241);
      END_STATE();
    case 206:
      if (lookahead == 'r') ADVANCE(242);
      END_STATE();
    case 207:
      if (lookahead == 'n') ADVANCE(243);
      END_STATE();
    case 208:
      if (lookahead == 'd') ADVANCE(244);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 210:
      if (lookahead == 'c') ADVANCE(245);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(246);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(sym_super);
      END_STATE();
    case 213:
      if (lookahead == 'h') ADVANCE(247);
      END_STATE();
    case 214:
      if (lookahead == 'r') ADVANCE(248);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_throw);
      if (lookahead == 's') ADVANCE(249);
      END_STATE();
    case 216:
      if (lookahead == 'i') ADVANCE(250);
      END_STATE();
    case 217:
      if (lookahead == 'i') ADVANCE(251);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 220:
      if (lookahead == 'c') ADVANCE(252);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 222:
      if (lookahead == 'n') ADVANCE(253);
      END_STATE();
    case 223:
      if (lookahead == 'u') ADVANCE(254);
      END_STATE();
    case 224:
      if (lookahead == 't') ADVANCE(255);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 226:
      if (lookahead == 's') ADVANCE(256);
      END_STATE();
    case 227:
      if (lookahead == 's') ADVANCE(257);
      END_STATE();
    case 228:
      if (lookahead == 'y') ADVANCE(258);
      END_STATE();
    case 229:
      if (lookahead == 'e') ADVANCE(259);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 231:
      if (lookahead == 'c') ADVANCE(260);
      END_STATE();
    case 232:
      if (lookahead == 'a') ADVANCE(261);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_native);
      END_STATE();
    case 235:
      if (lookahead == 'e') ADVANCE(262);
      END_STATE();
    case 236:
      if (lookahead == 's') ADVANCE(263);
      END_STATE();
    case 237:
      if (lookahead == 'e') ADVANCE(264);
      END_STATE();
    case 238:
      if (lookahead == 't') ADVANCE(265);
      END_STATE();
    case 239:
      if (lookahead == 'e') ADVANCE(266);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_record);
      END_STATE();
    case 242:
      if (lookahead == 'e') ADVANCE(267);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_sealed);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 246:
      if (lookahead == 'f') ADVANCE(268);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 248:
      if (lookahead == 'o') ADVANCE(269);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_throws);
      END_STATE();
    case 250:
      if (lookahead == 'e') ADVANCE(270);
      if (lookahead == 't') ADVANCE(271);
      END_STATE();
    case 251:
      if (lookahead == 'l') ADVANCE(272);
      END_STATE();
    case 252:
      if (lookahead == 't') ADVANCE(273);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(sym_boolean_type);
      END_STATE();
    case 254:
      if (lookahead == 'e') ADVANCE(274);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_exports);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 259:
      if (lookahead == 'n') ADVANCE(275);
      END_STATE();
    case 260:
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 261:
      if (lookahead == 'c') ADVANCE(277);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_permits);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 265:
      if (lookahead == 'e') ADVANCE(278);
      END_STATE();
    case 266:
      if (lookahead == 's') ADVANCE(279);
      END_STATE();
    case 267:
      if (lookahead == 's') ADVANCE(280);
      END_STATE();
    case 268:
      if (lookahead == 'p') ADVANCE(281);
      END_STATE();
    case 269:
      if (lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 270:
      if (lookahead == 'n') ADVANCE(283);
      END_STATE();
    case 271:
      if (lookahead == 'i') ADVANCE(284);
      END_STATE();
    case 272:
      if (lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 275:
      if (lookahead == 't') ADVANCE(286);
      END_STATE();
    case 276:
      if (lookahead == 'o') ADVANCE(287);
      END_STATE();
    case 277:
      if (lookahead == 'e') ADVANCE(288);
      END_STATE();
    case 278:
      if (lookahead == 'd') ADVANCE(289);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_provides);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_requires);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_strictfp);
      END_STATE();
    case 282:
      if (lookahead == 'i') ADVANCE(290);
      END_STATE();
    case 283:
      if (lookahead == 't') ADVANCE(291);
      END_STATE();
    case 284:
      if (lookahead == 'v') ADVANCE(292);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 286:
      if (lookahead == 's') ADVANCE(293);
      END_STATE();
    case 287:
      if (lookahead == 'f') ADVANCE(294);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 290:
      if (lookahead == 'z') ADVANCE(295);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_transient);
      END_STATE();
    case 292:
      if (lookahead == 'e') ADVANCE(296);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_instanceof);
      END_STATE();
    case 295:
      if (lookahead == 'e') ADVANCE(297);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_transitive);
      END_STATE();
    case 297:
      if (lookahead == 'd') ADVANCE(298);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_synchronized);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 0},
  [4] = {.lex_state = 0},
  [5] = {.lex_state = 0},
  [6] = {.lex_state = 0},
  [7] = {.lex_state = 0},
  [8] = {.lex_state = 0},
  [9] = {.lex_state = 0},
  [10] = {.lex_state = 0},
  [11] = {.lex_state = 0},
  [12] = {.lex_state = 0},
  [13] = {.lex_state = 0},
  [14] = {.lex_state = 0},
  [15] = {.lex_state = 0},
  [16] = {.lex_state = 0},
  [17] = {.lex_state = 0},
  [18] = {.lex_state = 0},
  [19] = {.lex_state = 0},
  [20] = {.lex_state = 0},
  [21] = {.lex_state = 0},
  [22] = {.lex_state = 0},
  [23] = {.lex_state = 0},
  [24] = {.lex_state = 0},
  [25] = {.lex_state = 0},
  [26] = {.lex_state = 0},
  [27] = {.lex_state = 0},
  [28] = {.lex_state = 0},
  [29] = {.lex_state = 0},
  [30] = {.lex_state = 0},
  [31] = {.lex_state = 0},
  [32] = {.lex_state = 0},
  [33] = {.lex_state = 0},
  [34] = {.lex_state = 0},
  [35] = {.lex_state = 0},
  [36] = {.lex_state = 0},
  [37] = {.lex_state = 0},
  [38] = {.lex_state = 0},
  [39] = {.lex_state = 0},
  [40] = {.lex_state = 0},
  [41] = {.lex_state = 0},
  [42] = {.lex_state = 0},
  [43] = {.lex_state = 0},
  [44] = {.lex_state = 0},
  [45] = {.lex_state = 0},
  [46] = {.lex_state = 0},
  [47] = {.lex_state = 0},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 0},
  [50] = {.lex_state = 0},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 0},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 0},
  [55] = {.lex_state = 0},
  [56] = {.lex_state = 0},
  [57] = {.lex_state = 0},
  [58] = {.lex_state = 0},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 0},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 0},
  [63] = {.lex_state = 0},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 0},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 0},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 0},
  [81] = {.lex_state = 0},
  [82] = {.lex_state = 0},
  [83] = {.lex_state = 0},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 0},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 0},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 0},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 0},
  [105] = {.lex_state = 0},
  [106] = {.lex_state = 1},
  [107] = {.lex_state = 68},
  [108] = {.lex_state = 68},
  [109] = {.lex_state = 68},
  [110] = {.lex_state = 68},
  [111] = {.lex_state = 68},
  [112] = {.lex_state = 68},
  [113] = {.lex_state = 68},
  [114] = {.lex_state = 68},
  [115] = {.lex_state = 2},
  [116] = {.lex_state = 2},
  [117] = {.lex_state = 2},
  [118] = {.lex_state = 2},
  [119] = {.lex_state = 2},
  [120] = {.lex_state = 2},
  [121] = {.lex_state = 68},
  [122] = {.lex_state = 68},
  [123] = {.lex_state = 1},
  [124] = {.lex_state = 1},
  [125] = {.lex_state = 1},
  [126] = {.lex_state = 1},
  [127] = {.lex_state = 1},
  [128] = {.lex_state = 1},
  [129] = {.lex_state = 1},
  [130] = {.lex_state = 1},
  [131] = {.lex_state = 1},
  [132] = {.lex_state = 1},
  [133] = {.lex_state = 1},
  [134] = {.lex_state = 1},
  [135] = {.lex_state = 1},
  [136] = {.lex_state = 1},
  [137] = {.lex_state = 1},
  [138] = {.lex_state = 0},
  [139] = {.lex_state = 1},
  [140] = {.lex_state = 1},
  [141] = {.lex_state = 1},
  [142] = {.lex_state = 1},
  [143] = {.lex_state = 1},
  [144] = {.lex_state = 1},
  [145] = {.lex_state = 1},
  [146] = {.lex_state = 1},
  [147] = {.lex_state = 1},
  [148] = {.lex_state = 1},
  [149] = {.lex_state = 1},
  [150] = {.lex_state = 1},
  [151] = {.lex_state = 1},
  [152] = {.lex_state = 1},
  [153] = {.lex_state = 1},
  [154] = {.lex_state = 1},
  [155] = {.lex_state = 1},
  [156] = {.lex_state = 1},
  [157] = {.lex_state = 0},
  [158] = {.lex_state = 1},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 1},
  [161] = {.lex_state = 1},
  [162] = {.lex_state = 1},
  [163] = {.lex_state = 1},
  [164] = {.lex_state = 1},
  [165] = {.lex_state = 1},
  [166] = {.lex_state = 1},
  [167] = {.lex_state = 1},
  [168] = {.lex_state = 1},
  [169] = {.lex_state = 1},
  [170] = {.lex_state = 1},
  [171] = {.lex_state = 1},
  [172] = {.lex_state = 1},
  [173] = {.lex_state = 1},
  [174] = {.lex_state = 1},
  [175] = {.lex_state = 1},
  [176] = {.lex_state = 1},
  [177] = {.lex_state = 1},
  [178] = {.lex_state = 1},
  [179] = {.lex_state = 0},
  [180] = {.lex_state = 1},
  [181] = {.lex_state = 1},
  [182] = {.lex_state = 1},
  [183] = {.lex_state = 1},
  [184] = {.lex_state = 1},
  [185] = {.lex_state = 0},
  [186] = {.lex_state = 1},
  [187] = {.lex_state = 1},
  [188] = {.lex_state = 1},
  [189] = {.lex_state = 1},
  [190] = {.lex_state = 1},
  [191] = {.lex_state = 1},
  [192] = {.lex_state = 1},
  [193] = {.lex_state = 1},
  [194] = {.lex_state = 1},
  [195] = {.lex_state = 1},
  [196] = {.lex_state = 1},
  [197] = {.lex_state = 1},
  [198] = {.lex_state = 1},
  [199] = {.lex_state = 1},
  [200] = {.lex_state = 1},
  [201] = {.lex_state = 1},
  [202] = {.lex_state = 1},
  [203] = {.lex_state = 1},
  [204] = {.lex_state = 1},
  [205] = {.lex_state = 1},
  [206] = {.lex_state = 0},
  [207] = {.lex_state = 1},
  [208] = {.lex_state = 1},
  [209] = {.lex_state = 1},
  [210] = {.lex_state = 1},
  [211] = {.lex_state = 1},
  [212] = {.lex_state = 1},
  [213] = {.lex_state = 1},
  [214] = {.lex_state = 1},
  [215] = {.lex_state = 1},
  [216] = {.lex_state = 1},
  [217] = {.lex_state = 1},
  [218] = {.lex_state = 1},
  [219] = {.lex_state = 1},
  [220] = {.lex_state = 1},
  [221] = {.lex_state = 1},
  [222] = {.lex_state = 1},
  [223] = {.lex_state = 1},
  [224] = {.lex_state = 1},
  [225] = {.lex_state = 1},
  [226] = {.lex_state = 1},
  [227] = {.lex_state = 1},
  [228] = {.lex_state = 1},
  [229] = {.lex_state = 1},
  [230] = {.lex_state = 1},
  [231] = {.lex_state = 1},
  [232] = {.lex_state = 1},
  [233] = {.lex_state = 1},
  [234] = {.lex_state = 1},
  [235] = {.lex_state = 1},
  [236] = {.lex_state = 1},
  [237] = {.lex_state = 1},
  [238] = {.lex_state = 1},
  [239] = {.lex_state = 1},
  [240] = {.lex_state = 1},
  [241] = {.lex_state = 1},
  [242] = {.lex_state = 1},
  [243] = {.lex_state = 1},
  [244] = {.lex_state = 1},
  [245] = {.lex_state = 1},
  [246] = {.lex_state = 1},
  [247] = {.lex_state = 1},
  [248] = {.lex_state = 0},
  [249] = {.lex_state = 0},
  [250] = {.lex_state = 0},
  [251] = {.lex_state = 2},
  [252] = {.lex_state = 2},
  [253] = {.lex_state = 2},
  [254] = {.lex_state = 2},
  [255] = {.lex_state = 0},
  [256] = {.lex_state = 0},
  [257] = {.lex_state = 0},
  [258] = {.lex_state = 0},
  [259] = {.lex_state = 0},
  [260] = {.lex_state = 0},
  [261] = {.lex_state = 0},
  [262] = {.lex_state = 0},
  [263] = {.lex_state = 0},
  [264] = {.lex_state = 0},
  [265] = {.lex_state = 0},
  [266] = {.lex_state = 0},
  [267] = {.lex_state = 0},
  [268] = {.lex_state = 0},
  [269] = {.lex_state = 0},
  [270] = {.lex_state = 0},
  [271] = {.lex_state = 0},
  [272] = {.lex_state = 0},
  [273] = {.lex_state = 0},
  [274] = {.lex_state = 0},
  [275] = {.lex_state = 0},
  [276] = {.lex_state = 0},
  [277] = {.lex_state = 0},
  [278] = {.lex_state = 0},
  [279] = {.lex_state = 0},
  [280] = {.lex_state = 0},
  [281] = {.lex_state = 0},
  [282] = {.lex_state = 0},
  [283] = {.lex_state = 0},
  [284] = {.lex_state = 0},
  [285] = {.lex_state = 0},
  [286] = {.lex_state = 0},
  [287] = {.lex_state = 0},
  [288] = {.lex_state = 0},
  [289] = {.lex_state = 0},
  [290] = {.lex_state = 0},
  [291] = {.lex_state = 0},
  [292] = {.lex_state = 0},
  [293] = {.lex_state = 0},
  [294] = {.lex_state = 0},
  [295] = {.lex_state = 0},
  [296] = {.lex_state = 0},
  [297] = {.lex_state = 0},
  [298] = {.lex_state = 0},
  [299] = {.lex_state = 0},
  [300] = {.lex_state = 0},
  [301] = {.lex_state = 0},
  [302] = {.lex_state = 0},
  [303] = {.lex_state = 0},
  [304] = {.lex_state = 0},
  [305] = {.lex_state = 0},
  [306] = {.lex_state = 0},
  [307] = {.lex_state = 0},
  [308] = {.lex_state = 0},
  [309] = {.lex_state = 0},
  [310] = {.lex_state = 0},
  [311] = {.lex_state = 0},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 0},
  [314] = {.lex_state = 0},
  [315] = {.lex_state = 0},
  [316] = {.lex_state = 0},
  [317] = {.lex_state = 0},
  [318] = {.lex_state = 0},
  [319] = {.lex_state = 0},
  [320] = {.lex_state = 0},
  [321] = {.lex_state = 0},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 0},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 0},
  [331] = {.lex_state = 0},
  [332] = {.lex_state = 0},
  [333] = {.lex_state = 0},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 0},
  [337] = {.lex_state = 0},
  [338] = {.lex_state = 0},
  [339] = {.lex_state = 0},
  [340] = {.lex_state = 0},
  [341] = {.lex_state = 0},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 0},
  [344] = {.lex_state = 0},
  [345] = {.lex_state = 0},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 0},
  [348] = {.lex_state = 0},
  [349] = {.lex_state = 0},
  [350] = {.lex_state = 0},
  [351] = {.lex_state = 0},
  [352] = {.lex_state = 0},
  [353] = {.lex_state = 0},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 0},
  [357] = {.lex_state = 0},
  [358] = {.lex_state = 0},
  [359] = {.lex_state = 0},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 0},
  [362] = {.lex_state = 0},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 0},
  [365] = {.lex_state = 0},
  [366] = {.lex_state = 0},
  [367] = {.lex_state = 0},
  [368] = {.lex_state = 0},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 0},
  [371] = {.lex_state = 0},
  [372] = {.lex_state = 0},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 0},
  [375] = {.lex_state = 0},
  [376] = {.lex_state = 0},
  [377] = {.lex_state = 0},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 0},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 0},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 0},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 0},
  [390] = {.lex_state = 0},
  [391] = {.lex_state = 0},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 0},
  [394] = {.lex_state = 0},
  [395] = {.lex_state = 0},
  [396] = {.lex_state = 0},
  [397] = {.lex_state = 0},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 0},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 2},
  [403] = {.lex_state = 1},
  [404] = {.lex_state = 1},
  [405] = {.lex_state = 3},
  [406] = {.lex_state = 0},
  [407] = {.lex_state = 0},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 0},
  [411] = {.lex_state = 1},
  [412] = {.lex_state = 1},
  [413] = {.lex_state = 1},
  [414] = {.lex_state = 0},
  [415] = {.lex_state = 1},
  [416] = {.lex_state = 0},
  [417] = {.lex_state = 0},
  [418] = {.lex_state = 1},
  [419] = {.lex_state = 1},
  [420] = {.lex_state = 1},
  [421] = {.lex_state = 1},
  [422] = {.lex_state = 1},
  [423] = {.lex_state = 1},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 0},
  [426] = {.lex_state = 0},
  [427] = {.lex_state = 1},
  [428] = {.lex_state = 1},
  [429] = {.lex_state = 1},
  [430] = {.lex_state = 4},
  [431] = {.lex_state = 4},
  [432] = {.lex_state = 4},
  [433] = {.lex_state = 1},
  [434] = {.lex_state = 1},
  [435] = {.lex_state = 1},
  [436] = {.lex_state = 1},
  [437] = {.lex_state = 4},
  [438] = {.lex_state = 1},
  [439] = {.lex_state = 1},
  [440] = {.lex_state = 1},
  [441] = {.lex_state = 1},
  [442] = {.lex_state = 1},
  [443] = {.lex_state = 1},
  [444] = {.lex_state = 1},
  [445] = {.lex_state = 4},
  [446] = {.lex_state = 4},
  [447] = {.lex_state = 4},
  [448] = {.lex_state = 4},
  [449] = {.lex_state = 4},
  [450] = {.lex_state = 4},
  [451] = {.lex_state = 4},
  [452] = {.lex_state = 4},
  [453] = {.lex_state = 4},
  [454] = {.lex_state = 1},
  [455] = {.lex_state = 4},
  [456] = {.lex_state = 4},
  [457] = {.lex_state = 1},
  [458] = {.lex_state = 1},
  [459] = {.lex_state = 4},
  [460] = {.lex_state = 4},
  [461] = {.lex_state = 4},
  [462] = {.lex_state = 4},
  [463] = {.lex_state = 4},
  [464] = {.lex_state = 4},
  [465] = {.lex_state = 4},
  [466] = {.lex_state = 2},
  [467] = {.lex_state = 4},
  [468] = {.lex_state = 1},
  [469] = {.lex_state = 4},
  [470] = {.lex_state = 0},
  [471] = {.lex_state = 1},
  [472] = {.lex_state = 4},
  [473] = {.lex_state = 4},
  [474] = {.lex_state = 4},
  [475] = {.lex_state = 4},
  [476] = {.lex_state = 4},
  [477] = {.lex_state = 2},
  [478] = {.lex_state = 4},
  [479] = {.lex_state = 4},
  [480] = {.lex_state = 2},
  [481] = {.lex_state = 4},
  [482] = {.lex_state = 4},
  [483] = {.lex_state = 2},
  [484] = {.lex_state = 0},
  [485] = {.lex_state = 4},
  [486] = {.lex_state = 4},
  [487] = {.lex_state = 4},
  [488] = {.lex_state = 4},
  [489] = {.lex_state = 4},
  [490] = {.lex_state = 4},
  [491] = {.lex_state = 4},
  [492] = {.lex_state = 4},
  [493] = {.lex_state = 4},
  [494] = {.lex_state = 4},
  [495] = {.lex_state = 4},
  [496] = {.lex_state = 4},
  [497] = {.lex_state = 4},
  [498] = {.lex_state = 4},
  [499] = {.lex_state = 4},
  [500] = {.lex_state = 4},
  [501] = {.lex_state = 4},
  [502] = {.lex_state = 0},
  [503] = {.lex_state = 9},
  [504] = {.lex_state = 9},
  [505] = {.lex_state = 4},
  [506] = {.lex_state = 4},
  [507] = {.lex_state = 4},
  [508] = {.lex_state = 9},
  [509] = {.lex_state = 0},
  [510] = {.lex_state = 4},
  [511] = {.lex_state = 0},
  [512] = {.lex_state = 4},
  [513] = {.lex_state = 0},
  [514] = {.lex_state = 4},
  [515] = {.lex_state = 0},
  [516] = {.lex_state = 4},
  [517] = {.lex_state = 4},
  [518] = {.lex_state = 4},
  [519] = {.lex_state = 4},
  [520] = {.lex_state = 4},
  [521] = {.lex_state = 4},
  [522] = {.lex_state = 0},
  [523] = {.lex_state = 4},
  [524] = {.lex_state = 4},
  [525] = {.lex_state = 4},
  [526] = {.lex_state = 4},
  [527] = {.lex_state = 4},
  [528] = {.lex_state = 0},
  [529] = {.lex_state = 4},
  [530] = {.lex_state = 4},
  [531] = {.lex_state = 4},
  [532] = {.lex_state = 4},
  [533] = {.lex_state = 4},
  [534] = {.lex_state = 0},
  [535] = {.lex_state = 4},
  [536] = {.lex_state = 4},
  [537] = {.lex_state = 4},
  [538] = {.lex_state = 4},
  [539] = {.lex_state = 4},
  [540] = {.lex_state = 4},
  [541] = {.lex_state = 4},
  [542] = {.lex_state = 0},
  [543] = {.lex_state = 4},
  [544] = {.lex_state = 0},
  [545] = {.lex_state = 4},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 4},
  [548] = {.lex_state = 4},
  [549] = {.lex_state = 4},
  [550] = {.lex_state = 4},
  [551] = {.lex_state = 4},
  [552] = {.lex_state = 4},
  [553] = {.lex_state = 4},
  [554] = {.lex_state = 4},
  [555] = {.lex_state = 4},
  [556] = {.lex_state = 4},
  [557] = {.lex_state = 4},
  [558] = {.lex_state = 4},
  [559] = {.lex_state = 4},
  [560] = {.lex_state = 0},
  [561] = {.lex_state = 4},
  [562] = {.lex_state = 4},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 4},
  [565] = {.lex_state = 0},
  [566] = {.lex_state = 4},
  [567] = {.lex_state = 0},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 4},
  [570] = {.lex_state = 4},
  [571] = {.lex_state = 4},
  [572] = {.lex_state = 0},
  [573] = {.lex_state = 0},
  [574] = {.lex_state = 0},
  [575] = {.lex_state = 4},
  [576] = {.lex_state = 0},
  [577] = {.lex_state = 0},
  [578] = {.lex_state = 0},
  [579] = {.lex_state = 0},
  [580] = {.lex_state = 4},
  [581] = {.lex_state = 9},
  [582] = {.lex_state = 9},
  [583] = {.lex_state = 1},
  [584] = {.lex_state = 4},
  [585] = {.lex_state = 4},
  [586] = {.lex_state = 4},
  [587] = {.lex_state = 4},
  [588] = {.lex_state = 0},
  [589] = {.lex_state = 0},
  [590] = {.lex_state = 0},
  [591] = {.lex_state = 4},
  [592] = {.lex_state = 4},
  [593] = {.lex_state = 4},
  [594] = {.lex_state = 4},
  [595] = {.lex_state = 0},
  [596] = {.lex_state = 1},
  [597] = {.lex_state = 0},
  [598] = {.lex_state = 4},
  [599] = {.lex_state = 0},
  [600] = {.lex_state = 0},
  [601] = {.lex_state = 4},
  [602] = {.lex_state = 4},
  [603] = {.lex_state = 0},
  [604] = {.lex_state = 4},
  [605] = {.lex_state = 4},
  [606] = {.lex_state = 4},
  [607] = {.lex_state = 4},
  [608] = {.lex_state = 4},
  [609] = {.lex_state = 4},
  [610] = {.lex_state = 4},
  [611] = {.lex_state = 4},
  [612] = {.lex_state = 4},
  [613] = {.lex_state = 4},
  [614] = {.lex_state = 4},
  [615] = {.lex_state = 4},
  [616] = {.lex_state = 4},
  [617] = {.lex_state = 4},
  [618] = {.lex_state = 4},
  [619] = {.lex_state = 4},
  [620] = {.lex_state = 4},
  [621] = {.lex_state = 4},
  [622] = {.lex_state = 4},
  [623] = {.lex_state = 4},
  [624] = {.lex_state = 2},
  [625] = {.lex_state = 4},
  [626] = {.lex_state = 2},
  [627] = {.lex_state = 2},
  [628] = {.lex_state = 4},
  [629] = {.lex_state = 4},
  [630] = {.lex_state = 2},
  [631] = {.lex_state = 4},
  [632] = {.lex_state = 4},
  [633] = {.lex_state = 4},
  [634] = {.lex_state = 4},
  [635] = {.lex_state = 4},
  [636] = {.lex_state = 4},
  [637] = {.lex_state = 4},
  [638] = {.lex_state = 9},
  [639] = {.lex_state = 4},
  [640] = {.lex_state = 4},
  [641] = {.lex_state = 4},
  [642] = {.lex_state = 4},
  [643] = {.lex_state = 1},
  [644] = {.lex_state = 4},
  [645] = {.lex_state = 4},
  [646] = {.lex_state = 4},
  [647] = {.lex_state = 4},
  [648] = {.lex_state = 9},
  [649] = {.lex_state = 4},
  [650] = {.lex_state = 2},
  [651] = {.lex_state = 4},
  [652] = {.lex_state = 9},
  [653] = {.lex_state = 4},
  [654] = {.lex_state = 4},
  [655] = {.lex_state = 4},
  [656] = {.lex_state = 4},
  [657] = {.lex_state = 4},
  [658] = {.lex_state = 4},
  [659] = {.lex_state = 4},
  [660] = {.lex_state = 4},
  [661] = {.lex_state = 4},
  [662] = {.lex_state = 4},
  [663] = {.lex_state = 2},
  [664] = {.lex_state = 4},
  [665] = {.lex_state = 4},
  [666] = {.lex_state = 4},
  [667] = {.lex_state = 4},
  [668] = {.lex_state = 4},
  [669] = {.lex_state = 2},
  [670] = {.lex_state = 4},
  [671] = {.lex_state = 4},
  [672] = {.lex_state = 4},
  [673] = {.lex_state = 2},
  [674] = {.lex_state = 4},
  [675] = {.lex_state = 4},
  [676] = {.lex_state = 4},
  [677] = {.lex_state = 4},
  [678] = {.lex_state = 4},
  [679] = {.lex_state = 4},
  [680] = {.lex_state = 1},
  [681] = {.lex_state = 4},
  [682] = {.lex_state = 4},
  [683] = {.lex_state = 4},
  [684] = {.lex_state = 4},
  [685] = {.lex_state = 9},
  [686] = {.lex_state = 4},
  [687] = {.lex_state = 4},
  [688] = {.lex_state = 2},
  [689] = {.lex_state = 1},
  [690] = {.lex_state = 9},
  [691] = {.lex_state = 2},
  [692] = {.lex_state = 1},
  [693] = {.lex_state = 9},
  [694] = {.lex_state = 4},
  [695] = {.lex_state = 9},
  [696] = {.lex_state = 17},
  [697] = {.lex_state = 4},
  [698] = {.lex_state = 2},
  [699] = {.lex_state = 4},
  [700] = {.lex_state = 9},
  [701] = {.lex_state = 4},
  [702] = {.lex_state = 2},
  [703] = {.lex_state = 4},
  [704] = {.lex_state = 4},
  [705] = {.lex_state = 4},
  [706] = {.lex_state = 9},
  [707] = {.lex_state = 9},
  [708] = {.lex_state = 4},
  [709] = {.lex_state = 4},
  [710] = {.lex_state = 4},
  [711] = {.lex_state = 1},
  [712] = {.lex_state = 9},
  [713] = {.lex_state = 4},
  [714] = {.lex_state = 1},
  [715] = {.lex_state = 4},
  [716] = {.lex_state = 4},
  [717] = {.lex_state = 4},
  [718] = {.lex_state = 4},
  [719] = {.lex_state = 4},
  [720] = {.lex_state = 4},
  [721] = {.lex_state = 4},
  [722] = {.lex_state = 4},
  [723] = {.lex_state = 4},
  [724] = {.lex_state = 4},
  [725] = {.lex_state = 4},
  [726] = {.lex_state = 4},
  [727] = {.lex_state = 4},
  [728] = {.lex_state = 9},
  [729] = {.lex_state = 9},
  [730] = {.lex_state = 4},
  [731] = {.lex_state = 4},
  [732] = {.lex_state = 4},
  [733] = {.lex_state = 4},
  [734] = {.lex_state = 4},
  [735] = {.lex_state = 4},
  [736] = {.lex_state = 4},
  [737] = {.lex_state = 4},
  [738] = {.lex_state = 4},
  [739] = {.lex_state = 17},
  [740] = {.lex_state = 4},
  [741] = {.lex_state = 4},
  [742] = {.lex_state = 4},
  [743] = {.lex_state = 1},
  [744] = {.lex_state = 4},
  [745] = {.lex_state = 9},
  [746] = {.lex_state = 4},
  [747] = {.lex_state = 17},
  [748] = {.lex_state = 4},
  [749] = {.lex_state = 4},
  [750] = {.lex_state = 1},
  [751] = {.lex_state = 4},
  [752] = {.lex_state = 1},
  [753] = {.lex_state = 1},
  [754] = {.lex_state = 1},
  [755] = {.lex_state = 9},
  [756] = {.lex_state = 1},
  [757] = {.lex_state = 9},
  [758] = {.lex_state = 9},
  [759] = {.lex_state = 1},
  [760] = {.lex_state = 1},
  [761] = {.lex_state = 1},
  [762] = {.lex_state = 1},
  [763] = {.lex_state = 1},
  [764] = {.lex_state = 1},
  [765] = {.lex_state = 1},
  [766] = {.lex_state = 2},
  [767] = {.lex_state = 1},
  [768] = {.lex_state = 1},
  [769] = {.lex_state = 1},
  [770] = {.lex_state = 1},
  [771] = {.lex_state = 1},
  [772] = {.lex_state = 1},
  [773] = {.lex_state = 1},
  [774] = {.lex_state = 1},
  [775] = {.lex_state = 1},
  [776] = {.lex_state = 1},
  [777] = {.lex_state = 1},
  [778] = {.lex_state = 1},
  [779] = {.lex_state = 1},
  [780] = {.lex_state = 1},
  [781] = {.lex_state = 1},
  [782] = {.lex_state = 17},
  [783] = {.lex_state = 1},
  [784] = {.lex_state = 1},
  [785] = {.lex_state = 1},
  [786] = {.lex_state = 1},
  [787] = {.lex_state = 1},
  [788] = {.lex_state = 1},
  [789] = {.lex_state = 1},
  [790] = {.lex_state = 1},
  [791] = {.lex_state = 1},
  [792] = {.lex_state = 1},
  [793] = {.lex_state = 1},
  [794] = {.lex_state = 17},
  [795] = {.lex_state = 1},
  [796] = {.lex_state = 1},
  [797] = {.lex_state = 1},
  [798] = {.lex_state = 1},
  [799] = {.lex_state = 1},
  [800] = {.lex_state = 1},
  [801] = {.lex_state = 1},
  [802] = {.lex_state = 1},
  [803] = {.lex_state = 1},
  [804] = {.lex_state = 1},
  [805] = {.lex_state = 1},
  [806] = {.lex_state = 1},
  [807] = {.lex_state = 1},
  [808] = {.lex_state = 1},
  [809] = {.lex_state = 1},
  [810] = {.lex_state = 1},
  [811] = {.lex_state = 1},
  [812] = {.lex_state = 1},
  [813] = {.lex_state = 1},
  [814] = {.lex_state = 1},
  [815] = {.lex_state = 1},
  [816] = {.lex_state = 1},
  [817] = {.lex_state = 1},
  [818] = {.lex_state = 1},
  [819] = {.lex_state = 1},
  [820] = {.lex_state = 9},
  [821] = {.lex_state = 1},
  [822] = {.lex_state = 1},
  [823] = {.lex_state = 1},
  [824] = {.lex_state = 1},
  [825] = {.lex_state = 1},
  [826] = {.lex_state = 1},
  [827] = {.lex_state = 1},
  [828] = {.lex_state = 1},
  [829] = {.lex_state = 9},
  [830] = {.lex_state = 1},
  [831] = {.lex_state = 1},
  [832] = {.lex_state = 1},
  [833] = {.lex_state = 1},
  [834] = {.lex_state = 1},
  [835] = {.lex_state = 1},
  [836] = {.lex_state = 1},
  [837] = {.lex_state = 1},
  [838] = {.lex_state = 1},
  [839] = {.lex_state = 1},
  [840] = {.lex_state = 1},
  [841] = {.lex_state = 1},
  [842] = {.lex_state = 1},
  [843] = {.lex_state = 1},
  [844] = {.lex_state = 1},
  [845] = {.lex_state = 1},
  [846] = {.lex_state = 1},
  [847] = {.lex_state = 1},
  [848] = {.lex_state = 1},
  [849] = {.lex_state = 1},
  [850] = {.lex_state = 1},
  [851] = {.lex_state = 1},
  [852] = {.lex_state = 1},
  [853] = {.lex_state = 1},
  [854] = {.lex_state = 1},
  [855] = {.lex_state = 1},
  [856] = {.lex_state = 1},
  [857] = {.lex_state = 1},
  [858] = {.lex_state = 1},
  [859] = {.lex_state = 1},
  [860] = {.lex_state = 1},
  [861] = {.lex_state = 1},
  [862] = {.lex_state = 1},
  [863] = {.lex_state = 1},
  [864] = {.lex_state = 1},
  [865] = {.lex_state = 1},
  [866] = {.lex_state = 1},
  [867] = {.lex_state = 1},
  [868] = {.lex_state = 1},
  [869] = {.lex_state = 1},
  [870] = {.lex_state = 1},
  [871] = {.lex_state = 1},
  [872] = {.lex_state = 1},
  [873] = {.lex_state = 1},
  [874] = {.lex_state = 1},
  [875] = {.lex_state = 1},
  [876] = {.lex_state = 1},
  [877] = {.lex_state = 1},
  [878] = {.lex_state = 1},
  [879] = {.lex_state = 1},
  [880] = {.lex_state = 1},
  [881] = {.lex_state = 1},
  [882] = {.lex_state = 1},
  [883] = {.lex_state = 1},
  [884] = {.lex_state = 1},
  [885] = {.lex_state = 1},
  [886] = {.lex_state = 1},
  [887] = {.lex_state = 1},
  [888] = {.lex_state = 1},
  [889] = {.lex_state = 1},
  [890] = {.lex_state = 1},
  [891] = {.lex_state = 6},
  [892] = {.lex_state = 1},
  [893] = {.lex_state = 1},
  [894] = {.lex_state = 6},
  [895] = {.lex_state = 1},
  [896] = {.lex_state = 6},
  [897] = {.lex_state = 1},
  [898] = {.lex_state = 1},
  [899] = {.lex_state = 1},
  [900] = {.lex_state = 1},
  [901] = {.lex_state = 1},
  [902] = {.lex_state = 1},
  [903] = {.lex_state = 1},
  [904] = {.lex_state = 1},
  [905] = {.lex_state = 9},
  [906] = {.lex_state = 1},
  [907] = {.lex_state = 1},
  [908] = {.lex_state = 1},
  [909] = {.lex_state = 1},
  [910] = {.lex_state = 1},
  [911] = {.lex_state = 1},
  [912] = {.lex_state = 1},
  [913] = {.lex_state = 1},
  [914] = {.lex_state = 1},
  [915] = {.lex_state = 1},
  [916] = {.lex_state = 1},
  [917] = {.lex_state = 1},
  [918] = {.lex_state = 1},
  [919] = {.lex_state = 1},
  [920] = {.lex_state = 1},
  [921] = {.lex_state = 1},
  [922] = {.lex_state = 1},
  [923] = {.lex_state = 1},
  [924] = {.lex_state = 1},
  [925] = {.lex_state = 1},
  [926] = {.lex_state = 0},
  [927] = {.lex_state = 1},
  [928] = {.lex_state = 1},
  [929] = {.lex_state = 1},
  [930] = {.lex_state = 1},
  [931] = {.lex_state = 0},
  [932] = {.lex_state = 1},
  [933] = {.lex_state = 1},
  [934] = {.lex_state = 1},
  [935] = {.lex_state = 1},
  [936] = {.lex_state = 1},
  [937] = {.lex_state = 1},
  [938] = {.lex_state = 1},
  [939] = {.lex_state = 1},
  [940] = {.lex_state = 1},
  [941] = {.lex_state = 1},
  [942] = {.lex_state = 1},
  [943] = {.lex_state = 1},
  [944] = {.lex_state = 1},
  [945] = {.lex_state = 1},
  [946] = {.lex_state = 1},
  [947] = {.lex_state = 1},
  [948] = {.lex_state = 1},
  [949] = {.lex_state = 1},
  [950] = {.lex_state = 1},
  [951] = {.lex_state = 1},
  [952] = {.lex_state = 1},
  [953] = {.lex_state = 1},
  [954] = {.lex_state = 1},
  [955] = {.lex_state = 1},
  [956] = {.lex_state = 1},
  [957] = {.lex_state = 1},
  [958] = {.lex_state = 8},
  [959] = {.lex_state = 1},
  [960] = {.lex_state = 6},
  [961] = {.lex_state = 1},
  [962] = {.lex_state = 1},
  [963] = {.lex_state = 1},
  [964] = {.lex_state = 1},
  [965] = {.lex_state = 1},
  [966] = {.lex_state = 8},
  [967] = {.lex_state = 6},
  [968] = {.lex_state = 1},
  [969] = {.lex_state = 1},
  [970] = {.lex_state = 1},
  [971] = {.lex_state = 1},
  [972] = {.lex_state = 1},
  [973] = {.lex_state = 1},
  [974] = {.lex_state = 1},
  [975] = {.lex_state = 1},
  [976] = {.lex_state = 1},
  [977] = {.lex_state = 1},
  [978] = {.lex_state = 1},
  [979] = {.lex_state = 8},
  [980] = {.lex_state = 0},
  [981] = {.lex_state = 0},
  [982] = {.lex_state = 1},
  [983] = {.lex_state = 0},
  [984] = {.lex_state = 1},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 1},
  [987] = {.lex_state = 0},
  [988] = {.lex_state = 0},
  [989] = {.lex_state = 0},
  [990] = {.lex_state = 0},
  [991] = {.lex_state = 0},
  [992] = {.lex_state = 0},
  [993] = {.lex_state = 0},
  [994] = {.lex_state = 0},
  [995] = {.lex_state = 9},
  [996] = {.lex_state = 1},
  [997] = {.lex_state = 0},
  [998] = {.lex_state = 0},
  [999] = {.lex_state = 0},
  [1000] = {.lex_state = 0},
  [1001] = {.lex_state = 0},
  [1002] = {.lex_state = 0},
  [1003] = {.lex_state = 0},
  [1004] = {.lex_state = 1},
  [1005] = {.lex_state = 9},
  [1006] = {.lex_state = 1},
  [1007] = {.lex_state = 1},
  [1008] = {.lex_state = 9},
  [1009] = {.lex_state = 1},
  [1010] = {.lex_state = 1},
  [1011] = {.lex_state = 0},
  [1012] = {.lex_state = 0},
  [1013] = {.lex_state = 1},
  [1014] = {.lex_state = 1},
  [1015] = {.lex_state = 0},
  [1016] = {.lex_state = 1},
  [1017] = {.lex_state = 0},
  [1018] = {.lex_state = 1},
  [1019] = {.lex_state = 1},
  [1020] = {.lex_state = 1},
  [1021] = {.lex_state = 9},
  [1022] = {.lex_state = 9},
  [1023] = {.lex_state = 1},
  [1024] = {.lex_state = 1},
  [1025] = {.lex_state = 0},
  [1026] = {.lex_state = 0},
  [1027] = {.lex_state = 1},
  [1028] = {.lex_state = 8},
  [1029] = {.lex_state = 1},
  [1030] = {.lex_state = 1},
  [1031] = {.lex_state = 0},
  [1032] = {.lex_state = 1},
  [1033] = {.lex_state = 1},
  [1034] = {.lex_state = 1},
  [1035] = {.lex_state = 9},
  [1036] = {.lex_state = 0},
  [1037] = {.lex_state = 0},
  [1038] = {.lex_state = 0},
  [1039] = {.lex_state = 0},
  [1040] = {.lex_state = 0},
  [1041] = {.lex_state = 0},
  [1042] = {.lex_state = 9},
  [1043] = {.lex_state = 0},
  [1044] = {.lex_state = 1},
  [1045] = {.lex_state = 1},
  [1046] = {.lex_state = 0},
  [1047] = {.lex_state = 1},
  [1048] = {.lex_state = 0},
  [1049] = {.lex_state = 1},
  [1050] = {.lex_state = 1},
  [1051] = {.lex_state = 1},
  [1052] = {.lex_state = 0},
  [1053] = {.lex_state = 0},
  [1054] = {.lex_state = 0},
  [1055] = {.lex_state = 1},
  [1056] = {.lex_state = 0},
  [1057] = {.lex_state = 0},
  [1058] = {.lex_state = 1},
  [1059] = {.lex_state = 0},
  [1060] = {.lex_state = 1},
  [1061] = {.lex_state = 0},
  [1062] = {.lex_state = 1},
  [1063] = {.lex_state = 1},
  [1064] = {.lex_state = 0},
  [1065] = {.lex_state = 0},
  [1066] = {.lex_state = 0},
  [1067] = {.lex_state = 0},
  [1068] = {.lex_state = 0},
  [1069] = {.lex_state = 0},
  [1070] = {.lex_state = 0},
  [1071] = {.lex_state = 1},
  [1072] = {.lex_state = 0},
  [1073] = {.lex_state = 9},
  [1074] = {.lex_state = 0},
  [1075] = {.lex_state = 0},
  [1076] = {.lex_state = 0},
  [1077] = {.lex_state = 0},
  [1078] = {.lex_state = 0},
  [1079] = {.lex_state = 0},
  [1080] = {.lex_state = 0},
  [1081] = {.lex_state = 0},
  [1082] = {.lex_state = 0},
  [1083] = {.lex_state = 0},
  [1084] = {.lex_state = 0},
  [1085] = {.lex_state = 0},
  [1086] = {.lex_state = 0},
  [1087] = {.lex_state = 0},
  [1088] = {.lex_state = 0},
  [1089] = {.lex_state = 0},
  [1090] = {.lex_state = 0},
  [1091] = {.lex_state = 0},
  [1092] = {.lex_state = 0},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 0},
  [1095] = {.lex_state = 0},
  [1096] = {.lex_state = 0},
  [1097] = {.lex_state = 0},
  [1098] = {.lex_state = 0},
  [1099] = {.lex_state = 0},
  [1100] = {.lex_state = 1},
  [1101] = {.lex_state = 0},
  [1102] = {.lex_state = 0},
  [1103] = {.lex_state = 9},
  [1104] = {.lex_state = 0},
  [1105] = {.lex_state = 9},
  [1106] = {.lex_state = 0},
  [1107] = {.lex_state = 0},
  [1108] = {.lex_state = 0},
  [1109] = {.lex_state = 0},
  [1110] = {.lex_state = 0},
  [1111] = {.lex_state = 0},
  [1112] = {.lex_state = 0},
  [1113] = {.lex_state = 0},
  [1114] = {.lex_state = 0},
  [1115] = {.lex_state = 0},
  [1116] = {.lex_state = 0},
  [1117] = {.lex_state = 0},
  [1118] = {.lex_state = 0},
  [1119] = {.lex_state = 0},
  [1120] = {.lex_state = 1},
  [1121] = {.lex_state = 0},
  [1122] = {.lex_state = 0},
  [1123] = {.lex_state = 0},
  [1124] = {.lex_state = 0},
  [1125] = {.lex_state = 0},
  [1126] = {.lex_state = 0},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 0},
  [1129] = {.lex_state = 0},
  [1130] = {.lex_state = 1},
  [1131] = {.lex_state = 1},
  [1132] = {.lex_state = 1},
  [1133] = {.lex_state = 0},
  [1134] = {.lex_state = 0},
  [1135] = {.lex_state = 1},
  [1136] = {.lex_state = 9},
  [1137] = {.lex_state = 0},
  [1138] = {.lex_state = 9},
  [1139] = {.lex_state = 0},
  [1140] = {.lex_state = 9},
  [1141] = {.lex_state = 0},
  [1142] = {.lex_state = 0},
  [1143] = {.lex_state = 0},
  [1144] = {.lex_state = 0},
  [1145] = {.lex_state = 0},
  [1146] = {.lex_state = 0},
  [1147] = {.lex_state = 0},
  [1148] = {.lex_state = 0},
  [1149] = {.lex_state = 0},
  [1150] = {.lex_state = 0},
  [1151] = {.lex_state = 1},
  [1152] = {.lex_state = 0},
  [1153] = {.lex_state = 1},
  [1154] = {.lex_state = 0},
  [1155] = {.lex_state = 0},
  [1156] = {.lex_state = 0},
  [1157] = {.lex_state = 1},
  [1158] = {.lex_state = 0},
  [1159] = {.lex_state = 0},
  [1160] = {.lex_state = 0},
  [1161] = {.lex_state = 0},
  [1162] = {.lex_state = 1},
  [1163] = {.lex_state = 1},
  [1164] = {.lex_state = 9},
  [1165] = {.lex_state = 0},
  [1166] = {.lex_state = 0},
  [1167] = {.lex_state = 0},
  [1168] = {.lex_state = 0},
  [1169] = {.lex_state = 1},
  [1170] = {.lex_state = 9},
  [1171] = {.lex_state = 0},
  [1172] = {.lex_state = 1},
  [1173] = {.lex_state = 9},
  [1174] = {.lex_state = 0},
  [1175] = {.lex_state = 0},
  [1176] = {.lex_state = 0},
  [1177] = {.lex_state = 0},
  [1178] = {.lex_state = 0},
  [1179] = {.lex_state = 0},
  [1180] = {.lex_state = 0},
  [1181] = {.lex_state = 1},
  [1182] = {.lex_state = 1},
  [1183] = {.lex_state = 0},
  [1184] = {.lex_state = 0},
  [1185] = {.lex_state = 0},
  [1186] = {.lex_state = 0},
  [1187] = {.lex_state = 0},
  [1188] = {.lex_state = 0},
  [1189] = {.lex_state = 0},
  [1190] = {.lex_state = 0},
  [1191] = {.lex_state = 0},
  [1192] = {.lex_state = 0},
  [1193] = {.lex_state = 1},
  [1194] = {.lex_state = 0},
  [1195] = {.lex_state = 0},
  [1196] = {.lex_state = 0},
  [1197] = {.lex_state = 0},
  [1198] = {.lex_state = 0},
  [1199] = {.lex_state = 0},
  [1200] = {.lex_state = 9},
  [1201] = {.lex_state = 1},
  [1202] = {.lex_state = 9},
  [1203] = {.lex_state = 9},
  [1204] = {.lex_state = 0},
  [1205] = {.lex_state = 0},
  [1206] = {.lex_state = 0},
  [1207] = {.lex_state = 0},
  [1208] = {.lex_state = 1},
  [1209] = {.lex_state = 0},
  [1210] = {.lex_state = 0},
  [1211] = {.lex_state = 0},
  [1212] = {.lex_state = 0},
  [1213] = {.lex_state = 0},
  [1214] = {.lex_state = 0},
  [1215] = {.lex_state = 0},
  [1216] = {.lex_state = 0},
  [1217] = {.lex_state = 0},
  [1218] = {.lex_state = 0},
  [1219] = {.lex_state = 0},
  [1220] = {.lex_state = 0},
  [1221] = {.lex_state = 0},
  [1222] = {.lex_state = 0},
  [1223] = {.lex_state = 1},
  [1224] = {.lex_state = 0},
  [1225] = {.lex_state = 0},
  [1226] = {.lex_state = 0},
  [1227] = {.lex_state = 0},
  [1228] = {.lex_state = 0},
  [1229] = {.lex_state = 0},
  [1230] = {.lex_state = 0},
  [1231] = {.lex_state = 0},
  [1232] = {.lex_state = 0},
  [1233] = {.lex_state = 0},
  [1234] = {.lex_state = 0},
  [1235] = {.lex_state = 9},
  [1236] = {.lex_state = 0},
  [1237] = {.lex_state = 0},
  [1238] = {.lex_state = 0},
  [1239] = {.lex_state = 0},
  [1240] = {.lex_state = 0},
  [1241] = {.lex_state = 0},
  [1242] = {.lex_state = 0},
  [1243] = {.lex_state = 0},
  [1244] = {.lex_state = 0},
  [1245] = {.lex_state = 0},
  [1246] = {.lex_state = 0},
  [1247] = {.lex_state = 0},
  [1248] = {.lex_state = 1},
  [1249] = {.lex_state = 0},
  [1250] = {.lex_state = 9},
  [1251] = {.lex_state = 0},
  [1252] = {.lex_state = 0},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 0},
  [1258] = {.lex_state = 9},
  [1259] = {.lex_state = 0},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 9},
  [1262] = {.lex_state = 1},
  [1263] = {.lex_state = 1},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 0},
  [1266] = {.lex_state = 0},
  [1267] = {.lex_state = 0},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 0},
  [1270] = {.lex_state = 0},
  [1271] = {.lex_state = 1},
  [1272] = {.lex_state = 0},
  [1273] = {.lex_state = 1},
  [1274] = {.lex_state = 0},
  [1275] = {.lex_state = 0},
  [1276] = {.lex_state = 0},
  [1277] = {.lex_state = 0},
  [1278] = {.lex_state = 0},
  [1279] = {.lex_state = 0},
  [1280] = {.lex_state = 0},
  [1281] = {.lex_state = 0},
  [1282] = {.lex_state = 0},
  [1283] = {.lex_state = 0},
  [1284] = {.lex_state = 0},
  [1285] = {.lex_state = 1},
  [1286] = {.lex_state = 0},
  [1287] = {.lex_state = 0},
  [1288] = {.lex_state = 0},
  [1289] = {.lex_state = 0},
  [1290] = {.lex_state = 0},
  [1291] = {.lex_state = 0},
  [1292] = {.lex_state = 0},
  [1293] = {.lex_state = 0},
  [1294] = {.lex_state = 0},
  [1295] = {.lex_state = 0},
  [1296] = {.lex_state = 0},
  [1297] = {.lex_state = 0},
  [1298] = {.lex_state = 0},
  [1299] = {.lex_state = 0},
  [1300] = {.lex_state = 1},
  [1301] = {.lex_state = 0},
  [1302] = {.lex_state = 0},
  [1303] = {.lex_state = 0},
  [1304] = {.lex_state = 0},
  [1305] = {.lex_state = 0},
  [1306] = {.lex_state = 1},
  [1307] = {.lex_state = 0},
  [1308] = {.lex_state = 0},
  [1309] = {.lex_state = 0},
  [1310] = {.lex_state = 0},
  [1311] = {.lex_state = 0},
  [1312] = {.lex_state = 0},
  [1313] = {.lex_state = 0},
  [1314] = {.lex_state = 0},
  [1315] = {.lex_state = 0},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 1},
  [1318] = {.lex_state = 0},
  [1319] = {.lex_state = 0},
  [1320] = {.lex_state = 0},
  [1321] = {.lex_state = 0},
  [1322] = {.lex_state = 0},
  [1323] = {.lex_state = 0},
  [1324] = {.lex_state = 1},
  [1325] = {.lex_state = 0},
  [1326] = {.lex_state = 0},
  [1327] = {.lex_state = 0},
  [1328] = {.lex_state = 0},
  [1329] = {.lex_state = 0},
  [1330] = {.lex_state = 0},
  [1331] = {.lex_state = 0},
  [1332] = {.lex_state = 1},
  [1333] = {.lex_state = 0},
  [1334] = {.lex_state = 0},
  [1335] = {.lex_state = 1},
  [1336] = {.lex_state = 0},
  [1337] = {.lex_state = 0},
  [1338] = {.lex_state = 0},
  [1339] = {.lex_state = 1},
  [1340] = {.lex_state = 0},
  [1341] = {.lex_state = 0},
  [1342] = {.lex_state = 1},
  [1343] = {.lex_state = 1},
  [1344] = {.lex_state = 1},
  [1345] = {.lex_state = 1},
  [1346] = {.lex_state = 1},
  [1347] = {.lex_state = 0},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 0},
  [1350] = {.lex_state = 0},
  [1351] = {.lex_state = 0},
  [1352] = {.lex_state = 0},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 0},
  [1355] = {.lex_state = 1},
  [1356] = {.lex_state = 0},
  [1357] = {.lex_state = 0},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 0},
  [1360] = {.lex_state = 0},
  [1361] = {.lex_state = 0},
  [1362] = {.lex_state = 0},
  [1363] = {.lex_state = 0},
  [1364] = {.lex_state = 0},
  [1365] = {.lex_state = 0},
  [1366] = {.lex_state = 1},
  [1367] = {.lex_state = 0},
  [1368] = {.lex_state = 1},
  [1369] = {.lex_state = 1},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 0},
  [1372] = {.lex_state = 0},
  [1373] = {.lex_state = 0},
  [1374] = {.lex_state = 0},
  [1375] = {.lex_state = 1},
  [1376] = {.lex_state = 0},
  [1377] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [sym_decimal_integer_literal] = ACTIONS(1),
    [sym_hex_integer_literal] = ACTIONS(1),
    [sym_octal_integer_literal] = ACTIONS(1),
    [sym_binary_integer_literal] = ACTIONS(1),
    [sym_decimal_floating_point_literal] = ACTIONS(1),
    [sym_hex_floating_point_literal] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_character_literal] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1),
    [anon_sym_BSLASH_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym__escape_sequence_token1] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_null_literal] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_instanceof] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [sym_underscore_pattern] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [anon_sym_synchronized] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_open] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_requires] = ACTIONS(1),
    [anon_sym_transitive] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_exports] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_opens] = ACTIONS(1),
    [anon_sym_uses] = ACTIONS(1),
    [anon_sym_provides] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_strictfp] = ACTIONS(1),
    [anon_sym_native] = ACTIONS(1),
    [anon_sym_transient] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_sealed] = ACTIONS(1),
    [anon_sym_non_DASHsealed] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
    [anon_sym_permits] = ACTIONS(1),
    [anon_sym_record] = ACTIONS(1),
    [anon_sym_ATinterface] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_byte] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_char] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [sym_boolean_type] = ACTIONS(1),
    [sym_void_type] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_throws] = ACTIONS(1),
    [sym_this] = ACTIONS(1),
    [sym_super] = ACTIONS(1),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_program] = STATE(1364),
    [sym__toplevel_statement] = STATE(3),
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(3),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(739),
    [sym_type_parameters] = STATE(775),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(753),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__method_header] = STATE(1070),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym_method_declaration] = STATE(3),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_program_repeat1] = STATE(3),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_LT] = ACTIONS(19),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(77),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__toplevel_statement] = STATE(2),
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(2),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(739),
    [sym_type_parameters] = STATE(775),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(753),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__method_header] = STATE(1070),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym_method_declaration] = STATE(2),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_program_repeat1] = STATE(2),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [ts_builtin_sym_end] = ACTIONS(97),
    [sym_identifier] = ACTIONS(99),
    [sym_decimal_integer_literal] = ACTIONS(102),
    [sym_hex_integer_literal] = ACTIONS(102),
    [sym_octal_integer_literal] = ACTIONS(102),
    [sym_binary_integer_literal] = ACTIONS(105),
    [sym_decimal_floating_point_literal] = ACTIONS(105),
    [sym_hex_floating_point_literal] = ACTIONS(102),
    [sym_true] = ACTIONS(102),
    [sym_false] = ACTIONS(102),
    [sym_character_literal] = ACTIONS(105),
    [anon_sym_DQUOTE] = ACTIONS(108),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(111),
    [sym_null_literal] = ACTIONS(102),
    [anon_sym_LPAREN] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(120),
    [anon_sym_DASH] = ACTIONS(120),
    [anon_sym_final] = ACTIONS(123),
    [anon_sym_BANG] = ACTIONS(126),
    [anon_sym_TILDE] = ACTIONS(126),
    [anon_sym_PLUS_PLUS] = ACTIONS(129),
    [anon_sym_DASH_DASH] = ACTIONS(129),
    [anon_sym_new] = ACTIONS(132),
    [anon_sym_class] = ACTIONS(135),
    [anon_sym_switch] = ACTIONS(138),
    [anon_sym_LBRACE] = ACTIONS(141),
    [anon_sym_default] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(144),
    [anon_sym_assert] = ACTIONS(147),
    [anon_sym_do] = ACTIONS(150),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(156),
    [anon_sym_continue] = ACTIONS(159),
    [anon_sym_return] = ACTIONS(162),
    [anon_sym_yield] = ACTIONS(165),
    [anon_sym_synchronized] = ACTIONS(168),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_try] = ACTIONS(174),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(180),
    [anon_sym_AT] = ACTIONS(183),
    [anon_sym_open] = ACTIONS(186),
    [anon_sym_module] = ACTIONS(189),
    [anon_sym_static] = ACTIONS(123),
    [anon_sym_with] = ACTIONS(192),
    [anon_sym_package] = ACTIONS(195),
    [anon_sym_import] = ACTIONS(198),
    [anon_sym_enum] = ACTIONS(201),
    [anon_sym_public] = ACTIONS(123),
    [anon_sym_protected] = ACTIONS(123),
    [anon_sym_private] = ACTIONS(123),
    [anon_sym_abstract] = ACTIONS(123),
    [anon_sym_strictfp] = ACTIONS(123),
    [anon_sym_native] = ACTIONS(123),
    [anon_sym_transient] = ACTIONS(123),
    [anon_sym_volatile] = ACTIONS(123),
    [anon_sym_sealed] = ACTIONS(204),
    [anon_sym_non_DASHsealed] = ACTIONS(207),
    [anon_sym_record] = ACTIONS(210),
    [anon_sym_ATinterface] = ACTIONS(213),
    [anon_sym_interface] = ACTIONS(216),
    [anon_sym_byte] = ACTIONS(219),
    [anon_sym_short] = ACTIONS(219),
    [anon_sym_int] = ACTIONS(219),
    [anon_sym_long] = ACTIONS(219),
    [anon_sym_char] = ACTIONS(219),
    [anon_sym_float] = ACTIONS(222),
    [anon_sym_double] = ACTIONS(222),
    [sym_boolean_type] = ACTIONS(225),
    [sym_void_type] = ACTIONS(225),
    [sym_this] = ACTIONS(228),
    [sym_super] = ACTIONS(231),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [3] = {
    [sym__toplevel_statement] = STATE(2),
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(2),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(739),
    [sym_type_parameters] = STATE(775),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(753),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__method_header] = STATE(1070),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym_method_declaration] = STATE(2),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_program_repeat1] = STATE(2),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [ts_builtin_sym_end] = ACTIONS(234),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_LT] = ACTIONS(19),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(77),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_switch_label] = STATE(1315),
    [sym_statement] = STATE(7),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat1] = STATE(388),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(7),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(238),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_case] = ACTIONS(240),
    [anon_sym_default] = ACTIONS(240),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(642),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_type_arguments] = STATE(1263),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(14),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_explicit_constructor_invocation] = STATE(8),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(14),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(250),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_LT] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(254),
    [sym_super] = ACTIONS(256),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(258),
    [sym_decimal_integer_literal] = ACTIONS(261),
    [sym_hex_integer_literal] = ACTIONS(261),
    [sym_octal_integer_literal] = ACTIONS(261),
    [sym_binary_integer_literal] = ACTIONS(264),
    [sym_decimal_floating_point_literal] = ACTIONS(264),
    [sym_hex_floating_point_literal] = ACTIONS(261),
    [sym_true] = ACTIONS(261),
    [sym_false] = ACTIONS(261),
    [sym_character_literal] = ACTIONS(264),
    [anon_sym_DQUOTE] = ACTIONS(267),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(270),
    [anon_sym_RBRACE] = ACTIONS(273),
    [sym_null_literal] = ACTIONS(261),
    [anon_sym_LPAREN] = ACTIONS(275),
    [anon_sym_PLUS] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(278),
    [anon_sym_final] = ACTIONS(281),
    [anon_sym_BANG] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_PLUS_PLUS] = ACTIONS(287),
    [anon_sym_DASH_DASH] = ACTIONS(287),
    [anon_sym_new] = ACTIONS(290),
    [anon_sym_class] = ACTIONS(293),
    [anon_sym_switch] = ACTIONS(296),
    [anon_sym_LBRACE] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(302),
    [anon_sym_default] = ACTIONS(281),
    [anon_sym_SEMI] = ACTIONS(304),
    [anon_sym_assert] = ACTIONS(307),
    [anon_sym_do] = ACTIONS(310),
    [anon_sym_while] = ACTIONS(313),
    [anon_sym_break] = ACTIONS(316),
    [anon_sym_continue] = ACTIONS(319),
    [anon_sym_return] = ACTIONS(322),
    [anon_sym_yield] = ACTIONS(325),
    [anon_sym_synchronized] = ACTIONS(328),
    [anon_sym_throw] = ACTIONS(331),
    [anon_sym_try] = ACTIONS(334),
    [anon_sym_if] = ACTIONS(337),
    [anon_sym_for] = ACTIONS(340),
    [anon_sym_AT] = ACTIONS(343),
    [anon_sym_open] = ACTIONS(346),
    [anon_sym_module] = ACTIONS(349),
    [anon_sym_static] = ACTIONS(281),
    [anon_sym_with] = ACTIONS(352),
    [anon_sym_package] = ACTIONS(355),
    [anon_sym_import] = ACTIONS(358),
    [anon_sym_enum] = ACTIONS(361),
    [anon_sym_public] = ACTIONS(281),
    [anon_sym_protected] = ACTIONS(281),
    [anon_sym_private] = ACTIONS(281),
    [anon_sym_abstract] = ACTIONS(281),
    [anon_sym_strictfp] = ACTIONS(281),
    [anon_sym_native] = ACTIONS(281),
    [anon_sym_transient] = ACTIONS(281),
    [anon_sym_volatile] = ACTIONS(281),
    [anon_sym_sealed] = ACTIONS(364),
    [anon_sym_non_DASHsealed] = ACTIONS(367),
    [anon_sym_record] = ACTIONS(370),
    [anon_sym_ATinterface] = ACTIONS(373),
    [anon_sym_interface] = ACTIONS(376),
    [anon_sym_byte] = ACTIONS(379),
    [anon_sym_short] = ACTIONS(379),
    [anon_sym_int] = ACTIONS(379),
    [anon_sym_long] = ACTIONS(379),
    [anon_sym_char] = ACTIONS(379),
    [anon_sym_float] = ACTIONS(382),
    [anon_sym_double] = ACTIONS(382),
    [sym_boolean_type] = ACTIONS(385),
    [sym_void_type] = ACTIONS(385),
    [sym_this] = ACTIONS(388),
    [sym_super] = ACTIONS(391),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(394),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_case] = ACTIONS(396),
    [anon_sym_default] = ACTIONS(396),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(9),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(9),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(398),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(400),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(402),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(12),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(12),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(404),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(406),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [13] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(10),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(10),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(408),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [14] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(6),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_switch_block_statement_group_repeat2] = STATE(6),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(398),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [15] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(371),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [16] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(343),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [17] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(307),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [18] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(297),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [19] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(293),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [20] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(289),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [21] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(326),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [22] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(285),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [23] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(308),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [24] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(1355),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [25] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(299),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [26] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(278),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [27] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(301),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [28] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(277),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [29] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(302),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [30] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(345),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [31] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(371),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [32] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(369),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [33] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(375),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [34] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(392),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [35] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(379),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [36] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(358),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [37] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(316),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [38] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(348),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [39] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(313),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [40] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(277),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [41] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(278),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [42] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(285),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [43] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(326),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [44] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(289),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [45] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(264),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [46] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(293),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [47] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(378),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [48] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(297),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [49] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(384),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [50] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(307),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [51] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(378),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [52] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(384),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [53] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(266),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [54] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(306),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [55] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(280),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [56] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(313),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [57] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(264),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [58] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(343),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [59] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(348),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [60] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(323),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [61] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(358),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [62] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(323),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [63] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(264),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [64] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(313),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [65] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(266),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [66] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(316),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [67] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(280),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [68] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(306),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [69] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(266),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [70] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(384),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [71] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(323),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [72] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(379),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [73] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(378),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [74] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(307),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [75] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(297),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [76] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(308),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [77] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(293),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [78] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(289),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [79] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(326),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [80] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(285),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [81] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(278),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [82] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(277),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [83] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(375),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [84] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(343),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [85] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(348),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [86] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(306),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [87] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(358),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [88] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(379),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [89] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(316),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [90] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(375),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [91] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(390),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [92] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(371),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [93] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(299),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [94] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(345),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [95] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(301),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [96] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(302),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [97] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(302),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [98] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(301),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [99] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(345),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [100] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(280),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [101] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(1273),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [102] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(299),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [103] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(657),
    [sym_statement] = STATE(369),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(410),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(412),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(416),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [104] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(121),
    [sym_statement] = STATE(308),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(236),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(242),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(246),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [105] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(122),
    [sym_statement] = STATE(369),
    [sym_block] = STATE(284),
    [sym_expression_statement] = STATE(284),
    [sym_labeled_statement] = STATE(284),
    [sym_assert_statement] = STATE(284),
    [sym_do_statement] = STATE(284),
    [sym_break_statement] = STATE(284),
    [sym_continue_statement] = STATE(284),
    [sym_return_statement] = STATE(284),
    [sym_yield_statement] = STATE(284),
    [sym_synchronized_statement] = STATE(284),
    [sym_throw_statement] = STATE(284),
    [sym_try_statement] = STATE(284),
    [sym_try_with_resources_statement] = STATE(284),
    [sym_if_statement] = STATE(284),
    [sym_while_statement] = STATE(284),
    [sym_for_statement] = STATE(284),
    [sym_enhanced_for_statement] = STATE(284),
    [sym__annotation] = STATE(534),
    [sym_marker_annotation] = STATE(534),
    [sym_annotation] = STATE(534),
    [sym_declaration] = STATE(284),
    [sym_module_declaration] = STATE(294),
    [sym_package_declaration] = STATE(294),
    [sym_import_declaration] = STATE(294),
    [sym_enum_declaration] = STATE(294),
    [sym_class_declaration] = STATE(294),
    [sym_modifiers] = STATE(782),
    [sym_record_declaration] = STATE(294),
    [sym_annotation_type_declaration] = STATE(294),
    [sym_interface_declaration] = STATE(294),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(767),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(284),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(743),
    [aux_sym_modifiers_repeat1] = STATE(509),
    [sym_identifier] = ACTIONS(7),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(23),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_default] = ACTIONS(23),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_assert] = ACTIONS(39),
    [anon_sym_do] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_yield] = ACTIONS(51),
    [anon_sym_synchronized] = ACTIONS(53),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_try] = ACTIONS(57),
    [anon_sym_if] = ACTIONS(59),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_open] = ACTIONS(65),
    [anon_sym_module] = ACTIONS(67),
    [anon_sym_static] = ACTIONS(23),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_package] = ACTIONS(71),
    [anon_sym_import] = ACTIONS(73),
    [anon_sym_enum] = ACTIONS(75),
    [anon_sym_public] = ACTIONS(23),
    [anon_sym_protected] = ACTIONS(23),
    [anon_sym_private] = ACTIONS(23),
    [anon_sym_abstract] = ACTIONS(23),
    [anon_sym_strictfp] = ACTIONS(23),
    [anon_sym_native] = ACTIONS(23),
    [anon_sym_transient] = ACTIONS(23),
    [anon_sym_volatile] = ACTIONS(23),
    [anon_sym_sealed] = ACTIONS(248),
    [anon_sym_non_DASHsealed] = ACTIONS(79),
    [anon_sym_record] = ACTIONS(81),
    [anon_sym_ATinterface] = ACTIONS(83),
    [anon_sym_interface] = ACTIONS(85),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [106] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(722),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_AMP_EQ] = ACTIONS(422),
    [anon_sym_PIPE_EQ] = ACTIONS(422),
    [anon_sym_CARET_EQ] = ACTIONS(422),
    [anon_sym_PERCENT_EQ] = ACTIONS(422),
    [anon_sym_LT_LT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_LT] = ACTIONS(420),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_AMP_AMP] = ACTIONS(422),
    [anon_sym_PIPE_PIPE] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PIPE] = ACTIONS(420),
    [anon_sym_CARET] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(420),
    [anon_sym_LT_LT] = ACTIONS(420),
    [anon_sym_GT_GT] = ACTIONS(420),
    [anon_sym_GT_GT_GT] = ACTIONS(420),
    [anon_sym_instanceof] = ACTIONS(420),
    [anon_sym_DASH_GT] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(420),
    [anon_sym_COLON_COLON] = ACTIONS(422),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [107] = {
    [ts_builtin_sym_end] = ACTIONS(426),
    [sym_identifier] = ACTIONS(428),
    [sym_decimal_integer_literal] = ACTIONS(428),
    [sym_hex_integer_literal] = ACTIONS(428),
    [sym_octal_integer_literal] = ACTIONS(428),
    [sym_binary_integer_literal] = ACTIONS(426),
    [sym_decimal_floating_point_literal] = ACTIONS(426),
    [sym_hex_floating_point_literal] = ACTIONS(428),
    [sym_true] = ACTIONS(428),
    [sym_false] = ACTIONS(428),
    [sym_character_literal] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(428),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(426),
    [anon_sym_RBRACE] = ACTIONS(426),
    [sym_null_literal] = ACTIONS(428),
    [anon_sym_LPAREN] = ACTIONS(426),
    [anon_sym_RPAREN] = ACTIONS(426),
    [anon_sym_AMP] = ACTIONS(428),
    [anon_sym_GT] = ACTIONS(428),
    [anon_sym_LT] = ACTIONS(428),
    [anon_sym_GT_EQ] = ACTIONS(426),
    [anon_sym_LT_EQ] = ACTIONS(426),
    [anon_sym_EQ_EQ] = ACTIONS(426),
    [anon_sym_BANG_EQ] = ACTIONS(426),
    [anon_sym_AMP_AMP] = ACTIONS(426),
    [anon_sym_PIPE_PIPE] = ACTIONS(426),
    [anon_sym_PLUS] = ACTIONS(428),
    [anon_sym_DASH] = ACTIONS(428),
    [anon_sym_STAR] = ACTIONS(426),
    [anon_sym_SLASH] = ACTIONS(428),
    [anon_sym_PIPE] = ACTIONS(428),
    [anon_sym_CARET] = ACTIONS(426),
    [anon_sym_PERCENT] = ACTIONS(426),
    [anon_sym_LT_LT] = ACTIONS(426),
    [anon_sym_GT_GT] = ACTIONS(428),
    [anon_sym_GT_GT_GT] = ACTIONS(426),
    [anon_sym_instanceof] = ACTIONS(428),
    [anon_sym_final] = ACTIONS(428),
    [anon_sym_DASH_GT] = ACTIONS(426),
    [anon_sym_COMMA] = ACTIONS(426),
    [anon_sym_QMARK] = ACTIONS(426),
    [anon_sym_COLON] = ACTIONS(428),
    [anon_sym_BANG] = ACTIONS(428),
    [anon_sym_TILDE] = ACTIONS(426),
    [anon_sym_PLUS_PLUS] = ACTIONS(426),
    [anon_sym_DASH_DASH] = ACTIONS(426),
    [anon_sym_new] = ACTIONS(428),
    [anon_sym_LBRACK] = ACTIONS(426),
    [anon_sym_RBRACK] = ACTIONS(426),
    [anon_sym_DOT] = ACTIONS(428),
    [anon_sym_class] = ACTIONS(428),
    [anon_sym_COLON_COLON] = ACTIONS(426),
    [anon_sym_switch] = ACTIONS(428),
    [anon_sym_LBRACE] = ACTIONS(426),
    [anon_sym_case] = ACTIONS(428),
    [anon_sym_default] = ACTIONS(428),
    [anon_sym_when] = ACTIONS(428),
    [anon_sym_SEMI] = ACTIONS(426),
    [anon_sym_assert] = ACTIONS(428),
    [anon_sym_do] = ACTIONS(428),
    [anon_sym_while] = ACTIONS(428),
    [anon_sym_break] = ACTIONS(428),
    [anon_sym_continue] = ACTIONS(428),
    [anon_sym_return] = ACTIONS(428),
    [anon_sym_yield] = ACTIONS(428),
    [anon_sym_synchronized] = ACTIONS(428),
    [anon_sym_throw] = ACTIONS(428),
    [anon_sym_try] = ACTIONS(428),
    [anon_sym_if] = ACTIONS(428),
    [anon_sym_else] = ACTIONS(428),
    [anon_sym_for] = ACTIONS(428),
    [anon_sym_AT] = ACTIONS(428),
    [anon_sym_open] = ACTIONS(428),
    [anon_sym_module] = ACTIONS(428),
    [anon_sym_static] = ACTIONS(428),
    [anon_sym_with] = ACTIONS(428),
    [anon_sym_package] = ACTIONS(428),
    [anon_sym_import] = ACTIONS(428),
    [anon_sym_enum] = ACTIONS(428),
    [anon_sym_public] = ACTIONS(428),
    [anon_sym_protected] = ACTIONS(428),
    [anon_sym_private] = ACTIONS(428),
    [anon_sym_abstract] = ACTIONS(428),
    [anon_sym_strictfp] = ACTIONS(428),
    [anon_sym_native] = ACTIONS(428),
    [anon_sym_transient] = ACTIONS(428),
    [anon_sym_volatile] = ACTIONS(428),
    [anon_sym_sealed] = ACTIONS(428),
    [anon_sym_non_DASHsealed] = ACTIONS(426),
    [anon_sym_record] = ACTIONS(428),
    [anon_sym_ATinterface] = ACTIONS(426),
    [anon_sym_interface] = ACTIONS(428),
    [anon_sym_byte] = ACTIONS(428),
    [anon_sym_short] = ACTIONS(428),
    [anon_sym_int] = ACTIONS(428),
    [anon_sym_long] = ACTIONS(428),
    [anon_sym_char] = ACTIONS(428),
    [anon_sym_float] = ACTIONS(428),
    [anon_sym_double] = ACTIONS(428),
    [sym_boolean_type] = ACTIONS(428),
    [sym_void_type] = ACTIONS(428),
    [sym_this] = ACTIONS(428),
    [sym_super] = ACTIONS(428),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [108] = {
    [ts_builtin_sym_end] = ACTIONS(430),
    [sym_identifier] = ACTIONS(432),
    [sym_decimal_integer_literal] = ACTIONS(432),
    [sym_hex_integer_literal] = ACTIONS(432),
    [sym_octal_integer_literal] = ACTIONS(432),
    [sym_binary_integer_literal] = ACTIONS(430),
    [sym_decimal_floating_point_literal] = ACTIONS(430),
    [sym_hex_floating_point_literal] = ACTIONS(432),
    [sym_true] = ACTIONS(432),
    [sym_false] = ACTIONS(432),
    [sym_character_literal] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(432),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(430),
    [anon_sym_RBRACE] = ACTIONS(430),
    [sym_null_literal] = ACTIONS(432),
    [anon_sym_LPAREN] = ACTIONS(430),
    [anon_sym_RPAREN] = ACTIONS(430),
    [anon_sym_AMP] = ACTIONS(432),
    [anon_sym_GT] = ACTIONS(432),
    [anon_sym_LT] = ACTIONS(432),
    [anon_sym_GT_EQ] = ACTIONS(430),
    [anon_sym_LT_EQ] = ACTIONS(430),
    [anon_sym_EQ_EQ] = ACTIONS(430),
    [anon_sym_BANG_EQ] = ACTIONS(430),
    [anon_sym_AMP_AMP] = ACTIONS(430),
    [anon_sym_PIPE_PIPE] = ACTIONS(430),
    [anon_sym_PLUS] = ACTIONS(432),
    [anon_sym_DASH] = ACTIONS(432),
    [anon_sym_STAR] = ACTIONS(430),
    [anon_sym_SLASH] = ACTIONS(432),
    [anon_sym_PIPE] = ACTIONS(432),
    [anon_sym_CARET] = ACTIONS(430),
    [anon_sym_PERCENT] = ACTIONS(430),
    [anon_sym_LT_LT] = ACTIONS(430),
    [anon_sym_GT_GT] = ACTIONS(432),
    [anon_sym_GT_GT_GT] = ACTIONS(430),
    [anon_sym_instanceof] = ACTIONS(432),
    [anon_sym_final] = ACTIONS(432),
    [anon_sym_DASH_GT] = ACTIONS(430),
    [anon_sym_COMMA] = ACTIONS(430),
    [anon_sym_QMARK] = ACTIONS(430),
    [anon_sym_COLON] = ACTIONS(432),
    [anon_sym_BANG] = ACTIONS(432),
    [anon_sym_TILDE] = ACTIONS(430),
    [anon_sym_PLUS_PLUS] = ACTIONS(430),
    [anon_sym_DASH_DASH] = ACTIONS(430),
    [anon_sym_new] = ACTIONS(432),
    [anon_sym_LBRACK] = ACTIONS(430),
    [anon_sym_RBRACK] = ACTIONS(430),
    [anon_sym_DOT] = ACTIONS(432),
    [anon_sym_class] = ACTIONS(432),
    [anon_sym_COLON_COLON] = ACTIONS(430),
    [anon_sym_switch] = ACTIONS(432),
    [anon_sym_LBRACE] = ACTIONS(430),
    [anon_sym_case] = ACTIONS(432),
    [anon_sym_default] = ACTIONS(432),
    [anon_sym_when] = ACTIONS(432),
    [anon_sym_SEMI] = ACTIONS(430),
    [anon_sym_assert] = ACTIONS(432),
    [anon_sym_do] = ACTIONS(432),
    [anon_sym_while] = ACTIONS(432),
    [anon_sym_break] = ACTIONS(432),
    [anon_sym_continue] = ACTIONS(432),
    [anon_sym_return] = ACTIONS(432),
    [anon_sym_yield] = ACTIONS(432),
    [anon_sym_synchronized] = ACTIONS(432),
    [anon_sym_throw] = ACTIONS(432),
    [anon_sym_try] = ACTIONS(432),
    [anon_sym_if] = ACTIONS(432),
    [anon_sym_else] = ACTIONS(432),
    [anon_sym_for] = ACTIONS(432),
    [anon_sym_AT] = ACTIONS(432),
    [anon_sym_open] = ACTIONS(432),
    [anon_sym_module] = ACTIONS(432),
    [anon_sym_static] = ACTIONS(432),
    [anon_sym_with] = ACTIONS(432),
    [anon_sym_package] = ACTIONS(432),
    [anon_sym_import] = ACTIONS(432),
    [anon_sym_enum] = ACTIONS(432),
    [anon_sym_public] = ACTIONS(432),
    [anon_sym_protected] = ACTIONS(432),
    [anon_sym_private] = ACTIONS(432),
    [anon_sym_abstract] = ACTIONS(432),
    [anon_sym_strictfp] = ACTIONS(432),
    [anon_sym_native] = ACTIONS(432),
    [anon_sym_transient] = ACTIONS(432),
    [anon_sym_volatile] = ACTIONS(432),
    [anon_sym_sealed] = ACTIONS(432),
    [anon_sym_non_DASHsealed] = ACTIONS(430),
    [anon_sym_record] = ACTIONS(432),
    [anon_sym_ATinterface] = ACTIONS(430),
    [anon_sym_interface] = ACTIONS(432),
    [anon_sym_byte] = ACTIONS(432),
    [anon_sym_short] = ACTIONS(432),
    [anon_sym_int] = ACTIONS(432),
    [anon_sym_long] = ACTIONS(432),
    [anon_sym_char] = ACTIONS(432),
    [anon_sym_float] = ACTIONS(432),
    [anon_sym_double] = ACTIONS(432),
    [sym_boolean_type] = ACTIONS(432),
    [sym_void_type] = ACTIONS(432),
    [sym_this] = ACTIONS(432),
    [sym_super] = ACTIONS(432),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [109] = {
    [ts_builtin_sym_end] = ACTIONS(434),
    [sym_identifier] = ACTIONS(436),
    [sym_decimal_integer_literal] = ACTIONS(436),
    [sym_hex_integer_literal] = ACTIONS(436),
    [sym_octal_integer_literal] = ACTIONS(436),
    [sym_binary_integer_literal] = ACTIONS(434),
    [sym_decimal_floating_point_literal] = ACTIONS(434),
    [sym_hex_floating_point_literal] = ACTIONS(436),
    [sym_true] = ACTIONS(436),
    [sym_false] = ACTIONS(436),
    [sym_character_literal] = ACTIONS(434),
    [anon_sym_DQUOTE] = ACTIONS(436),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(434),
    [anon_sym_RBRACE] = ACTIONS(434),
    [sym_null_literal] = ACTIONS(436),
    [anon_sym_LPAREN] = ACTIONS(434),
    [anon_sym_RPAREN] = ACTIONS(434),
    [anon_sym_AMP] = ACTIONS(436),
    [anon_sym_GT] = ACTIONS(436),
    [anon_sym_LT] = ACTIONS(436),
    [anon_sym_GT_EQ] = ACTIONS(434),
    [anon_sym_LT_EQ] = ACTIONS(434),
    [anon_sym_EQ_EQ] = ACTIONS(434),
    [anon_sym_BANG_EQ] = ACTIONS(434),
    [anon_sym_AMP_AMP] = ACTIONS(434),
    [anon_sym_PIPE_PIPE] = ACTIONS(434),
    [anon_sym_PLUS] = ACTIONS(436),
    [anon_sym_DASH] = ACTIONS(436),
    [anon_sym_STAR] = ACTIONS(434),
    [anon_sym_SLASH] = ACTIONS(436),
    [anon_sym_PIPE] = ACTIONS(436),
    [anon_sym_CARET] = ACTIONS(434),
    [anon_sym_PERCENT] = ACTIONS(434),
    [anon_sym_LT_LT] = ACTIONS(434),
    [anon_sym_GT_GT] = ACTIONS(436),
    [anon_sym_GT_GT_GT] = ACTIONS(434),
    [anon_sym_instanceof] = ACTIONS(436),
    [anon_sym_final] = ACTIONS(436),
    [anon_sym_DASH_GT] = ACTIONS(434),
    [anon_sym_COMMA] = ACTIONS(434),
    [anon_sym_QMARK] = ACTIONS(434),
    [anon_sym_COLON] = ACTIONS(434),
    [anon_sym_BANG] = ACTIONS(436),
    [anon_sym_TILDE] = ACTIONS(434),
    [anon_sym_PLUS_PLUS] = ACTIONS(434),
    [anon_sym_DASH_DASH] = ACTIONS(434),
    [anon_sym_new] = ACTIONS(436),
    [anon_sym_RBRACK] = ACTIONS(434),
    [anon_sym_class] = ACTIONS(436),
    [anon_sym_switch] = ACTIONS(436),
    [anon_sym_LBRACE] = ACTIONS(434),
    [anon_sym_case] = ACTIONS(436),
    [anon_sym_default] = ACTIONS(436),
    [anon_sym_when] = ACTIONS(436),
    [anon_sym_SEMI] = ACTIONS(434),
    [anon_sym_assert] = ACTIONS(436),
    [anon_sym_do] = ACTIONS(436),
    [anon_sym_while] = ACTIONS(436),
    [anon_sym_break] = ACTIONS(436),
    [anon_sym_continue] = ACTIONS(436),
    [anon_sym_return] = ACTIONS(436),
    [anon_sym_yield] = ACTIONS(436),
    [anon_sym_synchronized] = ACTIONS(436),
    [anon_sym_throw] = ACTIONS(436),
    [anon_sym_try] = ACTIONS(436),
    [anon_sym_if] = ACTIONS(436),
    [anon_sym_else] = ACTIONS(436),
    [anon_sym_for] = ACTIONS(436),
    [anon_sym_AT] = ACTIONS(436),
    [anon_sym_open] = ACTIONS(436),
    [anon_sym_module] = ACTIONS(436),
    [anon_sym_static] = ACTIONS(436),
    [anon_sym_with] = ACTIONS(436),
    [anon_sym_package] = ACTIONS(436),
    [anon_sym_import] = ACTIONS(436),
    [anon_sym_enum] = ACTIONS(436),
    [anon_sym_public] = ACTIONS(436),
    [anon_sym_protected] = ACTIONS(436),
    [anon_sym_private] = ACTIONS(436),
    [anon_sym_abstract] = ACTIONS(436),
    [anon_sym_strictfp] = ACTIONS(436),
    [anon_sym_native] = ACTIONS(436),
    [anon_sym_transient] = ACTIONS(436),
    [anon_sym_volatile] = ACTIONS(436),
    [anon_sym_sealed] = ACTIONS(436),
    [anon_sym_non_DASHsealed] = ACTIONS(434),
    [anon_sym_record] = ACTIONS(436),
    [anon_sym_ATinterface] = ACTIONS(434),
    [anon_sym_interface] = ACTIONS(436),
    [anon_sym_byte] = ACTIONS(436),
    [anon_sym_short] = ACTIONS(436),
    [anon_sym_int] = ACTIONS(436),
    [anon_sym_long] = ACTIONS(436),
    [anon_sym_char] = ACTIONS(436),
    [anon_sym_float] = ACTIONS(436),
    [anon_sym_double] = ACTIONS(436),
    [sym_boolean_type] = ACTIONS(436),
    [sym_void_type] = ACTIONS(436),
    [sym_this] = ACTIONS(436),
    [sym_super] = ACTIONS(436),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [110] = {
    [ts_builtin_sym_end] = ACTIONS(438),
    [sym_identifier] = ACTIONS(440),
    [sym_decimal_integer_literal] = ACTIONS(440),
    [sym_hex_integer_literal] = ACTIONS(440),
    [sym_octal_integer_literal] = ACTIONS(440),
    [sym_binary_integer_literal] = ACTIONS(438),
    [sym_decimal_floating_point_literal] = ACTIONS(438),
    [sym_hex_floating_point_literal] = ACTIONS(440),
    [sym_true] = ACTIONS(440),
    [sym_false] = ACTIONS(440),
    [sym_character_literal] = ACTIONS(438),
    [anon_sym_DQUOTE] = ACTIONS(440),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(438),
    [anon_sym_RBRACE] = ACTIONS(438),
    [sym_null_literal] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(438),
    [anon_sym_RPAREN] = ACTIONS(438),
    [anon_sym_AMP] = ACTIONS(440),
    [anon_sym_GT] = ACTIONS(440),
    [anon_sym_LT] = ACTIONS(440),
    [anon_sym_GT_EQ] = ACTIONS(438),
    [anon_sym_LT_EQ] = ACTIONS(438),
    [anon_sym_EQ_EQ] = ACTIONS(438),
    [anon_sym_BANG_EQ] = ACTIONS(438),
    [anon_sym_AMP_AMP] = ACTIONS(438),
    [anon_sym_PIPE_PIPE] = ACTIONS(438),
    [anon_sym_PLUS] = ACTIONS(440),
    [anon_sym_DASH] = ACTIONS(440),
    [anon_sym_STAR] = ACTIONS(438),
    [anon_sym_SLASH] = ACTIONS(440),
    [anon_sym_PIPE] = ACTIONS(440),
    [anon_sym_CARET] = ACTIONS(438),
    [anon_sym_PERCENT] = ACTIONS(438),
    [anon_sym_LT_LT] = ACTIONS(438),
    [anon_sym_GT_GT] = ACTIONS(440),
    [anon_sym_GT_GT_GT] = ACTIONS(438),
    [anon_sym_instanceof] = ACTIONS(440),
    [anon_sym_final] = ACTIONS(440),
    [anon_sym_DASH_GT] = ACTIONS(438),
    [anon_sym_COMMA] = ACTIONS(438),
    [anon_sym_QMARK] = ACTIONS(438),
    [anon_sym_COLON] = ACTIONS(438),
    [anon_sym_BANG] = ACTIONS(440),
    [anon_sym_TILDE] = ACTIONS(438),
    [anon_sym_PLUS_PLUS] = ACTIONS(438),
    [anon_sym_DASH_DASH] = ACTIONS(438),
    [anon_sym_new] = ACTIONS(440),
    [anon_sym_RBRACK] = ACTIONS(438),
    [anon_sym_class] = ACTIONS(440),
    [anon_sym_switch] = ACTIONS(440),
    [anon_sym_LBRACE] = ACTIONS(438),
    [anon_sym_case] = ACTIONS(440),
    [anon_sym_default] = ACTIONS(440),
    [anon_sym_when] = ACTIONS(440),
    [anon_sym_SEMI] = ACTIONS(438),
    [anon_sym_assert] = ACTIONS(440),
    [anon_sym_do] = ACTIONS(440),
    [anon_sym_while] = ACTIONS(440),
    [anon_sym_break] = ACTIONS(440),
    [anon_sym_continue] = ACTIONS(440),
    [anon_sym_return] = ACTIONS(440),
    [anon_sym_yield] = ACTIONS(440),
    [anon_sym_synchronized] = ACTIONS(440),
    [anon_sym_throw] = ACTIONS(440),
    [anon_sym_try] = ACTIONS(440),
    [anon_sym_if] = ACTIONS(440),
    [anon_sym_else] = ACTIONS(440),
    [anon_sym_for] = ACTIONS(440),
    [anon_sym_AT] = ACTIONS(440),
    [anon_sym_open] = ACTIONS(440),
    [anon_sym_module] = ACTIONS(440),
    [anon_sym_static] = ACTIONS(440),
    [anon_sym_with] = ACTIONS(440),
    [anon_sym_package] = ACTIONS(440),
    [anon_sym_import] = ACTIONS(440),
    [anon_sym_enum] = ACTIONS(440),
    [anon_sym_public] = ACTIONS(440),
    [anon_sym_protected] = ACTIONS(440),
    [anon_sym_private] = ACTIONS(440),
    [anon_sym_abstract] = ACTIONS(440),
    [anon_sym_strictfp] = ACTIONS(440),
    [anon_sym_native] = ACTIONS(440),
    [anon_sym_transient] = ACTIONS(440),
    [anon_sym_volatile] = ACTIONS(440),
    [anon_sym_sealed] = ACTIONS(440),
    [anon_sym_non_DASHsealed] = ACTIONS(438),
    [anon_sym_record] = ACTIONS(440),
    [anon_sym_ATinterface] = ACTIONS(438),
    [anon_sym_interface] = ACTIONS(440),
    [anon_sym_byte] = ACTIONS(440),
    [anon_sym_short] = ACTIONS(440),
    [anon_sym_int] = ACTIONS(440),
    [anon_sym_long] = ACTIONS(440),
    [anon_sym_char] = ACTIONS(440),
    [anon_sym_float] = ACTIONS(440),
    [anon_sym_double] = ACTIONS(440),
    [sym_boolean_type] = ACTIONS(440),
    [sym_void_type] = ACTIONS(440),
    [sym_this] = ACTIONS(440),
    [sym_super] = ACTIONS(440),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [111] = {
    [ts_builtin_sym_end] = ACTIONS(442),
    [sym_identifier] = ACTIONS(444),
    [sym_decimal_integer_literal] = ACTIONS(444),
    [sym_hex_integer_literal] = ACTIONS(444),
    [sym_octal_integer_literal] = ACTIONS(444),
    [sym_binary_integer_literal] = ACTIONS(442),
    [sym_decimal_floating_point_literal] = ACTIONS(442),
    [sym_hex_floating_point_literal] = ACTIONS(444),
    [sym_true] = ACTIONS(444),
    [sym_false] = ACTIONS(444),
    [sym_character_literal] = ACTIONS(442),
    [anon_sym_DQUOTE] = ACTIONS(444),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(442),
    [anon_sym_RBRACE] = ACTIONS(442),
    [sym_null_literal] = ACTIONS(444),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_RPAREN] = ACTIONS(442),
    [anon_sym_AMP] = ACTIONS(444),
    [anon_sym_GT] = ACTIONS(444),
    [anon_sym_LT] = ACTIONS(444),
    [anon_sym_GT_EQ] = ACTIONS(442),
    [anon_sym_LT_EQ] = ACTIONS(442),
    [anon_sym_EQ_EQ] = ACTIONS(442),
    [anon_sym_BANG_EQ] = ACTIONS(442),
    [anon_sym_AMP_AMP] = ACTIONS(442),
    [anon_sym_PIPE_PIPE] = ACTIONS(442),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_STAR] = ACTIONS(442),
    [anon_sym_SLASH] = ACTIONS(444),
    [anon_sym_PIPE] = ACTIONS(444),
    [anon_sym_CARET] = ACTIONS(442),
    [anon_sym_PERCENT] = ACTIONS(442),
    [anon_sym_LT_LT] = ACTIONS(442),
    [anon_sym_GT_GT] = ACTIONS(444),
    [anon_sym_GT_GT_GT] = ACTIONS(442),
    [anon_sym_instanceof] = ACTIONS(444),
    [anon_sym_final] = ACTIONS(444),
    [anon_sym_DASH_GT] = ACTIONS(442),
    [anon_sym_COMMA] = ACTIONS(442),
    [anon_sym_QMARK] = ACTIONS(442),
    [anon_sym_COLON] = ACTIONS(442),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_TILDE] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(442),
    [anon_sym_DASH_DASH] = ACTIONS(442),
    [anon_sym_new] = ACTIONS(444),
    [anon_sym_RBRACK] = ACTIONS(442),
    [anon_sym_class] = ACTIONS(444),
    [anon_sym_switch] = ACTIONS(444),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_case] = ACTIONS(444),
    [anon_sym_default] = ACTIONS(444),
    [anon_sym_when] = ACTIONS(444),
    [anon_sym_SEMI] = ACTIONS(442),
    [anon_sym_assert] = ACTIONS(444),
    [anon_sym_do] = ACTIONS(444),
    [anon_sym_while] = ACTIONS(444),
    [anon_sym_break] = ACTIONS(444),
    [anon_sym_continue] = ACTIONS(444),
    [anon_sym_return] = ACTIONS(444),
    [anon_sym_yield] = ACTIONS(444),
    [anon_sym_synchronized] = ACTIONS(444),
    [anon_sym_throw] = ACTIONS(444),
    [anon_sym_try] = ACTIONS(444),
    [anon_sym_if] = ACTIONS(444),
    [anon_sym_else] = ACTIONS(444),
    [anon_sym_for] = ACTIONS(444),
    [anon_sym_AT] = ACTIONS(444),
    [anon_sym_open] = ACTIONS(444),
    [anon_sym_module] = ACTIONS(444),
    [anon_sym_static] = ACTIONS(444),
    [anon_sym_with] = ACTIONS(444),
    [anon_sym_package] = ACTIONS(444),
    [anon_sym_import] = ACTIONS(444),
    [anon_sym_enum] = ACTIONS(444),
    [anon_sym_public] = ACTIONS(444),
    [anon_sym_protected] = ACTIONS(444),
    [anon_sym_private] = ACTIONS(444),
    [anon_sym_abstract] = ACTIONS(444),
    [anon_sym_strictfp] = ACTIONS(444),
    [anon_sym_native] = ACTIONS(444),
    [anon_sym_transient] = ACTIONS(444),
    [anon_sym_volatile] = ACTIONS(444),
    [anon_sym_sealed] = ACTIONS(444),
    [anon_sym_non_DASHsealed] = ACTIONS(442),
    [anon_sym_record] = ACTIONS(444),
    [anon_sym_ATinterface] = ACTIONS(442),
    [anon_sym_interface] = ACTIONS(444),
    [anon_sym_byte] = ACTIONS(444),
    [anon_sym_short] = ACTIONS(444),
    [anon_sym_int] = ACTIONS(444),
    [anon_sym_long] = ACTIONS(444),
    [anon_sym_char] = ACTIONS(444),
    [anon_sym_float] = ACTIONS(444),
    [anon_sym_double] = ACTIONS(444),
    [sym_boolean_type] = ACTIONS(444),
    [sym_void_type] = ACTIONS(444),
    [sym_this] = ACTIONS(444),
    [sym_super] = ACTIONS(444),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [112] = {
    [sym_identifier] = ACTIONS(446),
    [sym_decimal_integer_literal] = ACTIONS(446),
    [sym_hex_integer_literal] = ACTIONS(446),
    [sym_octal_integer_literal] = ACTIONS(446),
    [sym_binary_integer_literal] = ACTIONS(448),
    [sym_decimal_floating_point_literal] = ACTIONS(448),
    [sym_hex_floating_point_literal] = ACTIONS(446),
    [sym_true] = ACTIONS(446),
    [sym_false] = ACTIONS(446),
    [sym_character_literal] = ACTIONS(448),
    [anon_sym_DQUOTE] = ACTIONS(446),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(448),
    [anon_sym_RBRACE] = ACTIONS(448),
    [sym_null_literal] = ACTIONS(446),
    [anon_sym_LPAREN] = ACTIONS(448),
    [anon_sym_RPAREN] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(446),
    [anon_sym_GT] = ACTIONS(446),
    [anon_sym_LT] = ACTIONS(446),
    [anon_sym_GT_EQ] = ACTIONS(448),
    [anon_sym_LT_EQ] = ACTIONS(448),
    [anon_sym_EQ_EQ] = ACTIONS(448),
    [anon_sym_BANG_EQ] = ACTIONS(448),
    [anon_sym_AMP_AMP] = ACTIONS(448),
    [anon_sym_PIPE_PIPE] = ACTIONS(448),
    [anon_sym_PLUS] = ACTIONS(446),
    [anon_sym_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(446),
    [anon_sym_PIPE] = ACTIONS(446),
    [anon_sym_CARET] = ACTIONS(448),
    [anon_sym_PERCENT] = ACTIONS(448),
    [anon_sym_LT_LT] = ACTIONS(448),
    [anon_sym_GT_GT] = ACTIONS(446),
    [anon_sym_GT_GT_GT] = ACTIONS(448),
    [anon_sym_instanceof] = ACTIONS(446),
    [anon_sym_final] = ACTIONS(446),
    [anon_sym_DASH_GT] = ACTIONS(448),
    [anon_sym_COMMA] = ACTIONS(448),
    [anon_sym_QMARK] = ACTIONS(448),
    [anon_sym_COLON] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(446),
    [anon_sym_TILDE] = ACTIONS(448),
    [anon_sym_PLUS_PLUS] = ACTIONS(448),
    [anon_sym_DASH_DASH] = ACTIONS(448),
    [anon_sym_new] = ACTIONS(446),
    [anon_sym_LBRACK] = ACTIONS(448),
    [anon_sym_RBRACK] = ACTIONS(448),
    [anon_sym_DOT] = ACTIONS(446),
    [anon_sym_class] = ACTIONS(446),
    [anon_sym_COLON_COLON] = ACTIONS(448),
    [anon_sym_switch] = ACTIONS(446),
    [anon_sym_LBRACE] = ACTIONS(448),
    [anon_sym_default] = ACTIONS(446),
    [anon_sym_when] = ACTIONS(446),
    [anon_sym_SEMI] = ACTIONS(448),
    [anon_sym_assert] = ACTIONS(446),
    [anon_sym_do] = ACTIONS(446),
    [anon_sym_while] = ACTIONS(446),
    [anon_sym_break] = ACTIONS(446),
    [anon_sym_continue] = ACTIONS(446),
    [anon_sym_return] = ACTIONS(446),
    [anon_sym_yield] = ACTIONS(446),
    [anon_sym_synchronized] = ACTIONS(446),
    [anon_sym_throw] = ACTIONS(446),
    [anon_sym_try] = ACTIONS(446),
    [anon_sym_if] = ACTIONS(446),
    [anon_sym_for] = ACTIONS(446),
    [anon_sym_AT] = ACTIONS(446),
    [anon_sym_open] = ACTIONS(446),
    [anon_sym_module] = ACTIONS(446),
    [anon_sym_static] = ACTIONS(446),
    [anon_sym_with] = ACTIONS(446),
    [anon_sym_package] = ACTIONS(446),
    [anon_sym_import] = ACTIONS(446),
    [anon_sym_enum] = ACTIONS(446),
    [anon_sym_public] = ACTIONS(446),
    [anon_sym_protected] = ACTIONS(446),
    [anon_sym_private] = ACTIONS(446),
    [anon_sym_abstract] = ACTIONS(446),
    [anon_sym_strictfp] = ACTIONS(446),
    [anon_sym_native] = ACTIONS(446),
    [anon_sym_transient] = ACTIONS(446),
    [anon_sym_volatile] = ACTIONS(446),
    [anon_sym_sealed] = ACTIONS(446),
    [anon_sym_non_DASHsealed] = ACTIONS(448),
    [anon_sym_record] = ACTIONS(446),
    [anon_sym_ATinterface] = ACTIONS(448),
    [anon_sym_interface] = ACTIONS(446),
    [anon_sym_byte] = ACTIONS(446),
    [anon_sym_short] = ACTIONS(446),
    [anon_sym_int] = ACTIONS(446),
    [anon_sym_long] = ACTIONS(446),
    [anon_sym_char] = ACTIONS(446),
    [anon_sym_float] = ACTIONS(446),
    [anon_sym_double] = ACTIONS(446),
    [sym_boolean_type] = ACTIONS(446),
    [sym_void_type] = ACTIONS(446),
    [sym_this] = ACTIONS(446),
    [sym_super] = ACTIONS(446),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [113] = {
    [ts_builtin_sym_end] = ACTIONS(450),
    [sym_identifier] = ACTIONS(452),
    [sym_decimal_integer_literal] = ACTIONS(452),
    [sym_hex_integer_literal] = ACTIONS(452),
    [sym_octal_integer_literal] = ACTIONS(452),
    [sym_binary_integer_literal] = ACTIONS(450),
    [sym_decimal_floating_point_literal] = ACTIONS(450),
    [sym_hex_floating_point_literal] = ACTIONS(452),
    [sym_true] = ACTIONS(452),
    [sym_false] = ACTIONS(452),
    [sym_character_literal] = ACTIONS(450),
    [anon_sym_DQUOTE] = ACTIONS(452),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(450),
    [anon_sym_RBRACE] = ACTIONS(450),
    [sym_null_literal] = ACTIONS(452),
    [anon_sym_LPAREN] = ACTIONS(450),
    [anon_sym_RPAREN] = ACTIONS(450),
    [anon_sym_AMP] = ACTIONS(452),
    [anon_sym_GT] = ACTIONS(452),
    [anon_sym_LT] = ACTIONS(452),
    [anon_sym_GT_EQ] = ACTIONS(450),
    [anon_sym_LT_EQ] = ACTIONS(450),
    [anon_sym_EQ_EQ] = ACTIONS(450),
    [anon_sym_BANG_EQ] = ACTIONS(450),
    [anon_sym_AMP_AMP] = ACTIONS(450),
    [anon_sym_PIPE_PIPE] = ACTIONS(450),
    [anon_sym_PLUS] = ACTIONS(452),
    [anon_sym_DASH] = ACTIONS(452),
    [anon_sym_STAR] = ACTIONS(450),
    [anon_sym_SLASH] = ACTIONS(452),
    [anon_sym_PIPE] = ACTIONS(452),
    [anon_sym_CARET] = ACTIONS(450),
    [anon_sym_PERCENT] = ACTIONS(450),
    [anon_sym_LT_LT] = ACTIONS(450),
    [anon_sym_GT_GT] = ACTIONS(452),
    [anon_sym_GT_GT_GT] = ACTIONS(450),
    [anon_sym_instanceof] = ACTIONS(452),
    [anon_sym_final] = ACTIONS(452),
    [anon_sym_DASH_GT] = ACTIONS(450),
    [anon_sym_COMMA] = ACTIONS(450),
    [anon_sym_QMARK] = ACTIONS(450),
    [anon_sym_COLON] = ACTIONS(450),
    [anon_sym_BANG] = ACTIONS(452),
    [anon_sym_TILDE] = ACTIONS(450),
    [anon_sym_PLUS_PLUS] = ACTIONS(450),
    [anon_sym_DASH_DASH] = ACTIONS(450),
    [anon_sym_new] = ACTIONS(452),
    [anon_sym_RBRACK] = ACTIONS(450),
    [anon_sym_class] = ACTIONS(452),
    [anon_sym_switch] = ACTIONS(452),
    [anon_sym_LBRACE] = ACTIONS(450),
    [anon_sym_case] = ACTIONS(452),
    [anon_sym_default] = ACTIONS(452),
    [anon_sym_when] = ACTIONS(452),
    [anon_sym_SEMI] = ACTIONS(450),
    [anon_sym_assert] = ACTIONS(452),
    [anon_sym_do] = ACTIONS(452),
    [anon_sym_while] = ACTIONS(452),
    [anon_sym_break] = ACTIONS(452),
    [anon_sym_continue] = ACTIONS(452),
    [anon_sym_return] = ACTIONS(452),
    [anon_sym_yield] = ACTIONS(452),
    [anon_sym_synchronized] = ACTIONS(452),
    [anon_sym_throw] = ACTIONS(452),
    [anon_sym_try] = ACTIONS(452),
    [anon_sym_if] = ACTIONS(452),
    [anon_sym_else] = ACTIONS(452),
    [anon_sym_for] = ACTIONS(452),
    [anon_sym_AT] = ACTIONS(452),
    [anon_sym_open] = ACTIONS(452),
    [anon_sym_module] = ACTIONS(452),
    [anon_sym_static] = ACTIONS(452),
    [anon_sym_with] = ACTIONS(452),
    [anon_sym_package] = ACTIONS(452),
    [anon_sym_import] = ACTIONS(452),
    [anon_sym_enum] = ACTIONS(452),
    [anon_sym_public] = ACTIONS(452),
    [anon_sym_protected] = ACTIONS(452),
    [anon_sym_private] = ACTIONS(452),
    [anon_sym_abstract] = ACTIONS(452),
    [anon_sym_strictfp] = ACTIONS(452),
    [anon_sym_native] = ACTIONS(452),
    [anon_sym_transient] = ACTIONS(452),
    [anon_sym_volatile] = ACTIONS(452),
    [anon_sym_sealed] = ACTIONS(452),
    [anon_sym_non_DASHsealed] = ACTIONS(450),
    [anon_sym_record] = ACTIONS(452),
    [anon_sym_ATinterface] = ACTIONS(450),
    [anon_sym_interface] = ACTIONS(452),
    [anon_sym_byte] = ACTIONS(452),
    [anon_sym_short] = ACTIONS(452),
    [anon_sym_int] = ACTIONS(452),
    [anon_sym_long] = ACTIONS(452),
    [anon_sym_char] = ACTIONS(452),
    [anon_sym_float] = ACTIONS(452),
    [anon_sym_double] = ACTIONS(452),
    [sym_boolean_type] = ACTIONS(452),
    [sym_void_type] = ACTIONS(452),
    [sym_this] = ACTIONS(452),
    [sym_super] = ACTIONS(452),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [114] = {
    [ts_builtin_sym_end] = ACTIONS(454),
    [sym_identifier] = ACTIONS(456),
    [sym_decimal_integer_literal] = ACTIONS(456),
    [sym_hex_integer_literal] = ACTIONS(456),
    [sym_octal_integer_literal] = ACTIONS(456),
    [sym_binary_integer_literal] = ACTIONS(454),
    [sym_decimal_floating_point_literal] = ACTIONS(454),
    [sym_hex_floating_point_literal] = ACTIONS(456),
    [sym_true] = ACTIONS(456),
    [sym_false] = ACTIONS(456),
    [sym_character_literal] = ACTIONS(454),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(454),
    [anon_sym_RBRACE] = ACTIONS(454),
    [sym_null_literal] = ACTIONS(456),
    [anon_sym_LPAREN] = ACTIONS(454),
    [anon_sym_RPAREN] = ACTIONS(454),
    [anon_sym_AMP] = ACTIONS(456),
    [anon_sym_GT] = ACTIONS(456),
    [anon_sym_LT] = ACTIONS(456),
    [anon_sym_GT_EQ] = ACTIONS(454),
    [anon_sym_LT_EQ] = ACTIONS(454),
    [anon_sym_EQ_EQ] = ACTIONS(454),
    [anon_sym_BANG_EQ] = ACTIONS(454),
    [anon_sym_AMP_AMP] = ACTIONS(454),
    [anon_sym_PIPE_PIPE] = ACTIONS(454),
    [anon_sym_PLUS] = ACTIONS(456),
    [anon_sym_DASH] = ACTIONS(456),
    [anon_sym_STAR] = ACTIONS(454),
    [anon_sym_SLASH] = ACTIONS(456),
    [anon_sym_PIPE] = ACTIONS(456),
    [anon_sym_CARET] = ACTIONS(454),
    [anon_sym_PERCENT] = ACTIONS(454),
    [anon_sym_LT_LT] = ACTIONS(454),
    [anon_sym_GT_GT] = ACTIONS(456),
    [anon_sym_GT_GT_GT] = ACTIONS(454),
    [anon_sym_instanceof] = ACTIONS(456),
    [anon_sym_final] = ACTIONS(456),
    [anon_sym_DASH_GT] = ACTIONS(454),
    [anon_sym_COMMA] = ACTIONS(454),
    [anon_sym_QMARK] = ACTIONS(454),
    [anon_sym_COLON] = ACTIONS(454),
    [anon_sym_BANG] = ACTIONS(456),
    [anon_sym_TILDE] = ACTIONS(454),
    [anon_sym_PLUS_PLUS] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(454),
    [anon_sym_new] = ACTIONS(456),
    [anon_sym_RBRACK] = ACTIONS(454),
    [anon_sym_class] = ACTIONS(456),
    [anon_sym_switch] = ACTIONS(456),
    [anon_sym_LBRACE] = ACTIONS(454),
    [anon_sym_case] = ACTIONS(456),
    [anon_sym_default] = ACTIONS(456),
    [anon_sym_when] = ACTIONS(456),
    [anon_sym_SEMI] = ACTIONS(454),
    [anon_sym_assert] = ACTIONS(456),
    [anon_sym_do] = ACTIONS(456),
    [anon_sym_while] = ACTIONS(456),
    [anon_sym_break] = ACTIONS(456),
    [anon_sym_continue] = ACTIONS(456),
    [anon_sym_return] = ACTIONS(456),
    [anon_sym_yield] = ACTIONS(456),
    [anon_sym_synchronized] = ACTIONS(456),
    [anon_sym_throw] = ACTIONS(456),
    [anon_sym_try] = ACTIONS(456),
    [anon_sym_if] = ACTIONS(456),
    [anon_sym_else] = ACTIONS(456),
    [anon_sym_for] = ACTIONS(456),
    [anon_sym_AT] = ACTIONS(456),
    [anon_sym_open] = ACTIONS(456),
    [anon_sym_module] = ACTIONS(456),
    [anon_sym_static] = ACTIONS(456),
    [anon_sym_with] = ACTIONS(456),
    [anon_sym_package] = ACTIONS(456),
    [anon_sym_import] = ACTIONS(456),
    [anon_sym_enum] = ACTIONS(456),
    [anon_sym_public] = ACTIONS(456),
    [anon_sym_protected] = ACTIONS(456),
    [anon_sym_private] = ACTIONS(456),
    [anon_sym_abstract] = ACTIONS(456),
    [anon_sym_strictfp] = ACTIONS(456),
    [anon_sym_native] = ACTIONS(456),
    [anon_sym_transient] = ACTIONS(456),
    [anon_sym_volatile] = ACTIONS(456),
    [anon_sym_sealed] = ACTIONS(456),
    [anon_sym_non_DASHsealed] = ACTIONS(454),
    [anon_sym_record] = ACTIONS(456),
    [anon_sym_ATinterface] = ACTIONS(454),
    [anon_sym_interface] = ACTIONS(456),
    [anon_sym_byte] = ACTIONS(456),
    [anon_sym_short] = ACTIONS(456),
    [anon_sym_int] = ACTIONS(456),
    [anon_sym_long] = ACTIONS(456),
    [anon_sym_char] = ACTIONS(456),
    [anon_sym_float] = ACTIONS(456),
    [anon_sym_double] = ACTIONS(456),
    [sym_boolean_type] = ACTIONS(456),
    [sym_void_type] = ACTIONS(456),
    [sym_this] = ACTIONS(456),
    [sym_super] = ACTIONS(456),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [115] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(746),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(834),
    [sym__type] = STATE(1056),
    [sym__unannotated_type] = STATE(689),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_formal_parameter] = STATE(1072),
    [sym_receiver_parameter] = STATE(1187),
    [sym_spread_parameter] = STATE(1072),
    [sym__reserved_identifier] = STATE(444),
    [aux_sym_array_creation_expression_repeat1] = STATE(780),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(458),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(460),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [116] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(746),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(834),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(689),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_formal_parameter] = STATE(1072),
    [sym_receiver_parameter] = STATE(1187),
    [sym_spread_parameter] = STATE(1072),
    [sym__reserved_identifier] = STATE(444),
    [aux_sym_array_creation_expression_repeat1] = STATE(780),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(470),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(460),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [117] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(746),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(834),
    [sym__type] = STATE(1025),
    [sym__unannotated_type] = STATE(689),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_formal_parameter] = STATE(1072),
    [sym_receiver_parameter] = STATE(1187),
    [sym_spread_parameter] = STATE(1072),
    [sym__reserved_identifier] = STATE(444),
    [aux_sym_array_creation_expression_repeat1] = STATE(780),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(458),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(460),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [118] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(677),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(833),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(771),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(189),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(472),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [119] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(653),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(832),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(769),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(160),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(474),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [120] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(660),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(837),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(765),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym_local_variable_declaration] = STATE(177),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_SEMI] = ACTIONS(476),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [121] = {
    [sym_identifier] = ACTIONS(478),
    [sym_decimal_integer_literal] = ACTIONS(478),
    [sym_hex_integer_literal] = ACTIONS(478),
    [sym_octal_integer_literal] = ACTIONS(478),
    [sym_binary_integer_literal] = ACTIONS(480),
    [sym_decimal_floating_point_literal] = ACTIONS(480),
    [sym_hex_floating_point_literal] = ACTIONS(478),
    [sym_true] = ACTIONS(478),
    [sym_false] = ACTIONS(478),
    [sym_character_literal] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(478),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(480),
    [anon_sym_RBRACE] = ACTIONS(480),
    [sym_null_literal] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(480),
    [anon_sym_AMP] = ACTIONS(482),
    [anon_sym_GT] = ACTIONS(482),
    [anon_sym_LT] = ACTIONS(482),
    [anon_sym_GT_EQ] = ACTIONS(484),
    [anon_sym_LT_EQ] = ACTIONS(484),
    [anon_sym_EQ_EQ] = ACTIONS(484),
    [anon_sym_BANG_EQ] = ACTIONS(484),
    [anon_sym_AMP_AMP] = ACTIONS(484),
    [anon_sym_PIPE_PIPE] = ACTIONS(484),
    [anon_sym_PLUS] = ACTIONS(486),
    [anon_sym_DASH] = ACTIONS(486),
    [anon_sym_STAR] = ACTIONS(484),
    [anon_sym_SLASH] = ACTIONS(482),
    [anon_sym_PIPE] = ACTIONS(482),
    [anon_sym_CARET] = ACTIONS(484),
    [anon_sym_PERCENT] = ACTIONS(484),
    [anon_sym_LT_LT] = ACTIONS(484),
    [anon_sym_GT_GT] = ACTIONS(482),
    [anon_sym_GT_GT_GT] = ACTIONS(484),
    [anon_sym_instanceof] = ACTIONS(482),
    [anon_sym_final] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(484),
    [anon_sym_BANG] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(489),
    [anon_sym_DASH_DASH] = ACTIONS(489),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(480),
    [anon_sym_case] = ACTIONS(478),
    [anon_sym_default] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_assert] = ACTIONS(478),
    [anon_sym_do] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_continue] = ACTIONS(478),
    [anon_sym_return] = ACTIONS(478),
    [anon_sym_yield] = ACTIONS(478),
    [anon_sym_synchronized] = ACTIONS(478),
    [anon_sym_throw] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(478),
    [anon_sym_open] = ACTIONS(478),
    [anon_sym_module] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_with] = ACTIONS(478),
    [anon_sym_package] = ACTIONS(478),
    [anon_sym_import] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_protected] = ACTIONS(478),
    [anon_sym_private] = ACTIONS(478),
    [anon_sym_abstract] = ACTIONS(478),
    [anon_sym_strictfp] = ACTIONS(478),
    [anon_sym_native] = ACTIONS(478),
    [anon_sym_transient] = ACTIONS(478),
    [anon_sym_volatile] = ACTIONS(478),
    [anon_sym_sealed] = ACTIONS(478),
    [anon_sym_non_DASHsealed] = ACTIONS(480),
    [anon_sym_record] = ACTIONS(478),
    [anon_sym_ATinterface] = ACTIONS(480),
    [anon_sym_interface] = ACTIONS(478),
    [anon_sym_byte] = ACTIONS(478),
    [anon_sym_short] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_long] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_double] = ACTIONS(478),
    [sym_boolean_type] = ACTIONS(478),
    [sym_void_type] = ACTIONS(478),
    [sym_this] = ACTIONS(478),
    [sym_super] = ACTIONS(478),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [122] = {
    [ts_builtin_sym_end] = ACTIONS(480),
    [sym_identifier] = ACTIONS(478),
    [sym_decimal_integer_literal] = ACTIONS(478),
    [sym_hex_integer_literal] = ACTIONS(478),
    [sym_octal_integer_literal] = ACTIONS(478),
    [sym_binary_integer_literal] = ACTIONS(480),
    [sym_decimal_floating_point_literal] = ACTIONS(480),
    [sym_hex_floating_point_literal] = ACTIONS(478),
    [sym_true] = ACTIONS(478),
    [sym_false] = ACTIONS(478),
    [sym_character_literal] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(478),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(480),
    [sym_null_literal] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(480),
    [anon_sym_AMP] = ACTIONS(482),
    [anon_sym_GT] = ACTIONS(482),
    [anon_sym_LT] = ACTIONS(486),
    [anon_sym_GT_EQ] = ACTIONS(484),
    [anon_sym_LT_EQ] = ACTIONS(484),
    [anon_sym_EQ_EQ] = ACTIONS(484),
    [anon_sym_BANG_EQ] = ACTIONS(484),
    [anon_sym_AMP_AMP] = ACTIONS(484),
    [anon_sym_PIPE_PIPE] = ACTIONS(484),
    [anon_sym_PLUS] = ACTIONS(486),
    [anon_sym_DASH] = ACTIONS(486),
    [anon_sym_STAR] = ACTIONS(484),
    [anon_sym_SLASH] = ACTIONS(482),
    [anon_sym_PIPE] = ACTIONS(482),
    [anon_sym_CARET] = ACTIONS(484),
    [anon_sym_PERCENT] = ACTIONS(484),
    [anon_sym_LT_LT] = ACTIONS(484),
    [anon_sym_GT_GT] = ACTIONS(482),
    [anon_sym_GT_GT_GT] = ACTIONS(484),
    [anon_sym_instanceof] = ACTIONS(482),
    [anon_sym_final] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(484),
    [anon_sym_BANG] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(489),
    [anon_sym_DASH_DASH] = ACTIONS(489),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(480),
    [anon_sym_default] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_assert] = ACTIONS(478),
    [anon_sym_do] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_continue] = ACTIONS(478),
    [anon_sym_return] = ACTIONS(478),
    [anon_sym_yield] = ACTIONS(478),
    [anon_sym_synchronized] = ACTIONS(478),
    [anon_sym_throw] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(478),
    [anon_sym_open] = ACTIONS(478),
    [anon_sym_module] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_with] = ACTIONS(478),
    [anon_sym_package] = ACTIONS(478),
    [anon_sym_import] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_protected] = ACTIONS(478),
    [anon_sym_private] = ACTIONS(478),
    [anon_sym_abstract] = ACTIONS(478),
    [anon_sym_strictfp] = ACTIONS(478),
    [anon_sym_native] = ACTIONS(478),
    [anon_sym_transient] = ACTIONS(478),
    [anon_sym_volatile] = ACTIONS(478),
    [anon_sym_sealed] = ACTIONS(478),
    [anon_sym_non_DASHsealed] = ACTIONS(480),
    [anon_sym_record] = ACTIONS(478),
    [anon_sym_ATinterface] = ACTIONS(480),
    [anon_sym_interface] = ACTIONS(478),
    [anon_sym_byte] = ACTIONS(478),
    [anon_sym_short] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_long] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_double] = ACTIONS(478),
    [sym_boolean_type] = ACTIONS(478),
    [sym_void_type] = ACTIONS(478),
    [sym_this] = ACTIONS(478),
    [sym_super] = ACTIONS(478),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [123] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(733),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_block] = STATE(1131),
    [sym_expression_statement] = STATE(1131),
    [sym_throw_statement] = STATE(1131),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_throw] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [124] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym_element_value_pair] = STATE(1174),
    [sym__element_value] = STATE(1352),
    [sym_element_value_array_initializer] = STATE(1352),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(492),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(494),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [125] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym_element_value_pair] = STATE(1147),
    [sym__element_value] = STATE(1322),
    [sym_element_value_array_initializer] = STATE(1322),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(492),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(498),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [126] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1167),
    [sym_element_value_array_initializer] = STATE(1167),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(500),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(502),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [127] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym_element_value_pair] = STATE(1149),
    [sym__element_value] = STATE(1325),
    [sym_element_value_array_initializer] = STATE(1325),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(492),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(504),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [128] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(684),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_record_pattern] = STATE(1150),
    [sym_record_pattern_component] = STATE(1150),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(815),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(852),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(442),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(506),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(508),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [sym_underscore_pattern] = ACTIONS(510),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [129] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(682),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym_array_initializer] = STATE(1168),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(512),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_COMMA] = ACTIONS(514),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [130] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1226),
    [sym_element_value_array_initializer] = STATE(1226),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(518),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [131] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1226),
    [sym_element_value_array_initializer] = STATE(1226),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(520),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [132] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(684),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_record_pattern] = STATE(1150),
    [sym_record_pattern_component] = STATE(1150),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(815),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(852),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(442),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(506),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(522),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [sym_underscore_pattern] = ACTIONS(510),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [133] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(704),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1281),
    [sym_element_value_array_initializer] = STATE(1281),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [134] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1281),
    [sym_element_value_array_initializer] = STATE(1281),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [135] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1226),
    [sym_element_value_array_initializer] = STATE(1226),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [136] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(703),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym_array_initializer] = STATE(1232),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(524),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [137] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(703),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym_array_initializer] = STATE(1232),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [anon_sym_RBRACE] = ACTIONS(526),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [138] = {
    [sym_identifier] = ACTIONS(420),
    [anon_sym_RBRACE] = ACTIONS(422),
    [anon_sym_LPAREN] = ACTIONS(422),
    [anon_sym_RPAREN] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_AMP_EQ] = ACTIONS(422),
    [anon_sym_PIPE_EQ] = ACTIONS(422),
    [anon_sym_CARET_EQ] = ACTIONS(422),
    [anon_sym_PERCENT_EQ] = ACTIONS(422),
    [anon_sym_LT_LT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_LT] = ACTIONS(420),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_AMP_AMP] = ACTIONS(422),
    [anon_sym_PIPE_PIPE] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(420),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PIPE] = ACTIONS(420),
    [anon_sym_CARET] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(420),
    [anon_sym_LT_LT] = ACTIONS(420),
    [anon_sym_GT_GT] = ACTIONS(420),
    [anon_sym_GT_GT_GT] = ACTIONS(420),
    [anon_sym_instanceof] = ACTIONS(420),
    [anon_sym_final] = ACTIONS(420),
    [anon_sym_DASH_GT] = ACTIONS(422),
    [anon_sym_COMMA] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_COLON] = ACTIONS(420),
    [anon_sym_PLUS_PLUS] = ACTIONS(422),
    [anon_sym_DASH_DASH] = ACTIONS(422),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_RBRACK] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_class] = ACTIONS(420),
    [anon_sym_COLON_COLON] = ACTIONS(422),
    [anon_sym_LBRACE] = ACTIONS(422),
    [anon_sym_default] = ACTIONS(420),
    [anon_sym_when] = ACTIONS(420),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_synchronized] = ACTIONS(420),
    [anon_sym_AT] = ACTIONS(420),
    [anon_sym_open] = ACTIONS(420),
    [anon_sym_module] = ACTIONS(420),
    [anon_sym_static] = ACTIONS(420),
    [anon_sym_to] = ACTIONS(420),
    [anon_sym_with] = ACTIONS(420),
    [anon_sym_package] = ACTIONS(420),
    [anon_sym_enum] = ACTIONS(420),
    [anon_sym_public] = ACTIONS(420),
    [anon_sym_protected] = ACTIONS(420),
    [anon_sym_private] = ACTIONS(420),
    [anon_sym_abstract] = ACTIONS(420),
    [anon_sym_strictfp] = ACTIONS(420),
    [anon_sym_native] = ACTIONS(420),
    [anon_sym_transient] = ACTIONS(420),
    [anon_sym_volatile] = ACTIONS(420),
    [anon_sym_sealed] = ACTIONS(420),
    [anon_sym_non_DASHsealed] = ACTIONS(422),
    [anon_sym_record] = ACTIONS(420),
    [anon_sym_ATinterface] = ACTIONS(422),
    [anon_sym_interface] = ACTIONS(420),
    [anon_sym_byte] = ACTIONS(420),
    [anon_sym_short] = ACTIONS(420),
    [anon_sym_int] = ACTIONS(420),
    [anon_sym_long] = ACTIONS(420),
    [anon_sym_char] = ACTIONS(420),
    [anon_sym_float] = ACTIONS(420),
    [anon_sym_double] = ACTIONS(420),
    [sym_boolean_type] = ACTIONS(420),
    [sym_void_type] = ACTIONS(420),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [139] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(625),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_pattern] = STATE(1044),
    [sym_type_pattern] = STATE(1172),
    [sym_record_pattern] = STATE(1172),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(814),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(852),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(440),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(528),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [140] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(628),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_pattern] = STATE(1169),
    [sym_type_pattern] = STATE(1172),
    [sym_record_pattern] = STATE(1172),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(814),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(852),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(438),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(538),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [141] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(649),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(846),
    [sym_marker_annotation] = STATE(846),
    [sym_annotation] = STATE(846),
    [sym__element_value] = STATE(1367),
    [sym_element_value_array_initializer] = STATE(1367),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(496),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [142] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(703),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym_array_initializer] = STATE(1232),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [143] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(621),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_block] = STATE(593),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [144] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(633),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym_block] = STATE(593),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(35),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [145] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(687),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym_array_initializer] = STATE(1159),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [146] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(719),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_RBRACK] = ACTIONS(542),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [147] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(668),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(544),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [148] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(667),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [149] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(720),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(548),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [150] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(732),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(550),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [151] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(670),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(552),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [152] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(725),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(554),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [153] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(672),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(556),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [154] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(686),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(558),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [155] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(659),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(560),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [156] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(679),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(562),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [157] = {
    [sym_catch_clause] = STATE(206),
    [sym_finally_clause] = STATE(324),
    [aux_sym_try_statement_repeat1] = STATE(206),
    [ts_builtin_sym_end] = ACTIONS(564),
    [sym_identifier] = ACTIONS(566),
    [sym_decimal_integer_literal] = ACTIONS(566),
    [sym_hex_integer_literal] = ACTIONS(566),
    [sym_octal_integer_literal] = ACTIONS(566),
    [sym_binary_integer_literal] = ACTIONS(564),
    [sym_decimal_floating_point_literal] = ACTIONS(564),
    [sym_hex_floating_point_literal] = ACTIONS(566),
    [sym_true] = ACTIONS(566),
    [sym_false] = ACTIONS(566),
    [sym_character_literal] = ACTIONS(564),
    [anon_sym_DQUOTE] = ACTIONS(566),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(564),
    [anon_sym_RBRACE] = ACTIONS(564),
    [sym_null_literal] = ACTIONS(566),
    [anon_sym_LPAREN] = ACTIONS(564),
    [anon_sym_LT] = ACTIONS(564),
    [anon_sym_PLUS] = ACTIONS(566),
    [anon_sym_DASH] = ACTIONS(566),
    [anon_sym_final] = ACTIONS(566),
    [anon_sym_BANG] = ACTIONS(564),
    [anon_sym_TILDE] = ACTIONS(564),
    [anon_sym_PLUS_PLUS] = ACTIONS(564),
    [anon_sym_DASH_DASH] = ACTIONS(564),
    [anon_sym_new] = ACTIONS(566),
    [anon_sym_class] = ACTIONS(566),
    [anon_sym_switch] = ACTIONS(566),
    [anon_sym_LBRACE] = ACTIONS(564),
    [anon_sym_case] = ACTIONS(566),
    [anon_sym_default] = ACTIONS(566),
    [anon_sym_SEMI] = ACTIONS(564),
    [anon_sym_assert] = ACTIONS(566),
    [anon_sym_do] = ACTIONS(566),
    [anon_sym_while] = ACTIONS(566),
    [anon_sym_break] = ACTIONS(566),
    [anon_sym_continue] = ACTIONS(566),
    [anon_sym_return] = ACTIONS(566),
    [anon_sym_yield] = ACTIONS(566),
    [anon_sym_synchronized] = ACTIONS(566),
    [anon_sym_throw] = ACTIONS(566),
    [anon_sym_try] = ACTIONS(566),
    [anon_sym_catch] = ACTIONS(568),
    [anon_sym_finally] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(566),
    [anon_sym_else] = ACTIONS(566),
    [anon_sym_for] = ACTIONS(566),
    [anon_sym_AT] = ACTIONS(566),
    [anon_sym_open] = ACTIONS(566),
    [anon_sym_module] = ACTIONS(566),
    [anon_sym_static] = ACTIONS(566),
    [anon_sym_with] = ACTIONS(566),
    [anon_sym_package] = ACTIONS(566),
    [anon_sym_import] = ACTIONS(566),
    [anon_sym_enum] = ACTIONS(566),
    [anon_sym_public] = ACTIONS(566),
    [anon_sym_protected] = ACTIONS(566),
    [anon_sym_private] = ACTIONS(566),
    [anon_sym_abstract] = ACTIONS(566),
    [anon_sym_strictfp] = ACTIONS(566),
    [anon_sym_native] = ACTIONS(566),
    [anon_sym_transient] = ACTIONS(566),
    [anon_sym_volatile] = ACTIONS(566),
    [anon_sym_sealed] = ACTIONS(566),
    [anon_sym_non_DASHsealed] = ACTIONS(564),
    [anon_sym_record] = ACTIONS(566),
    [anon_sym_ATinterface] = ACTIONS(564),
    [anon_sym_interface] = ACTIONS(566),
    [anon_sym_byte] = ACTIONS(566),
    [anon_sym_short] = ACTIONS(566),
    [anon_sym_int] = ACTIONS(566),
    [anon_sym_long] = ACTIONS(566),
    [anon_sym_char] = ACTIONS(566),
    [anon_sym_float] = ACTIONS(566),
    [anon_sym_double] = ACTIONS(566),
    [sym_boolean_type] = ACTIONS(566),
    [sym_void_type] = ACTIONS(566),
    [sym_this] = ACTIONS(566),
    [sym_super] = ACTIONS(566),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [158] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(741),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(572),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [159] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(675),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(574),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [160] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(751),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(576),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [161] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(651),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(578),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [162] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(655),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(580),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [163] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(730),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [164] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(658),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [165] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(684),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(586),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [166] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(676),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [167] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(674),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(590),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [168] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(724),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_RBRACK] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [169] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(671),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(594),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [170] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(678),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(596),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [171] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(724),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_RBRACK] = ACTIONS(598),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [172] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(664),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(600),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [173] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(654),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(602),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [174] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(717),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(604),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [175] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(681),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(606),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [176] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(749),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(608),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [177] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(736),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(610),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [178] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(734),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(612),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [179] = {
    [sym_catch_clause] = STATE(157),
    [sym_finally_clause] = STATE(296),
    [aux_sym_try_statement_repeat1] = STATE(157),
    [ts_builtin_sym_end] = ACTIONS(614),
    [sym_identifier] = ACTIONS(616),
    [sym_decimal_integer_literal] = ACTIONS(616),
    [sym_hex_integer_literal] = ACTIONS(616),
    [sym_octal_integer_literal] = ACTIONS(616),
    [sym_binary_integer_literal] = ACTIONS(614),
    [sym_decimal_floating_point_literal] = ACTIONS(614),
    [sym_hex_floating_point_literal] = ACTIONS(616),
    [sym_true] = ACTIONS(616),
    [sym_false] = ACTIONS(616),
    [sym_character_literal] = ACTIONS(614),
    [anon_sym_DQUOTE] = ACTIONS(616),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(614),
    [anon_sym_RBRACE] = ACTIONS(614),
    [sym_null_literal] = ACTIONS(616),
    [anon_sym_LPAREN] = ACTIONS(614),
    [anon_sym_LT] = ACTIONS(614),
    [anon_sym_PLUS] = ACTIONS(616),
    [anon_sym_DASH] = ACTIONS(616),
    [anon_sym_final] = ACTIONS(616),
    [anon_sym_BANG] = ACTIONS(614),
    [anon_sym_TILDE] = ACTIONS(614),
    [anon_sym_PLUS_PLUS] = ACTIONS(614),
    [anon_sym_DASH_DASH] = ACTIONS(614),
    [anon_sym_new] = ACTIONS(616),
    [anon_sym_class] = ACTIONS(616),
    [anon_sym_switch] = ACTIONS(616),
    [anon_sym_LBRACE] = ACTIONS(614),
    [anon_sym_case] = ACTIONS(616),
    [anon_sym_default] = ACTIONS(616),
    [anon_sym_SEMI] = ACTIONS(614),
    [anon_sym_assert] = ACTIONS(616),
    [anon_sym_do] = ACTIONS(616),
    [anon_sym_while] = ACTIONS(616),
    [anon_sym_break] = ACTIONS(616),
    [anon_sym_continue] = ACTIONS(616),
    [anon_sym_return] = ACTIONS(616),
    [anon_sym_yield] = ACTIONS(616),
    [anon_sym_synchronized] = ACTIONS(616),
    [anon_sym_throw] = ACTIONS(616),
    [anon_sym_try] = ACTIONS(616),
    [anon_sym_catch] = ACTIONS(568),
    [anon_sym_finally] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(616),
    [anon_sym_else] = ACTIONS(616),
    [anon_sym_for] = ACTIONS(616),
    [anon_sym_AT] = ACTIONS(616),
    [anon_sym_open] = ACTIONS(616),
    [anon_sym_module] = ACTIONS(616),
    [anon_sym_static] = ACTIONS(616),
    [anon_sym_with] = ACTIONS(616),
    [anon_sym_package] = ACTIONS(616),
    [anon_sym_import] = ACTIONS(616),
    [anon_sym_enum] = ACTIONS(616),
    [anon_sym_public] = ACTIONS(616),
    [anon_sym_protected] = ACTIONS(616),
    [anon_sym_private] = ACTIONS(616),
    [anon_sym_abstract] = ACTIONS(616),
    [anon_sym_strictfp] = ACTIONS(616),
    [anon_sym_native] = ACTIONS(616),
    [anon_sym_transient] = ACTIONS(616),
    [anon_sym_volatile] = ACTIONS(616),
    [anon_sym_sealed] = ACTIONS(616),
    [anon_sym_non_DASHsealed] = ACTIONS(614),
    [anon_sym_record] = ACTIONS(616),
    [anon_sym_ATinterface] = ACTIONS(614),
    [anon_sym_interface] = ACTIONS(616),
    [anon_sym_byte] = ACTIONS(616),
    [anon_sym_short] = ACTIONS(616),
    [anon_sym_int] = ACTIONS(616),
    [anon_sym_long] = ACTIONS(616),
    [anon_sym_char] = ACTIONS(616),
    [anon_sym_float] = ACTIONS(616),
    [anon_sym_double] = ACTIONS(616),
    [sym_boolean_type] = ACTIONS(616),
    [sym_void_type] = ACTIONS(616),
    [sym_this] = ACTIONS(616),
    [sym_super] = ACTIONS(616),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [180] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(662),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [181] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(719),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_RBRACK] = ACTIONS(620),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [182] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(666),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(622),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [183] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(710),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [184] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(656),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(626),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [185] = {
    [sym_catch_clause] = STATE(206),
    [sym_finally_clause] = STATE(300),
    [aux_sym_try_statement_repeat1] = STATE(206),
    [ts_builtin_sym_end] = ACTIONS(628),
    [sym_identifier] = ACTIONS(630),
    [sym_decimal_integer_literal] = ACTIONS(630),
    [sym_hex_integer_literal] = ACTIONS(630),
    [sym_octal_integer_literal] = ACTIONS(630),
    [sym_binary_integer_literal] = ACTIONS(628),
    [sym_decimal_floating_point_literal] = ACTIONS(628),
    [sym_hex_floating_point_literal] = ACTIONS(630),
    [sym_true] = ACTIONS(630),
    [sym_false] = ACTIONS(630),
    [sym_character_literal] = ACTIONS(628),
    [anon_sym_DQUOTE] = ACTIONS(630),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(628),
    [anon_sym_RBRACE] = ACTIONS(628),
    [sym_null_literal] = ACTIONS(630),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LT] = ACTIONS(628),
    [anon_sym_PLUS] = ACTIONS(630),
    [anon_sym_DASH] = ACTIONS(630),
    [anon_sym_final] = ACTIONS(630),
    [anon_sym_BANG] = ACTIONS(628),
    [anon_sym_TILDE] = ACTIONS(628),
    [anon_sym_PLUS_PLUS] = ACTIONS(628),
    [anon_sym_DASH_DASH] = ACTIONS(628),
    [anon_sym_new] = ACTIONS(630),
    [anon_sym_class] = ACTIONS(630),
    [anon_sym_switch] = ACTIONS(630),
    [anon_sym_LBRACE] = ACTIONS(628),
    [anon_sym_case] = ACTIONS(630),
    [anon_sym_default] = ACTIONS(630),
    [anon_sym_SEMI] = ACTIONS(628),
    [anon_sym_assert] = ACTIONS(630),
    [anon_sym_do] = ACTIONS(630),
    [anon_sym_while] = ACTIONS(630),
    [anon_sym_break] = ACTIONS(630),
    [anon_sym_continue] = ACTIONS(630),
    [anon_sym_return] = ACTIONS(630),
    [anon_sym_yield] = ACTIONS(630),
    [anon_sym_synchronized] = ACTIONS(630),
    [anon_sym_throw] = ACTIONS(630),
    [anon_sym_try] = ACTIONS(630),
    [anon_sym_catch] = ACTIONS(568),
    [anon_sym_finally] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(630),
    [anon_sym_else] = ACTIONS(630),
    [anon_sym_for] = ACTIONS(630),
    [anon_sym_AT] = ACTIONS(630),
    [anon_sym_open] = ACTIONS(630),
    [anon_sym_module] = ACTIONS(630),
    [anon_sym_static] = ACTIONS(630),
    [anon_sym_with] = ACTIONS(630),
    [anon_sym_package] = ACTIONS(630),
    [anon_sym_import] = ACTIONS(630),
    [anon_sym_enum] = ACTIONS(630),
    [anon_sym_public] = ACTIONS(630),
    [anon_sym_protected] = ACTIONS(630),
    [anon_sym_private] = ACTIONS(630),
    [anon_sym_abstract] = ACTIONS(630),
    [anon_sym_strictfp] = ACTIONS(630),
    [anon_sym_native] = ACTIONS(630),
    [anon_sym_transient] = ACTIONS(630),
    [anon_sym_volatile] = ACTIONS(630),
    [anon_sym_sealed] = ACTIONS(630),
    [anon_sym_non_DASHsealed] = ACTIONS(628),
    [anon_sym_record] = ACTIONS(630),
    [anon_sym_ATinterface] = ACTIONS(628),
    [anon_sym_interface] = ACTIONS(630),
    [anon_sym_byte] = ACTIONS(630),
    [anon_sym_short] = ACTIONS(630),
    [anon_sym_int] = ACTIONS(630),
    [anon_sym_long] = ACTIONS(630),
    [anon_sym_char] = ACTIONS(630),
    [anon_sym_float] = ACTIONS(630),
    [anon_sym_double] = ACTIONS(630),
    [sym_boolean_type] = ACTIONS(630),
    [sym_void_type] = ACTIONS(630),
    [sym_this] = ACTIONS(630),
    [sym_super] = ACTIONS(630),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [186] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(665),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(632),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [187] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(727),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(634),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [188] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(661),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(636),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [189] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(737),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_SEMI] = ACTIONS(638),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [190] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(683),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_RPAREN] = ACTIONS(640),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [191] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(713),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [192] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(744),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [193] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(632),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [194] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(645),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [195] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(726),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [196] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(586),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(607),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(535),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [197] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(586),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(607),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(535),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [198] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(699),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [199] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(641),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [200] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(639),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [201] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(708),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [202] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(721),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [203] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(602),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [204] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(609),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [205] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(740),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [206] = {
    [sym_catch_clause] = STATE(206),
    [aux_sym_try_statement_repeat1] = STATE(206),
    [ts_builtin_sym_end] = ACTIONS(642),
    [sym_identifier] = ACTIONS(644),
    [sym_decimal_integer_literal] = ACTIONS(644),
    [sym_hex_integer_literal] = ACTIONS(644),
    [sym_octal_integer_literal] = ACTIONS(644),
    [sym_binary_integer_literal] = ACTIONS(642),
    [sym_decimal_floating_point_literal] = ACTIONS(642),
    [sym_hex_floating_point_literal] = ACTIONS(644),
    [sym_true] = ACTIONS(644),
    [sym_false] = ACTIONS(644),
    [sym_character_literal] = ACTIONS(642),
    [anon_sym_DQUOTE] = ACTIONS(644),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(642),
    [anon_sym_RBRACE] = ACTIONS(642),
    [sym_null_literal] = ACTIONS(644),
    [anon_sym_LPAREN] = ACTIONS(642),
    [anon_sym_LT] = ACTIONS(642),
    [anon_sym_PLUS] = ACTIONS(644),
    [anon_sym_DASH] = ACTIONS(644),
    [anon_sym_final] = ACTIONS(644),
    [anon_sym_BANG] = ACTIONS(642),
    [anon_sym_TILDE] = ACTIONS(642),
    [anon_sym_PLUS_PLUS] = ACTIONS(642),
    [anon_sym_DASH_DASH] = ACTIONS(642),
    [anon_sym_new] = ACTIONS(644),
    [anon_sym_class] = ACTIONS(644),
    [anon_sym_switch] = ACTIONS(644),
    [anon_sym_LBRACE] = ACTIONS(642),
    [anon_sym_case] = ACTIONS(644),
    [anon_sym_default] = ACTIONS(644),
    [anon_sym_SEMI] = ACTIONS(642),
    [anon_sym_assert] = ACTIONS(644),
    [anon_sym_do] = ACTIONS(644),
    [anon_sym_while] = ACTIONS(644),
    [anon_sym_break] = ACTIONS(644),
    [anon_sym_continue] = ACTIONS(644),
    [anon_sym_return] = ACTIONS(644),
    [anon_sym_yield] = ACTIONS(644),
    [anon_sym_synchronized] = ACTIONS(644),
    [anon_sym_throw] = ACTIONS(644),
    [anon_sym_try] = ACTIONS(644),
    [anon_sym_catch] = ACTIONS(646),
    [anon_sym_finally] = ACTIONS(644),
    [anon_sym_if] = ACTIONS(644),
    [anon_sym_else] = ACTIONS(644),
    [anon_sym_for] = ACTIONS(644),
    [anon_sym_AT] = ACTIONS(644),
    [anon_sym_open] = ACTIONS(644),
    [anon_sym_module] = ACTIONS(644),
    [anon_sym_static] = ACTIONS(644),
    [anon_sym_with] = ACTIONS(644),
    [anon_sym_package] = ACTIONS(644),
    [anon_sym_import] = ACTIONS(644),
    [anon_sym_enum] = ACTIONS(644),
    [anon_sym_public] = ACTIONS(644),
    [anon_sym_protected] = ACTIONS(644),
    [anon_sym_private] = ACTIONS(644),
    [anon_sym_abstract] = ACTIONS(644),
    [anon_sym_strictfp] = ACTIONS(644),
    [anon_sym_native] = ACTIONS(644),
    [anon_sym_transient] = ACTIONS(644),
    [anon_sym_volatile] = ACTIONS(644),
    [anon_sym_sealed] = ACTIONS(644),
    [anon_sym_non_DASHsealed] = ACTIONS(642),
    [anon_sym_record] = ACTIONS(644),
    [anon_sym_ATinterface] = ACTIONS(642),
    [anon_sym_interface] = ACTIONS(644),
    [anon_sym_byte] = ACTIONS(644),
    [anon_sym_short] = ACTIONS(644),
    [anon_sym_int] = ACTIONS(644),
    [anon_sym_long] = ACTIONS(644),
    [anon_sym_char] = ACTIONS(644),
    [anon_sym_float] = ACTIONS(644),
    [anon_sym_double] = ACTIONS(644),
    [sym_boolean_type] = ACTIONS(644),
    [sym_void_type] = ACTIONS(644),
    [sym_this] = ACTIONS(644),
    [sym_super] = ACTIONS(644),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [207] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(705),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [208] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(636),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [209] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(701),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [210] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(724),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [211] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(718),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [212] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(719),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [213] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(716),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [214] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(694),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [215] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(634),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [216] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(635),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [217] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(697),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [218] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(715),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [219] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(604),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [220] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(618),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [221] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(617),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [222] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(622),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [223] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(612),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [224] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(735),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [225] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(731),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [226] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(609),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [227] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(613),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [228] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(611),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [229] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(610),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [230] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(637),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [231] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(615),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [232] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(619),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [233] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(640),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [234] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(620),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [235] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(647),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [236] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(748),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [237] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(723),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [238] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(604),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [239] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(742),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [240] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(646),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [241] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(738),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [242] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(602),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [243] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(631),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1347),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(458),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(458),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(443),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(540),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(532),
    [anon_sym_DASH] = ACTIONS(532),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(536),
    [anon_sym_DASH_DASH] = ACTIONS(536),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [244] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(709),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [245] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(616),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [246] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(644),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [247] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_expression] = STATE(746),
    [sym_cast_expression] = STATE(591),
    [sym_assignment_expression] = STATE(591),
    [sym_binary_expression] = STATE(591),
    [sym_instanceof_expression] = STATE(591),
    [sym_lambda_expression] = STATE(591),
    [sym_inferred_parameters] = STATE(1363),
    [sym_ternary_expression] = STATE(591),
    [sym_unary_expression] = STATE(591),
    [sym_update_expression] = STATE(591),
    [sym_primary_expression] = STATE(523),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(439),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(439),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_switch_expression] = STATE(591),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(428),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(418),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(17),
    [anon_sym_PLUS] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(21),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(25),
    [anon_sym_PLUS_PLUS] = ACTIONS(27),
    [anon_sym_DASH_DASH] = ACTIONS(27),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_sealed] = ACTIONS(69),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [248] = {
    [ts_builtin_sym_end] = ACTIONS(649),
    [sym_identifier] = ACTIONS(651),
    [sym_decimal_integer_literal] = ACTIONS(651),
    [sym_hex_integer_literal] = ACTIONS(651),
    [sym_octal_integer_literal] = ACTIONS(651),
    [sym_binary_integer_literal] = ACTIONS(649),
    [sym_decimal_floating_point_literal] = ACTIONS(649),
    [sym_hex_floating_point_literal] = ACTIONS(651),
    [sym_true] = ACTIONS(651),
    [sym_false] = ACTIONS(651),
    [sym_character_literal] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(651),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(649),
    [anon_sym_RBRACE] = ACTIONS(649),
    [sym_null_literal] = ACTIONS(651),
    [anon_sym_LPAREN] = ACTIONS(649),
    [anon_sym_LT] = ACTIONS(649),
    [anon_sym_PLUS] = ACTIONS(651),
    [anon_sym_DASH] = ACTIONS(651),
    [anon_sym_final] = ACTIONS(651),
    [anon_sym_BANG] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(649),
    [anon_sym_PLUS_PLUS] = ACTIONS(649),
    [anon_sym_DASH_DASH] = ACTIONS(649),
    [anon_sym_new] = ACTIONS(651),
    [anon_sym_class] = ACTIONS(651),
    [anon_sym_switch] = ACTIONS(651),
    [anon_sym_LBRACE] = ACTIONS(649),
    [anon_sym_case] = ACTIONS(651),
    [anon_sym_default] = ACTIONS(651),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_assert] = ACTIONS(651),
    [anon_sym_do] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(651),
    [anon_sym_break] = ACTIONS(651),
    [anon_sym_continue] = ACTIONS(651),
    [anon_sym_return] = ACTIONS(651),
    [anon_sym_yield] = ACTIONS(651),
    [anon_sym_synchronized] = ACTIONS(651),
    [anon_sym_throw] = ACTIONS(651),
    [anon_sym_try] = ACTIONS(651),
    [anon_sym_catch] = ACTIONS(651),
    [anon_sym_finally] = ACTIONS(651),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_else] = ACTIONS(651),
    [anon_sym_for] = ACTIONS(651),
    [anon_sym_AT] = ACTIONS(651),
    [anon_sym_open] = ACTIONS(651),
    [anon_sym_module] = ACTIONS(651),
    [anon_sym_static] = ACTIONS(651),
    [anon_sym_with] = ACTIONS(651),
    [anon_sym_package] = ACTIONS(651),
    [anon_sym_import] = ACTIONS(651),
    [anon_sym_enum] = ACTIONS(651),
    [anon_sym_public] = ACTIONS(651),
    [anon_sym_protected] = ACTIONS(651),
    [anon_sym_private] = ACTIONS(651),
    [anon_sym_abstract] = ACTIONS(651),
    [anon_sym_strictfp] = ACTIONS(651),
    [anon_sym_native] = ACTIONS(651),
    [anon_sym_transient] = ACTIONS(651),
    [anon_sym_volatile] = ACTIONS(651),
    [anon_sym_sealed] = ACTIONS(651),
    [anon_sym_non_DASHsealed] = ACTIONS(649),
    [anon_sym_record] = ACTIONS(651),
    [anon_sym_ATinterface] = ACTIONS(649),
    [anon_sym_interface] = ACTIONS(651),
    [anon_sym_byte] = ACTIONS(651),
    [anon_sym_short] = ACTIONS(651),
    [anon_sym_int] = ACTIONS(651),
    [anon_sym_long] = ACTIONS(651),
    [anon_sym_char] = ACTIONS(651),
    [anon_sym_float] = ACTIONS(651),
    [anon_sym_double] = ACTIONS(651),
    [sym_boolean_type] = ACTIONS(651),
    [sym_void_type] = ACTIONS(651),
    [sym_this] = ACTIONS(651),
    [sym_super] = ACTIONS(651),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [249] = {
    [ts_builtin_sym_end] = ACTIONS(438),
    [sym_identifier] = ACTIONS(440),
    [sym_decimal_integer_literal] = ACTIONS(440),
    [sym_hex_integer_literal] = ACTIONS(440),
    [sym_octal_integer_literal] = ACTIONS(440),
    [sym_binary_integer_literal] = ACTIONS(438),
    [sym_decimal_floating_point_literal] = ACTIONS(438),
    [sym_hex_floating_point_literal] = ACTIONS(440),
    [sym_true] = ACTIONS(440),
    [sym_false] = ACTIONS(440),
    [sym_character_literal] = ACTIONS(438),
    [anon_sym_DQUOTE] = ACTIONS(440),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(438),
    [anon_sym_RBRACE] = ACTIONS(438),
    [sym_null_literal] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(438),
    [anon_sym_LT] = ACTIONS(438),
    [anon_sym_PLUS] = ACTIONS(440),
    [anon_sym_DASH] = ACTIONS(440),
    [anon_sym_final] = ACTIONS(440),
    [anon_sym_BANG] = ACTIONS(438),
    [anon_sym_TILDE] = ACTIONS(438),
    [anon_sym_PLUS_PLUS] = ACTIONS(438),
    [anon_sym_DASH_DASH] = ACTIONS(438),
    [anon_sym_new] = ACTIONS(440),
    [anon_sym_class] = ACTIONS(440),
    [anon_sym_switch] = ACTIONS(440),
    [anon_sym_LBRACE] = ACTIONS(438),
    [anon_sym_case] = ACTIONS(440),
    [anon_sym_default] = ACTIONS(440),
    [anon_sym_SEMI] = ACTIONS(438),
    [anon_sym_assert] = ACTIONS(440),
    [anon_sym_do] = ACTIONS(440),
    [anon_sym_while] = ACTIONS(440),
    [anon_sym_break] = ACTIONS(440),
    [anon_sym_continue] = ACTIONS(440),
    [anon_sym_return] = ACTIONS(440),
    [anon_sym_yield] = ACTIONS(440),
    [anon_sym_synchronized] = ACTIONS(440),
    [anon_sym_throw] = ACTIONS(440),
    [anon_sym_try] = ACTIONS(440),
    [anon_sym_catch] = ACTIONS(440),
    [anon_sym_finally] = ACTIONS(440),
    [anon_sym_if] = ACTIONS(440),
    [anon_sym_else] = ACTIONS(440),
    [anon_sym_for] = ACTIONS(440),
    [anon_sym_AT] = ACTIONS(440),
    [anon_sym_open] = ACTIONS(440),
    [anon_sym_module] = ACTIONS(440),
    [anon_sym_static] = ACTIONS(440),
    [anon_sym_with] = ACTIONS(440),
    [anon_sym_package] = ACTIONS(440),
    [anon_sym_import] = ACTIONS(440),
    [anon_sym_enum] = ACTIONS(440),
    [anon_sym_public] = ACTIONS(440),
    [anon_sym_protected] = ACTIONS(440),
    [anon_sym_private] = ACTIONS(440),
    [anon_sym_abstract] = ACTIONS(440),
    [anon_sym_strictfp] = ACTIONS(440),
    [anon_sym_native] = ACTIONS(440),
    [anon_sym_transient] = ACTIONS(440),
    [anon_sym_volatile] = ACTIONS(440),
    [anon_sym_sealed] = ACTIONS(440),
    [anon_sym_non_DASHsealed] = ACTIONS(438),
    [anon_sym_record] = ACTIONS(440),
    [anon_sym_ATinterface] = ACTIONS(438),
    [anon_sym_interface] = ACTIONS(440),
    [anon_sym_byte] = ACTIONS(440),
    [anon_sym_short] = ACTIONS(440),
    [anon_sym_int] = ACTIONS(440),
    [anon_sym_long] = ACTIONS(440),
    [anon_sym_char] = ACTIONS(440),
    [anon_sym_float] = ACTIONS(440),
    [anon_sym_double] = ACTIONS(440),
    [sym_boolean_type] = ACTIONS(440),
    [sym_void_type] = ACTIONS(440),
    [sym_this] = ACTIONS(440),
    [sym_super] = ACTIONS(440),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [250] = {
    [ts_builtin_sym_end] = ACTIONS(442),
    [sym_identifier] = ACTIONS(444),
    [sym_decimal_integer_literal] = ACTIONS(444),
    [sym_hex_integer_literal] = ACTIONS(444),
    [sym_octal_integer_literal] = ACTIONS(444),
    [sym_binary_integer_literal] = ACTIONS(442),
    [sym_decimal_floating_point_literal] = ACTIONS(442),
    [sym_hex_floating_point_literal] = ACTIONS(444),
    [sym_true] = ACTIONS(444),
    [sym_false] = ACTIONS(444),
    [sym_character_literal] = ACTIONS(442),
    [anon_sym_DQUOTE] = ACTIONS(444),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(442),
    [anon_sym_RBRACE] = ACTIONS(442),
    [sym_null_literal] = ACTIONS(444),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_LT] = ACTIONS(442),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_final] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(442),
    [anon_sym_DASH_DASH] = ACTIONS(442),
    [anon_sym_new] = ACTIONS(444),
    [anon_sym_class] = ACTIONS(444),
    [anon_sym_switch] = ACTIONS(444),
    [anon_sym_LBRACE] = ACTIONS(442),
    [anon_sym_case] = ACTIONS(444),
    [anon_sym_default] = ACTIONS(444),
    [anon_sym_SEMI] = ACTIONS(442),
    [anon_sym_assert] = ACTIONS(444),
    [anon_sym_do] = ACTIONS(444),
    [anon_sym_while] = ACTIONS(444),
    [anon_sym_break] = ACTIONS(444),
    [anon_sym_continue] = ACTIONS(444),
    [anon_sym_return] = ACTIONS(444),
    [anon_sym_yield] = ACTIONS(444),
    [anon_sym_synchronized] = ACTIONS(444),
    [anon_sym_throw] = ACTIONS(444),
    [anon_sym_try] = ACTIONS(444),
    [anon_sym_catch] = ACTIONS(444),
    [anon_sym_finally] = ACTIONS(444),
    [anon_sym_if] = ACTIONS(444),
    [anon_sym_else] = ACTIONS(444),
    [anon_sym_for] = ACTIONS(444),
    [anon_sym_AT] = ACTIONS(444),
    [anon_sym_open] = ACTIONS(444),
    [anon_sym_module] = ACTIONS(444),
    [anon_sym_static] = ACTIONS(444),
    [anon_sym_with] = ACTIONS(444),
    [anon_sym_package] = ACTIONS(444),
    [anon_sym_import] = ACTIONS(444),
    [anon_sym_enum] = ACTIONS(444),
    [anon_sym_public] = ACTIONS(444),
    [anon_sym_protected] = ACTIONS(444),
    [anon_sym_private] = ACTIONS(444),
    [anon_sym_abstract] = ACTIONS(444),
    [anon_sym_strictfp] = ACTIONS(444),
    [anon_sym_native] = ACTIONS(444),
    [anon_sym_transient] = ACTIONS(444),
    [anon_sym_volatile] = ACTIONS(444),
    [anon_sym_sealed] = ACTIONS(444),
    [anon_sym_non_DASHsealed] = ACTIONS(442),
    [anon_sym_record] = ACTIONS(444),
    [anon_sym_ATinterface] = ACTIONS(442),
    [anon_sym_interface] = ACTIONS(444),
    [anon_sym_byte] = ACTIONS(444),
    [anon_sym_short] = ACTIONS(444),
    [anon_sym_int] = ACTIONS(444),
    [anon_sym_long] = ACTIONS(444),
    [anon_sym_char] = ACTIONS(444),
    [anon_sym_float] = ACTIONS(444),
    [anon_sym_double] = ACTIONS(444),
    [sym_boolean_type] = ACTIONS(444),
    [sym_void_type] = ACTIONS(444),
    [sym_this] = ACTIONS(444),
    [sym_super] = ACTIONS(444),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [251] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_primary_expression] = STATE(1107),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(980),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_resource] = STATE(1180),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(831),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(800),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__reserved_identifier] = STATE(989),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(653),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(655),
    [anon_sym_RPAREN] = ACTIONS(657),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [252] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_primary_expression] = STATE(1107),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(980),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_resource] = STATE(1180),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(831),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(800),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__reserved_identifier] = STATE(989),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(653),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(655),
    [anon_sym_RPAREN] = ACTIONS(661),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [253] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_primary_expression] = STATE(1107),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(980),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_resource] = STATE(1137),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(831),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(800),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__reserved_identifier] = STATE(989),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(653),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(655),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [254] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_primary_expression] = STATE(1107),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(980),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym_resource] = STATE(1180),
    [sym__annotation] = STATE(702),
    [sym_marker_annotation] = STATE(702),
    [sym_annotation] = STATE(702),
    [sym_modifiers] = STATE(831),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(800),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym__reserved_identifier] = STATE(989),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [aux_sym_modifiers_repeat1] = STATE(624),
    [sym_identifier] = ACTIONS(653),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(655),
    [anon_sym_final] = ACTIONS(462),
    [anon_sym_new] = ACTIONS(659),
    [anon_sym_default] = ACTIONS(462),
    [anon_sym_yield] = ACTIONS(69),
    [anon_sym_synchronized] = ACTIONS(462),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_open] = ACTIONS(69),
    [anon_sym_module] = ACTIONS(69),
    [anon_sym_static] = ACTIONS(462),
    [anon_sym_with] = ACTIONS(69),
    [anon_sym_public] = ACTIONS(462),
    [anon_sym_protected] = ACTIONS(462),
    [anon_sym_private] = ACTIONS(462),
    [anon_sym_abstract] = ACTIONS(462),
    [anon_sym_strictfp] = ACTIONS(462),
    [anon_sym_native] = ACTIONS(462),
    [anon_sym_transient] = ACTIONS(462),
    [anon_sym_volatile] = ACTIONS(462),
    [anon_sym_sealed] = ACTIONS(466),
    [anon_sym_non_DASHsealed] = ACTIONS(468),
    [anon_sym_record] = ACTIONS(69),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(95),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [255] = {
    [ts_builtin_sym_end] = ACTIONS(663),
    [sym_identifier] = ACTIONS(665),
    [sym_decimal_integer_literal] = ACTIONS(665),
    [sym_hex_integer_literal] = ACTIONS(665),
    [sym_octal_integer_literal] = ACTIONS(665),
    [sym_binary_integer_literal] = ACTIONS(663),
    [sym_decimal_floating_point_literal] = ACTIONS(663),
    [sym_hex_floating_point_literal] = ACTIONS(665),
    [sym_true] = ACTIONS(665),
    [sym_false] = ACTIONS(665),
    [sym_character_literal] = ACTIONS(663),
    [anon_sym_DQUOTE] = ACTIONS(665),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(663),
    [anon_sym_RBRACE] = ACTIONS(663),
    [sym_null_literal] = ACTIONS(665),
    [anon_sym_LPAREN] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(665),
    [anon_sym_final] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(663),
    [anon_sym_TILDE] = ACTIONS(663),
    [anon_sym_PLUS_PLUS] = ACTIONS(663),
    [anon_sym_DASH_DASH] = ACTIONS(663),
    [anon_sym_new] = ACTIONS(665),
    [anon_sym_class] = ACTIONS(665),
    [anon_sym_switch] = ACTIONS(665),
    [anon_sym_LBRACE] = ACTIONS(663),
    [anon_sym_case] = ACTIONS(665),
    [anon_sym_default] = ACTIONS(665),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_assert] = ACTIONS(665),
    [anon_sym_do] = ACTIONS(665),
    [anon_sym_while] = ACTIONS(665),
    [anon_sym_break] = ACTIONS(665),
    [anon_sym_continue] = ACTIONS(665),
    [anon_sym_return] = ACTIONS(665),
    [anon_sym_yield] = ACTIONS(665),
    [anon_sym_synchronized] = ACTIONS(665),
    [anon_sym_throw] = ACTIONS(665),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_if] = ACTIONS(665),
    [anon_sym_else] = ACTIONS(665),
    [anon_sym_for] = ACTIONS(665),
    [anon_sym_AT] = ACTIONS(665),
    [anon_sym_open] = ACTIONS(665),
    [anon_sym_module] = ACTIONS(665),
    [anon_sym_static] = ACTIONS(665),
    [anon_sym_with] = ACTIONS(665),
    [anon_sym_package] = ACTIONS(665),
    [anon_sym_import] = ACTIONS(665),
    [anon_sym_enum] = ACTIONS(665),
    [anon_sym_public] = ACTIONS(665),
    [anon_sym_protected] = ACTIONS(665),
    [anon_sym_private] = ACTIONS(665),
    [anon_sym_abstract] = ACTIONS(665),
    [anon_sym_strictfp] = ACTIONS(665),
    [anon_sym_native] = ACTIONS(665),
    [anon_sym_transient] = ACTIONS(665),
    [anon_sym_volatile] = ACTIONS(665),
    [anon_sym_sealed] = ACTIONS(665),
    [anon_sym_non_DASHsealed] = ACTIONS(663),
    [anon_sym_record] = ACTIONS(665),
    [anon_sym_ATinterface] = ACTIONS(663),
    [anon_sym_interface] = ACTIONS(665),
    [anon_sym_byte] = ACTIONS(665),
    [anon_sym_short] = ACTIONS(665),
    [anon_sym_int] = ACTIONS(665),
    [anon_sym_long] = ACTIONS(665),
    [anon_sym_char] = ACTIONS(665),
    [anon_sym_float] = ACTIONS(665),
    [anon_sym_double] = ACTIONS(665),
    [sym_boolean_type] = ACTIONS(665),
    [sym_void_type] = ACTIONS(665),
    [sym_this] = ACTIONS(665),
    [sym_super] = ACTIONS(665),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [256] = {
    [ts_builtin_sym_end] = ACTIONS(667),
    [sym_identifier] = ACTIONS(669),
    [sym_decimal_integer_literal] = ACTIONS(669),
    [sym_hex_integer_literal] = ACTIONS(669),
    [sym_octal_integer_literal] = ACTIONS(669),
    [sym_binary_integer_literal] = ACTIONS(667),
    [sym_decimal_floating_point_literal] = ACTIONS(667),
    [sym_hex_floating_point_literal] = ACTIONS(669),
    [sym_true] = ACTIONS(669),
    [sym_false] = ACTIONS(669),
    [sym_character_literal] = ACTIONS(667),
    [anon_sym_DQUOTE] = ACTIONS(669),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(667),
    [anon_sym_RBRACE] = ACTIONS(667),
    [sym_null_literal] = ACTIONS(669),
    [anon_sym_LPAREN] = ACTIONS(667),
    [anon_sym_LT] = ACTIONS(667),
    [anon_sym_PLUS] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_final] = ACTIONS(669),
    [anon_sym_BANG] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(667),
    [anon_sym_PLUS_PLUS] = ACTIONS(667),
    [anon_sym_DASH_DASH] = ACTIONS(667),
    [anon_sym_new] = ACTIONS(669),
    [anon_sym_class] = ACTIONS(669),
    [anon_sym_switch] = ACTIONS(669),
    [anon_sym_LBRACE] = ACTIONS(667),
    [anon_sym_case] = ACTIONS(669),
    [anon_sym_default] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(667),
    [anon_sym_assert] = ACTIONS(669),
    [anon_sym_do] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_break] = ACTIONS(669),
    [anon_sym_continue] = ACTIONS(669),
    [anon_sym_return] = ACTIONS(669),
    [anon_sym_yield] = ACTIONS(669),
    [anon_sym_synchronized] = ACTIONS(669),
    [anon_sym_throw] = ACTIONS(669),
    [anon_sym_try] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_else] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_AT] = ACTIONS(669),
    [anon_sym_open] = ACTIONS(669),
    [anon_sym_module] = ACTIONS(669),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_with] = ACTIONS(669),
    [anon_sym_package] = ACTIONS(669),
    [anon_sym_import] = ACTIONS(669),
    [anon_sym_enum] = ACTIONS(669),
    [anon_sym_public] = ACTIONS(669),
    [anon_sym_protected] = ACTIONS(669),
    [anon_sym_private] = ACTIONS(669),
    [anon_sym_abstract] = ACTIONS(669),
    [anon_sym_strictfp] = ACTIONS(669),
    [anon_sym_native] = ACTIONS(669),
    [anon_sym_transient] = ACTIONS(669),
    [anon_sym_volatile] = ACTIONS(669),
    [anon_sym_sealed] = ACTIONS(669),
    [anon_sym_non_DASHsealed] = ACTIONS(667),
    [anon_sym_record] = ACTIONS(669),
    [anon_sym_ATinterface] = ACTIONS(667),
    [anon_sym_interface] = ACTIONS(669),
    [anon_sym_byte] = ACTIONS(669),
    [anon_sym_short] = ACTIONS(669),
    [anon_sym_int] = ACTIONS(669),
    [anon_sym_long] = ACTIONS(669),
    [anon_sym_char] = ACTIONS(669),
    [anon_sym_float] = ACTIONS(669),
    [anon_sym_double] = ACTIONS(669),
    [sym_boolean_type] = ACTIONS(669),
    [sym_void_type] = ACTIONS(669),
    [sym_this] = ACTIONS(669),
    [sym_super] = ACTIONS(669),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [257] = {
    [ts_builtin_sym_end] = ACTIONS(671),
    [sym_identifier] = ACTIONS(673),
    [sym_decimal_integer_literal] = ACTIONS(673),
    [sym_hex_integer_literal] = ACTIONS(673),
    [sym_octal_integer_literal] = ACTIONS(673),
    [sym_binary_integer_literal] = ACTIONS(671),
    [sym_decimal_floating_point_literal] = ACTIONS(671),
    [sym_hex_floating_point_literal] = ACTIONS(673),
    [sym_true] = ACTIONS(673),
    [sym_false] = ACTIONS(673),
    [sym_character_literal] = ACTIONS(671),
    [anon_sym_DQUOTE] = ACTIONS(673),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(671),
    [anon_sym_RBRACE] = ACTIONS(671),
    [sym_null_literal] = ACTIONS(673),
    [anon_sym_LPAREN] = ACTIONS(671),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_PLUS] = ACTIONS(673),
    [anon_sym_DASH] = ACTIONS(673),
    [anon_sym_final] = ACTIONS(673),
    [anon_sym_BANG] = ACTIONS(671),
    [anon_sym_TILDE] = ACTIONS(671),
    [anon_sym_PLUS_PLUS] = ACTIONS(671),
    [anon_sym_DASH_DASH] = ACTIONS(671),
    [anon_sym_new] = ACTIONS(673),
    [anon_sym_class] = ACTIONS(673),
    [anon_sym_switch] = ACTIONS(673),
    [anon_sym_LBRACE] = ACTIONS(671),
    [anon_sym_case] = ACTIONS(673),
    [anon_sym_default] = ACTIONS(673),
    [anon_sym_SEMI] = ACTIONS(671),
    [anon_sym_assert] = ACTIONS(673),
    [anon_sym_do] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(673),
    [anon_sym_break] = ACTIONS(673),
    [anon_sym_continue] = ACTIONS(673),
    [anon_sym_return] = ACTIONS(673),
    [anon_sym_yield] = ACTIONS(673),
    [anon_sym_synchronized] = ACTIONS(673),
    [anon_sym_throw] = ACTIONS(673),
    [anon_sym_try] = ACTIONS(673),
    [anon_sym_if] = ACTIONS(673),
    [anon_sym_else] = ACTIONS(673),
    [anon_sym_for] = ACTIONS(673),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_open] = ACTIONS(673),
    [anon_sym_module] = ACTIONS(673),
    [anon_sym_static] = ACTIONS(673),
    [anon_sym_with] = ACTIONS(673),
    [anon_sym_package] = ACTIONS(673),
    [anon_sym_import] = ACTIONS(673),
    [anon_sym_enum] = ACTIONS(673),
    [anon_sym_public] = ACTIONS(673),
    [anon_sym_protected] = ACTIONS(673),
    [anon_sym_private] = ACTIONS(673),
    [anon_sym_abstract] = ACTIONS(673),
    [anon_sym_strictfp] = ACTIONS(673),
    [anon_sym_native] = ACTIONS(673),
    [anon_sym_transient] = ACTIONS(673),
    [anon_sym_volatile] = ACTIONS(673),
    [anon_sym_sealed] = ACTIONS(673),
    [anon_sym_non_DASHsealed] = ACTIONS(671),
    [anon_sym_record] = ACTIONS(673),
    [anon_sym_ATinterface] = ACTIONS(671),
    [anon_sym_interface] = ACTIONS(673),
    [anon_sym_byte] = ACTIONS(673),
    [anon_sym_short] = ACTIONS(673),
    [anon_sym_int] = ACTIONS(673),
    [anon_sym_long] = ACTIONS(673),
    [anon_sym_char] = ACTIONS(673),
    [anon_sym_float] = ACTIONS(673),
    [anon_sym_double] = ACTIONS(673),
    [sym_boolean_type] = ACTIONS(673),
    [sym_void_type] = ACTIONS(673),
    [sym_this] = ACTIONS(673),
    [sym_super] = ACTIONS(673),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [258] = {
    [ts_builtin_sym_end] = ACTIONS(675),
    [sym_identifier] = ACTIONS(677),
    [sym_decimal_integer_literal] = ACTIONS(677),
    [sym_hex_integer_literal] = ACTIONS(677),
    [sym_octal_integer_literal] = ACTIONS(677),
    [sym_binary_integer_literal] = ACTIONS(675),
    [sym_decimal_floating_point_literal] = ACTIONS(675),
    [sym_hex_floating_point_literal] = ACTIONS(677),
    [sym_true] = ACTIONS(677),
    [sym_false] = ACTIONS(677),
    [sym_character_literal] = ACTIONS(675),
    [anon_sym_DQUOTE] = ACTIONS(677),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(675),
    [anon_sym_RBRACE] = ACTIONS(675),
    [sym_null_literal] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_LT] = ACTIONS(675),
    [anon_sym_PLUS] = ACTIONS(677),
    [anon_sym_DASH] = ACTIONS(677),
    [anon_sym_final] = ACTIONS(677),
    [anon_sym_BANG] = ACTIONS(675),
    [anon_sym_TILDE] = ACTIONS(675),
    [anon_sym_PLUS_PLUS] = ACTIONS(675),
    [anon_sym_DASH_DASH] = ACTIONS(675),
    [anon_sym_new] = ACTIONS(677),
    [anon_sym_class] = ACTIONS(677),
    [anon_sym_switch] = ACTIONS(677),
    [anon_sym_LBRACE] = ACTIONS(675),
    [anon_sym_case] = ACTIONS(677),
    [anon_sym_default] = ACTIONS(677),
    [anon_sym_SEMI] = ACTIONS(675),
    [anon_sym_assert] = ACTIONS(677),
    [anon_sym_do] = ACTIONS(677),
    [anon_sym_while] = ACTIONS(677),
    [anon_sym_break] = ACTIONS(677),
    [anon_sym_continue] = ACTIONS(677),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_yield] = ACTIONS(677),
    [anon_sym_synchronized] = ACTIONS(677),
    [anon_sym_throw] = ACTIONS(677),
    [anon_sym_try] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_else] = ACTIONS(677),
    [anon_sym_for] = ACTIONS(677),
    [anon_sym_AT] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_module] = ACTIONS(677),
    [anon_sym_static] = ACTIONS(677),
    [anon_sym_with] = ACTIONS(677),
    [anon_sym_package] = ACTIONS(677),
    [anon_sym_import] = ACTIONS(677),
    [anon_sym_enum] = ACTIONS(677),
    [anon_sym_public] = ACTIONS(677),
    [anon_sym_protected] = ACTIONS(677),
    [anon_sym_private] = ACTIONS(677),
    [anon_sym_abstract] = ACTIONS(677),
    [anon_sym_strictfp] = ACTIONS(677),
    [anon_sym_native] = ACTIONS(677),
    [anon_sym_transient] = ACTIONS(677),
    [anon_sym_volatile] = ACTIONS(677),
    [anon_sym_sealed] = ACTIONS(677),
    [anon_sym_non_DASHsealed] = ACTIONS(675),
    [anon_sym_record] = ACTIONS(677),
    [anon_sym_ATinterface] = ACTIONS(675),
    [anon_sym_interface] = ACTIONS(677),
    [anon_sym_byte] = ACTIONS(677),
    [anon_sym_short] = ACTIONS(677),
    [anon_sym_int] = ACTIONS(677),
    [anon_sym_long] = ACTIONS(677),
    [anon_sym_char] = ACTIONS(677),
    [anon_sym_float] = ACTIONS(677),
    [anon_sym_double] = ACTIONS(677),
    [sym_boolean_type] = ACTIONS(677),
    [sym_void_type] = ACTIONS(677),
    [sym_this] = ACTIONS(677),
    [sym_super] = ACTIONS(677),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [259] = {
    [ts_builtin_sym_end] = ACTIONS(679),
    [sym_identifier] = ACTIONS(681),
    [sym_decimal_integer_literal] = ACTIONS(681),
    [sym_hex_integer_literal] = ACTIONS(681),
    [sym_octal_integer_literal] = ACTIONS(681),
    [sym_binary_integer_literal] = ACTIONS(679),
    [sym_decimal_floating_point_literal] = ACTIONS(679),
    [sym_hex_floating_point_literal] = ACTIONS(681),
    [sym_true] = ACTIONS(681),
    [sym_false] = ACTIONS(681),
    [sym_character_literal] = ACTIONS(679),
    [anon_sym_DQUOTE] = ACTIONS(681),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(679),
    [anon_sym_RBRACE] = ACTIONS(679),
    [sym_null_literal] = ACTIONS(681),
    [anon_sym_LPAREN] = ACTIONS(679),
    [anon_sym_LT] = ACTIONS(679),
    [anon_sym_PLUS] = ACTIONS(681),
    [anon_sym_DASH] = ACTIONS(681),
    [anon_sym_final] = ACTIONS(681),
    [anon_sym_BANG] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(679),
    [anon_sym_PLUS_PLUS] = ACTIONS(679),
    [anon_sym_DASH_DASH] = ACTIONS(679),
    [anon_sym_new] = ACTIONS(681),
    [anon_sym_class] = ACTIONS(681),
    [anon_sym_switch] = ACTIONS(681),
    [anon_sym_LBRACE] = ACTIONS(679),
    [anon_sym_case] = ACTIONS(681),
    [anon_sym_default] = ACTIONS(681),
    [anon_sym_SEMI] = ACTIONS(679),
    [anon_sym_assert] = ACTIONS(681),
    [anon_sym_do] = ACTIONS(681),
    [anon_sym_while] = ACTIONS(681),
    [anon_sym_break] = ACTIONS(681),
    [anon_sym_continue] = ACTIONS(681),
    [anon_sym_return] = ACTIONS(681),
    [anon_sym_yield] = ACTIONS(681),
    [anon_sym_synchronized] = ACTIONS(681),
    [anon_sym_throw] = ACTIONS(681),
    [anon_sym_try] = ACTIONS(681),
    [anon_sym_if] = ACTIONS(681),
    [anon_sym_else] = ACTIONS(681),
    [anon_sym_for] = ACTIONS(681),
    [anon_sym_AT] = ACTIONS(681),
    [anon_sym_open] = ACTIONS(681),
    [anon_sym_module] = ACTIONS(681),
    [anon_sym_static] = ACTIONS(681),
    [anon_sym_with] = ACTIONS(681),
    [anon_sym_package] = ACTIONS(681),
    [anon_sym_import] = ACTIONS(681),
    [anon_sym_enum] = ACTIONS(681),
    [anon_sym_public] = ACTIONS(681),
    [anon_sym_protected] = ACTIONS(681),
    [anon_sym_private] = ACTIONS(681),
    [anon_sym_abstract] = ACTIONS(681),
    [anon_sym_strictfp] = ACTIONS(681),
    [anon_sym_native] = ACTIONS(681),
    [anon_sym_transient] = ACTIONS(681),
    [anon_sym_volatile] = ACTIONS(681),
    [anon_sym_sealed] = ACTIONS(681),
    [anon_sym_non_DASHsealed] = ACTIONS(679),
    [anon_sym_record] = ACTIONS(681),
    [anon_sym_ATinterface] = ACTIONS(679),
    [anon_sym_interface] = ACTIONS(681),
    [anon_sym_byte] = ACTIONS(681),
    [anon_sym_short] = ACTIONS(681),
    [anon_sym_int] = ACTIONS(681),
    [anon_sym_long] = ACTIONS(681),
    [anon_sym_char] = ACTIONS(681),
    [anon_sym_float] = ACTIONS(681),
    [anon_sym_double] = ACTIONS(681),
    [sym_boolean_type] = ACTIONS(681),
    [sym_void_type] = ACTIONS(681),
    [sym_this] = ACTIONS(681),
    [sym_super] = ACTIONS(681),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [260] = {
    [ts_builtin_sym_end] = ACTIONS(683),
    [sym_identifier] = ACTIONS(685),
    [sym_decimal_integer_literal] = ACTIONS(685),
    [sym_hex_integer_literal] = ACTIONS(685),
    [sym_octal_integer_literal] = ACTIONS(685),
    [sym_binary_integer_literal] = ACTIONS(683),
    [sym_decimal_floating_point_literal] = ACTIONS(683),
    [sym_hex_floating_point_literal] = ACTIONS(685),
    [sym_true] = ACTIONS(685),
    [sym_false] = ACTIONS(685),
    [sym_character_literal] = ACTIONS(683),
    [anon_sym_DQUOTE] = ACTIONS(685),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(683),
    [anon_sym_RBRACE] = ACTIONS(683),
    [sym_null_literal] = ACTIONS(685),
    [anon_sym_LPAREN] = ACTIONS(683),
    [anon_sym_LT] = ACTIONS(683),
    [anon_sym_PLUS] = ACTIONS(685),
    [anon_sym_DASH] = ACTIONS(685),
    [anon_sym_final] = ACTIONS(685),
    [anon_sym_BANG] = ACTIONS(683),
    [anon_sym_TILDE] = ACTIONS(683),
    [anon_sym_PLUS_PLUS] = ACTIONS(683),
    [anon_sym_DASH_DASH] = ACTIONS(683),
    [anon_sym_new] = ACTIONS(685),
    [anon_sym_class] = ACTIONS(685),
    [anon_sym_switch] = ACTIONS(685),
    [anon_sym_LBRACE] = ACTIONS(683),
    [anon_sym_case] = ACTIONS(685),
    [anon_sym_default] = ACTIONS(685),
    [anon_sym_SEMI] = ACTIONS(683),
    [anon_sym_assert] = ACTIONS(685),
    [anon_sym_do] = ACTIONS(685),
    [anon_sym_while] = ACTIONS(685),
    [anon_sym_break] = ACTIONS(685),
    [anon_sym_continue] = ACTIONS(685),
    [anon_sym_return] = ACTIONS(685),
    [anon_sym_yield] = ACTIONS(685),
    [anon_sym_synchronized] = ACTIONS(685),
    [anon_sym_throw] = ACTIONS(685),
    [anon_sym_try] = ACTIONS(685),
    [anon_sym_if] = ACTIONS(685),
    [anon_sym_else] = ACTIONS(685),
    [anon_sym_for] = ACTIONS(685),
    [anon_sym_AT] = ACTIONS(685),
    [anon_sym_open] = ACTIONS(685),
    [anon_sym_module] = ACTIONS(685),
    [anon_sym_static] = ACTIONS(685),
    [anon_sym_with] = ACTIONS(685),
    [anon_sym_package] = ACTIONS(685),
    [anon_sym_import] = ACTIONS(685),
    [anon_sym_enum] = ACTIONS(685),
    [anon_sym_public] = ACTIONS(685),
    [anon_sym_protected] = ACTIONS(685),
    [anon_sym_private] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(685),
    [anon_sym_strictfp] = ACTIONS(685),
    [anon_sym_native] = ACTIONS(685),
    [anon_sym_transient] = ACTIONS(685),
    [anon_sym_volatile] = ACTIONS(685),
    [anon_sym_sealed] = ACTIONS(685),
    [anon_sym_non_DASHsealed] = ACTIONS(683),
    [anon_sym_record] = ACTIONS(685),
    [anon_sym_ATinterface] = ACTIONS(683),
    [anon_sym_interface] = ACTIONS(685),
    [anon_sym_byte] = ACTIONS(685),
    [anon_sym_short] = ACTIONS(685),
    [anon_sym_int] = ACTIONS(685),
    [anon_sym_long] = ACTIONS(685),
    [anon_sym_char] = ACTIONS(685),
    [anon_sym_float] = ACTIONS(685),
    [anon_sym_double] = ACTIONS(685),
    [sym_boolean_type] = ACTIONS(685),
    [sym_void_type] = ACTIONS(685),
    [sym_this] = ACTIONS(685),
    [sym_super] = ACTIONS(685),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [261] = {
    [ts_builtin_sym_end] = ACTIONS(687),
    [sym_identifier] = ACTIONS(689),
    [sym_decimal_integer_literal] = ACTIONS(689),
    [sym_hex_integer_literal] = ACTIONS(689),
    [sym_octal_integer_literal] = ACTIONS(689),
    [sym_binary_integer_literal] = ACTIONS(687),
    [sym_decimal_floating_point_literal] = ACTIONS(687),
    [sym_hex_floating_point_literal] = ACTIONS(689),
    [sym_true] = ACTIONS(689),
    [sym_false] = ACTIONS(689),
    [sym_character_literal] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(687),
    [anon_sym_RBRACE] = ACTIONS(687),
    [sym_null_literal] = ACTIONS(689),
    [anon_sym_LPAREN] = ACTIONS(687),
    [anon_sym_LT] = ACTIONS(687),
    [anon_sym_PLUS] = ACTIONS(689),
    [anon_sym_DASH] = ACTIONS(689),
    [anon_sym_final] = ACTIONS(689),
    [anon_sym_BANG] = ACTIONS(687),
    [anon_sym_TILDE] = ACTIONS(687),
    [anon_sym_PLUS_PLUS] = ACTIONS(687),
    [anon_sym_DASH_DASH] = ACTIONS(687),
    [anon_sym_new] = ACTIONS(689),
    [anon_sym_class] = ACTIONS(689),
    [anon_sym_switch] = ACTIONS(689),
    [anon_sym_LBRACE] = ACTIONS(687),
    [anon_sym_case] = ACTIONS(689),
    [anon_sym_default] = ACTIONS(689),
    [anon_sym_SEMI] = ACTIONS(687),
    [anon_sym_assert] = ACTIONS(689),
    [anon_sym_do] = ACTIONS(689),
    [anon_sym_while] = ACTIONS(689),
    [anon_sym_break] = ACTIONS(689),
    [anon_sym_continue] = ACTIONS(689),
    [anon_sym_return] = ACTIONS(689),
    [anon_sym_yield] = ACTIONS(689),
    [anon_sym_synchronized] = ACTIONS(689),
    [anon_sym_throw] = ACTIONS(689),
    [anon_sym_try] = ACTIONS(689),
    [anon_sym_if] = ACTIONS(689),
    [anon_sym_else] = ACTIONS(689),
    [anon_sym_for] = ACTIONS(689),
    [anon_sym_AT] = ACTIONS(689),
    [anon_sym_open] = ACTIONS(689),
    [anon_sym_module] = ACTIONS(689),
    [anon_sym_static] = ACTIONS(689),
    [anon_sym_with] = ACTIONS(689),
    [anon_sym_package] = ACTIONS(689),
    [anon_sym_import] = ACTIONS(689),
    [anon_sym_enum] = ACTIONS(689),
    [anon_sym_public] = ACTIONS(689),
    [anon_sym_protected] = ACTIONS(689),
    [anon_sym_private] = ACTIONS(689),
    [anon_sym_abstract] = ACTIONS(689),
    [anon_sym_strictfp] = ACTIONS(689),
    [anon_sym_native] = ACTIONS(689),
    [anon_sym_transient] = ACTIONS(689),
    [anon_sym_volatile] = ACTIONS(689),
    [anon_sym_sealed] = ACTIONS(689),
    [anon_sym_non_DASHsealed] = ACTIONS(687),
    [anon_sym_record] = ACTIONS(689),
    [anon_sym_ATinterface] = ACTIONS(687),
    [anon_sym_interface] = ACTIONS(689),
    [anon_sym_byte] = ACTIONS(689),
    [anon_sym_short] = ACTIONS(689),
    [anon_sym_int] = ACTIONS(689),
    [anon_sym_long] = ACTIONS(689),
    [anon_sym_char] = ACTIONS(689),
    [anon_sym_float] = ACTIONS(689),
    [anon_sym_double] = ACTIONS(689),
    [sym_boolean_type] = ACTIONS(689),
    [sym_void_type] = ACTIONS(689),
    [sym_this] = ACTIONS(689),
    [sym_super] = ACTIONS(689),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [262] = {
    [ts_builtin_sym_end] = ACTIONS(691),
    [sym_identifier] = ACTIONS(693),
    [sym_decimal_integer_literal] = ACTIONS(693),
    [sym_hex_integer_literal] = ACTIONS(693),
    [sym_octal_integer_literal] = ACTIONS(693),
    [sym_binary_integer_literal] = ACTIONS(691),
    [sym_decimal_floating_point_literal] = ACTIONS(691),
    [sym_hex_floating_point_literal] = ACTIONS(693),
    [sym_true] = ACTIONS(693),
    [sym_false] = ACTIONS(693),
    [sym_character_literal] = ACTIONS(691),
    [anon_sym_DQUOTE] = ACTIONS(693),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(691),
    [anon_sym_RBRACE] = ACTIONS(691),
    [sym_null_literal] = ACTIONS(693),
    [anon_sym_LPAREN] = ACTIONS(691),
    [anon_sym_LT] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(693),
    [anon_sym_DASH] = ACTIONS(693),
    [anon_sym_final] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(691),
    [anon_sym_TILDE] = ACTIONS(691),
    [anon_sym_PLUS_PLUS] = ACTIONS(691),
    [anon_sym_DASH_DASH] = ACTIONS(691),
    [anon_sym_new] = ACTIONS(693),
    [anon_sym_class] = ACTIONS(693),
    [anon_sym_switch] = ACTIONS(693),
    [anon_sym_LBRACE] = ACTIONS(691),
    [anon_sym_case] = ACTIONS(693),
    [anon_sym_default] = ACTIONS(693),
    [anon_sym_SEMI] = ACTIONS(691),
    [anon_sym_assert] = ACTIONS(693),
    [anon_sym_do] = ACTIONS(693),
    [anon_sym_while] = ACTIONS(693),
    [anon_sym_break] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(693),
    [anon_sym_return] = ACTIONS(693),
    [anon_sym_yield] = ACTIONS(693),
    [anon_sym_synchronized] = ACTIONS(693),
    [anon_sym_throw] = ACTIONS(693),
    [anon_sym_try] = ACTIONS(693),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_else] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(693),
    [anon_sym_AT] = ACTIONS(693),
    [anon_sym_open] = ACTIONS(693),
    [anon_sym_module] = ACTIONS(693),
    [anon_sym_static] = ACTIONS(693),
    [anon_sym_with] = ACTIONS(693),
    [anon_sym_package] = ACTIONS(693),
    [anon_sym_import] = ACTIONS(693),
    [anon_sym_enum] = ACTIONS(693),
    [anon_sym_public] = ACTIONS(693),
    [anon_sym_protected] = ACTIONS(693),
    [anon_sym_private] = ACTIONS(693),
    [anon_sym_abstract] = ACTIONS(693),
    [anon_sym_strictfp] = ACTIONS(693),
    [anon_sym_native] = ACTIONS(693),
    [anon_sym_transient] = ACTIONS(693),
    [anon_sym_volatile] = ACTIONS(693),
    [anon_sym_sealed] = ACTIONS(693),
    [anon_sym_non_DASHsealed] = ACTIONS(691),
    [anon_sym_record] = ACTIONS(693),
    [anon_sym_ATinterface] = ACTIONS(691),
    [anon_sym_interface] = ACTIONS(693),
    [anon_sym_byte] = ACTIONS(693),
    [anon_sym_short] = ACTIONS(693),
    [anon_sym_int] = ACTIONS(693),
    [anon_sym_long] = ACTIONS(693),
    [anon_sym_char] = ACTIONS(693),
    [anon_sym_float] = ACTIONS(693),
    [anon_sym_double] = ACTIONS(693),
    [sym_boolean_type] = ACTIONS(693),
    [sym_void_type] = ACTIONS(693),
    [sym_this] = ACTIONS(693),
    [sym_super] = ACTIONS(693),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [263] = {
    [ts_builtin_sym_end] = ACTIONS(695),
    [sym_identifier] = ACTIONS(697),
    [sym_decimal_integer_literal] = ACTIONS(697),
    [sym_hex_integer_literal] = ACTIONS(697),
    [sym_octal_integer_literal] = ACTIONS(697),
    [sym_binary_integer_literal] = ACTIONS(695),
    [sym_decimal_floating_point_literal] = ACTIONS(695),
    [sym_hex_floating_point_literal] = ACTIONS(697),
    [sym_true] = ACTIONS(697),
    [sym_false] = ACTIONS(697),
    [sym_character_literal] = ACTIONS(695),
    [anon_sym_DQUOTE] = ACTIONS(697),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(695),
    [anon_sym_RBRACE] = ACTIONS(695),
    [sym_null_literal] = ACTIONS(697),
    [anon_sym_LPAREN] = ACTIONS(695),
    [anon_sym_LT] = ACTIONS(695),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_final] = ACTIONS(697),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_new] = ACTIONS(697),
    [anon_sym_class] = ACTIONS(697),
    [anon_sym_switch] = ACTIONS(697),
    [anon_sym_LBRACE] = ACTIONS(695),
    [anon_sym_case] = ACTIONS(697),
    [anon_sym_default] = ACTIONS(697),
    [anon_sym_SEMI] = ACTIONS(695),
    [anon_sym_assert] = ACTIONS(697),
    [anon_sym_do] = ACTIONS(697),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_break] = ACTIONS(697),
    [anon_sym_continue] = ACTIONS(697),
    [anon_sym_return] = ACTIONS(697),
    [anon_sym_yield] = ACTIONS(697),
    [anon_sym_synchronized] = ACTIONS(697),
    [anon_sym_throw] = ACTIONS(697),
    [anon_sym_try] = ACTIONS(697),
    [anon_sym_if] = ACTIONS(697),
    [anon_sym_else] = ACTIONS(697),
    [anon_sym_for] = ACTIONS(697),
    [anon_sym_AT] = ACTIONS(697),
    [anon_sym_open] = ACTIONS(697),
    [anon_sym_module] = ACTIONS(697),
    [anon_sym_static] = ACTIONS(697),
    [anon_sym_with] = ACTIONS(697),
    [anon_sym_package] = ACTIONS(697),
    [anon_sym_import] = ACTIONS(697),
    [anon_sym_enum] = ACTIONS(697),
    [anon_sym_public] = ACTIONS(697),
    [anon_sym_protected] = ACTIONS(697),
    [anon_sym_private] = ACTIONS(697),
    [anon_sym_abstract] = ACTIONS(697),
    [anon_sym_strictfp] = ACTIONS(697),
    [anon_sym_native] = ACTIONS(697),
    [anon_sym_transient] = ACTIONS(697),
    [anon_sym_volatile] = ACTIONS(697),
    [anon_sym_sealed] = ACTIONS(697),
    [anon_sym_non_DASHsealed] = ACTIONS(695),
    [anon_sym_record] = ACTIONS(697),
    [anon_sym_ATinterface] = ACTIONS(695),
    [anon_sym_interface] = ACTIONS(697),
    [anon_sym_byte] = ACTIONS(697),
    [anon_sym_short] = ACTIONS(697),
    [anon_sym_int] = ACTIONS(697),
    [anon_sym_long] = ACTIONS(697),
    [anon_sym_char] = ACTIONS(697),
    [anon_sym_float] = ACTIONS(697),
    [anon_sym_double] = ACTIONS(697),
    [sym_boolean_type] = ACTIONS(697),
    [sym_void_type] = ACTIONS(697),
    [sym_this] = ACTIONS(697),
    [sym_super] = ACTIONS(697),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [264] = {
    [ts_builtin_sym_end] = ACTIONS(699),
    [sym_identifier] = ACTIONS(701),
    [sym_decimal_integer_literal] = ACTIONS(701),
    [sym_hex_integer_literal] = ACTIONS(701),
    [sym_octal_integer_literal] = ACTIONS(701),
    [sym_binary_integer_literal] = ACTIONS(699),
    [sym_decimal_floating_point_literal] = ACTIONS(699),
    [sym_hex_floating_point_literal] = ACTIONS(701),
    [sym_true] = ACTIONS(701),
    [sym_false] = ACTIONS(701),
    [sym_character_literal] = ACTIONS(699),
    [anon_sym_DQUOTE] = ACTIONS(701),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(699),
    [anon_sym_RBRACE] = ACTIONS(699),
    [sym_null_literal] = ACTIONS(701),
    [anon_sym_LPAREN] = ACTIONS(699),
    [anon_sym_LT] = ACTIONS(699),
    [anon_sym_PLUS] = ACTIONS(701),
    [anon_sym_DASH] = ACTIONS(701),
    [anon_sym_final] = ACTIONS(701),
    [anon_sym_BANG] = ACTIONS(699),
    [anon_sym_TILDE] = ACTIONS(699),
    [anon_sym_PLUS_PLUS] = ACTIONS(699),
    [anon_sym_DASH_DASH] = ACTIONS(699),
    [anon_sym_new] = ACTIONS(701),
    [anon_sym_class] = ACTIONS(701),
    [anon_sym_switch] = ACTIONS(701),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_case] = ACTIONS(701),
    [anon_sym_default] = ACTIONS(701),
    [anon_sym_SEMI] = ACTIONS(699),
    [anon_sym_assert] = ACTIONS(701),
    [anon_sym_do] = ACTIONS(701),
    [anon_sym_while] = ACTIONS(701),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_continue] = ACTIONS(701),
    [anon_sym_return] = ACTIONS(701),
    [anon_sym_yield] = ACTIONS(701),
    [anon_sym_synchronized] = ACTIONS(701),
    [anon_sym_throw] = ACTIONS(701),
    [anon_sym_try] = ACTIONS(701),
    [anon_sym_if] = ACTIONS(701),
    [anon_sym_else] = ACTIONS(701),
    [anon_sym_for] = ACTIONS(701),
    [anon_sym_AT] = ACTIONS(701),
    [anon_sym_open] = ACTIONS(701),
    [anon_sym_module] = ACTIONS(701),
    [anon_sym_static] = ACTIONS(701),
    [anon_sym_with] = ACTIONS(701),
    [anon_sym_package] = ACTIONS(701),
    [anon_sym_import] = ACTIONS(701),
    [anon_sym_enum] = ACTIONS(701),
    [anon_sym_public] = ACTIONS(701),
    [anon_sym_protected] = ACTIONS(701),
    [anon_sym_private] = ACTIONS(701),
    [anon_sym_abstract] = ACTIONS(701),
    [anon_sym_strictfp] = ACTIONS(701),
    [anon_sym_native] = ACTIONS(701),
    [anon_sym_transient] = ACTIONS(701),
    [anon_sym_volatile] = ACTIONS(701),
    [anon_sym_sealed] = ACTIONS(701),
    [anon_sym_non_DASHsealed] = ACTIONS(699),
    [anon_sym_record] = ACTIONS(701),
    [anon_sym_ATinterface] = ACTIONS(699),
    [anon_sym_interface] = ACTIONS(701),
    [anon_sym_byte] = ACTIONS(701),
    [anon_sym_short] = ACTIONS(701),
    [anon_sym_int] = ACTIONS(701),
    [anon_sym_long] = ACTIONS(701),
    [anon_sym_char] = ACTIONS(701),
    [anon_sym_float] = ACTIONS(701),
    [anon_sym_double] = ACTIONS(701),
    [sym_boolean_type] = ACTIONS(701),
    [sym_void_type] = ACTIONS(701),
    [sym_this] = ACTIONS(701),
    [sym_super] = ACTIONS(701),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [265] = {
    [ts_builtin_sym_end] = ACTIONS(703),
    [sym_identifier] = ACTIONS(705),
    [sym_decimal_integer_literal] = ACTIONS(705),
    [sym_hex_integer_literal] = ACTIONS(705),
    [sym_octal_integer_literal] = ACTIONS(705),
    [sym_binary_integer_literal] = ACTIONS(703),
    [sym_decimal_floating_point_literal] = ACTIONS(703),
    [sym_hex_floating_point_literal] = ACTIONS(705),
    [sym_true] = ACTIONS(705),
    [sym_false] = ACTIONS(705),
    [sym_character_literal] = ACTIONS(703),
    [anon_sym_DQUOTE] = ACTIONS(705),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(703),
    [anon_sym_RBRACE] = ACTIONS(703),
    [sym_null_literal] = ACTIONS(705),
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_LT] = ACTIONS(703),
    [anon_sym_PLUS] = ACTIONS(705),
    [anon_sym_DASH] = ACTIONS(705),
    [anon_sym_final] = ACTIONS(705),
    [anon_sym_BANG] = ACTIONS(703),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_PLUS_PLUS] = ACTIONS(703),
    [anon_sym_DASH_DASH] = ACTIONS(703),
    [anon_sym_new] = ACTIONS(705),
    [anon_sym_class] = ACTIONS(705),
    [anon_sym_switch] = ACTIONS(705),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_case] = ACTIONS(705),
    [anon_sym_default] = ACTIONS(705),
    [anon_sym_SEMI] = ACTIONS(703),
    [anon_sym_assert] = ACTIONS(705),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(705),
    [anon_sym_break] = ACTIONS(705),
    [anon_sym_continue] = ACTIONS(705),
    [anon_sym_return] = ACTIONS(705),
    [anon_sym_yield] = ACTIONS(705),
    [anon_sym_synchronized] = ACTIONS(705),
    [anon_sym_throw] = ACTIONS(705),
    [anon_sym_try] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(705),
    [anon_sym_else] = ACTIONS(705),
    [anon_sym_for] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(705),
    [anon_sym_open] = ACTIONS(705),
    [anon_sym_module] = ACTIONS(705),
    [anon_sym_static] = ACTIONS(705),
    [anon_sym_with] = ACTIONS(705),
    [anon_sym_package] = ACTIONS(705),
    [anon_sym_import] = ACTIONS(705),
    [anon_sym_enum] = ACTIONS(705),
    [anon_sym_public] = ACTIONS(705),
    [anon_sym_protected] = ACTIONS(705),
    [anon_sym_private] = ACTIONS(705),
    [anon_sym_abstract] = ACTIONS(705),
    [anon_sym_strictfp] = ACTIONS(705),
    [anon_sym_native] = ACTIONS(705),
    [anon_sym_transient] = ACTIONS(705),
    [anon_sym_volatile] = ACTIONS(705),
    [anon_sym_sealed] = ACTIONS(705),
    [anon_sym_non_DASHsealed] = ACTIONS(703),
    [anon_sym_record] = ACTIONS(705),
    [anon_sym_ATinterface] = ACTIONS(703),
    [anon_sym_interface] = ACTIONS(705),
    [anon_sym_byte] = ACTIONS(705),
    [anon_sym_short] = ACTIONS(705),
    [anon_sym_int] = ACTIONS(705),
    [anon_sym_long] = ACTIONS(705),
    [anon_sym_char] = ACTIONS(705),
    [anon_sym_float] = ACTIONS(705),
    [anon_sym_double] = ACTIONS(705),
    [sym_boolean_type] = ACTIONS(705),
    [sym_void_type] = ACTIONS(705),
    [sym_this] = ACTIONS(705),
    [sym_super] = ACTIONS(705),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [266] = {
    [ts_builtin_sym_end] = ACTIONS(707),
    [sym_identifier] = ACTIONS(709),
    [sym_decimal_integer_literal] = ACTIONS(709),
    [sym_hex_integer_literal] = ACTIONS(709),
    [sym_octal_integer_literal] = ACTIONS(709),
    [sym_binary_integer_literal] = ACTIONS(707),
    [sym_decimal_floating_point_literal] = ACTIONS(707),
    [sym_hex_floating_point_literal] = ACTIONS(709),
    [sym_true] = ACTIONS(709),
    [sym_false] = ACTIONS(709),
    [sym_character_literal] = ACTIONS(707),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(707),
    [anon_sym_RBRACE] = ACTIONS(707),
    [sym_null_literal] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(709),
    [anon_sym_final] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(707),
    [anon_sym_TILDE] = ACTIONS(707),
    [anon_sym_PLUS_PLUS] = ACTIONS(707),
    [anon_sym_DASH_DASH] = ACTIONS(707),
    [anon_sym_new] = ACTIONS(709),
    [anon_sym_class] = ACTIONS(709),
    [anon_sym_switch] = ACTIONS(709),
    [anon_sym_LBRACE] = ACTIONS(707),
    [anon_sym_case] = ACTIONS(709),
    [anon_sym_default] = ACTIONS(709),
    [anon_sym_SEMI] = ACTIONS(707),
    [anon_sym_assert] = ACTIONS(709),
    [anon_sym_do] = ACTIONS(709),
    [anon_sym_while] = ACTIONS(709),
    [anon_sym_break] = ACTIONS(709),
    [anon_sym_continue] = ACTIONS(709),
    [anon_sym_return] = ACTIONS(709),
    [anon_sym_yield] = ACTIONS(709),
    [anon_sym_synchronized] = ACTIONS(709),
    [anon_sym_throw] = ACTIONS(709),
    [anon_sym_try] = ACTIONS(709),
    [anon_sym_if] = ACTIONS(709),
    [anon_sym_else] = ACTIONS(709),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(709),
    [anon_sym_open] = ACTIONS(709),
    [anon_sym_module] = ACTIONS(709),
    [anon_sym_static] = ACTIONS(709),
    [anon_sym_with] = ACTIONS(709),
    [anon_sym_package] = ACTIONS(709),
    [anon_sym_import] = ACTIONS(709),
    [anon_sym_enum] = ACTIONS(709),
    [anon_sym_public] = ACTIONS(709),
    [anon_sym_protected] = ACTIONS(709),
    [anon_sym_private] = ACTIONS(709),
    [anon_sym_abstract] = ACTIONS(709),
    [anon_sym_strictfp] = ACTIONS(709),
    [anon_sym_native] = ACTIONS(709),
    [anon_sym_transient] = ACTIONS(709),
    [anon_sym_volatile] = ACTIONS(709),
    [anon_sym_sealed] = ACTIONS(709),
    [anon_sym_non_DASHsealed] = ACTIONS(707),
    [anon_sym_record] = ACTIONS(709),
    [anon_sym_ATinterface] = ACTIONS(707),
    [anon_sym_interface] = ACTIONS(709),
    [anon_sym_byte] = ACTIONS(709),
    [anon_sym_short] = ACTIONS(709),
    [anon_sym_int] = ACTIONS(709),
    [anon_sym_long] = ACTIONS(709),
    [anon_sym_char] = ACTIONS(709),
    [anon_sym_float] = ACTIONS(709),
    [anon_sym_double] = ACTIONS(709),
    [sym_boolean_type] = ACTIONS(709),
    [sym_void_type] = ACTIONS(709),
    [sym_this] = ACTIONS(709),
    [sym_super] = ACTIONS(709),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [267] = {
    [ts_builtin_sym_end] = ACTIONS(711),
    [sym_identifier] = ACTIONS(713),
    [sym_decimal_integer_literal] = ACTIONS(713),
    [sym_hex_integer_literal] = ACTIONS(713),
    [sym_octal_integer_literal] = ACTIONS(713),
    [sym_binary_integer_literal] = ACTIONS(711),
    [sym_decimal_floating_point_literal] = ACTIONS(711),
    [sym_hex_floating_point_literal] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_character_literal] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(711),
    [anon_sym_RBRACE] = ACTIONS(711),
    [sym_null_literal] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_PLUS] = ACTIONS(713),
    [anon_sym_DASH] = ACTIONS(713),
    [anon_sym_final] = ACTIONS(713),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(711),
    [anon_sym_DASH_DASH] = ACTIONS(711),
    [anon_sym_new] = ACTIONS(713),
    [anon_sym_class] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(713),
    [anon_sym_LBRACE] = ACTIONS(711),
    [anon_sym_case] = ACTIONS(713),
    [anon_sym_default] = ACTIONS(713),
    [anon_sym_SEMI] = ACTIONS(711),
    [anon_sym_assert] = ACTIONS(713),
    [anon_sym_do] = ACTIONS(713),
    [anon_sym_while] = ACTIONS(713),
    [anon_sym_break] = ACTIONS(713),
    [anon_sym_continue] = ACTIONS(713),
    [anon_sym_return] = ACTIONS(713),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_synchronized] = ACTIONS(713),
    [anon_sym_throw] = ACTIONS(713),
    [anon_sym_try] = ACTIONS(713),
    [anon_sym_if] = ACTIONS(713),
    [anon_sym_else] = ACTIONS(713),
    [anon_sym_for] = ACTIONS(713),
    [anon_sym_AT] = ACTIONS(713),
    [anon_sym_open] = ACTIONS(713),
    [anon_sym_module] = ACTIONS(713),
    [anon_sym_static] = ACTIONS(713),
    [anon_sym_with] = ACTIONS(713),
    [anon_sym_package] = ACTIONS(713),
    [anon_sym_import] = ACTIONS(713),
    [anon_sym_enum] = ACTIONS(713),
    [anon_sym_public] = ACTIONS(713),
    [anon_sym_protected] = ACTIONS(713),
    [anon_sym_private] = ACTIONS(713),
    [anon_sym_abstract] = ACTIONS(713),
    [anon_sym_strictfp] = ACTIONS(713),
    [anon_sym_native] = ACTIONS(713),
    [anon_sym_transient] = ACTIONS(713),
    [anon_sym_volatile] = ACTIONS(713),
    [anon_sym_sealed] = ACTIONS(713),
    [anon_sym_non_DASHsealed] = ACTIONS(711),
    [anon_sym_record] = ACTIONS(713),
    [anon_sym_ATinterface] = ACTIONS(711),
    [anon_sym_interface] = ACTIONS(713),
    [anon_sym_byte] = ACTIONS(713),
    [anon_sym_short] = ACTIONS(713),
    [anon_sym_int] = ACTIONS(713),
    [anon_sym_long] = ACTIONS(713),
    [anon_sym_char] = ACTIONS(713),
    [anon_sym_float] = ACTIONS(713),
    [anon_sym_double] = ACTIONS(713),
    [sym_boolean_type] = ACTIONS(713),
    [sym_void_type] = ACTIONS(713),
    [sym_this] = ACTIONS(713),
    [sym_super] = ACTIONS(713),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [268] = {
    [ts_builtin_sym_end] = ACTIONS(715),
    [sym_identifier] = ACTIONS(717),
    [sym_decimal_integer_literal] = ACTIONS(717),
    [sym_hex_integer_literal] = ACTIONS(717),
    [sym_octal_integer_literal] = ACTIONS(717),
    [sym_binary_integer_literal] = ACTIONS(715),
    [sym_decimal_floating_point_literal] = ACTIONS(715),
    [sym_hex_floating_point_literal] = ACTIONS(717),
    [sym_true] = ACTIONS(717),
    [sym_false] = ACTIONS(717),
    [sym_character_literal] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(715),
    [anon_sym_RBRACE] = ACTIONS(715),
    [sym_null_literal] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(715),
    [anon_sym_LT] = ACTIONS(715),
    [anon_sym_PLUS] = ACTIONS(717),
    [anon_sym_DASH] = ACTIONS(717),
    [anon_sym_final] = ACTIONS(717),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(715),
    [anon_sym_DASH_DASH] = ACTIONS(715),
    [anon_sym_new] = ACTIONS(717),
    [anon_sym_class] = ACTIONS(717),
    [anon_sym_switch] = ACTIONS(717),
    [anon_sym_LBRACE] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(717),
    [anon_sym_default] = ACTIONS(717),
    [anon_sym_SEMI] = ACTIONS(715),
    [anon_sym_assert] = ACTIONS(717),
    [anon_sym_do] = ACTIONS(717),
    [anon_sym_while] = ACTIONS(717),
    [anon_sym_break] = ACTIONS(717),
    [anon_sym_continue] = ACTIONS(717),
    [anon_sym_return] = ACTIONS(717),
    [anon_sym_yield] = ACTIONS(717),
    [anon_sym_synchronized] = ACTIONS(717),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(717),
    [anon_sym_if] = ACTIONS(717),
    [anon_sym_else] = ACTIONS(717),
    [anon_sym_for] = ACTIONS(717),
    [anon_sym_AT] = ACTIONS(717),
    [anon_sym_open] = ACTIONS(717),
    [anon_sym_module] = ACTIONS(717),
    [anon_sym_static] = ACTIONS(717),
    [anon_sym_with] = ACTIONS(717),
    [anon_sym_package] = ACTIONS(717),
    [anon_sym_import] = ACTIONS(717),
    [anon_sym_enum] = ACTIONS(717),
    [anon_sym_public] = ACTIONS(717),
    [anon_sym_protected] = ACTIONS(717),
    [anon_sym_private] = ACTIONS(717),
    [anon_sym_abstract] = ACTIONS(717),
    [anon_sym_strictfp] = ACTIONS(717),
    [anon_sym_native] = ACTIONS(717),
    [anon_sym_transient] = ACTIONS(717),
    [anon_sym_volatile] = ACTIONS(717),
    [anon_sym_sealed] = ACTIONS(717),
    [anon_sym_non_DASHsealed] = ACTIONS(715),
    [anon_sym_record] = ACTIONS(717),
    [anon_sym_ATinterface] = ACTIONS(715),
    [anon_sym_interface] = ACTIONS(717),
    [anon_sym_byte] = ACTIONS(717),
    [anon_sym_short] = ACTIONS(717),
    [anon_sym_int] = ACTIONS(717),
    [anon_sym_long] = ACTIONS(717),
    [anon_sym_char] = ACTIONS(717),
    [anon_sym_float] = ACTIONS(717),
    [anon_sym_double] = ACTIONS(717),
    [sym_boolean_type] = ACTIONS(717),
    [sym_void_type] = ACTIONS(717),
    [sym_this] = ACTIONS(717),
    [sym_super] = ACTIONS(717),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [269] = {
    [ts_builtin_sym_end] = ACTIONS(719),
    [sym_identifier] = ACTIONS(721),
    [sym_decimal_integer_literal] = ACTIONS(721),
    [sym_hex_integer_literal] = ACTIONS(721),
    [sym_octal_integer_literal] = ACTIONS(721),
    [sym_binary_integer_literal] = ACTIONS(719),
    [sym_decimal_floating_point_literal] = ACTIONS(719),
    [sym_hex_floating_point_literal] = ACTIONS(721),
    [sym_true] = ACTIONS(721),
    [sym_false] = ACTIONS(721),
    [sym_character_literal] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(719),
    [anon_sym_RBRACE] = ACTIONS(719),
    [sym_null_literal] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(719),
    [anon_sym_LT] = ACTIONS(719),
    [anon_sym_PLUS] = ACTIONS(721),
    [anon_sym_DASH] = ACTIONS(721),
    [anon_sym_final] = ACTIONS(721),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(719),
    [anon_sym_DASH_DASH] = ACTIONS(719),
    [anon_sym_new] = ACTIONS(721),
    [anon_sym_class] = ACTIONS(721),
    [anon_sym_switch] = ACTIONS(721),
    [anon_sym_LBRACE] = ACTIONS(719),
    [anon_sym_case] = ACTIONS(721),
    [anon_sym_default] = ACTIONS(721),
    [anon_sym_SEMI] = ACTIONS(719),
    [anon_sym_assert] = ACTIONS(721),
    [anon_sym_do] = ACTIONS(721),
    [anon_sym_while] = ACTIONS(721),
    [anon_sym_break] = ACTIONS(721),
    [anon_sym_continue] = ACTIONS(721),
    [anon_sym_return] = ACTIONS(721),
    [anon_sym_yield] = ACTIONS(721),
    [anon_sym_synchronized] = ACTIONS(721),
    [anon_sym_throw] = ACTIONS(721),
    [anon_sym_try] = ACTIONS(721),
    [anon_sym_if] = ACTIONS(721),
    [anon_sym_else] = ACTIONS(721),
    [anon_sym_for] = ACTIONS(721),
    [anon_sym_AT] = ACTIONS(721),
    [anon_sym_open] = ACTIONS(721),
    [anon_sym_module] = ACTIONS(721),
    [anon_sym_static] = ACTIONS(721),
    [anon_sym_with] = ACTIONS(721),
    [anon_sym_package] = ACTIONS(721),
    [anon_sym_import] = ACTIONS(721),
    [anon_sym_enum] = ACTIONS(721),
    [anon_sym_public] = ACTIONS(721),
    [anon_sym_protected] = ACTIONS(721),
    [anon_sym_private] = ACTIONS(721),
    [anon_sym_abstract] = ACTIONS(721),
    [anon_sym_strictfp] = ACTIONS(721),
    [anon_sym_native] = ACTIONS(721),
    [anon_sym_transient] = ACTIONS(721),
    [anon_sym_volatile] = ACTIONS(721),
    [anon_sym_sealed] = ACTIONS(721),
    [anon_sym_non_DASHsealed] = ACTIONS(719),
    [anon_sym_record] = ACTIONS(721),
    [anon_sym_ATinterface] = ACTIONS(719),
    [anon_sym_interface] = ACTIONS(721),
    [anon_sym_byte] = ACTIONS(721),
    [anon_sym_short] = ACTIONS(721),
    [anon_sym_int] = ACTIONS(721),
    [anon_sym_long] = ACTIONS(721),
    [anon_sym_char] = ACTIONS(721),
    [anon_sym_float] = ACTIONS(721),
    [anon_sym_double] = ACTIONS(721),
    [sym_boolean_type] = ACTIONS(721),
    [sym_void_type] = ACTIONS(721),
    [sym_this] = ACTIONS(721),
    [sym_super] = ACTIONS(721),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [270] = {
    [ts_builtin_sym_end] = ACTIONS(723),
    [sym_identifier] = ACTIONS(725),
    [sym_decimal_integer_literal] = ACTIONS(725),
    [sym_hex_integer_literal] = ACTIONS(725),
    [sym_octal_integer_literal] = ACTIONS(725),
    [sym_binary_integer_literal] = ACTIONS(723),
    [sym_decimal_floating_point_literal] = ACTIONS(723),
    [sym_hex_floating_point_literal] = ACTIONS(725),
    [sym_true] = ACTIONS(725),
    [sym_false] = ACTIONS(725),
    [sym_character_literal] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(725),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(723),
    [anon_sym_RBRACE] = ACTIONS(723),
    [sym_null_literal] = ACTIONS(725),
    [anon_sym_LPAREN] = ACTIONS(723),
    [anon_sym_LT] = ACTIONS(723),
    [anon_sym_PLUS] = ACTIONS(725),
    [anon_sym_DASH] = ACTIONS(725),
    [anon_sym_final] = ACTIONS(725),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(723),
    [anon_sym_DASH_DASH] = ACTIONS(723),
    [anon_sym_new] = ACTIONS(725),
    [anon_sym_class] = ACTIONS(725),
    [anon_sym_switch] = ACTIONS(725),
    [anon_sym_LBRACE] = ACTIONS(723),
    [anon_sym_case] = ACTIONS(725),
    [anon_sym_default] = ACTIONS(725),
    [anon_sym_SEMI] = ACTIONS(723),
    [anon_sym_assert] = ACTIONS(725),
    [anon_sym_do] = ACTIONS(725),
    [anon_sym_while] = ACTIONS(725),
    [anon_sym_break] = ACTIONS(725),
    [anon_sym_continue] = ACTIONS(725),
    [anon_sym_return] = ACTIONS(725),
    [anon_sym_yield] = ACTIONS(725),
    [anon_sym_synchronized] = ACTIONS(725),
    [anon_sym_throw] = ACTIONS(725),
    [anon_sym_try] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(725),
    [anon_sym_else] = ACTIONS(725),
    [anon_sym_for] = ACTIONS(725),
    [anon_sym_AT] = ACTIONS(725),
    [anon_sym_open] = ACTIONS(725),
    [anon_sym_module] = ACTIONS(725),
    [anon_sym_static] = ACTIONS(725),
    [anon_sym_with] = ACTIONS(725),
    [anon_sym_package] = ACTIONS(725),
    [anon_sym_import] = ACTIONS(725),
    [anon_sym_enum] = ACTIONS(725),
    [anon_sym_public] = ACTIONS(725),
    [anon_sym_protected] = ACTIONS(725),
    [anon_sym_private] = ACTIONS(725),
    [anon_sym_abstract] = ACTIONS(725),
    [anon_sym_strictfp] = ACTIONS(725),
    [anon_sym_native] = ACTIONS(725),
    [anon_sym_transient] = ACTIONS(725),
    [anon_sym_volatile] = ACTIONS(725),
    [anon_sym_sealed] = ACTIONS(725),
    [anon_sym_non_DASHsealed] = ACTIONS(723),
    [anon_sym_record] = ACTIONS(725),
    [anon_sym_ATinterface] = ACTIONS(723),
    [anon_sym_interface] = ACTIONS(725),
    [anon_sym_byte] = ACTIONS(725),
    [anon_sym_short] = ACTIONS(725),
    [anon_sym_int] = ACTIONS(725),
    [anon_sym_long] = ACTIONS(725),
    [anon_sym_char] = ACTIONS(725),
    [anon_sym_float] = ACTIONS(725),
    [anon_sym_double] = ACTIONS(725),
    [sym_boolean_type] = ACTIONS(725),
    [sym_void_type] = ACTIONS(725),
    [sym_this] = ACTIONS(725),
    [sym_super] = ACTIONS(725),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [271] = {
    [ts_builtin_sym_end] = ACTIONS(727),
    [sym_identifier] = ACTIONS(729),
    [sym_decimal_integer_literal] = ACTIONS(729),
    [sym_hex_integer_literal] = ACTIONS(729),
    [sym_octal_integer_literal] = ACTIONS(729),
    [sym_binary_integer_literal] = ACTIONS(727),
    [sym_decimal_floating_point_literal] = ACTIONS(727),
    [sym_hex_floating_point_literal] = ACTIONS(729),
    [sym_true] = ACTIONS(729),
    [sym_false] = ACTIONS(729),
    [sym_character_literal] = ACTIONS(727),
    [anon_sym_DQUOTE] = ACTIONS(729),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(727),
    [anon_sym_RBRACE] = ACTIONS(727),
    [sym_null_literal] = ACTIONS(729),
    [anon_sym_LPAREN] = ACTIONS(727),
    [anon_sym_LT] = ACTIONS(727),
    [anon_sym_PLUS] = ACTIONS(729),
    [anon_sym_DASH] = ACTIONS(729),
    [anon_sym_final] = ACTIONS(729),
    [anon_sym_BANG] = ACTIONS(727),
    [anon_sym_TILDE] = ACTIONS(727),
    [anon_sym_PLUS_PLUS] = ACTIONS(727),
    [anon_sym_DASH_DASH] = ACTIONS(727),
    [anon_sym_new] = ACTIONS(729),
    [anon_sym_class] = ACTIONS(729),
    [anon_sym_switch] = ACTIONS(729),
    [anon_sym_LBRACE] = ACTIONS(727),
    [anon_sym_case] = ACTIONS(729),
    [anon_sym_default] = ACTIONS(729),
    [anon_sym_SEMI] = ACTIONS(727),
    [anon_sym_assert] = ACTIONS(729),
    [anon_sym_do] = ACTIONS(729),
    [anon_sym_while] = ACTIONS(729),
    [anon_sym_break] = ACTIONS(729),
    [anon_sym_continue] = ACTIONS(729),
    [anon_sym_return] = ACTIONS(729),
    [anon_sym_yield] = ACTIONS(729),
    [anon_sym_synchronized] = ACTIONS(729),
    [anon_sym_throw] = ACTIONS(729),
    [anon_sym_try] = ACTIONS(729),
    [anon_sym_if] = ACTIONS(729),
    [anon_sym_else] = ACTIONS(729),
    [anon_sym_for] = ACTIONS(729),
    [anon_sym_AT] = ACTIONS(729),
    [anon_sym_open] = ACTIONS(729),
    [anon_sym_module] = ACTIONS(729),
    [anon_sym_static] = ACTIONS(729),
    [anon_sym_with] = ACTIONS(729),
    [anon_sym_package] = ACTIONS(729),
    [anon_sym_import] = ACTIONS(729),
    [anon_sym_enum] = ACTIONS(729),
    [anon_sym_public] = ACTIONS(729),
    [anon_sym_protected] = ACTIONS(729),
    [anon_sym_private] = ACTIONS(729),
    [anon_sym_abstract] = ACTIONS(729),
    [anon_sym_strictfp] = ACTIONS(729),
    [anon_sym_native] = ACTIONS(729),
    [anon_sym_transient] = ACTIONS(729),
    [anon_sym_volatile] = ACTIONS(729),
    [anon_sym_sealed] = ACTIONS(729),
    [anon_sym_non_DASHsealed] = ACTIONS(727),
    [anon_sym_record] = ACTIONS(729),
    [anon_sym_ATinterface] = ACTIONS(727),
    [anon_sym_interface] = ACTIONS(729),
    [anon_sym_byte] = ACTIONS(729),
    [anon_sym_short] = ACTIONS(729),
    [anon_sym_int] = ACTIONS(729),
    [anon_sym_long] = ACTIONS(729),
    [anon_sym_char] = ACTIONS(729),
    [anon_sym_float] = ACTIONS(729),
    [anon_sym_double] = ACTIONS(729),
    [sym_boolean_type] = ACTIONS(729),
    [sym_void_type] = ACTIONS(729),
    [sym_this] = ACTIONS(729),
    [sym_super] = ACTIONS(729),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [272] = {
    [ts_builtin_sym_end] = ACTIONS(628),
    [sym_identifier] = ACTIONS(630),
    [sym_decimal_integer_literal] = ACTIONS(630),
    [sym_hex_integer_literal] = ACTIONS(630),
    [sym_octal_integer_literal] = ACTIONS(630),
    [sym_binary_integer_literal] = ACTIONS(628),
    [sym_decimal_floating_point_literal] = ACTIONS(628),
    [sym_hex_floating_point_literal] = ACTIONS(630),
    [sym_true] = ACTIONS(630),
    [sym_false] = ACTIONS(630),
    [sym_character_literal] = ACTIONS(628),
    [anon_sym_DQUOTE] = ACTIONS(630),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(628),
    [anon_sym_RBRACE] = ACTIONS(628),
    [sym_null_literal] = ACTIONS(630),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_LT] = ACTIONS(628),
    [anon_sym_PLUS] = ACTIONS(630),
    [anon_sym_DASH] = ACTIONS(630),
    [anon_sym_final] = ACTIONS(630),
    [anon_sym_BANG] = ACTIONS(628),
    [anon_sym_TILDE] = ACTIONS(628),
    [anon_sym_PLUS_PLUS] = ACTIONS(628),
    [anon_sym_DASH_DASH] = ACTIONS(628),
    [anon_sym_new] = ACTIONS(630),
    [anon_sym_class] = ACTIONS(630),
    [anon_sym_switch] = ACTIONS(630),
    [anon_sym_LBRACE] = ACTIONS(628),
    [anon_sym_case] = ACTIONS(630),
    [anon_sym_default] = ACTIONS(630),
    [anon_sym_SEMI] = ACTIONS(628),
    [anon_sym_assert] = ACTIONS(630),
    [anon_sym_do] = ACTIONS(630),
    [anon_sym_while] = ACTIONS(630),
    [anon_sym_break] = ACTIONS(630),
    [anon_sym_continue] = ACTIONS(630),
    [anon_sym_return] = ACTIONS(630),
    [anon_sym_yield] = ACTIONS(630),
    [anon_sym_synchronized] = ACTIONS(630),
    [anon_sym_throw] = ACTIONS(630),
    [anon_sym_try] = ACTIONS(630),
    [anon_sym_if] = ACTIONS(630),
    [anon_sym_else] = ACTIONS(630),
    [anon_sym_for] = ACTIONS(630),
    [anon_sym_AT] = ACTIONS(630),
    [anon_sym_open] = ACTIONS(630),
    [anon_sym_module] = ACTIONS(630),
    [anon_sym_static] = ACTIONS(630),
    [anon_sym_with] = ACTIONS(630),
    [anon_sym_package] = ACTIONS(630),
    [anon_sym_import] = ACTIONS(630),
    [anon_sym_enum] = ACTIONS(630),
    [anon_sym_public] = ACTIONS(630),
    [anon_sym_protected] = ACTIONS(630),
    [anon_sym_private] = ACTIONS(630),
    [anon_sym_abstract] = ACTIONS(630),
    [anon_sym_strictfp] = ACTIONS(630),
    [anon_sym_native] = ACTIONS(630),
    [anon_sym_transient] = ACTIONS(630),
    [anon_sym_volatile] = ACTIONS(630),
    [anon_sym_sealed] = ACTIONS(630),
    [anon_sym_non_DASHsealed] = ACTIONS(628),
    [anon_sym_record] = ACTIONS(630),
    [anon_sym_ATinterface] = ACTIONS(628),
    [anon_sym_interface] = ACTIONS(630),
    [anon_sym_byte] = ACTIONS(630),
    [anon_sym_short] = ACTIONS(630),
    [anon_sym_int] = ACTIONS(630),
    [anon_sym_long] = ACTIONS(630),
    [anon_sym_char] = ACTIONS(630),
    [anon_sym_float] = ACTIONS(630),
    [anon_sym_double] = ACTIONS(630),
    [sym_boolean_type] = ACTIONS(630),
    [sym_void_type] = ACTIONS(630),
    [sym_this] = ACTIONS(630),
    [sym_super] = ACTIONS(630),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [273] = {
    [ts_builtin_sym_end] = ACTIONS(731),
    [sym_identifier] = ACTIONS(733),
    [sym_decimal_integer_literal] = ACTIONS(733),
    [sym_hex_integer_literal] = ACTIONS(733),
    [sym_octal_integer_literal] = ACTIONS(733),
    [sym_binary_integer_literal] = ACTIONS(731),
    [sym_decimal_floating_point_literal] = ACTIONS(731),
    [sym_hex_floating_point_literal] = ACTIONS(733),
    [sym_true] = ACTIONS(733),
    [sym_false] = ACTIONS(733),
    [sym_character_literal] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(731),
    [anon_sym_RBRACE] = ACTIONS(731),
    [sym_null_literal] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(731),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_PLUS] = ACTIONS(733),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_final] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(731),
    [anon_sym_DASH_DASH] = ACTIONS(731),
    [anon_sym_new] = ACTIONS(733),
    [anon_sym_class] = ACTIONS(733),
    [anon_sym_switch] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(731),
    [anon_sym_case] = ACTIONS(733),
    [anon_sym_default] = ACTIONS(733),
    [anon_sym_SEMI] = ACTIONS(731),
    [anon_sym_assert] = ACTIONS(733),
    [anon_sym_do] = ACTIONS(733),
    [anon_sym_while] = ACTIONS(733),
    [anon_sym_break] = ACTIONS(733),
    [anon_sym_continue] = ACTIONS(733),
    [anon_sym_return] = ACTIONS(733),
    [anon_sym_yield] = ACTIONS(733),
    [anon_sym_synchronized] = ACTIONS(733),
    [anon_sym_throw] = ACTIONS(733),
    [anon_sym_try] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(733),
    [anon_sym_else] = ACTIONS(733),
    [anon_sym_for] = ACTIONS(733),
    [anon_sym_AT] = ACTIONS(733),
    [anon_sym_open] = ACTIONS(733),
    [anon_sym_module] = ACTIONS(733),
    [anon_sym_static] = ACTIONS(733),
    [anon_sym_with] = ACTIONS(733),
    [anon_sym_package] = ACTIONS(733),
    [anon_sym_import] = ACTIONS(733),
    [anon_sym_enum] = ACTIONS(733),
    [anon_sym_public] = ACTIONS(733),
    [anon_sym_protected] = ACTIONS(733),
    [anon_sym_private] = ACTIONS(733),
    [anon_sym_abstract] = ACTIONS(733),
    [anon_sym_strictfp] = ACTIONS(733),
    [anon_sym_native] = ACTIONS(733),
    [anon_sym_transient] = ACTIONS(733),
    [anon_sym_volatile] = ACTIONS(733),
    [anon_sym_sealed] = ACTIONS(733),
    [anon_sym_non_DASHsealed] = ACTIONS(731),
    [anon_sym_record] = ACTIONS(733),
    [anon_sym_ATinterface] = ACTIONS(731),
    [anon_sym_interface] = ACTIONS(733),
    [anon_sym_byte] = ACTIONS(733),
    [anon_sym_short] = ACTIONS(733),
    [anon_sym_int] = ACTIONS(733),
    [anon_sym_long] = ACTIONS(733),
    [anon_sym_char] = ACTIONS(733),
    [anon_sym_float] = ACTIONS(733),
    [anon_sym_double] = ACTIONS(733),
    [sym_boolean_type] = ACTIONS(733),
    [sym_void_type] = ACTIONS(733),
    [sym_this] = ACTIONS(733),
    [sym_super] = ACTIONS(733),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [274] = {
    [ts_builtin_sym_end] = ACTIONS(735),
    [sym_identifier] = ACTIONS(737),
    [sym_decimal_integer_literal] = ACTIONS(737),
    [sym_hex_integer_literal] = ACTIONS(737),
    [sym_octal_integer_literal] = ACTIONS(737),
    [sym_binary_integer_literal] = ACTIONS(735),
    [sym_decimal_floating_point_literal] = ACTIONS(735),
    [sym_hex_floating_point_literal] = ACTIONS(737),
    [sym_true] = ACTIONS(737),
    [sym_false] = ACTIONS(737),
    [sym_character_literal] = ACTIONS(735),
    [anon_sym_DQUOTE] = ACTIONS(737),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(735),
    [anon_sym_RBRACE] = ACTIONS(735),
    [sym_null_literal] = ACTIONS(737),
    [anon_sym_LPAREN] = ACTIONS(735),
    [anon_sym_LT] = ACTIONS(735),
    [anon_sym_PLUS] = ACTIONS(737),
    [anon_sym_DASH] = ACTIONS(737),
    [anon_sym_final] = ACTIONS(737),
    [anon_sym_BANG] = ACTIONS(735),
    [anon_sym_TILDE] = ACTIONS(735),
    [anon_sym_PLUS_PLUS] = ACTIONS(735),
    [anon_sym_DASH_DASH] = ACTIONS(735),
    [anon_sym_new] = ACTIONS(737),
    [anon_sym_class] = ACTIONS(737),
    [anon_sym_switch] = ACTIONS(737),
    [anon_sym_LBRACE] = ACTIONS(735),
    [anon_sym_case] = ACTIONS(737),
    [anon_sym_default] = ACTIONS(737),
    [anon_sym_SEMI] = ACTIONS(735),
    [anon_sym_assert] = ACTIONS(737),
    [anon_sym_do] = ACTIONS(737),
    [anon_sym_while] = ACTIONS(737),
    [anon_sym_break] = ACTIONS(737),
    [anon_sym_continue] = ACTIONS(737),
    [anon_sym_return] = ACTIONS(737),
    [anon_sym_yield] = ACTIONS(737),
    [anon_sym_synchronized] = ACTIONS(737),
    [anon_sym_throw] = ACTIONS(737),
    [anon_sym_try] = ACTIONS(737),
    [anon_sym_if] = ACTIONS(737),
    [anon_sym_else] = ACTIONS(737),
    [anon_sym_for] = ACTIONS(737),
    [anon_sym_AT] = ACTIONS(737),
    [anon_sym_open] = ACTIONS(737),
    [anon_sym_module] = ACTIONS(737),
    [anon_sym_static] = ACTIONS(737),
    [anon_sym_with] = ACTIONS(737),
    [anon_sym_package] = ACTIONS(737),
    [anon_sym_import] = ACTIONS(737),
    [anon_sym_enum] = ACTIONS(737),
    [anon_sym_public] = ACTIONS(737),
    [anon_sym_protected] = ACTIONS(737),
    [anon_sym_private] = ACTIONS(737),
    [anon_sym_abstract] = ACTIONS(737),
    [anon_sym_strictfp] = ACTIONS(737),
    [anon_sym_native] = ACTIONS(737),
    [anon_sym_transient] = ACTIONS(737),
    [anon_sym_volatile] = ACTIONS(737),
    [anon_sym_sealed] = ACTIONS(737),
    [anon_sym_non_DASHsealed] = ACTIONS(735),
    [anon_sym_record] = ACTIONS(737),
    [anon_sym_ATinterface] = ACTIONS(735),
    [anon_sym_interface] = ACTIONS(737),
    [anon_sym_byte] = ACTIONS(737),
    [anon_sym_short] = ACTIONS(737),
    [anon_sym_int] = ACTIONS(737),
    [anon_sym_long] = ACTIONS(737),
    [anon_sym_char] = ACTIONS(737),
    [anon_sym_float] = ACTIONS(737),
    [anon_sym_double] = ACTIONS(737),
    [sym_boolean_type] = ACTIONS(737),
    [sym_void_type] = ACTIONS(737),
    [sym_this] = ACTIONS(737),
    [sym_super] = ACTIONS(737),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [275] = {
    [ts_builtin_sym_end] = ACTIONS(739),
    [sym_identifier] = ACTIONS(741),
    [sym_decimal_integer_literal] = ACTIONS(741),
    [sym_hex_integer_literal] = ACTIONS(741),
    [sym_octal_integer_literal] = ACTIONS(741),
    [sym_binary_integer_literal] = ACTIONS(739),
    [sym_decimal_floating_point_literal] = ACTIONS(739),
    [sym_hex_floating_point_literal] = ACTIONS(741),
    [sym_true] = ACTIONS(741),
    [sym_false] = ACTIONS(741),
    [sym_character_literal] = ACTIONS(739),
    [anon_sym_DQUOTE] = ACTIONS(741),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(739),
    [anon_sym_RBRACE] = ACTIONS(739),
    [sym_null_literal] = ACTIONS(741),
    [anon_sym_LPAREN] = ACTIONS(739),
    [anon_sym_LT] = ACTIONS(739),
    [anon_sym_PLUS] = ACTIONS(741),
    [anon_sym_DASH] = ACTIONS(741),
    [anon_sym_final] = ACTIONS(741),
    [anon_sym_BANG] = ACTIONS(739),
    [anon_sym_TILDE] = ACTIONS(739),
    [anon_sym_PLUS_PLUS] = ACTIONS(739),
    [anon_sym_DASH_DASH] = ACTIONS(739),
    [anon_sym_new] = ACTIONS(741),
    [anon_sym_class] = ACTIONS(741),
    [anon_sym_switch] = ACTIONS(741),
    [anon_sym_LBRACE] = ACTIONS(739),
    [anon_sym_case] = ACTIONS(741),
    [anon_sym_default] = ACTIONS(741),
    [anon_sym_SEMI] = ACTIONS(739),
    [anon_sym_assert] = ACTIONS(741),
    [anon_sym_do] = ACTIONS(741),
    [anon_sym_while] = ACTIONS(741),
    [anon_sym_break] = ACTIONS(741),
    [anon_sym_continue] = ACTIONS(741),
    [anon_sym_return] = ACTIONS(741),
    [anon_sym_yield] = ACTIONS(741),
    [anon_sym_synchronized] = ACTIONS(741),
    [anon_sym_throw] = ACTIONS(741),
    [anon_sym_try] = ACTIONS(741),
    [anon_sym_if] = ACTIONS(741),
    [anon_sym_else] = ACTIONS(741),
    [anon_sym_for] = ACTIONS(741),
    [anon_sym_AT] = ACTIONS(741),
    [anon_sym_open] = ACTIONS(741),
    [anon_sym_module] = ACTIONS(741),
    [anon_sym_static] = ACTIONS(741),
    [anon_sym_with] = ACTIONS(741),
    [anon_sym_package] = ACTIONS(741),
    [anon_sym_import] = ACTIONS(741),
    [anon_sym_enum] = ACTIONS(741),
    [anon_sym_public] = ACTIONS(741),
    [anon_sym_protected] = ACTIONS(741),
    [anon_sym_private] = ACTIONS(741),
    [anon_sym_abstract] = ACTIONS(741),
    [anon_sym_strictfp] = ACTIONS(741),
    [anon_sym_native] = ACTIONS(741),
    [anon_sym_transient] = ACTIONS(741),
    [anon_sym_volatile] = ACTIONS(741),
    [anon_sym_sealed] = ACTIONS(741),
    [anon_sym_non_DASHsealed] = ACTIONS(739),
    [anon_sym_record] = ACTIONS(741),
    [anon_sym_ATinterface] = ACTIONS(739),
    [anon_sym_interface] = ACTIONS(741),
    [anon_sym_byte] = ACTIONS(741),
    [anon_sym_short] = ACTIONS(741),
    [anon_sym_int] = ACTIONS(741),
    [anon_sym_long] = ACTIONS(741),
    [anon_sym_char] = ACTIONS(741),
    [anon_sym_float] = ACTIONS(741),
    [anon_sym_double] = ACTIONS(741),
    [sym_boolean_type] = ACTIONS(741),
    [sym_void_type] = ACTIONS(741),
    [sym_this] = ACTIONS(741),
    [sym_super] = ACTIONS(741),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [276] = {
    [ts_builtin_sym_end] = ACTIONS(743),
    [sym_identifier] = ACTIONS(745),
    [sym_decimal_integer_literal] = ACTIONS(745),
    [sym_hex_integer_literal] = ACTIONS(745),
    [sym_octal_integer_literal] = ACTIONS(745),
    [sym_binary_integer_literal] = ACTIONS(743),
    [sym_decimal_floating_point_literal] = ACTIONS(743),
    [sym_hex_floating_point_literal] = ACTIONS(745),
    [sym_true] = ACTIONS(745),
    [sym_false] = ACTIONS(745),
    [sym_character_literal] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(745),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(743),
    [anon_sym_RBRACE] = ACTIONS(743),
    [sym_null_literal] = ACTIONS(745),
    [anon_sym_LPAREN] = ACTIONS(743),
    [anon_sym_LT] = ACTIONS(743),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_final] = ACTIONS(745),
    [anon_sym_BANG] = ACTIONS(743),
    [anon_sym_TILDE] = ACTIONS(743),
    [anon_sym_PLUS_PLUS] = ACTIONS(743),
    [anon_sym_DASH_DASH] = ACTIONS(743),
    [anon_sym_new] = ACTIONS(745),
    [anon_sym_class] = ACTIONS(745),
    [anon_sym_switch] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(743),
    [anon_sym_case] = ACTIONS(745),
    [anon_sym_default] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(743),
    [anon_sym_assert] = ACTIONS(745),
    [anon_sym_do] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_break] = ACTIONS(745),
    [anon_sym_continue] = ACTIONS(745),
    [anon_sym_return] = ACTIONS(745),
    [anon_sym_yield] = ACTIONS(745),
    [anon_sym_synchronized] = ACTIONS(745),
    [anon_sym_throw] = ACTIONS(745),
    [anon_sym_try] = ACTIONS(745),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_else] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_AT] = ACTIONS(745),
    [anon_sym_open] = ACTIONS(745),
    [anon_sym_module] = ACTIONS(745),
    [anon_sym_static] = ACTIONS(745),
    [anon_sym_with] = ACTIONS(745),
    [anon_sym_package] = ACTIONS(745),
    [anon_sym_import] = ACTIONS(745),
    [anon_sym_enum] = ACTIONS(745),
    [anon_sym_public] = ACTIONS(745),
    [anon_sym_protected] = ACTIONS(745),
    [anon_sym_private] = ACTIONS(745),
    [anon_sym_abstract] = ACTIONS(745),
    [anon_sym_strictfp] = ACTIONS(745),
    [anon_sym_native] = ACTIONS(745),
    [anon_sym_transient] = ACTIONS(745),
    [anon_sym_volatile] = ACTIONS(745),
    [anon_sym_sealed] = ACTIONS(745),
    [anon_sym_non_DASHsealed] = ACTIONS(743),
    [anon_sym_record] = ACTIONS(745),
    [anon_sym_ATinterface] = ACTIONS(743),
    [anon_sym_interface] = ACTIONS(745),
    [anon_sym_byte] = ACTIONS(745),
    [anon_sym_short] = ACTIONS(745),
    [anon_sym_int] = ACTIONS(745),
    [anon_sym_long] = ACTIONS(745),
    [anon_sym_char] = ACTIONS(745),
    [anon_sym_float] = ACTIONS(745),
    [anon_sym_double] = ACTIONS(745),
    [sym_boolean_type] = ACTIONS(745),
    [sym_void_type] = ACTIONS(745),
    [sym_this] = ACTIONS(745),
    [sym_super] = ACTIONS(745),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [277] = {
    [ts_builtin_sym_end] = ACTIONS(747),
    [sym_identifier] = ACTIONS(749),
    [sym_decimal_integer_literal] = ACTIONS(749),
    [sym_hex_integer_literal] = ACTIONS(749),
    [sym_octal_integer_literal] = ACTIONS(749),
    [sym_binary_integer_literal] = ACTIONS(747),
    [sym_decimal_floating_point_literal] = ACTIONS(747),
    [sym_hex_floating_point_literal] = ACTIONS(749),
    [sym_true] = ACTIONS(749),
    [sym_false] = ACTIONS(749),
    [sym_character_literal] = ACTIONS(747),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(747),
    [anon_sym_RBRACE] = ACTIONS(747),
    [sym_null_literal] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(749),
    [anon_sym_DASH] = ACTIONS(749),
    [anon_sym_final] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(747),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(749),
    [anon_sym_class] = ACTIONS(749),
    [anon_sym_switch] = ACTIONS(749),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_case] = ACTIONS(749),
    [anon_sym_default] = ACTIONS(749),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_assert] = ACTIONS(749),
    [anon_sym_do] = ACTIONS(749),
    [anon_sym_while] = ACTIONS(749),
    [anon_sym_break] = ACTIONS(749),
    [anon_sym_continue] = ACTIONS(749),
    [anon_sym_return] = ACTIONS(749),
    [anon_sym_yield] = ACTIONS(749),
    [anon_sym_synchronized] = ACTIONS(749),
    [anon_sym_throw] = ACTIONS(749),
    [anon_sym_try] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(749),
    [anon_sym_else] = ACTIONS(749),
    [anon_sym_for] = ACTIONS(749),
    [anon_sym_AT] = ACTIONS(749),
    [anon_sym_open] = ACTIONS(749),
    [anon_sym_module] = ACTIONS(749),
    [anon_sym_static] = ACTIONS(749),
    [anon_sym_with] = ACTIONS(749),
    [anon_sym_package] = ACTIONS(749),
    [anon_sym_import] = ACTIONS(749),
    [anon_sym_enum] = ACTIONS(749),
    [anon_sym_public] = ACTIONS(749),
    [anon_sym_protected] = ACTIONS(749),
    [anon_sym_private] = ACTIONS(749),
    [anon_sym_abstract] = ACTIONS(749),
    [anon_sym_strictfp] = ACTIONS(749),
    [anon_sym_native] = ACTIONS(749),
    [anon_sym_transient] = ACTIONS(749),
    [anon_sym_volatile] = ACTIONS(749),
    [anon_sym_sealed] = ACTIONS(749),
    [anon_sym_non_DASHsealed] = ACTIONS(747),
    [anon_sym_record] = ACTIONS(749),
    [anon_sym_ATinterface] = ACTIONS(747),
    [anon_sym_interface] = ACTIONS(749),
    [anon_sym_byte] = ACTIONS(749),
    [anon_sym_short] = ACTIONS(749),
    [anon_sym_int] = ACTIONS(749),
    [anon_sym_long] = ACTIONS(749),
    [anon_sym_char] = ACTIONS(749),
    [anon_sym_float] = ACTIONS(749),
    [anon_sym_double] = ACTIONS(749),
    [sym_boolean_type] = ACTIONS(749),
    [sym_void_type] = ACTIONS(749),
    [sym_this] = ACTIONS(749),
    [sym_super] = ACTIONS(749),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [278] = {
    [ts_builtin_sym_end] = ACTIONS(751),
    [sym_identifier] = ACTIONS(753),
    [sym_decimal_integer_literal] = ACTIONS(753),
    [sym_hex_integer_literal] = ACTIONS(753),
    [sym_octal_integer_literal] = ACTIONS(753),
    [sym_binary_integer_literal] = ACTIONS(751),
    [sym_decimal_floating_point_literal] = ACTIONS(751),
    [sym_hex_floating_point_literal] = ACTIONS(753),
    [sym_true] = ACTIONS(753),
    [sym_false] = ACTIONS(753),
    [sym_character_literal] = ACTIONS(751),
    [anon_sym_DQUOTE] = ACTIONS(753),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(751),
    [anon_sym_RBRACE] = ACTIONS(751),
    [sym_null_literal] = ACTIONS(753),
    [anon_sym_LPAREN] = ACTIONS(751),
    [anon_sym_LT] = ACTIONS(751),
    [anon_sym_PLUS] = ACTIONS(753),
    [anon_sym_DASH] = ACTIONS(753),
    [anon_sym_final] = ACTIONS(753),
    [anon_sym_BANG] = ACTIONS(751),
    [anon_sym_TILDE] = ACTIONS(751),
    [anon_sym_PLUS_PLUS] = ACTIONS(751),
    [anon_sym_DASH_DASH] = ACTIONS(751),
    [anon_sym_new] = ACTIONS(753),
    [anon_sym_class] = ACTIONS(753),
    [anon_sym_switch] = ACTIONS(753),
    [anon_sym_LBRACE] = ACTIONS(751),
    [anon_sym_case] = ACTIONS(753),
    [anon_sym_default] = ACTIONS(753),
    [anon_sym_SEMI] = ACTIONS(751),
    [anon_sym_assert] = ACTIONS(753),
    [anon_sym_do] = ACTIONS(753),
    [anon_sym_while] = ACTIONS(753),
    [anon_sym_break] = ACTIONS(753),
    [anon_sym_continue] = ACTIONS(753),
    [anon_sym_return] = ACTIONS(753),
    [anon_sym_yield] = ACTIONS(753),
    [anon_sym_synchronized] = ACTIONS(753),
    [anon_sym_throw] = ACTIONS(753),
    [anon_sym_try] = ACTIONS(753),
    [anon_sym_if] = ACTIONS(753),
    [anon_sym_else] = ACTIONS(753),
    [anon_sym_for] = ACTIONS(753),
    [anon_sym_AT] = ACTIONS(753),
    [anon_sym_open] = ACTIONS(753),
    [anon_sym_module] = ACTIONS(753),
    [anon_sym_static] = ACTIONS(753),
    [anon_sym_with] = ACTIONS(753),
    [anon_sym_package] = ACTIONS(753),
    [anon_sym_import] = ACTIONS(753),
    [anon_sym_enum] = ACTIONS(753),
    [anon_sym_public] = ACTIONS(753),
    [anon_sym_protected] = ACTIONS(753),
    [anon_sym_private] = ACTIONS(753),
    [anon_sym_abstract] = ACTIONS(753),
    [anon_sym_strictfp] = ACTIONS(753),
    [anon_sym_native] = ACTIONS(753),
    [anon_sym_transient] = ACTIONS(753),
    [anon_sym_volatile] = ACTIONS(753),
    [anon_sym_sealed] = ACTIONS(753),
    [anon_sym_non_DASHsealed] = ACTIONS(751),
    [anon_sym_record] = ACTIONS(753),
    [anon_sym_ATinterface] = ACTIONS(751),
    [anon_sym_interface] = ACTIONS(753),
    [anon_sym_byte] = ACTIONS(753),
    [anon_sym_short] = ACTIONS(753),
    [anon_sym_int] = ACTIONS(753),
    [anon_sym_long] = ACTIONS(753),
    [anon_sym_char] = ACTIONS(753),
    [anon_sym_float] = ACTIONS(753),
    [anon_sym_double] = ACTIONS(753),
    [sym_boolean_type] = ACTIONS(753),
    [sym_void_type] = ACTIONS(753),
    [sym_this] = ACTIONS(753),
    [sym_super] = ACTIONS(753),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [279] = {
    [ts_builtin_sym_end] = ACTIONS(755),
    [sym_identifier] = ACTIONS(757),
    [sym_decimal_integer_literal] = ACTIONS(757),
    [sym_hex_integer_literal] = ACTIONS(757),
    [sym_octal_integer_literal] = ACTIONS(757),
    [sym_binary_integer_literal] = ACTIONS(755),
    [sym_decimal_floating_point_literal] = ACTIONS(755),
    [sym_hex_floating_point_literal] = ACTIONS(757),
    [sym_true] = ACTIONS(757),
    [sym_false] = ACTIONS(757),
    [sym_character_literal] = ACTIONS(755),
    [anon_sym_DQUOTE] = ACTIONS(757),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(755),
    [anon_sym_RBRACE] = ACTIONS(755),
    [sym_null_literal] = ACTIONS(757),
    [anon_sym_LPAREN] = ACTIONS(755),
    [anon_sym_LT] = ACTIONS(755),
    [anon_sym_PLUS] = ACTIONS(757),
    [anon_sym_DASH] = ACTIONS(757),
    [anon_sym_final] = ACTIONS(757),
    [anon_sym_BANG] = ACTIONS(755),
    [anon_sym_TILDE] = ACTIONS(755),
    [anon_sym_PLUS_PLUS] = ACTIONS(755),
    [anon_sym_DASH_DASH] = ACTIONS(755),
    [anon_sym_new] = ACTIONS(757),
    [anon_sym_class] = ACTIONS(757),
    [anon_sym_switch] = ACTIONS(757),
    [anon_sym_LBRACE] = ACTIONS(755),
    [anon_sym_case] = ACTIONS(757),
    [anon_sym_default] = ACTIONS(757),
    [anon_sym_SEMI] = ACTIONS(755),
    [anon_sym_assert] = ACTIONS(757),
    [anon_sym_do] = ACTIONS(757),
    [anon_sym_while] = ACTIONS(757),
    [anon_sym_break] = ACTIONS(757),
    [anon_sym_continue] = ACTIONS(757),
    [anon_sym_return] = ACTIONS(757),
    [anon_sym_yield] = ACTIONS(757),
    [anon_sym_synchronized] = ACTIONS(757),
    [anon_sym_throw] = ACTIONS(757),
    [anon_sym_try] = ACTIONS(757),
    [anon_sym_if] = ACTIONS(757),
    [anon_sym_else] = ACTIONS(757),
    [anon_sym_for] = ACTIONS(757),
    [anon_sym_AT] = ACTIONS(757),
    [anon_sym_open] = ACTIONS(757),
    [anon_sym_module] = ACTIONS(757),
    [anon_sym_static] = ACTIONS(757),
    [anon_sym_with] = ACTIONS(757),
    [anon_sym_package] = ACTIONS(757),
    [anon_sym_import] = ACTIONS(757),
    [anon_sym_enum] = ACTIONS(757),
    [anon_sym_public] = ACTIONS(757),
    [anon_sym_protected] = ACTIONS(757),
    [anon_sym_private] = ACTIONS(757),
    [anon_sym_abstract] = ACTIONS(757),
    [anon_sym_strictfp] = ACTIONS(757),
    [anon_sym_native] = ACTIONS(757),
    [anon_sym_transient] = ACTIONS(757),
    [anon_sym_volatile] = ACTIONS(757),
    [anon_sym_sealed] = ACTIONS(757),
    [anon_sym_non_DASHsealed] = ACTIONS(755),
    [anon_sym_record] = ACTIONS(757),
    [anon_sym_ATinterface] = ACTIONS(755),
    [anon_sym_interface] = ACTIONS(757),
    [anon_sym_byte] = ACTIONS(757),
    [anon_sym_short] = ACTIONS(757),
    [anon_sym_int] = ACTIONS(757),
    [anon_sym_long] = ACTIONS(757),
    [anon_sym_char] = ACTIONS(757),
    [anon_sym_float] = ACTIONS(757),
    [anon_sym_double] = ACTIONS(757),
    [sym_boolean_type] = ACTIONS(757),
    [sym_void_type] = ACTIONS(757),
    [sym_this] = ACTIONS(757),
    [sym_super] = ACTIONS(757),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [280] = {
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_identifier] = ACTIONS(761),
    [sym_decimal_integer_literal] = ACTIONS(761),
    [sym_hex_integer_literal] = ACTIONS(761),
    [sym_octal_integer_literal] = ACTIONS(761),
    [sym_binary_integer_literal] = ACTIONS(759),
    [sym_decimal_floating_point_literal] = ACTIONS(759),
    [sym_hex_floating_point_literal] = ACTIONS(761),
    [sym_true] = ACTIONS(761),
    [sym_false] = ACTIONS(761),
    [sym_character_literal] = ACTIONS(759),
    [anon_sym_DQUOTE] = ACTIONS(761),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [sym_null_literal] = ACTIONS(761),
    [anon_sym_LPAREN] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(759),
    [anon_sym_PLUS] = ACTIONS(761),
    [anon_sym_DASH] = ACTIONS(761),
    [anon_sym_final] = ACTIONS(761),
    [anon_sym_BANG] = ACTIONS(759),
    [anon_sym_TILDE] = ACTIONS(759),
    [anon_sym_PLUS_PLUS] = ACTIONS(759),
    [anon_sym_DASH_DASH] = ACTIONS(759),
    [anon_sym_new] = ACTIONS(761),
    [anon_sym_class] = ACTIONS(761),
    [anon_sym_switch] = ACTIONS(761),
    [anon_sym_LBRACE] = ACTIONS(759),
    [anon_sym_case] = ACTIONS(761),
    [anon_sym_default] = ACTIONS(761),
    [anon_sym_SEMI] = ACTIONS(759),
    [anon_sym_assert] = ACTIONS(761),
    [anon_sym_do] = ACTIONS(761),
    [anon_sym_while] = ACTIONS(761),
    [anon_sym_break] = ACTIONS(761),
    [anon_sym_continue] = ACTIONS(761),
    [anon_sym_return] = ACTIONS(761),
    [anon_sym_yield] = ACTIONS(761),
    [anon_sym_synchronized] = ACTIONS(761),
    [anon_sym_throw] = ACTIONS(761),
    [anon_sym_try] = ACTIONS(761),
    [anon_sym_if] = ACTIONS(761),
    [anon_sym_else] = ACTIONS(761),
    [anon_sym_for] = ACTIONS(761),
    [anon_sym_AT] = ACTIONS(761),
    [anon_sym_open] = ACTIONS(761),
    [anon_sym_module] = ACTIONS(761),
    [anon_sym_static] = ACTIONS(761),
    [anon_sym_with] = ACTIONS(761),
    [anon_sym_package] = ACTIONS(761),
    [anon_sym_import] = ACTIONS(761),
    [anon_sym_enum] = ACTIONS(761),
    [anon_sym_public] = ACTIONS(761),
    [anon_sym_protected] = ACTIONS(761),
    [anon_sym_private] = ACTIONS(761),
    [anon_sym_abstract] = ACTIONS(761),
    [anon_sym_strictfp] = ACTIONS(761),
    [anon_sym_native] = ACTIONS(761),
    [anon_sym_transient] = ACTIONS(761),
    [anon_sym_volatile] = ACTIONS(761),
    [anon_sym_sealed] = ACTIONS(761),
    [anon_sym_non_DASHsealed] = ACTIONS(759),
    [anon_sym_record] = ACTIONS(761),
    [anon_sym_ATinterface] = ACTIONS(759),
    [anon_sym_interface] = ACTIONS(761),
    [anon_sym_byte] = ACTIONS(761),
    [anon_sym_short] = ACTIONS(761),
    [anon_sym_int] = ACTIONS(761),
    [anon_sym_long] = ACTIONS(761),
    [anon_sym_char] = ACTIONS(761),
    [anon_sym_float] = ACTIONS(761),
    [anon_sym_double] = ACTIONS(761),
    [sym_boolean_type] = ACTIONS(761),
    [sym_void_type] = ACTIONS(761),
    [sym_this] = ACTIONS(761),
    [sym_super] = ACTIONS(761),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [281] = {
    [ts_builtin_sym_end] = ACTIONS(763),
    [sym_identifier] = ACTIONS(765),
    [sym_decimal_integer_literal] = ACTIONS(765),
    [sym_hex_integer_literal] = ACTIONS(765),
    [sym_octal_integer_literal] = ACTIONS(765),
    [sym_binary_integer_literal] = ACTIONS(763),
    [sym_decimal_floating_point_literal] = ACTIONS(763),
    [sym_hex_floating_point_literal] = ACTIONS(765),
    [sym_true] = ACTIONS(765),
    [sym_false] = ACTIONS(765),
    [sym_character_literal] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(763),
    [anon_sym_RBRACE] = ACTIONS(763),
    [sym_null_literal] = ACTIONS(765),
    [anon_sym_LPAREN] = ACTIONS(763),
    [anon_sym_LT] = ACTIONS(763),
    [anon_sym_PLUS] = ACTIONS(765),
    [anon_sym_DASH] = ACTIONS(765),
    [anon_sym_final] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(763),
    [anon_sym_PLUS_PLUS] = ACTIONS(763),
    [anon_sym_DASH_DASH] = ACTIONS(763),
    [anon_sym_new] = ACTIONS(765),
    [anon_sym_class] = ACTIONS(765),
    [anon_sym_switch] = ACTIONS(765),
    [anon_sym_LBRACE] = ACTIONS(763),
    [anon_sym_case] = ACTIONS(765),
    [anon_sym_default] = ACTIONS(765),
    [anon_sym_SEMI] = ACTIONS(763),
    [anon_sym_assert] = ACTIONS(765),
    [anon_sym_do] = ACTIONS(765),
    [anon_sym_while] = ACTIONS(765),
    [anon_sym_break] = ACTIONS(765),
    [anon_sym_continue] = ACTIONS(765),
    [anon_sym_return] = ACTIONS(765),
    [anon_sym_yield] = ACTIONS(765),
    [anon_sym_synchronized] = ACTIONS(765),
    [anon_sym_throw] = ACTIONS(765),
    [anon_sym_try] = ACTIONS(765),
    [anon_sym_if] = ACTIONS(765),
    [anon_sym_else] = ACTIONS(765),
    [anon_sym_for] = ACTIONS(765),
    [anon_sym_AT] = ACTIONS(765),
    [anon_sym_open] = ACTIONS(765),
    [anon_sym_module] = ACTIONS(765),
    [anon_sym_static] = ACTIONS(765),
    [anon_sym_with] = ACTIONS(765),
    [anon_sym_package] = ACTIONS(765),
    [anon_sym_import] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(765),
    [anon_sym_public] = ACTIONS(765),
    [anon_sym_protected] = ACTIONS(765),
    [anon_sym_private] = ACTIONS(765),
    [anon_sym_abstract] = ACTIONS(765),
    [anon_sym_strictfp] = ACTIONS(765),
    [anon_sym_native] = ACTIONS(765),
    [anon_sym_transient] = ACTIONS(765),
    [anon_sym_volatile] = ACTIONS(765),
    [anon_sym_sealed] = ACTIONS(765),
    [anon_sym_non_DASHsealed] = ACTIONS(763),
    [anon_sym_record] = ACTIONS(765),
    [anon_sym_ATinterface] = ACTIONS(763),
    [anon_sym_interface] = ACTIONS(765),
    [anon_sym_byte] = ACTIONS(765),
    [anon_sym_short] = ACTIONS(765),
    [anon_sym_int] = ACTIONS(765),
    [anon_sym_long] = ACTIONS(765),
    [anon_sym_char] = ACTIONS(765),
    [anon_sym_float] = ACTIONS(765),
    [anon_sym_double] = ACTIONS(765),
    [sym_boolean_type] = ACTIONS(765),
    [sym_void_type] = ACTIONS(765),
    [sym_this] = ACTIONS(765),
    [sym_super] = ACTIONS(765),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [282] = {
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(769),
    [sym_decimal_integer_literal] = ACTIONS(769),
    [sym_hex_integer_literal] = ACTIONS(769),
    [sym_octal_integer_literal] = ACTIONS(769),
    [sym_binary_integer_literal] = ACTIONS(767),
    [sym_decimal_floating_point_literal] = ACTIONS(767),
    [sym_hex_floating_point_literal] = ACTIONS(769),
    [sym_true] = ACTIONS(769),
    [sym_false] = ACTIONS(769),
    [sym_character_literal] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [sym_null_literal] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(769),
    [anon_sym_DASH] = ACTIONS(769),
    [anon_sym_final] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(767),
    [anon_sym_DASH_DASH] = ACTIONS(767),
    [anon_sym_new] = ACTIONS(769),
    [anon_sym_class] = ACTIONS(769),
    [anon_sym_switch] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_case] = ACTIONS(769),
    [anon_sym_default] = ACTIONS(769),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_assert] = ACTIONS(769),
    [anon_sym_do] = ACTIONS(769),
    [anon_sym_while] = ACTIONS(769),
    [anon_sym_break] = ACTIONS(769),
    [anon_sym_continue] = ACTIONS(769),
    [anon_sym_return] = ACTIONS(769),
    [anon_sym_yield] = ACTIONS(769),
    [anon_sym_synchronized] = ACTIONS(769),
    [anon_sym_throw] = ACTIONS(769),
    [anon_sym_try] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(769),
    [anon_sym_else] = ACTIONS(769),
    [anon_sym_for] = ACTIONS(769),
    [anon_sym_AT] = ACTIONS(769),
    [anon_sym_open] = ACTIONS(769),
    [anon_sym_module] = ACTIONS(769),
    [anon_sym_static] = ACTIONS(769),
    [anon_sym_with] = ACTIONS(769),
    [anon_sym_package] = ACTIONS(769),
    [anon_sym_import] = ACTIONS(769),
    [anon_sym_enum] = ACTIONS(769),
    [anon_sym_public] = ACTIONS(769),
    [anon_sym_protected] = ACTIONS(769),
    [anon_sym_private] = ACTIONS(769),
    [anon_sym_abstract] = ACTIONS(769),
    [anon_sym_strictfp] = ACTIONS(769),
    [anon_sym_native] = ACTIONS(769),
    [anon_sym_transient] = ACTIONS(769),
    [anon_sym_volatile] = ACTIONS(769),
    [anon_sym_sealed] = ACTIONS(769),
    [anon_sym_non_DASHsealed] = ACTIONS(767),
    [anon_sym_record] = ACTIONS(769),
    [anon_sym_ATinterface] = ACTIONS(767),
    [anon_sym_interface] = ACTIONS(769),
    [anon_sym_byte] = ACTIONS(769),
    [anon_sym_short] = ACTIONS(769),
    [anon_sym_int] = ACTIONS(769),
    [anon_sym_long] = ACTIONS(769),
    [anon_sym_char] = ACTIONS(769),
    [anon_sym_float] = ACTIONS(769),
    [anon_sym_double] = ACTIONS(769),
    [sym_boolean_type] = ACTIONS(769),
    [sym_void_type] = ACTIONS(769),
    [sym_this] = ACTIONS(769),
    [sym_super] = ACTIONS(769),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [283] = {
    [ts_builtin_sym_end] = ACTIONS(771),
    [sym_identifier] = ACTIONS(773),
    [sym_decimal_integer_literal] = ACTIONS(773),
    [sym_hex_integer_literal] = ACTIONS(773),
    [sym_octal_integer_literal] = ACTIONS(773),
    [sym_binary_integer_literal] = ACTIONS(771),
    [sym_decimal_floating_point_literal] = ACTIONS(771),
    [sym_hex_floating_point_literal] = ACTIONS(773),
    [sym_true] = ACTIONS(773),
    [sym_false] = ACTIONS(773),
    [sym_character_literal] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(771),
    [anon_sym_RBRACE] = ACTIONS(771),
    [sym_null_literal] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(771),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_final] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(771),
    [anon_sym_DASH_DASH] = ACTIONS(771),
    [anon_sym_new] = ACTIONS(773),
    [anon_sym_class] = ACTIONS(773),
    [anon_sym_switch] = ACTIONS(773),
    [anon_sym_LBRACE] = ACTIONS(771),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_default] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(771),
    [anon_sym_assert] = ACTIONS(773),
    [anon_sym_do] = ACTIONS(773),
    [anon_sym_while] = ACTIONS(773),
    [anon_sym_break] = ACTIONS(773),
    [anon_sym_continue] = ACTIONS(773),
    [anon_sym_return] = ACTIONS(773),
    [anon_sym_yield] = ACTIONS(773),
    [anon_sym_synchronized] = ACTIONS(773),
    [anon_sym_throw] = ACTIONS(773),
    [anon_sym_try] = ACTIONS(773),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_for] = ACTIONS(773),
    [anon_sym_AT] = ACTIONS(773),
    [anon_sym_open] = ACTIONS(773),
    [anon_sym_module] = ACTIONS(773),
    [anon_sym_static] = ACTIONS(773),
    [anon_sym_with] = ACTIONS(773),
    [anon_sym_package] = ACTIONS(773),
    [anon_sym_import] = ACTIONS(773),
    [anon_sym_enum] = ACTIONS(773),
    [anon_sym_public] = ACTIONS(773),
    [anon_sym_protected] = ACTIONS(773),
    [anon_sym_private] = ACTIONS(773),
    [anon_sym_abstract] = ACTIONS(773),
    [anon_sym_strictfp] = ACTIONS(773),
    [anon_sym_native] = ACTIONS(773),
    [anon_sym_transient] = ACTIONS(773),
    [anon_sym_volatile] = ACTIONS(773),
    [anon_sym_sealed] = ACTIONS(773),
    [anon_sym_non_DASHsealed] = ACTIONS(771),
    [anon_sym_record] = ACTIONS(773),
    [anon_sym_ATinterface] = ACTIONS(771),
    [anon_sym_interface] = ACTIONS(773),
    [anon_sym_byte] = ACTIONS(773),
    [anon_sym_short] = ACTIONS(773),
    [anon_sym_int] = ACTIONS(773),
    [anon_sym_long] = ACTIONS(773),
    [anon_sym_char] = ACTIONS(773),
    [anon_sym_float] = ACTIONS(773),
    [anon_sym_double] = ACTIONS(773),
    [sym_boolean_type] = ACTIONS(773),
    [sym_void_type] = ACTIONS(773),
    [sym_this] = ACTIONS(773),
    [sym_super] = ACTIONS(773),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [284] = {
    [ts_builtin_sym_end] = ACTIONS(480),
    [sym_identifier] = ACTIONS(478),
    [sym_decimal_integer_literal] = ACTIONS(478),
    [sym_hex_integer_literal] = ACTIONS(478),
    [sym_octal_integer_literal] = ACTIONS(478),
    [sym_binary_integer_literal] = ACTIONS(480),
    [sym_decimal_floating_point_literal] = ACTIONS(480),
    [sym_hex_floating_point_literal] = ACTIONS(478),
    [sym_true] = ACTIONS(478),
    [sym_false] = ACTIONS(478),
    [sym_character_literal] = ACTIONS(480),
    [anon_sym_DQUOTE] = ACTIONS(478),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(480),
    [anon_sym_RBRACE] = ACTIONS(480),
    [sym_null_literal] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(480),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_PLUS] = ACTIONS(478),
    [anon_sym_DASH] = ACTIONS(478),
    [anon_sym_final] = ACTIONS(478),
    [anon_sym_BANG] = ACTIONS(480),
    [anon_sym_TILDE] = ACTIONS(480),
    [anon_sym_PLUS_PLUS] = ACTIONS(480),
    [anon_sym_DASH_DASH] = ACTIONS(480),
    [anon_sym_new] = ACTIONS(478),
    [anon_sym_class] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(480),
    [anon_sym_case] = ACTIONS(478),
    [anon_sym_default] = ACTIONS(478),
    [anon_sym_SEMI] = ACTIONS(480),
    [anon_sym_assert] = ACTIONS(478),
    [anon_sym_do] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_break] = ACTIONS(478),
    [anon_sym_continue] = ACTIONS(478),
    [anon_sym_return] = ACTIONS(478),
    [anon_sym_yield] = ACTIONS(478),
    [anon_sym_synchronized] = ACTIONS(478),
    [anon_sym_throw] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(478),
    [anon_sym_open] = ACTIONS(478),
    [anon_sym_module] = ACTIONS(478),
    [anon_sym_static] = ACTIONS(478),
    [anon_sym_with] = ACTIONS(478),
    [anon_sym_package] = ACTIONS(478),
    [anon_sym_import] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(478),
    [anon_sym_public] = ACTIONS(478),
    [anon_sym_protected] = ACTIONS(478),
    [anon_sym_private] = ACTIONS(478),
    [anon_sym_abstract] = ACTIONS(478),
    [anon_sym_strictfp] = ACTIONS(478),
    [anon_sym_native] = ACTIONS(478),
    [anon_sym_transient] = ACTIONS(478),
    [anon_sym_volatile] = ACTIONS(478),
    [anon_sym_sealed] = ACTIONS(478),
    [anon_sym_non_DASHsealed] = ACTIONS(480),
    [anon_sym_record] = ACTIONS(478),
    [anon_sym_ATinterface] = ACTIONS(480),
    [anon_sym_interface] = ACTIONS(478),
    [anon_sym_byte] = ACTIONS(478),
    [anon_sym_short] = ACTIONS(478),
    [anon_sym_int] = ACTIONS(478),
    [anon_sym_long] = ACTIONS(478),
    [anon_sym_char] = ACTIONS(478),
    [anon_sym_float] = ACTIONS(478),
    [anon_sym_double] = ACTIONS(478),
    [sym_boolean_type] = ACTIONS(478),
    [sym_void_type] = ACTIONS(478),
    [sym_this] = ACTIONS(478),
    [sym_super] = ACTIONS(478),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [285] = {
    [ts_builtin_sym_end] = ACTIONS(775),
    [sym_identifier] = ACTIONS(777),
    [sym_decimal_integer_literal] = ACTIONS(777),
    [sym_hex_integer_literal] = ACTIONS(777),
    [sym_octal_integer_literal] = ACTIONS(777),
    [sym_binary_integer_literal] = ACTIONS(775),
    [sym_decimal_floating_point_literal] = ACTIONS(775),
    [sym_hex_floating_point_literal] = ACTIONS(777),
    [sym_true] = ACTIONS(777),
    [sym_false] = ACTIONS(777),
    [sym_character_literal] = ACTIONS(775),
    [anon_sym_DQUOTE] = ACTIONS(777),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(775),
    [anon_sym_RBRACE] = ACTIONS(775),
    [sym_null_literal] = ACTIONS(777),
    [anon_sym_LPAREN] = ACTIONS(775),
    [anon_sym_LT] = ACTIONS(775),
    [anon_sym_PLUS] = ACTIONS(777),
    [anon_sym_DASH] = ACTIONS(777),
    [anon_sym_final] = ACTIONS(777),
    [anon_sym_BANG] = ACTIONS(775),
    [anon_sym_TILDE] = ACTIONS(775),
    [anon_sym_PLUS_PLUS] = ACTIONS(775),
    [anon_sym_DASH_DASH] = ACTIONS(775),
    [anon_sym_new] = ACTIONS(777),
    [anon_sym_class] = ACTIONS(777),
    [anon_sym_switch] = ACTIONS(777),
    [anon_sym_LBRACE] = ACTIONS(775),
    [anon_sym_case] = ACTIONS(777),
    [anon_sym_default] = ACTIONS(777),
    [anon_sym_SEMI] = ACTIONS(775),
    [anon_sym_assert] = ACTIONS(777),
    [anon_sym_do] = ACTIONS(777),
    [anon_sym_while] = ACTIONS(777),
    [anon_sym_break] = ACTIONS(777),
    [anon_sym_continue] = ACTIONS(777),
    [anon_sym_return] = ACTIONS(777),
    [anon_sym_yield] = ACTIONS(777),
    [anon_sym_synchronized] = ACTIONS(777),
    [anon_sym_throw] = ACTIONS(777),
    [anon_sym_try] = ACTIONS(777),
    [anon_sym_if] = ACTIONS(777),
    [anon_sym_else] = ACTIONS(777),
    [anon_sym_for] = ACTIONS(777),
    [anon_sym_AT] = ACTIONS(777),
    [anon_sym_open] = ACTIONS(777),
    [anon_sym_module] = ACTIONS(777),
    [anon_sym_static] = ACTIONS(777),
    [anon_sym_with] = ACTIONS(777),
    [anon_sym_package] = ACTIONS(777),
    [anon_sym_import] = ACTIONS(777),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_public] = ACTIONS(777),
    [anon_sym_protected] = ACTIONS(777),
    [anon_sym_private] = ACTIONS(777),
    [anon_sym_abstract] = ACTIONS(777),
    [anon_sym_strictfp] = ACTIONS(777),
    [anon_sym_native] = ACTIONS(777),
    [anon_sym_transient] = ACTIONS(777),
    [anon_sym_volatile] = ACTIONS(777),
    [anon_sym_sealed] = ACTIONS(777),
    [anon_sym_non_DASHsealed] = ACTIONS(775),
    [anon_sym_record] = ACTIONS(777),
    [anon_sym_ATinterface] = ACTIONS(775),
    [anon_sym_interface] = ACTIONS(777),
    [anon_sym_byte] = ACTIONS(777),
    [anon_sym_short] = ACTIONS(777),
    [anon_sym_int] = ACTIONS(777),
    [anon_sym_long] = ACTIONS(777),
    [anon_sym_char] = ACTIONS(777),
    [anon_sym_float] = ACTIONS(777),
    [anon_sym_double] = ACTIONS(777),
    [sym_boolean_type] = ACTIONS(777),
    [sym_void_type] = ACTIONS(777),
    [sym_this] = ACTIONS(777),
    [sym_super] = ACTIONS(777),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [286] = {
    [ts_builtin_sym_end] = ACTIONS(779),
    [sym_identifier] = ACTIONS(781),
    [sym_decimal_integer_literal] = ACTIONS(781),
    [sym_hex_integer_literal] = ACTIONS(781),
    [sym_octal_integer_literal] = ACTIONS(781),
    [sym_binary_integer_literal] = ACTIONS(779),
    [sym_decimal_floating_point_literal] = ACTIONS(779),
    [sym_hex_floating_point_literal] = ACTIONS(781),
    [sym_true] = ACTIONS(781),
    [sym_false] = ACTIONS(781),
    [sym_character_literal] = ACTIONS(779),
    [anon_sym_DQUOTE] = ACTIONS(781),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(779),
    [anon_sym_RBRACE] = ACTIONS(779),
    [sym_null_literal] = ACTIONS(781),
    [anon_sym_LPAREN] = ACTIONS(779),
    [anon_sym_LT] = ACTIONS(779),
    [anon_sym_PLUS] = ACTIONS(781),
    [anon_sym_DASH] = ACTIONS(781),
    [anon_sym_final] = ACTIONS(781),
    [anon_sym_BANG] = ACTIONS(779),
    [anon_sym_TILDE] = ACTIONS(779),
    [anon_sym_PLUS_PLUS] = ACTIONS(779),
    [anon_sym_DASH_DASH] = ACTIONS(779),
    [anon_sym_new] = ACTIONS(781),
    [anon_sym_class] = ACTIONS(781),
    [anon_sym_switch] = ACTIONS(781),
    [anon_sym_LBRACE] = ACTIONS(779),
    [anon_sym_case] = ACTIONS(781),
    [anon_sym_default] = ACTIONS(781),
    [anon_sym_SEMI] = ACTIONS(779),
    [anon_sym_assert] = ACTIONS(781),
    [anon_sym_do] = ACTIONS(781),
    [anon_sym_while] = ACTIONS(781),
    [anon_sym_break] = ACTIONS(781),
    [anon_sym_continue] = ACTIONS(781),
    [anon_sym_return] = ACTIONS(781),
    [anon_sym_yield] = ACTIONS(781),
    [anon_sym_synchronized] = ACTIONS(781),
    [anon_sym_throw] = ACTIONS(781),
    [anon_sym_try] = ACTIONS(781),
    [anon_sym_if] = ACTIONS(781),
    [anon_sym_else] = ACTIONS(781),
    [anon_sym_for] = ACTIONS(781),
    [anon_sym_AT] = ACTIONS(781),
    [anon_sym_open] = ACTIONS(781),
    [anon_sym_module] = ACTIONS(781),
    [anon_sym_static] = ACTIONS(781),
    [anon_sym_with] = ACTIONS(781),
    [anon_sym_package] = ACTIONS(781),
    [anon_sym_import] = ACTIONS(781),
    [anon_sym_enum] = ACTIONS(781),
    [anon_sym_public] = ACTIONS(781),
    [anon_sym_protected] = ACTIONS(781),
    [anon_sym_private] = ACTIONS(781),
    [anon_sym_abstract] = ACTIONS(781),
    [anon_sym_strictfp] = ACTIONS(781),
    [anon_sym_native] = ACTIONS(781),
    [anon_sym_transient] = ACTIONS(781),
    [anon_sym_volatile] = ACTIONS(781),
    [anon_sym_sealed] = ACTIONS(781),
    [anon_sym_non_DASHsealed] = ACTIONS(779),
    [anon_sym_record] = ACTIONS(781),
    [anon_sym_ATinterface] = ACTIONS(779),
    [anon_sym_interface] = ACTIONS(781),
    [anon_sym_byte] = ACTIONS(781),
    [anon_sym_short] = ACTIONS(781),
    [anon_sym_int] = ACTIONS(781),
    [anon_sym_long] = ACTIONS(781),
    [anon_sym_char] = ACTIONS(781),
    [anon_sym_float] = ACTIONS(781),
    [anon_sym_double] = ACTIONS(781),
    [sym_boolean_type] = ACTIONS(781),
    [sym_void_type] = ACTIONS(781),
    [sym_this] = ACTIONS(781),
    [sym_super] = ACTIONS(781),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [287] = {
    [ts_builtin_sym_end] = ACTIONS(783),
    [sym_identifier] = ACTIONS(785),
    [sym_decimal_integer_literal] = ACTIONS(785),
    [sym_hex_integer_literal] = ACTIONS(785),
    [sym_octal_integer_literal] = ACTIONS(785),
    [sym_binary_integer_literal] = ACTIONS(783),
    [sym_decimal_floating_point_literal] = ACTIONS(783),
    [sym_hex_floating_point_literal] = ACTIONS(785),
    [sym_true] = ACTIONS(785),
    [sym_false] = ACTIONS(785),
    [sym_character_literal] = ACTIONS(783),
    [anon_sym_DQUOTE] = ACTIONS(785),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(783),
    [anon_sym_RBRACE] = ACTIONS(783),
    [sym_null_literal] = ACTIONS(785),
    [anon_sym_LPAREN] = ACTIONS(783),
    [anon_sym_LT] = ACTIONS(783),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_final] = ACTIONS(785),
    [anon_sym_BANG] = ACTIONS(783),
    [anon_sym_TILDE] = ACTIONS(783),
    [anon_sym_PLUS_PLUS] = ACTIONS(783),
    [anon_sym_DASH_DASH] = ACTIONS(783),
    [anon_sym_new] = ACTIONS(785),
    [anon_sym_class] = ACTIONS(785),
    [anon_sym_switch] = ACTIONS(785),
    [anon_sym_LBRACE] = ACTIONS(783),
    [anon_sym_case] = ACTIONS(785),
    [anon_sym_default] = ACTIONS(785),
    [anon_sym_SEMI] = ACTIONS(783),
    [anon_sym_assert] = ACTIONS(785),
    [anon_sym_do] = ACTIONS(785),
    [anon_sym_while] = ACTIONS(785),
    [anon_sym_break] = ACTIONS(785),
    [anon_sym_continue] = ACTIONS(785),
    [anon_sym_return] = ACTIONS(785),
    [anon_sym_yield] = ACTIONS(785),
    [anon_sym_synchronized] = ACTIONS(785),
    [anon_sym_throw] = ACTIONS(785),
    [anon_sym_try] = ACTIONS(785),
    [anon_sym_if] = ACTIONS(785),
    [anon_sym_else] = ACTIONS(785),
    [anon_sym_for] = ACTIONS(785),
    [anon_sym_AT] = ACTIONS(785),
    [anon_sym_open] = ACTIONS(785),
    [anon_sym_module] = ACTIONS(785),
    [anon_sym_static] = ACTIONS(785),
    [anon_sym_with] = ACTIONS(785),
    [anon_sym_package] = ACTIONS(785),
    [anon_sym_import] = ACTIONS(785),
    [anon_sym_enum] = ACTIONS(785),
    [anon_sym_public] = ACTIONS(785),
    [anon_sym_protected] = ACTIONS(785),
    [anon_sym_private] = ACTIONS(785),
    [anon_sym_abstract] = ACTIONS(785),
    [anon_sym_strictfp] = ACTIONS(785),
    [anon_sym_native] = ACTIONS(785),
    [anon_sym_transient] = ACTIONS(785),
    [anon_sym_volatile] = ACTIONS(785),
    [anon_sym_sealed] = ACTIONS(785),
    [anon_sym_non_DASHsealed] = ACTIONS(783),
    [anon_sym_record] = ACTIONS(785),
    [anon_sym_ATinterface] = ACTIONS(783),
    [anon_sym_interface] = ACTIONS(785),
    [anon_sym_byte] = ACTIONS(785),
    [anon_sym_short] = ACTIONS(785),
    [anon_sym_int] = ACTIONS(785),
    [anon_sym_long] = ACTIONS(785),
    [anon_sym_char] = ACTIONS(785),
    [anon_sym_float] = ACTIONS(785),
    [anon_sym_double] = ACTIONS(785),
    [sym_boolean_type] = ACTIONS(785),
    [sym_void_type] = ACTIONS(785),
    [sym_this] = ACTIONS(785),
    [sym_super] = ACTIONS(785),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [288] = {
    [ts_builtin_sym_end] = ACTIONS(787),
    [sym_identifier] = ACTIONS(789),
    [sym_decimal_integer_literal] = ACTIONS(789),
    [sym_hex_integer_literal] = ACTIONS(789),
    [sym_octal_integer_literal] = ACTIONS(789),
    [sym_binary_integer_literal] = ACTIONS(787),
    [sym_decimal_floating_point_literal] = ACTIONS(787),
    [sym_hex_floating_point_literal] = ACTIONS(789),
    [sym_true] = ACTIONS(789),
    [sym_false] = ACTIONS(789),
    [sym_character_literal] = ACTIONS(787),
    [anon_sym_DQUOTE] = ACTIONS(789),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(787),
    [anon_sym_RBRACE] = ACTIONS(787),
    [sym_null_literal] = ACTIONS(789),
    [anon_sym_LPAREN] = ACTIONS(787),
    [anon_sym_LT] = ACTIONS(787),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_final] = ACTIONS(789),
    [anon_sym_BANG] = ACTIONS(787),
    [anon_sym_TILDE] = ACTIONS(787),
    [anon_sym_PLUS_PLUS] = ACTIONS(787),
    [anon_sym_DASH_DASH] = ACTIONS(787),
    [anon_sym_new] = ACTIONS(789),
    [anon_sym_class] = ACTIONS(789),
    [anon_sym_switch] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(787),
    [anon_sym_case] = ACTIONS(789),
    [anon_sym_default] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(787),
    [anon_sym_assert] = ACTIONS(789),
    [anon_sym_do] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(789),
    [anon_sym_break] = ACTIONS(789),
    [anon_sym_continue] = ACTIONS(789),
    [anon_sym_return] = ACTIONS(789),
    [anon_sym_yield] = ACTIONS(789),
    [anon_sym_synchronized] = ACTIONS(789),
    [anon_sym_throw] = ACTIONS(789),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_else] = ACTIONS(789),
    [anon_sym_for] = ACTIONS(789),
    [anon_sym_AT] = ACTIONS(789),
    [anon_sym_open] = ACTIONS(789),
    [anon_sym_module] = ACTIONS(789),
    [anon_sym_static] = ACTIONS(789),
    [anon_sym_with] = ACTIONS(789),
    [anon_sym_package] = ACTIONS(789),
    [anon_sym_import] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(789),
    [anon_sym_public] = ACTIONS(789),
    [anon_sym_protected] = ACTIONS(789),
    [anon_sym_private] = ACTIONS(789),
    [anon_sym_abstract] = ACTIONS(789),
    [anon_sym_strictfp] = ACTIONS(789),
    [anon_sym_native] = ACTIONS(789),
    [anon_sym_transient] = ACTIONS(789),
    [anon_sym_volatile] = ACTIONS(789),
    [anon_sym_sealed] = ACTIONS(789),
    [anon_sym_non_DASHsealed] = ACTIONS(787),
    [anon_sym_record] = ACTIONS(789),
    [anon_sym_ATinterface] = ACTIONS(787),
    [anon_sym_interface] = ACTIONS(789),
    [anon_sym_byte] = ACTIONS(789),
    [anon_sym_short] = ACTIONS(789),
    [anon_sym_int] = ACTIONS(789),
    [anon_sym_long] = ACTIONS(789),
    [anon_sym_char] = ACTIONS(789),
    [anon_sym_float] = ACTIONS(789),
    [anon_sym_double] = ACTIONS(789),
    [sym_boolean_type] = ACTIONS(789),
    [sym_void_type] = ACTIONS(789),
    [sym_this] = ACTIONS(789),
    [sym_super] = ACTIONS(789),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [289] = {
    [ts_builtin_sym_end] = ACTIONS(791),
    [sym_identifier] = ACTIONS(793),
    [sym_decimal_integer_literal] = ACTIONS(793),
    [sym_hex_integer_literal] = ACTIONS(793),
    [sym_octal_integer_literal] = ACTIONS(793),
    [sym_binary_integer_literal] = ACTIONS(791),
    [sym_decimal_floating_point_literal] = ACTIONS(791),
    [sym_hex_floating_point_literal] = ACTIONS(793),
    [sym_true] = ACTIONS(793),
    [sym_false] = ACTIONS(793),
    [sym_character_literal] = ACTIONS(791),
    [anon_sym_DQUOTE] = ACTIONS(793),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [sym_null_literal] = ACTIONS(793),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(793),
    [anon_sym_DASH] = ACTIONS(793),
    [anon_sym_final] = ACTIONS(793),
    [anon_sym_BANG] = ACTIONS(791),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_PLUS_PLUS] = ACTIONS(791),
    [anon_sym_DASH_DASH] = ACTIONS(791),
    [anon_sym_new] = ACTIONS(793),
    [anon_sym_class] = ACTIONS(793),
    [anon_sym_switch] = ACTIONS(793),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_case] = ACTIONS(793),
    [anon_sym_default] = ACTIONS(793),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_assert] = ACTIONS(793),
    [anon_sym_do] = ACTIONS(793),
    [anon_sym_while] = ACTIONS(793),
    [anon_sym_break] = ACTIONS(793),
    [anon_sym_continue] = ACTIONS(793),
    [anon_sym_return] = ACTIONS(793),
    [anon_sym_yield] = ACTIONS(793),
    [anon_sym_synchronized] = ACTIONS(793),
    [anon_sym_throw] = ACTIONS(793),
    [anon_sym_try] = ACTIONS(793),
    [anon_sym_if] = ACTIONS(793),
    [anon_sym_else] = ACTIONS(793),
    [anon_sym_for] = ACTIONS(793),
    [anon_sym_AT] = ACTIONS(793),
    [anon_sym_open] = ACTIONS(793),
    [anon_sym_module] = ACTIONS(793),
    [anon_sym_static] = ACTIONS(793),
    [anon_sym_with] = ACTIONS(793),
    [anon_sym_package] = ACTIONS(793),
    [anon_sym_import] = ACTIONS(793),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_public] = ACTIONS(793),
    [anon_sym_protected] = ACTIONS(793),
    [anon_sym_private] = ACTIONS(793),
    [anon_sym_abstract] = ACTIONS(793),
    [anon_sym_strictfp] = ACTIONS(793),
    [anon_sym_native] = ACTIONS(793),
    [anon_sym_transient] = ACTIONS(793),
    [anon_sym_volatile] = ACTIONS(793),
    [anon_sym_sealed] = ACTIONS(793),
    [anon_sym_non_DASHsealed] = ACTIONS(791),
    [anon_sym_record] = ACTIONS(793),
    [anon_sym_ATinterface] = ACTIONS(791),
    [anon_sym_interface] = ACTIONS(793),
    [anon_sym_byte] = ACTIONS(793),
    [anon_sym_short] = ACTIONS(793),
    [anon_sym_int] = ACTIONS(793),
    [anon_sym_long] = ACTIONS(793),
    [anon_sym_char] = ACTIONS(793),
    [anon_sym_float] = ACTIONS(793),
    [anon_sym_double] = ACTIONS(793),
    [sym_boolean_type] = ACTIONS(793),
    [sym_void_type] = ACTIONS(793),
    [sym_this] = ACTIONS(793),
    [sym_super] = ACTIONS(793),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [290] = {
    [ts_builtin_sym_end] = ACTIONS(795),
    [sym_identifier] = ACTIONS(797),
    [sym_decimal_integer_literal] = ACTIONS(797),
    [sym_hex_integer_literal] = ACTIONS(797),
    [sym_octal_integer_literal] = ACTIONS(797),
    [sym_binary_integer_literal] = ACTIONS(795),
    [sym_decimal_floating_point_literal] = ACTIONS(795),
    [sym_hex_floating_point_literal] = ACTIONS(797),
    [sym_true] = ACTIONS(797),
    [sym_false] = ACTIONS(797),
    [sym_character_literal] = ACTIONS(795),
    [anon_sym_DQUOTE] = ACTIONS(797),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(795),
    [anon_sym_RBRACE] = ACTIONS(795),
    [sym_null_literal] = ACTIONS(797),
    [anon_sym_LPAREN] = ACTIONS(795),
    [anon_sym_LT] = ACTIONS(795),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_final] = ACTIONS(797),
    [anon_sym_BANG] = ACTIONS(795),
    [anon_sym_TILDE] = ACTIONS(795),
    [anon_sym_PLUS_PLUS] = ACTIONS(795),
    [anon_sym_DASH_DASH] = ACTIONS(795),
    [anon_sym_new] = ACTIONS(797),
    [anon_sym_class] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(795),
    [anon_sym_case] = ACTIONS(797),
    [anon_sym_default] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(795),
    [anon_sym_assert] = ACTIONS(797),
    [anon_sym_do] = ACTIONS(797),
    [anon_sym_while] = ACTIONS(797),
    [anon_sym_break] = ACTIONS(797),
    [anon_sym_continue] = ACTIONS(797),
    [anon_sym_return] = ACTIONS(797),
    [anon_sym_yield] = ACTIONS(797),
    [anon_sym_synchronized] = ACTIONS(797),
    [anon_sym_throw] = ACTIONS(797),
    [anon_sym_try] = ACTIONS(797),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(797),
    [anon_sym_for] = ACTIONS(797),
    [anon_sym_AT] = ACTIONS(797),
    [anon_sym_open] = ACTIONS(797),
    [anon_sym_module] = ACTIONS(797),
    [anon_sym_static] = ACTIONS(797),
    [anon_sym_with] = ACTIONS(797),
    [anon_sym_package] = ACTIONS(797),
    [anon_sym_import] = ACTIONS(797),
    [anon_sym_enum] = ACTIONS(797),
    [anon_sym_public] = ACTIONS(797),
    [anon_sym_protected] = ACTIONS(797),
    [anon_sym_private] = ACTIONS(797),
    [anon_sym_abstract] = ACTIONS(797),
    [anon_sym_strictfp] = ACTIONS(797),
    [anon_sym_native] = ACTIONS(797),
    [anon_sym_transient] = ACTIONS(797),
    [anon_sym_volatile] = ACTIONS(797),
    [anon_sym_sealed] = ACTIONS(797),
    [anon_sym_non_DASHsealed] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_ATinterface] = ACTIONS(795),
    [anon_sym_interface] = ACTIONS(797),
    [anon_sym_byte] = ACTIONS(797),
    [anon_sym_short] = ACTIONS(797),
    [anon_sym_int] = ACTIONS(797),
    [anon_sym_long] = ACTIONS(797),
    [anon_sym_char] = ACTIONS(797),
    [anon_sym_float] = ACTIONS(797),
    [anon_sym_double] = ACTIONS(797),
    [sym_boolean_type] = ACTIONS(797),
    [sym_void_type] = ACTIONS(797),
    [sym_this] = ACTIONS(797),
    [sym_super] = ACTIONS(797),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [291] = {
    [ts_builtin_sym_end] = ACTIONS(799),
    [sym_identifier] = ACTIONS(801),
    [sym_decimal_integer_literal] = ACTIONS(801),
    [sym_hex_integer_literal] = ACTIONS(801),
    [sym_octal_integer_literal] = ACTIONS(801),
    [sym_binary_integer_literal] = ACTIONS(799),
    [sym_decimal_floating_point_literal] = ACTIONS(799),
    [sym_hex_floating_point_literal] = ACTIONS(801),
    [sym_true] = ACTIONS(801),
    [sym_false] = ACTIONS(801),
    [sym_character_literal] = ACTIONS(799),
    [anon_sym_DQUOTE] = ACTIONS(801),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [sym_null_literal] = ACTIONS(801),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(801),
    [anon_sym_DASH] = ACTIONS(801),
    [anon_sym_final] = ACTIONS(801),
    [anon_sym_BANG] = ACTIONS(799),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(801),
    [anon_sym_class] = ACTIONS(801),
    [anon_sym_switch] = ACTIONS(801),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(801),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_assert] = ACTIONS(801),
    [anon_sym_do] = ACTIONS(801),
    [anon_sym_while] = ACTIONS(801),
    [anon_sym_break] = ACTIONS(801),
    [anon_sym_continue] = ACTIONS(801),
    [anon_sym_return] = ACTIONS(801),
    [anon_sym_yield] = ACTIONS(801),
    [anon_sym_synchronized] = ACTIONS(801),
    [anon_sym_throw] = ACTIONS(801),
    [anon_sym_try] = ACTIONS(801),
    [anon_sym_if] = ACTIONS(801),
    [anon_sym_else] = ACTIONS(801),
    [anon_sym_for] = ACTIONS(801),
    [anon_sym_AT] = ACTIONS(801),
    [anon_sym_open] = ACTIONS(801),
    [anon_sym_module] = ACTIONS(801),
    [anon_sym_static] = ACTIONS(801),
    [anon_sym_with] = ACTIONS(801),
    [anon_sym_package] = ACTIONS(801),
    [anon_sym_import] = ACTIONS(801),
    [anon_sym_enum] = ACTIONS(801),
    [anon_sym_public] = ACTIONS(801),
    [anon_sym_protected] = ACTIONS(801),
    [anon_sym_private] = ACTIONS(801),
    [anon_sym_abstract] = ACTIONS(801),
    [anon_sym_strictfp] = ACTIONS(801),
    [anon_sym_native] = ACTIONS(801),
    [anon_sym_transient] = ACTIONS(801),
    [anon_sym_volatile] = ACTIONS(801),
    [anon_sym_sealed] = ACTIONS(801),
    [anon_sym_non_DASHsealed] = ACTIONS(799),
    [anon_sym_record] = ACTIONS(801),
    [anon_sym_ATinterface] = ACTIONS(799),
    [anon_sym_interface] = ACTIONS(801),
    [anon_sym_byte] = ACTIONS(801),
    [anon_sym_short] = ACTIONS(801),
    [anon_sym_int] = ACTIONS(801),
    [anon_sym_long] = ACTIONS(801),
    [anon_sym_char] = ACTIONS(801),
    [anon_sym_float] = ACTIONS(801),
    [anon_sym_double] = ACTIONS(801),
    [sym_boolean_type] = ACTIONS(801),
    [sym_void_type] = ACTIONS(801),
    [sym_this] = ACTIONS(801),
    [sym_super] = ACTIONS(801),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [292] = {
    [ts_builtin_sym_end] = ACTIONS(803),
    [sym_identifier] = ACTIONS(805),
    [sym_decimal_integer_literal] = ACTIONS(805),
    [sym_hex_integer_literal] = ACTIONS(805),
    [sym_octal_integer_literal] = ACTIONS(805),
    [sym_binary_integer_literal] = ACTIONS(803),
    [sym_decimal_floating_point_literal] = ACTIONS(803),
    [sym_hex_floating_point_literal] = ACTIONS(805),
    [sym_true] = ACTIONS(805),
    [sym_false] = ACTIONS(805),
    [sym_character_literal] = ACTIONS(803),
    [anon_sym_DQUOTE] = ACTIONS(805),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(803),
    [anon_sym_RBRACE] = ACTIONS(803),
    [sym_null_literal] = ACTIONS(805),
    [anon_sym_LPAREN] = ACTIONS(803),
    [anon_sym_LT] = ACTIONS(803),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_final] = ACTIONS(805),
    [anon_sym_BANG] = ACTIONS(803),
    [anon_sym_TILDE] = ACTIONS(803),
    [anon_sym_PLUS_PLUS] = ACTIONS(803),
    [anon_sym_DASH_DASH] = ACTIONS(803),
    [anon_sym_new] = ACTIONS(805),
    [anon_sym_class] = ACTIONS(805),
    [anon_sym_switch] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(803),
    [anon_sym_case] = ACTIONS(805),
    [anon_sym_default] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(803),
    [anon_sym_assert] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(805),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_break] = ACTIONS(805),
    [anon_sym_continue] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(805),
    [anon_sym_yield] = ACTIONS(805),
    [anon_sym_synchronized] = ACTIONS(805),
    [anon_sym_throw] = ACTIONS(805),
    [anon_sym_try] = ACTIONS(805),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_else] = ACTIONS(805),
    [anon_sym_for] = ACTIONS(805),
    [anon_sym_AT] = ACTIONS(805),
    [anon_sym_open] = ACTIONS(805),
    [anon_sym_module] = ACTIONS(805),
    [anon_sym_static] = ACTIONS(805),
    [anon_sym_with] = ACTIONS(805),
    [anon_sym_package] = ACTIONS(805),
    [anon_sym_import] = ACTIONS(805),
    [anon_sym_enum] = ACTIONS(805),
    [anon_sym_public] = ACTIONS(805),
    [anon_sym_protected] = ACTIONS(805),
    [anon_sym_private] = ACTIONS(805),
    [anon_sym_abstract] = ACTIONS(805),
    [anon_sym_strictfp] = ACTIONS(805),
    [anon_sym_native] = ACTIONS(805),
    [anon_sym_transient] = ACTIONS(805),
    [anon_sym_volatile] = ACTIONS(805),
    [anon_sym_sealed] = ACTIONS(805),
    [anon_sym_non_DASHsealed] = ACTIONS(803),
    [anon_sym_record] = ACTIONS(805),
    [anon_sym_ATinterface] = ACTIONS(803),
    [anon_sym_interface] = ACTIONS(805),
    [anon_sym_byte] = ACTIONS(805),
    [anon_sym_short] = ACTIONS(805),
    [anon_sym_int] = ACTIONS(805),
    [anon_sym_long] = ACTIONS(805),
    [anon_sym_char] = ACTIONS(805),
    [anon_sym_float] = ACTIONS(805),
    [anon_sym_double] = ACTIONS(805),
    [sym_boolean_type] = ACTIONS(805),
    [sym_void_type] = ACTIONS(805),
    [sym_this] = ACTIONS(805),
    [sym_super] = ACTIONS(805),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [293] = {
    [ts_builtin_sym_end] = ACTIONS(807),
    [sym_identifier] = ACTIONS(809),
    [sym_decimal_integer_literal] = ACTIONS(809),
    [sym_hex_integer_literal] = ACTIONS(809),
    [sym_octal_integer_literal] = ACTIONS(809),
    [sym_binary_integer_literal] = ACTIONS(807),
    [sym_decimal_floating_point_literal] = ACTIONS(807),
    [sym_hex_floating_point_literal] = ACTIONS(809),
    [sym_true] = ACTIONS(809),
    [sym_false] = ACTIONS(809),
    [sym_character_literal] = ACTIONS(807),
    [anon_sym_DQUOTE] = ACTIONS(809),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [sym_null_literal] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_final] = ACTIONS(809),
    [anon_sym_BANG] = ACTIONS(807),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(809),
    [anon_sym_class] = ACTIONS(809),
    [anon_sym_switch] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_case] = ACTIONS(809),
    [anon_sym_default] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_assert] = ACTIONS(809),
    [anon_sym_do] = ACTIONS(809),
    [anon_sym_while] = ACTIONS(809),
    [anon_sym_break] = ACTIONS(809),
    [anon_sym_continue] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(809),
    [anon_sym_yield] = ACTIONS(809),
    [anon_sym_synchronized] = ACTIONS(809),
    [anon_sym_throw] = ACTIONS(809),
    [anon_sym_try] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(809),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_AT] = ACTIONS(809),
    [anon_sym_open] = ACTIONS(809),
    [anon_sym_module] = ACTIONS(809),
    [anon_sym_static] = ACTIONS(809),
    [anon_sym_with] = ACTIONS(809),
    [anon_sym_package] = ACTIONS(809),
    [anon_sym_import] = ACTIONS(809),
    [anon_sym_enum] = ACTIONS(809),
    [anon_sym_public] = ACTIONS(809),
    [anon_sym_protected] = ACTIONS(809),
    [anon_sym_private] = ACTIONS(809),
    [anon_sym_abstract] = ACTIONS(809),
    [anon_sym_strictfp] = ACTIONS(809),
    [anon_sym_native] = ACTIONS(809),
    [anon_sym_transient] = ACTIONS(809),
    [anon_sym_volatile] = ACTIONS(809),
    [anon_sym_sealed] = ACTIONS(809),
    [anon_sym_non_DASHsealed] = ACTIONS(807),
    [anon_sym_record] = ACTIONS(809),
    [anon_sym_ATinterface] = ACTIONS(807),
    [anon_sym_interface] = ACTIONS(809),
    [anon_sym_byte] = ACTIONS(809),
    [anon_sym_short] = ACTIONS(809),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_long] = ACTIONS(809),
    [anon_sym_char] = ACTIONS(809),
    [anon_sym_float] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [sym_boolean_type] = ACTIONS(809),
    [sym_void_type] = ACTIONS(809),
    [sym_this] = ACTIONS(809),
    [sym_super] = ACTIONS(809),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [294] = {
    [ts_builtin_sym_end] = ACTIONS(811),
    [sym_identifier] = ACTIONS(813),
    [sym_decimal_integer_literal] = ACTIONS(813),
    [sym_hex_integer_literal] = ACTIONS(813),
    [sym_octal_integer_literal] = ACTIONS(813),
    [sym_binary_integer_literal] = ACTIONS(811),
    [sym_decimal_floating_point_literal] = ACTIONS(811),
    [sym_hex_floating_point_literal] = ACTIONS(813),
    [sym_true] = ACTIONS(813),
    [sym_false] = ACTIONS(813),
    [sym_character_literal] = ACTIONS(811),
    [anon_sym_DQUOTE] = ACTIONS(813),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [sym_null_literal] = ACTIONS(813),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(813),
    [anon_sym_DASH] = ACTIONS(813),
    [anon_sym_final] = ACTIONS(813),
    [anon_sym_BANG] = ACTIONS(811),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(813),
    [anon_sym_class] = ACTIONS(813),
    [anon_sym_switch] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_case] = ACTIONS(813),
    [anon_sym_default] = ACTIONS(813),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_assert] = ACTIONS(813),
    [anon_sym_do] = ACTIONS(813),
    [anon_sym_while] = ACTIONS(813),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(813),
    [anon_sym_return] = ACTIONS(813),
    [anon_sym_yield] = ACTIONS(813),
    [anon_sym_synchronized] = ACTIONS(813),
    [anon_sym_throw] = ACTIONS(813),
    [anon_sym_try] = ACTIONS(813),
    [anon_sym_if] = ACTIONS(813),
    [anon_sym_else] = ACTIONS(813),
    [anon_sym_for] = ACTIONS(813),
    [anon_sym_AT] = ACTIONS(813),
    [anon_sym_open] = ACTIONS(813),
    [anon_sym_module] = ACTIONS(813),
    [anon_sym_static] = ACTIONS(813),
    [anon_sym_with] = ACTIONS(813),
    [anon_sym_package] = ACTIONS(813),
    [anon_sym_import] = ACTIONS(813),
    [anon_sym_enum] = ACTIONS(813),
    [anon_sym_public] = ACTIONS(813),
    [anon_sym_protected] = ACTIONS(813),
    [anon_sym_private] = ACTIONS(813),
    [anon_sym_abstract] = ACTIONS(813),
    [anon_sym_strictfp] = ACTIONS(813),
    [anon_sym_native] = ACTIONS(813),
    [anon_sym_transient] = ACTIONS(813),
    [anon_sym_volatile] = ACTIONS(813),
    [anon_sym_sealed] = ACTIONS(813),
    [anon_sym_non_DASHsealed] = ACTIONS(811),
    [anon_sym_record] = ACTIONS(813),
    [anon_sym_ATinterface] = ACTIONS(811),
    [anon_sym_interface] = ACTIONS(813),
    [anon_sym_byte] = ACTIONS(813),
    [anon_sym_short] = ACTIONS(813),
    [anon_sym_int] = ACTIONS(813),
    [anon_sym_long] = ACTIONS(813),
    [anon_sym_char] = ACTIONS(813),
    [anon_sym_float] = ACTIONS(813),
    [anon_sym_double] = ACTIONS(813),
    [sym_boolean_type] = ACTIONS(813),
    [sym_void_type] = ACTIONS(813),
    [sym_this] = ACTIONS(813),
    [sym_super] = ACTIONS(813),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [295] = {
    [ts_builtin_sym_end] = ACTIONS(815),
    [sym_identifier] = ACTIONS(817),
    [sym_decimal_integer_literal] = ACTIONS(817),
    [sym_hex_integer_literal] = ACTIONS(817),
    [sym_octal_integer_literal] = ACTIONS(817),
    [sym_binary_integer_literal] = ACTIONS(815),
    [sym_decimal_floating_point_literal] = ACTIONS(815),
    [sym_hex_floating_point_literal] = ACTIONS(817),
    [sym_true] = ACTIONS(817),
    [sym_false] = ACTIONS(817),
    [sym_character_literal] = ACTIONS(815),
    [anon_sym_DQUOTE] = ACTIONS(817),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(815),
    [anon_sym_RBRACE] = ACTIONS(815),
    [sym_null_literal] = ACTIONS(817),
    [anon_sym_LPAREN] = ACTIONS(815),
    [anon_sym_LT] = ACTIONS(815),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_final] = ACTIONS(817),
    [anon_sym_BANG] = ACTIONS(815),
    [anon_sym_TILDE] = ACTIONS(815),
    [anon_sym_PLUS_PLUS] = ACTIONS(815),
    [anon_sym_DASH_DASH] = ACTIONS(815),
    [anon_sym_new] = ACTIONS(817),
    [anon_sym_class] = ACTIONS(817),
    [anon_sym_switch] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_case] = ACTIONS(817),
    [anon_sym_default] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(815),
    [anon_sym_assert] = ACTIONS(817),
    [anon_sym_do] = ACTIONS(817),
    [anon_sym_while] = ACTIONS(817),
    [anon_sym_break] = ACTIONS(817),
    [anon_sym_continue] = ACTIONS(817),
    [anon_sym_return] = ACTIONS(817),
    [anon_sym_yield] = ACTIONS(817),
    [anon_sym_synchronized] = ACTIONS(817),
    [anon_sym_throw] = ACTIONS(817),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_else] = ACTIONS(817),
    [anon_sym_for] = ACTIONS(817),
    [anon_sym_AT] = ACTIONS(817),
    [anon_sym_open] = ACTIONS(817),
    [anon_sym_module] = ACTIONS(817),
    [anon_sym_static] = ACTIONS(817),
    [anon_sym_with] = ACTIONS(817),
    [anon_sym_package] = ACTIONS(817),
    [anon_sym_import] = ACTIONS(817),
    [anon_sym_enum] = ACTIONS(817),
    [anon_sym_public] = ACTIONS(817),
    [anon_sym_protected] = ACTIONS(817),
    [anon_sym_private] = ACTIONS(817),
    [anon_sym_abstract] = ACTIONS(817),
    [anon_sym_strictfp] = ACTIONS(817),
    [anon_sym_native] = ACTIONS(817),
    [anon_sym_transient] = ACTIONS(817),
    [anon_sym_volatile] = ACTIONS(817),
    [anon_sym_sealed] = ACTIONS(817),
    [anon_sym_non_DASHsealed] = ACTIONS(815),
    [anon_sym_record] = ACTIONS(817),
    [anon_sym_ATinterface] = ACTIONS(815),
    [anon_sym_interface] = ACTIONS(817),
    [anon_sym_byte] = ACTIONS(817),
    [anon_sym_short] = ACTIONS(817),
    [anon_sym_int] = ACTIONS(817),
    [anon_sym_long] = ACTIONS(817),
    [anon_sym_char] = ACTIONS(817),
    [anon_sym_float] = ACTIONS(817),
    [anon_sym_double] = ACTIONS(817),
    [sym_boolean_type] = ACTIONS(817),
    [sym_void_type] = ACTIONS(817),
    [sym_this] = ACTIONS(817),
    [sym_super] = ACTIONS(817),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [296] = {
    [ts_builtin_sym_end] = ACTIONS(564),
    [sym_identifier] = ACTIONS(566),
    [sym_decimal_integer_literal] = ACTIONS(566),
    [sym_hex_integer_literal] = ACTIONS(566),
    [sym_octal_integer_literal] = ACTIONS(566),
    [sym_binary_integer_literal] = ACTIONS(564),
    [sym_decimal_floating_point_literal] = ACTIONS(564),
    [sym_hex_floating_point_literal] = ACTIONS(566),
    [sym_true] = ACTIONS(566),
    [sym_false] = ACTIONS(566),
    [sym_character_literal] = ACTIONS(564),
    [anon_sym_DQUOTE] = ACTIONS(566),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(564),
    [anon_sym_RBRACE] = ACTIONS(564),
    [sym_null_literal] = ACTIONS(566),
    [anon_sym_LPAREN] = ACTIONS(564),
    [anon_sym_LT] = ACTIONS(564),
    [anon_sym_PLUS] = ACTIONS(566),
    [anon_sym_DASH] = ACTIONS(566),
    [anon_sym_final] = ACTIONS(566),
    [anon_sym_BANG] = ACTIONS(564),
    [anon_sym_TILDE] = ACTIONS(564),
    [anon_sym_PLUS_PLUS] = ACTIONS(564),
    [anon_sym_DASH_DASH] = ACTIONS(564),
    [anon_sym_new] = ACTIONS(566),
    [anon_sym_class] = ACTIONS(566),
    [anon_sym_switch] = ACTIONS(566),
    [anon_sym_LBRACE] = ACTIONS(564),
    [anon_sym_case] = ACTIONS(566),
    [anon_sym_default] = ACTIONS(566),
    [anon_sym_SEMI] = ACTIONS(564),
    [anon_sym_assert] = ACTIONS(566),
    [anon_sym_do] = ACTIONS(566),
    [anon_sym_while] = ACTIONS(566),
    [anon_sym_break] = ACTIONS(566),
    [anon_sym_continue] = ACTIONS(566),
    [anon_sym_return] = ACTIONS(566),
    [anon_sym_yield] = ACTIONS(566),
    [anon_sym_synchronized] = ACTIONS(566),
    [anon_sym_throw] = ACTIONS(566),
    [anon_sym_try] = ACTIONS(566),
    [anon_sym_if] = ACTIONS(566),
    [anon_sym_else] = ACTIONS(566),
    [anon_sym_for] = ACTIONS(566),
    [anon_sym_AT] = ACTIONS(566),
    [anon_sym_open] = ACTIONS(566),
    [anon_sym_module] = ACTIONS(566),
    [anon_sym_static] = ACTIONS(566),
    [anon_sym_with] = ACTIONS(566),
    [anon_sym_package] = ACTIONS(566),
    [anon_sym_import] = ACTIONS(566),
    [anon_sym_enum] = ACTIONS(566),
    [anon_sym_public] = ACTIONS(566),
    [anon_sym_protected] = ACTIONS(566),
    [anon_sym_private] = ACTIONS(566),
    [anon_sym_abstract] = ACTIONS(566),
    [anon_sym_strictfp] = ACTIONS(566),
    [anon_sym_native] = ACTIONS(566),
    [anon_sym_transient] = ACTIONS(566),
    [anon_sym_volatile] = ACTIONS(566),
    [anon_sym_sealed] = ACTIONS(566),
    [anon_sym_non_DASHsealed] = ACTIONS(564),
    [anon_sym_record] = ACTIONS(566),
    [anon_sym_ATinterface] = ACTIONS(564),
    [anon_sym_interface] = ACTIONS(566),
    [anon_sym_byte] = ACTIONS(566),
    [anon_sym_short] = ACTIONS(566),
    [anon_sym_int] = ACTIONS(566),
    [anon_sym_long] = ACTIONS(566),
    [anon_sym_char] = ACTIONS(566),
    [anon_sym_float] = ACTIONS(566),
    [anon_sym_double] = ACTIONS(566),
    [sym_boolean_type] = ACTIONS(566),
    [sym_void_type] = ACTIONS(566),
    [sym_this] = ACTIONS(566),
    [sym_super] = ACTIONS(566),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [297] = {
    [ts_builtin_sym_end] = ACTIONS(819),
    [sym_identifier] = ACTIONS(821),
    [sym_decimal_integer_literal] = ACTIONS(821),
    [sym_hex_integer_literal] = ACTIONS(821),
    [sym_octal_integer_literal] = ACTIONS(821),
    [sym_binary_integer_literal] = ACTIONS(819),
    [sym_decimal_floating_point_literal] = ACTIONS(819),
    [sym_hex_floating_point_literal] = ACTIONS(821),
    [sym_true] = ACTIONS(821),
    [sym_false] = ACTIONS(821),
    [sym_character_literal] = ACTIONS(819),
    [anon_sym_DQUOTE] = ACTIONS(821),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [sym_null_literal] = ACTIONS(821),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(821),
    [anon_sym_DASH] = ACTIONS(821),
    [anon_sym_final] = ACTIONS(821),
    [anon_sym_BANG] = ACTIONS(819),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(821),
    [anon_sym_class] = ACTIONS(821),
    [anon_sym_switch] = ACTIONS(821),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_case] = ACTIONS(821),
    [anon_sym_default] = ACTIONS(821),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_assert] = ACTIONS(821),
    [anon_sym_do] = ACTIONS(821),
    [anon_sym_while] = ACTIONS(821),
    [anon_sym_break] = ACTIONS(821),
    [anon_sym_continue] = ACTIONS(821),
    [anon_sym_return] = ACTIONS(821),
    [anon_sym_yield] = ACTIONS(821),
    [anon_sym_synchronized] = ACTIONS(821),
    [anon_sym_throw] = ACTIONS(821),
    [anon_sym_try] = ACTIONS(821),
    [anon_sym_if] = ACTIONS(821),
    [anon_sym_else] = ACTIONS(821),
    [anon_sym_for] = ACTIONS(821),
    [anon_sym_AT] = ACTIONS(821),
    [anon_sym_open] = ACTIONS(821),
    [anon_sym_module] = ACTIONS(821),
    [anon_sym_static] = ACTIONS(821),
    [anon_sym_with] = ACTIONS(821),
    [anon_sym_package] = ACTIONS(821),
    [anon_sym_import] = ACTIONS(821),
    [anon_sym_enum] = ACTIONS(821),
    [anon_sym_public] = ACTIONS(821),
    [anon_sym_protected] = ACTIONS(821),
    [anon_sym_private] = ACTIONS(821),
    [anon_sym_abstract] = ACTIONS(821),
    [anon_sym_strictfp] = ACTIONS(821),
    [anon_sym_native] = ACTIONS(821),
    [anon_sym_transient] = ACTIONS(821),
    [anon_sym_volatile] = ACTIONS(821),
    [anon_sym_sealed] = ACTIONS(821),
    [anon_sym_non_DASHsealed] = ACTIONS(819),
    [anon_sym_record] = ACTIONS(821),
    [anon_sym_ATinterface] = ACTIONS(819),
    [anon_sym_interface] = ACTIONS(821),
    [anon_sym_byte] = ACTIONS(821),
    [anon_sym_short] = ACTIONS(821),
    [anon_sym_int] = ACTIONS(821),
    [anon_sym_long] = ACTIONS(821),
    [anon_sym_char] = ACTIONS(821),
    [anon_sym_float] = ACTIONS(821),
    [anon_sym_double] = ACTIONS(821),
    [sym_boolean_type] = ACTIONS(821),
    [sym_void_type] = ACTIONS(821),
    [sym_this] = ACTIONS(821),
    [sym_super] = ACTIONS(821),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [298] = {
    [ts_builtin_sym_end] = ACTIONS(823),
    [sym_identifier] = ACTIONS(825),
    [sym_decimal_integer_literal] = ACTIONS(825),
    [sym_hex_integer_literal] = ACTIONS(825),
    [sym_octal_integer_literal] = ACTIONS(825),
    [sym_binary_integer_literal] = ACTIONS(823),
    [sym_decimal_floating_point_literal] = ACTIONS(823),
    [sym_hex_floating_point_literal] = ACTIONS(825),
    [sym_true] = ACTIONS(825),
    [sym_false] = ACTIONS(825),
    [sym_character_literal] = ACTIONS(823),
    [anon_sym_DQUOTE] = ACTIONS(825),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(823),
    [anon_sym_RBRACE] = ACTIONS(823),
    [sym_null_literal] = ACTIONS(825),
    [anon_sym_LPAREN] = ACTIONS(823),
    [anon_sym_LT] = ACTIONS(823),
    [anon_sym_PLUS] = ACTIONS(825),
    [anon_sym_DASH] = ACTIONS(825),
    [anon_sym_final] = ACTIONS(825),
    [anon_sym_BANG] = ACTIONS(823),
    [anon_sym_TILDE] = ACTIONS(823),
    [anon_sym_PLUS_PLUS] = ACTIONS(823),
    [anon_sym_DASH_DASH] = ACTIONS(823),
    [anon_sym_new] = ACTIONS(825),
    [anon_sym_class] = ACTIONS(825),
    [anon_sym_switch] = ACTIONS(825),
    [anon_sym_LBRACE] = ACTIONS(823),
    [anon_sym_case] = ACTIONS(825),
    [anon_sym_default] = ACTIONS(825),
    [anon_sym_SEMI] = ACTIONS(823),
    [anon_sym_assert] = ACTIONS(825),
    [anon_sym_do] = ACTIONS(825),
    [anon_sym_while] = ACTIONS(825),
    [anon_sym_break] = ACTIONS(825),
    [anon_sym_continue] = ACTIONS(825),
    [anon_sym_return] = ACTIONS(825),
    [anon_sym_yield] = ACTIONS(825),
    [anon_sym_synchronized] = ACTIONS(825),
    [anon_sym_throw] = ACTIONS(825),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_if] = ACTIONS(825),
    [anon_sym_else] = ACTIONS(825),
    [anon_sym_for] = ACTIONS(825),
    [anon_sym_AT] = ACTIONS(825),
    [anon_sym_open] = ACTIONS(825),
    [anon_sym_module] = ACTIONS(825),
    [anon_sym_static] = ACTIONS(825),
    [anon_sym_with] = ACTIONS(825),
    [anon_sym_package] = ACTIONS(825),
    [anon_sym_import] = ACTIONS(825),
    [anon_sym_enum] = ACTIONS(825),
    [anon_sym_public] = ACTIONS(825),
    [anon_sym_protected] = ACTIONS(825),
    [anon_sym_private] = ACTIONS(825),
    [anon_sym_abstract] = ACTIONS(825),
    [anon_sym_strictfp] = ACTIONS(825),
    [anon_sym_native] = ACTIONS(825),
    [anon_sym_transient] = ACTIONS(825),
    [anon_sym_volatile] = ACTIONS(825),
    [anon_sym_sealed] = ACTIONS(825),
    [anon_sym_non_DASHsealed] = ACTIONS(823),
    [anon_sym_record] = ACTIONS(825),
    [anon_sym_ATinterface] = ACTIONS(823),
    [anon_sym_interface] = ACTIONS(825),
    [anon_sym_byte] = ACTIONS(825),
    [anon_sym_short] = ACTIONS(825),
    [anon_sym_int] = ACTIONS(825),
    [anon_sym_long] = ACTIONS(825),
    [anon_sym_char] = ACTIONS(825),
    [anon_sym_float] = ACTIONS(825),
    [anon_sym_double] = ACTIONS(825),
    [sym_boolean_type] = ACTIONS(825),
    [sym_void_type] = ACTIONS(825),
    [sym_this] = ACTIONS(825),
    [sym_super] = ACTIONS(825),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [299] = {
    [ts_builtin_sym_end] = ACTIONS(827),
    [sym_identifier] = ACTIONS(829),
    [sym_decimal_integer_literal] = ACTIONS(829),
    [sym_hex_integer_literal] = ACTIONS(829),
    [sym_octal_integer_literal] = ACTIONS(829),
    [sym_binary_integer_literal] = ACTIONS(827),
    [sym_decimal_floating_point_literal] = ACTIONS(827),
    [sym_hex_floating_point_literal] = ACTIONS(829),
    [sym_true] = ACTIONS(829),
    [sym_false] = ACTIONS(829),
    [sym_character_literal] = ACTIONS(827),
    [anon_sym_DQUOTE] = ACTIONS(829),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(827),
    [anon_sym_RBRACE] = ACTIONS(827),
    [sym_null_literal] = ACTIONS(829),
    [anon_sym_LPAREN] = ACTIONS(827),
    [anon_sym_LT] = ACTIONS(827),
    [anon_sym_PLUS] = ACTIONS(829),
    [anon_sym_DASH] = ACTIONS(829),
    [anon_sym_final] = ACTIONS(829),
    [anon_sym_BANG] = ACTIONS(827),
    [anon_sym_TILDE] = ACTIONS(827),
    [anon_sym_PLUS_PLUS] = ACTIONS(827),
    [anon_sym_DASH_DASH] = ACTIONS(827),
    [anon_sym_new] = ACTIONS(829),
    [anon_sym_class] = ACTIONS(829),
    [anon_sym_switch] = ACTIONS(829),
    [anon_sym_LBRACE] = ACTIONS(827),
    [anon_sym_case] = ACTIONS(829),
    [anon_sym_default] = ACTIONS(829),
    [anon_sym_SEMI] = ACTIONS(827),
    [anon_sym_assert] = ACTIONS(829),
    [anon_sym_do] = ACTIONS(829),
    [anon_sym_while] = ACTIONS(829),
    [anon_sym_break] = ACTIONS(829),
    [anon_sym_continue] = ACTIONS(829),
    [anon_sym_return] = ACTIONS(829),
    [anon_sym_yield] = ACTIONS(829),
    [anon_sym_synchronized] = ACTIONS(829),
    [anon_sym_throw] = ACTIONS(829),
    [anon_sym_try] = ACTIONS(829),
    [anon_sym_if] = ACTIONS(829),
    [anon_sym_else] = ACTIONS(829),
    [anon_sym_for] = ACTIONS(829),
    [anon_sym_AT] = ACTIONS(829),
    [anon_sym_open] = ACTIONS(829),
    [anon_sym_module] = ACTIONS(829),
    [anon_sym_static] = ACTIONS(829),
    [anon_sym_with] = ACTIONS(829),
    [anon_sym_package] = ACTIONS(829),
    [anon_sym_import] = ACTIONS(829),
    [anon_sym_enum] = ACTIONS(829),
    [anon_sym_public] = ACTIONS(829),
    [anon_sym_protected] = ACTIONS(829),
    [anon_sym_private] = ACTIONS(829),
    [anon_sym_abstract] = ACTIONS(829),
    [anon_sym_strictfp] = ACTIONS(829),
    [anon_sym_native] = ACTIONS(829),
    [anon_sym_transient] = ACTIONS(829),
    [anon_sym_volatile] = ACTIONS(829),
    [anon_sym_sealed] = ACTIONS(829),
    [anon_sym_non_DASHsealed] = ACTIONS(827),
    [anon_sym_record] = ACTIONS(829),
    [anon_sym_ATinterface] = ACTIONS(827),
    [anon_sym_interface] = ACTIONS(829),
    [anon_sym_byte] = ACTIONS(829),
    [anon_sym_short] = ACTIONS(829),
    [anon_sym_int] = ACTIONS(829),
    [anon_sym_long] = ACTIONS(829),
    [anon_sym_char] = ACTIONS(829),
    [anon_sym_float] = ACTIONS(829),
    [anon_sym_double] = ACTIONS(829),
    [sym_boolean_type] = ACTIONS(829),
    [sym_void_type] = ACTIONS(829),
    [sym_this] = ACTIONS(829),
    [sym_super] = ACTIONS(829),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [300] = {
    [ts_builtin_sym_end] = ACTIONS(831),
    [sym_identifier] = ACTIONS(833),
    [sym_decimal_integer_literal] = ACTIONS(833),
    [sym_hex_integer_literal] = ACTIONS(833),
    [sym_octal_integer_literal] = ACTIONS(833),
    [sym_binary_integer_literal] = ACTIONS(831),
    [sym_decimal_floating_point_literal] = ACTIONS(831),
    [sym_hex_floating_point_literal] = ACTIONS(833),
    [sym_true] = ACTIONS(833),
    [sym_false] = ACTIONS(833),
    [sym_character_literal] = ACTIONS(831),
    [anon_sym_DQUOTE] = ACTIONS(833),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(831),
    [anon_sym_RBRACE] = ACTIONS(831),
    [sym_null_literal] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(831),
    [anon_sym_LT] = ACTIONS(831),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(833),
    [anon_sym_final] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(831),
    [anon_sym_TILDE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(831),
    [anon_sym_DASH_DASH] = ACTIONS(831),
    [anon_sym_new] = ACTIONS(833),
    [anon_sym_class] = ACTIONS(833),
    [anon_sym_switch] = ACTIONS(833),
    [anon_sym_LBRACE] = ACTIONS(831),
    [anon_sym_case] = ACTIONS(833),
    [anon_sym_default] = ACTIONS(833),
    [anon_sym_SEMI] = ACTIONS(831),
    [anon_sym_assert] = ACTIONS(833),
    [anon_sym_do] = ACTIONS(833),
    [anon_sym_while] = ACTIONS(833),
    [anon_sym_break] = ACTIONS(833),
    [anon_sym_continue] = ACTIONS(833),
    [anon_sym_return] = ACTIONS(833),
    [anon_sym_yield] = ACTIONS(833),
    [anon_sym_synchronized] = ACTIONS(833),
    [anon_sym_throw] = ACTIONS(833),
    [anon_sym_try] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(833),
    [anon_sym_for] = ACTIONS(833),
    [anon_sym_AT] = ACTIONS(833),
    [anon_sym_open] = ACTIONS(833),
    [anon_sym_module] = ACTIONS(833),
    [anon_sym_static] = ACTIONS(833),
    [anon_sym_with] = ACTIONS(833),
    [anon_sym_package] = ACTIONS(833),
    [anon_sym_import] = ACTIONS(833),
    [anon_sym_enum] = ACTIONS(833),
    [anon_sym_public] = ACTIONS(833),
    [anon_sym_protected] = ACTIONS(833),
    [anon_sym_private] = ACTIONS(833),
    [anon_sym_abstract] = ACTIONS(833),
    [anon_sym_strictfp] = ACTIONS(833),
    [anon_sym_native] = ACTIONS(833),
    [anon_sym_transient] = ACTIONS(833),
    [anon_sym_volatile] = ACTIONS(833),
    [anon_sym_sealed] = ACTIONS(833),
    [anon_sym_non_DASHsealed] = ACTIONS(831),
    [anon_sym_record] = ACTIONS(833),
    [anon_sym_ATinterface] = ACTIONS(831),
    [anon_sym_interface] = ACTIONS(833),
    [anon_sym_byte] = ACTIONS(833),
    [anon_sym_short] = ACTIONS(833),
    [anon_sym_int] = ACTIONS(833),
    [anon_sym_long] = ACTIONS(833),
    [anon_sym_char] = ACTIONS(833),
    [anon_sym_float] = ACTIONS(833),
    [anon_sym_double] = ACTIONS(833),
    [sym_boolean_type] = ACTIONS(833),
    [sym_void_type] = ACTIONS(833),
    [sym_this] = ACTIONS(833),
    [sym_super] = ACTIONS(833),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [301] = {
    [ts_builtin_sym_end] = ACTIONS(835),
    [sym_identifier] = ACTIONS(837),
    [sym_decimal_integer_literal] = ACTIONS(837),
    [sym_hex_integer_literal] = ACTIONS(837),
    [sym_octal_integer_literal] = ACTIONS(837),
    [sym_binary_integer_literal] = ACTIONS(835),
    [sym_decimal_floating_point_literal] = ACTIONS(835),
    [sym_hex_floating_point_literal] = ACTIONS(837),
    [sym_true] = ACTIONS(837),
    [sym_false] = ACTIONS(837),
    [sym_character_literal] = ACTIONS(835),
    [anon_sym_DQUOTE] = ACTIONS(837),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(835),
    [anon_sym_RBRACE] = ACTIONS(835),
    [sym_null_literal] = ACTIONS(837),
    [anon_sym_LPAREN] = ACTIONS(835),
    [anon_sym_LT] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(837),
    [anon_sym_DASH] = ACTIONS(837),
    [anon_sym_final] = ACTIONS(837),
    [anon_sym_BANG] = ACTIONS(835),
    [anon_sym_TILDE] = ACTIONS(835),
    [anon_sym_PLUS_PLUS] = ACTIONS(835),
    [anon_sym_DASH_DASH] = ACTIONS(835),
    [anon_sym_new] = ACTIONS(837),
    [anon_sym_class] = ACTIONS(837),
    [anon_sym_switch] = ACTIONS(837),
    [anon_sym_LBRACE] = ACTIONS(835),
    [anon_sym_case] = ACTIONS(837),
    [anon_sym_default] = ACTIONS(837),
    [anon_sym_SEMI] = ACTIONS(835),
    [anon_sym_assert] = ACTIONS(837),
    [anon_sym_do] = ACTIONS(837),
    [anon_sym_while] = ACTIONS(837),
    [anon_sym_break] = ACTIONS(837),
    [anon_sym_continue] = ACTIONS(837),
    [anon_sym_return] = ACTIONS(837),
    [anon_sym_yield] = ACTIONS(837),
    [anon_sym_synchronized] = ACTIONS(837),
    [anon_sym_throw] = ACTIONS(837),
    [anon_sym_try] = ACTIONS(837),
    [anon_sym_if] = ACTIONS(837),
    [anon_sym_else] = ACTIONS(837),
    [anon_sym_for] = ACTIONS(837),
    [anon_sym_AT] = ACTIONS(837),
    [anon_sym_open] = ACTIONS(837),
    [anon_sym_module] = ACTIONS(837),
    [anon_sym_static] = ACTIONS(837),
    [anon_sym_with] = ACTIONS(837),
    [anon_sym_package] = ACTIONS(837),
    [anon_sym_import] = ACTIONS(837),
    [anon_sym_enum] = ACTIONS(837),
    [anon_sym_public] = ACTIONS(837),
    [anon_sym_protected] = ACTIONS(837),
    [anon_sym_private] = ACTIONS(837),
    [anon_sym_abstract] = ACTIONS(837),
    [anon_sym_strictfp] = ACTIONS(837),
    [anon_sym_native] = ACTIONS(837),
    [anon_sym_transient] = ACTIONS(837),
    [anon_sym_volatile] = ACTIONS(837),
    [anon_sym_sealed] = ACTIONS(837),
    [anon_sym_non_DASHsealed] = ACTIONS(835),
    [anon_sym_record] = ACTIONS(837),
    [anon_sym_ATinterface] = ACTIONS(835),
    [anon_sym_interface] = ACTIONS(837),
    [anon_sym_byte] = ACTIONS(837),
    [anon_sym_short] = ACTIONS(837),
    [anon_sym_int] = ACTIONS(837),
    [anon_sym_long] = ACTIONS(837),
    [anon_sym_char] = ACTIONS(837),
    [anon_sym_float] = ACTIONS(837),
    [anon_sym_double] = ACTIONS(837),
    [sym_boolean_type] = ACTIONS(837),
    [sym_void_type] = ACTIONS(837),
    [sym_this] = ACTIONS(837),
    [sym_super] = ACTIONS(837),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [302] = {
    [ts_builtin_sym_end] = ACTIONS(839),
    [sym_identifier] = ACTIONS(841),
    [sym_decimal_integer_literal] = ACTIONS(841),
    [sym_hex_integer_literal] = ACTIONS(841),
    [sym_octal_integer_literal] = ACTIONS(841),
    [sym_binary_integer_literal] = ACTIONS(839),
    [sym_decimal_floating_point_literal] = ACTIONS(839),
    [sym_hex_floating_point_literal] = ACTIONS(841),
    [sym_true] = ACTIONS(841),
    [sym_false] = ACTIONS(841),
    [sym_character_literal] = ACTIONS(839),
    [anon_sym_DQUOTE] = ACTIONS(841),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(839),
    [anon_sym_RBRACE] = ACTIONS(839),
    [sym_null_literal] = ACTIONS(841),
    [anon_sym_LPAREN] = ACTIONS(839),
    [anon_sym_LT] = ACTIONS(839),
    [anon_sym_PLUS] = ACTIONS(841),
    [anon_sym_DASH] = ACTIONS(841),
    [anon_sym_final] = ACTIONS(841),
    [anon_sym_BANG] = ACTIONS(839),
    [anon_sym_TILDE] = ACTIONS(839),
    [anon_sym_PLUS_PLUS] = ACTIONS(839),
    [anon_sym_DASH_DASH] = ACTIONS(839),
    [anon_sym_new] = ACTIONS(841),
    [anon_sym_class] = ACTIONS(841),
    [anon_sym_switch] = ACTIONS(841),
    [anon_sym_LBRACE] = ACTIONS(839),
    [anon_sym_case] = ACTIONS(841),
    [anon_sym_default] = ACTIONS(841),
    [anon_sym_SEMI] = ACTIONS(839),
    [anon_sym_assert] = ACTIONS(841),
    [anon_sym_do] = ACTIONS(841),
    [anon_sym_while] = ACTIONS(841),
    [anon_sym_break] = ACTIONS(841),
    [anon_sym_continue] = ACTIONS(841),
    [anon_sym_return] = ACTIONS(841),
    [anon_sym_yield] = ACTIONS(841),
    [anon_sym_synchronized] = ACTIONS(841),
    [anon_sym_throw] = ACTIONS(841),
    [anon_sym_try] = ACTIONS(841),
    [anon_sym_if] = ACTIONS(841),
    [anon_sym_else] = ACTIONS(841),
    [anon_sym_for] = ACTIONS(841),
    [anon_sym_AT] = ACTIONS(841),
    [anon_sym_open] = ACTIONS(841),
    [anon_sym_module] = ACTIONS(841),
    [anon_sym_static] = ACTIONS(841),
    [anon_sym_with] = ACTIONS(841),
    [anon_sym_package] = ACTIONS(841),
    [anon_sym_import] = ACTIONS(841),
    [anon_sym_enum] = ACTIONS(841),
    [anon_sym_public] = ACTIONS(841),
    [anon_sym_protected] = ACTIONS(841),
    [anon_sym_private] = ACTIONS(841),
    [anon_sym_abstract] = ACTIONS(841),
    [anon_sym_strictfp] = ACTIONS(841),
    [anon_sym_native] = ACTIONS(841),
    [anon_sym_transient] = ACTIONS(841),
    [anon_sym_volatile] = ACTIONS(841),
    [anon_sym_sealed] = ACTIONS(841),
    [anon_sym_non_DASHsealed] = ACTIONS(839),
    [anon_sym_record] = ACTIONS(841),
    [anon_sym_ATinterface] = ACTIONS(839),
    [anon_sym_interface] = ACTIONS(841),
    [anon_sym_byte] = ACTIONS(841),
    [anon_sym_short] = ACTIONS(841),
    [anon_sym_int] = ACTIONS(841),
    [anon_sym_long] = ACTIONS(841),
    [anon_sym_char] = ACTIONS(841),
    [anon_sym_float] = ACTIONS(841),
    [anon_sym_double] = ACTIONS(841),
    [sym_boolean_type] = ACTIONS(841),
    [sym_void_type] = ACTIONS(841),
    [sym_this] = ACTIONS(841),
    [sym_super] = ACTIONS(841),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [303] = {
    [ts_builtin_sym_end] = ACTIONS(843),
    [sym_identifier] = ACTIONS(845),
    [sym_decimal_integer_literal] = ACTIONS(845),
    [sym_hex_integer_literal] = ACTIONS(845),
    [sym_octal_integer_literal] = ACTIONS(845),
    [sym_binary_integer_literal] = ACTIONS(843),
    [sym_decimal_floating_point_literal] = ACTIONS(843),
    [sym_hex_floating_point_literal] = ACTIONS(845),
    [sym_true] = ACTIONS(845),
    [sym_false] = ACTIONS(845),
    [sym_character_literal] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(843),
    [anon_sym_RBRACE] = ACTIONS(843),
    [sym_null_literal] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(843),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_PLUS] = ACTIONS(845),
    [anon_sym_DASH] = ACTIONS(845),
    [anon_sym_final] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(843),
    [anon_sym_DASH_DASH] = ACTIONS(843),
    [anon_sym_new] = ACTIONS(845),
    [anon_sym_class] = ACTIONS(845),
    [anon_sym_switch] = ACTIONS(845),
    [anon_sym_LBRACE] = ACTIONS(843),
    [anon_sym_case] = ACTIONS(845),
    [anon_sym_default] = ACTIONS(845),
    [anon_sym_SEMI] = ACTIONS(843),
    [anon_sym_assert] = ACTIONS(845),
    [anon_sym_do] = ACTIONS(845),
    [anon_sym_while] = ACTIONS(845),
    [anon_sym_break] = ACTIONS(845),
    [anon_sym_continue] = ACTIONS(845),
    [anon_sym_return] = ACTIONS(845),
    [anon_sym_yield] = ACTIONS(845),
    [anon_sym_synchronized] = ACTIONS(845),
    [anon_sym_throw] = ACTIONS(845),
    [anon_sym_try] = ACTIONS(845),
    [anon_sym_if] = ACTIONS(845),
    [anon_sym_else] = ACTIONS(845),
    [anon_sym_for] = ACTIONS(845),
    [anon_sym_AT] = ACTIONS(845),
    [anon_sym_open] = ACTIONS(845),
    [anon_sym_module] = ACTIONS(845),
    [anon_sym_static] = ACTIONS(845),
    [anon_sym_with] = ACTIONS(845),
    [anon_sym_package] = ACTIONS(845),
    [anon_sym_import] = ACTIONS(845),
    [anon_sym_enum] = ACTIONS(845),
    [anon_sym_public] = ACTIONS(845),
    [anon_sym_protected] = ACTIONS(845),
    [anon_sym_private] = ACTIONS(845),
    [anon_sym_abstract] = ACTIONS(845),
    [anon_sym_strictfp] = ACTIONS(845),
    [anon_sym_native] = ACTIONS(845),
    [anon_sym_transient] = ACTIONS(845),
    [anon_sym_volatile] = ACTIONS(845),
    [anon_sym_sealed] = ACTIONS(845),
    [anon_sym_non_DASHsealed] = ACTIONS(843),
    [anon_sym_record] = ACTIONS(845),
    [anon_sym_ATinterface] = ACTIONS(843),
    [anon_sym_interface] = ACTIONS(845),
    [anon_sym_byte] = ACTIONS(845),
    [anon_sym_short] = ACTIONS(845),
    [anon_sym_int] = ACTIONS(845),
    [anon_sym_long] = ACTIONS(845),
    [anon_sym_char] = ACTIONS(845),
    [anon_sym_float] = ACTIONS(845),
    [anon_sym_double] = ACTIONS(845),
    [sym_boolean_type] = ACTIONS(845),
    [sym_void_type] = ACTIONS(845),
    [sym_this] = ACTIONS(845),
    [sym_super] = ACTIONS(845),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [304] = {
    [ts_builtin_sym_end] = ACTIONS(847),
    [sym_identifier] = ACTIONS(849),
    [sym_decimal_integer_literal] = ACTIONS(849),
    [sym_hex_integer_literal] = ACTIONS(849),
    [sym_octal_integer_literal] = ACTIONS(849),
    [sym_binary_integer_literal] = ACTIONS(847),
    [sym_decimal_floating_point_literal] = ACTIONS(847),
    [sym_hex_floating_point_literal] = ACTIONS(849),
    [sym_true] = ACTIONS(849),
    [sym_false] = ACTIONS(849),
    [sym_character_literal] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(847),
    [anon_sym_RBRACE] = ACTIONS(847),
    [sym_null_literal] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(847),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_PLUS] = ACTIONS(849),
    [anon_sym_DASH] = ACTIONS(849),
    [anon_sym_final] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(847),
    [anon_sym_DASH_DASH] = ACTIONS(847),
    [anon_sym_new] = ACTIONS(849),
    [anon_sym_class] = ACTIONS(849),
    [anon_sym_switch] = ACTIONS(849),
    [anon_sym_LBRACE] = ACTIONS(847),
    [anon_sym_case] = ACTIONS(849),
    [anon_sym_default] = ACTIONS(849),
    [anon_sym_SEMI] = ACTIONS(847),
    [anon_sym_assert] = ACTIONS(849),
    [anon_sym_do] = ACTIONS(849),
    [anon_sym_while] = ACTIONS(849),
    [anon_sym_break] = ACTIONS(849),
    [anon_sym_continue] = ACTIONS(849),
    [anon_sym_return] = ACTIONS(849),
    [anon_sym_yield] = ACTIONS(849),
    [anon_sym_synchronized] = ACTIONS(849),
    [anon_sym_throw] = ACTIONS(849),
    [anon_sym_try] = ACTIONS(849),
    [anon_sym_if] = ACTIONS(849),
    [anon_sym_else] = ACTIONS(849),
    [anon_sym_for] = ACTIONS(849),
    [anon_sym_AT] = ACTIONS(849),
    [anon_sym_open] = ACTIONS(849),
    [anon_sym_module] = ACTIONS(849),
    [anon_sym_static] = ACTIONS(849),
    [anon_sym_with] = ACTIONS(849),
    [anon_sym_package] = ACTIONS(849),
    [anon_sym_import] = ACTIONS(849),
    [anon_sym_enum] = ACTIONS(849),
    [anon_sym_public] = ACTIONS(849),
    [anon_sym_protected] = ACTIONS(849),
    [anon_sym_private] = ACTIONS(849),
    [anon_sym_abstract] = ACTIONS(849),
    [anon_sym_strictfp] = ACTIONS(849),
    [anon_sym_native] = ACTIONS(849),
    [anon_sym_transient] = ACTIONS(849),
    [anon_sym_volatile] = ACTIONS(849),
    [anon_sym_sealed] = ACTIONS(849),
    [anon_sym_non_DASHsealed] = ACTIONS(847),
    [anon_sym_record] = ACTIONS(849),
    [anon_sym_ATinterface] = ACTIONS(847),
    [anon_sym_interface] = ACTIONS(849),
    [anon_sym_byte] = ACTIONS(849),
    [anon_sym_short] = ACTIONS(849),
    [anon_sym_int] = ACTIONS(849),
    [anon_sym_long] = ACTIONS(849),
    [anon_sym_char] = ACTIONS(849),
    [anon_sym_float] = ACTIONS(849),
    [anon_sym_double] = ACTIONS(849),
    [sym_boolean_type] = ACTIONS(849),
    [sym_void_type] = ACTIONS(849),
    [sym_this] = ACTIONS(849),
    [sym_super] = ACTIONS(849),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [305] = {
    [ts_builtin_sym_end] = ACTIONS(851),
    [sym_identifier] = ACTIONS(853),
    [sym_decimal_integer_literal] = ACTIONS(853),
    [sym_hex_integer_literal] = ACTIONS(853),
    [sym_octal_integer_literal] = ACTIONS(853),
    [sym_binary_integer_literal] = ACTIONS(851),
    [sym_decimal_floating_point_literal] = ACTIONS(851),
    [sym_hex_floating_point_literal] = ACTIONS(853),
    [sym_true] = ACTIONS(853),
    [sym_false] = ACTIONS(853),
    [sym_character_literal] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(851),
    [anon_sym_RBRACE] = ACTIONS(851),
    [sym_null_literal] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(851),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_PLUS] = ACTIONS(853),
    [anon_sym_DASH] = ACTIONS(853),
    [anon_sym_final] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(851),
    [anon_sym_DASH_DASH] = ACTIONS(851),
    [anon_sym_new] = ACTIONS(853),
    [anon_sym_class] = ACTIONS(853),
    [anon_sym_switch] = ACTIONS(853),
    [anon_sym_LBRACE] = ACTIONS(851),
    [anon_sym_case] = ACTIONS(853),
    [anon_sym_default] = ACTIONS(853),
    [anon_sym_SEMI] = ACTIONS(851),
    [anon_sym_assert] = ACTIONS(853),
    [anon_sym_do] = ACTIONS(853),
    [anon_sym_while] = ACTIONS(853),
    [anon_sym_break] = ACTIONS(853),
    [anon_sym_continue] = ACTIONS(853),
    [anon_sym_return] = ACTIONS(853),
    [anon_sym_yield] = ACTIONS(853),
    [anon_sym_synchronized] = ACTIONS(853),
    [anon_sym_throw] = ACTIONS(853),
    [anon_sym_try] = ACTIONS(853),
    [anon_sym_if] = ACTIONS(853),
    [anon_sym_else] = ACTIONS(853),
    [anon_sym_for] = ACTIONS(853),
    [anon_sym_AT] = ACTIONS(853),
    [anon_sym_open] = ACTIONS(853),
    [anon_sym_module] = ACTIONS(853),
    [anon_sym_static] = ACTIONS(853),
    [anon_sym_with] = ACTIONS(853),
    [anon_sym_package] = ACTIONS(853),
    [anon_sym_import] = ACTIONS(853),
    [anon_sym_enum] = ACTIONS(853),
    [anon_sym_public] = ACTIONS(853),
    [anon_sym_protected] = ACTIONS(853),
    [anon_sym_private] = ACTIONS(853),
    [anon_sym_abstract] = ACTIONS(853),
    [anon_sym_strictfp] = ACTIONS(853),
    [anon_sym_native] = ACTIONS(853),
    [anon_sym_transient] = ACTIONS(853),
    [anon_sym_volatile] = ACTIONS(853),
    [anon_sym_sealed] = ACTIONS(853),
    [anon_sym_non_DASHsealed] = ACTIONS(851),
    [anon_sym_record] = ACTIONS(853),
    [anon_sym_ATinterface] = ACTIONS(851),
    [anon_sym_interface] = ACTIONS(853),
    [anon_sym_byte] = ACTIONS(853),
    [anon_sym_short] = ACTIONS(853),
    [anon_sym_int] = ACTIONS(853),
    [anon_sym_long] = ACTIONS(853),
    [anon_sym_char] = ACTIONS(853),
    [anon_sym_float] = ACTIONS(853),
    [anon_sym_double] = ACTIONS(853),
    [sym_boolean_type] = ACTIONS(853),
    [sym_void_type] = ACTIONS(853),
    [sym_this] = ACTIONS(853),
    [sym_super] = ACTIONS(853),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [306] = {
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(857),
    [sym_decimal_integer_literal] = ACTIONS(857),
    [sym_hex_integer_literal] = ACTIONS(857),
    [sym_octal_integer_literal] = ACTIONS(857),
    [sym_binary_integer_literal] = ACTIONS(855),
    [sym_decimal_floating_point_literal] = ACTIONS(855),
    [sym_hex_floating_point_literal] = ACTIONS(857),
    [sym_true] = ACTIONS(857),
    [sym_false] = ACTIONS(857),
    [sym_character_literal] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [sym_null_literal] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_final] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(855),
    [anon_sym_DASH_DASH] = ACTIONS(855),
    [anon_sym_new] = ACTIONS(857),
    [anon_sym_class] = ACTIONS(857),
    [anon_sym_switch] = ACTIONS(857),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_default] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_assert] = ACTIONS(857),
    [anon_sym_do] = ACTIONS(857),
    [anon_sym_while] = ACTIONS(857),
    [anon_sym_break] = ACTIONS(857),
    [anon_sym_continue] = ACTIONS(857),
    [anon_sym_return] = ACTIONS(857),
    [anon_sym_yield] = ACTIONS(857),
    [anon_sym_synchronized] = ACTIONS(857),
    [anon_sym_throw] = ACTIONS(857),
    [anon_sym_try] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_for] = ACTIONS(857),
    [anon_sym_AT] = ACTIONS(857),
    [anon_sym_open] = ACTIONS(857),
    [anon_sym_module] = ACTIONS(857),
    [anon_sym_static] = ACTIONS(857),
    [anon_sym_with] = ACTIONS(857),
    [anon_sym_package] = ACTIONS(857),
    [anon_sym_import] = ACTIONS(857),
    [anon_sym_enum] = ACTIONS(857),
    [anon_sym_public] = ACTIONS(857),
    [anon_sym_protected] = ACTIONS(857),
    [anon_sym_private] = ACTIONS(857),
    [anon_sym_abstract] = ACTIONS(857),
    [anon_sym_strictfp] = ACTIONS(857),
    [anon_sym_native] = ACTIONS(857),
    [anon_sym_transient] = ACTIONS(857),
    [anon_sym_volatile] = ACTIONS(857),
    [anon_sym_sealed] = ACTIONS(857),
    [anon_sym_non_DASHsealed] = ACTIONS(855),
    [anon_sym_record] = ACTIONS(857),
    [anon_sym_ATinterface] = ACTIONS(855),
    [anon_sym_interface] = ACTIONS(857),
    [anon_sym_byte] = ACTIONS(857),
    [anon_sym_short] = ACTIONS(857),
    [anon_sym_int] = ACTIONS(857),
    [anon_sym_long] = ACTIONS(857),
    [anon_sym_char] = ACTIONS(857),
    [anon_sym_float] = ACTIONS(857),
    [anon_sym_double] = ACTIONS(857),
    [sym_boolean_type] = ACTIONS(857),
    [sym_void_type] = ACTIONS(857),
    [sym_this] = ACTIONS(857),
    [sym_super] = ACTIONS(857),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [307] = {
    [ts_builtin_sym_end] = ACTIONS(859),
    [sym_identifier] = ACTIONS(861),
    [sym_decimal_integer_literal] = ACTIONS(861),
    [sym_hex_integer_literal] = ACTIONS(861),
    [sym_octal_integer_literal] = ACTIONS(861),
    [sym_binary_integer_literal] = ACTIONS(859),
    [sym_decimal_floating_point_literal] = ACTIONS(859),
    [sym_hex_floating_point_literal] = ACTIONS(861),
    [sym_true] = ACTIONS(861),
    [sym_false] = ACTIONS(861),
    [sym_character_literal] = ACTIONS(859),
    [anon_sym_DQUOTE] = ACTIONS(861),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(859),
    [anon_sym_RBRACE] = ACTIONS(859),
    [sym_null_literal] = ACTIONS(861),
    [anon_sym_LPAREN] = ACTIONS(859),
    [anon_sym_LT] = ACTIONS(859),
    [anon_sym_PLUS] = ACTIONS(861),
    [anon_sym_DASH] = ACTIONS(861),
    [anon_sym_final] = ACTIONS(861),
    [anon_sym_BANG] = ACTIONS(859),
    [anon_sym_TILDE] = ACTIONS(859),
    [anon_sym_PLUS_PLUS] = ACTIONS(859),
    [anon_sym_DASH_DASH] = ACTIONS(859),
    [anon_sym_new] = ACTIONS(861),
    [anon_sym_class] = ACTIONS(861),
    [anon_sym_switch] = ACTIONS(861),
    [anon_sym_LBRACE] = ACTIONS(859),
    [anon_sym_case] = ACTIONS(861),
    [anon_sym_default] = ACTIONS(861),
    [anon_sym_SEMI] = ACTIONS(859),
    [anon_sym_assert] = ACTIONS(861),
    [anon_sym_do] = ACTIONS(861),
    [anon_sym_while] = ACTIONS(861),
    [anon_sym_break] = ACTIONS(861),
    [anon_sym_continue] = ACTIONS(861),
    [anon_sym_return] = ACTIONS(861),
    [anon_sym_yield] = ACTIONS(861),
    [anon_sym_synchronized] = ACTIONS(861),
    [anon_sym_throw] = ACTIONS(861),
    [anon_sym_try] = ACTIONS(861),
    [anon_sym_if] = ACTIONS(861),
    [anon_sym_else] = ACTIONS(861),
    [anon_sym_for] = ACTIONS(861),
    [anon_sym_AT] = ACTIONS(861),
    [anon_sym_open] = ACTIONS(861),
    [anon_sym_module] = ACTIONS(861),
    [anon_sym_static] = ACTIONS(861),
    [anon_sym_with] = ACTIONS(861),
    [anon_sym_package] = ACTIONS(861),
    [anon_sym_import] = ACTIONS(861),
    [anon_sym_enum] = ACTIONS(861),
    [anon_sym_public] = ACTIONS(861),
    [anon_sym_protected] = ACTIONS(861),
    [anon_sym_private] = ACTIONS(861),
    [anon_sym_abstract] = ACTIONS(861),
    [anon_sym_strictfp] = ACTIONS(861),
    [anon_sym_native] = ACTIONS(861),
    [anon_sym_transient] = ACTIONS(861),
    [anon_sym_volatile] = ACTIONS(861),
    [anon_sym_sealed] = ACTIONS(861),
    [anon_sym_non_DASHsealed] = ACTIONS(859),
    [anon_sym_record] = ACTIONS(861),
    [anon_sym_ATinterface] = ACTIONS(859),
    [anon_sym_interface] = ACTIONS(861),
    [anon_sym_byte] = ACTIONS(861),
    [anon_sym_short] = ACTIONS(861),
    [anon_sym_int] = ACTIONS(861),
    [anon_sym_long] = ACTIONS(861),
    [anon_sym_char] = ACTIONS(861),
    [anon_sym_float] = ACTIONS(861),
    [anon_sym_double] = ACTIONS(861),
    [sym_boolean_type] = ACTIONS(861),
    [sym_void_type] = ACTIONS(861),
    [sym_this] = ACTIONS(861),
    [sym_super] = ACTIONS(861),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [308] = {
    [ts_builtin_sym_end] = ACTIONS(863),
    [sym_identifier] = ACTIONS(865),
    [sym_decimal_integer_literal] = ACTIONS(865),
    [sym_hex_integer_literal] = ACTIONS(865),
    [sym_octal_integer_literal] = ACTIONS(865),
    [sym_binary_integer_literal] = ACTIONS(863),
    [sym_decimal_floating_point_literal] = ACTIONS(863),
    [sym_hex_floating_point_literal] = ACTIONS(865),
    [sym_true] = ACTIONS(865),
    [sym_false] = ACTIONS(865),
    [sym_character_literal] = ACTIONS(863),
    [anon_sym_DQUOTE] = ACTIONS(865),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(863),
    [anon_sym_RBRACE] = ACTIONS(863),
    [sym_null_literal] = ACTIONS(865),
    [anon_sym_LPAREN] = ACTIONS(863),
    [anon_sym_LT] = ACTIONS(863),
    [anon_sym_PLUS] = ACTIONS(865),
    [anon_sym_DASH] = ACTIONS(865),
    [anon_sym_final] = ACTIONS(865),
    [anon_sym_BANG] = ACTIONS(863),
    [anon_sym_TILDE] = ACTIONS(863),
    [anon_sym_PLUS_PLUS] = ACTIONS(863),
    [anon_sym_DASH_DASH] = ACTIONS(863),
    [anon_sym_new] = ACTIONS(865),
    [anon_sym_class] = ACTIONS(865),
    [anon_sym_switch] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(863),
    [anon_sym_case] = ACTIONS(865),
    [anon_sym_default] = ACTIONS(865),
    [anon_sym_SEMI] = ACTIONS(863),
    [anon_sym_assert] = ACTIONS(865),
    [anon_sym_do] = ACTIONS(865),
    [anon_sym_while] = ACTIONS(865),
    [anon_sym_break] = ACTIONS(865),
    [anon_sym_continue] = ACTIONS(865),
    [anon_sym_return] = ACTIONS(865),
    [anon_sym_yield] = ACTIONS(865),
    [anon_sym_synchronized] = ACTIONS(865),
    [anon_sym_throw] = ACTIONS(865),
    [anon_sym_try] = ACTIONS(865),
    [anon_sym_if] = ACTIONS(865),
    [anon_sym_else] = ACTIONS(865),
    [anon_sym_for] = ACTIONS(865),
    [anon_sym_AT] = ACTIONS(865),
    [anon_sym_open] = ACTIONS(865),
    [anon_sym_module] = ACTIONS(865),
    [anon_sym_static] = ACTIONS(865),
    [anon_sym_with] = ACTIONS(865),
    [anon_sym_package] = ACTIONS(865),
    [anon_sym_import] = ACTIONS(865),
    [anon_sym_enum] = ACTIONS(865),
    [anon_sym_public] = ACTIONS(865),
    [anon_sym_protected] = ACTIONS(865),
    [anon_sym_private] = ACTIONS(865),
    [anon_sym_abstract] = ACTIONS(865),
    [anon_sym_strictfp] = ACTIONS(865),
    [anon_sym_native] = ACTIONS(865),
    [anon_sym_transient] = ACTIONS(865),
    [anon_sym_volatile] = ACTIONS(865),
    [anon_sym_sealed] = ACTIONS(865),
    [anon_sym_non_DASHsealed] = ACTIONS(863),
    [anon_sym_record] = ACTIONS(865),
    [anon_sym_ATinterface] = ACTIONS(863),
    [anon_sym_interface] = ACTIONS(865),
    [anon_sym_byte] = ACTIONS(865),
    [anon_sym_short] = ACTIONS(865),
    [anon_sym_int] = ACTIONS(865),
    [anon_sym_long] = ACTIONS(865),
    [anon_sym_char] = ACTIONS(865),
    [anon_sym_float] = ACTIONS(865),
    [anon_sym_double] = ACTIONS(865),
    [sym_boolean_type] = ACTIONS(865),
    [sym_void_type] = ACTIONS(865),
    [sym_this] = ACTIONS(865),
    [sym_super] = ACTIONS(865),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [309] = {
    [ts_builtin_sym_end] = ACTIONS(867),
    [sym_identifier] = ACTIONS(869),
    [sym_decimal_integer_literal] = ACTIONS(869),
    [sym_hex_integer_literal] = ACTIONS(869),
    [sym_octal_integer_literal] = ACTIONS(869),
    [sym_binary_integer_literal] = ACTIONS(867),
    [sym_decimal_floating_point_literal] = ACTIONS(867),
    [sym_hex_floating_point_literal] = ACTIONS(869),
    [sym_true] = ACTIONS(869),
    [sym_false] = ACTIONS(869),
    [sym_character_literal] = ACTIONS(867),
    [anon_sym_DQUOTE] = ACTIONS(869),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(867),
    [anon_sym_RBRACE] = ACTIONS(867),
    [sym_null_literal] = ACTIONS(869),
    [anon_sym_LPAREN] = ACTIONS(867),
    [anon_sym_LT] = ACTIONS(867),
    [anon_sym_PLUS] = ACTIONS(869),
    [anon_sym_DASH] = ACTIONS(869),
    [anon_sym_final] = ACTIONS(869),
    [anon_sym_BANG] = ACTIONS(867),
    [anon_sym_TILDE] = ACTIONS(867),
    [anon_sym_PLUS_PLUS] = ACTIONS(867),
    [anon_sym_DASH_DASH] = ACTIONS(867),
    [anon_sym_new] = ACTIONS(869),
    [anon_sym_class] = ACTIONS(869),
    [anon_sym_switch] = ACTIONS(869),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_case] = ACTIONS(869),
    [anon_sym_default] = ACTIONS(869),
    [anon_sym_SEMI] = ACTIONS(867),
    [anon_sym_assert] = ACTIONS(869),
    [anon_sym_do] = ACTIONS(869),
    [anon_sym_while] = ACTIONS(869),
    [anon_sym_break] = ACTIONS(869),
    [anon_sym_continue] = ACTIONS(869),
    [anon_sym_return] = ACTIONS(869),
    [anon_sym_yield] = ACTIONS(869),
    [anon_sym_synchronized] = ACTIONS(869),
    [anon_sym_throw] = ACTIONS(869),
    [anon_sym_try] = ACTIONS(869),
    [anon_sym_if] = ACTIONS(869),
    [anon_sym_else] = ACTIONS(869),
    [anon_sym_for] = ACTIONS(869),
    [anon_sym_AT] = ACTIONS(869),
    [anon_sym_open] = ACTIONS(869),
    [anon_sym_module] = ACTIONS(869),
    [anon_sym_static] = ACTIONS(869),
    [anon_sym_with] = ACTIONS(869),
    [anon_sym_package] = ACTIONS(869),
    [anon_sym_import] = ACTIONS(869),
    [anon_sym_enum] = ACTIONS(869),
    [anon_sym_public] = ACTIONS(869),
    [anon_sym_protected] = ACTIONS(869),
    [anon_sym_private] = ACTIONS(869),
    [anon_sym_abstract] = ACTIONS(869),
    [anon_sym_strictfp] = ACTIONS(869),
    [anon_sym_native] = ACTIONS(869),
    [anon_sym_transient] = ACTIONS(869),
    [anon_sym_volatile] = ACTIONS(869),
    [anon_sym_sealed] = ACTIONS(869),
    [anon_sym_non_DASHsealed] = ACTIONS(867),
    [anon_sym_record] = ACTIONS(869),
    [anon_sym_ATinterface] = ACTIONS(867),
    [anon_sym_interface] = ACTIONS(869),
    [anon_sym_byte] = ACTIONS(869),
    [anon_sym_short] = ACTIONS(869),
    [anon_sym_int] = ACTIONS(869),
    [anon_sym_long] = ACTIONS(869),
    [anon_sym_char] = ACTIONS(869),
    [anon_sym_float] = ACTIONS(869),
    [anon_sym_double] = ACTIONS(869),
    [sym_boolean_type] = ACTIONS(869),
    [sym_void_type] = ACTIONS(869),
    [sym_this] = ACTIONS(869),
    [sym_super] = ACTIONS(869),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [310] = {
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(873),
    [sym_decimal_integer_literal] = ACTIONS(873),
    [sym_hex_integer_literal] = ACTIONS(873),
    [sym_octal_integer_literal] = ACTIONS(873),
    [sym_binary_integer_literal] = ACTIONS(871),
    [sym_decimal_floating_point_literal] = ACTIONS(871),
    [sym_hex_floating_point_literal] = ACTIONS(873),
    [sym_true] = ACTIONS(873),
    [sym_false] = ACTIONS(873),
    [sym_character_literal] = ACTIONS(871),
    [anon_sym_DQUOTE] = ACTIONS(873),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [sym_null_literal] = ACTIONS(873),
    [anon_sym_LPAREN] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(873),
    [anon_sym_DASH] = ACTIONS(873),
    [anon_sym_final] = ACTIONS(873),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_TILDE] = ACTIONS(871),
    [anon_sym_PLUS_PLUS] = ACTIONS(871),
    [anon_sym_DASH_DASH] = ACTIONS(871),
    [anon_sym_new] = ACTIONS(873),
    [anon_sym_class] = ACTIONS(873),
    [anon_sym_switch] = ACTIONS(873),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_case] = ACTIONS(873),
    [anon_sym_default] = ACTIONS(873),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_assert] = ACTIONS(873),
    [anon_sym_do] = ACTIONS(873),
    [anon_sym_while] = ACTIONS(873),
    [anon_sym_break] = ACTIONS(873),
    [anon_sym_continue] = ACTIONS(873),
    [anon_sym_return] = ACTIONS(873),
    [anon_sym_yield] = ACTIONS(873),
    [anon_sym_synchronized] = ACTIONS(873),
    [anon_sym_throw] = ACTIONS(873),
    [anon_sym_try] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(873),
    [anon_sym_else] = ACTIONS(873),
    [anon_sym_for] = ACTIONS(873),
    [anon_sym_AT] = ACTIONS(873),
    [anon_sym_open] = ACTIONS(873),
    [anon_sym_module] = ACTIONS(873),
    [anon_sym_static] = ACTIONS(873),
    [anon_sym_with] = ACTIONS(873),
    [anon_sym_package] = ACTIONS(873),
    [anon_sym_import] = ACTIONS(873),
    [anon_sym_enum] = ACTIONS(873),
    [anon_sym_public] = ACTIONS(873),
    [anon_sym_protected] = ACTIONS(873),
    [anon_sym_private] = ACTIONS(873),
    [anon_sym_abstract] = ACTIONS(873),
    [anon_sym_strictfp] = ACTIONS(873),
    [anon_sym_native] = ACTIONS(873),
    [anon_sym_transient] = ACTIONS(873),
    [anon_sym_volatile] = ACTIONS(873),
    [anon_sym_sealed] = ACTIONS(873),
    [anon_sym_non_DASHsealed] = ACTIONS(871),
    [anon_sym_record] = ACTIONS(873),
    [anon_sym_ATinterface] = ACTIONS(871),
    [anon_sym_interface] = ACTIONS(873),
    [anon_sym_byte] = ACTIONS(873),
    [anon_sym_short] = ACTIONS(873),
    [anon_sym_int] = ACTIONS(873),
    [anon_sym_long] = ACTIONS(873),
    [anon_sym_char] = ACTIONS(873),
    [anon_sym_float] = ACTIONS(873),
    [anon_sym_double] = ACTIONS(873),
    [sym_boolean_type] = ACTIONS(873),
    [sym_void_type] = ACTIONS(873),
    [sym_this] = ACTIONS(873),
    [sym_super] = ACTIONS(873),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [311] = {
    [ts_builtin_sym_end] = ACTIONS(875),
    [sym_identifier] = ACTIONS(877),
    [sym_decimal_integer_literal] = ACTIONS(877),
    [sym_hex_integer_literal] = ACTIONS(877),
    [sym_octal_integer_literal] = ACTIONS(877),
    [sym_binary_integer_literal] = ACTIONS(875),
    [sym_decimal_floating_point_literal] = ACTIONS(875),
    [sym_hex_floating_point_literal] = ACTIONS(877),
    [sym_true] = ACTIONS(877),
    [sym_false] = ACTIONS(877),
    [sym_character_literal] = ACTIONS(875),
    [anon_sym_DQUOTE] = ACTIONS(877),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(875),
    [anon_sym_RBRACE] = ACTIONS(875),
    [sym_null_literal] = ACTIONS(877),
    [anon_sym_LPAREN] = ACTIONS(875),
    [anon_sym_LT] = ACTIONS(875),
    [anon_sym_PLUS] = ACTIONS(877),
    [anon_sym_DASH] = ACTIONS(877),
    [anon_sym_final] = ACTIONS(877),
    [anon_sym_BANG] = ACTIONS(875),
    [anon_sym_TILDE] = ACTIONS(875),
    [anon_sym_PLUS_PLUS] = ACTIONS(875),
    [anon_sym_DASH_DASH] = ACTIONS(875),
    [anon_sym_new] = ACTIONS(877),
    [anon_sym_class] = ACTIONS(877),
    [anon_sym_switch] = ACTIONS(877),
    [anon_sym_LBRACE] = ACTIONS(875),
    [anon_sym_case] = ACTIONS(877),
    [anon_sym_default] = ACTIONS(877),
    [anon_sym_SEMI] = ACTIONS(875),
    [anon_sym_assert] = ACTIONS(877),
    [anon_sym_do] = ACTIONS(877),
    [anon_sym_while] = ACTIONS(877),
    [anon_sym_break] = ACTIONS(877),
    [anon_sym_continue] = ACTIONS(877),
    [anon_sym_return] = ACTIONS(877),
    [anon_sym_yield] = ACTIONS(877),
    [anon_sym_synchronized] = ACTIONS(877),
    [anon_sym_throw] = ACTIONS(877),
    [anon_sym_try] = ACTIONS(877),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_else] = ACTIONS(877),
    [anon_sym_for] = ACTIONS(877),
    [anon_sym_AT] = ACTIONS(877),
    [anon_sym_open] = ACTIONS(877),
    [anon_sym_module] = ACTIONS(877),
    [anon_sym_static] = ACTIONS(877),
    [anon_sym_with] = ACTIONS(877),
    [anon_sym_package] = ACTIONS(877),
    [anon_sym_import] = ACTIONS(877),
    [anon_sym_enum] = ACTIONS(877),
    [anon_sym_public] = ACTIONS(877),
    [anon_sym_protected] = ACTIONS(877),
    [anon_sym_private] = ACTIONS(877),
    [anon_sym_abstract] = ACTIONS(877),
    [anon_sym_strictfp] = ACTIONS(877),
    [anon_sym_native] = ACTIONS(877),
    [anon_sym_transient] = ACTIONS(877),
    [anon_sym_volatile] = ACTIONS(877),
    [anon_sym_sealed] = ACTIONS(877),
    [anon_sym_non_DASHsealed] = ACTIONS(875),
    [anon_sym_record] = ACTIONS(877),
    [anon_sym_ATinterface] = ACTIONS(875),
    [anon_sym_interface] = ACTIONS(877),
    [anon_sym_byte] = ACTIONS(877),
    [anon_sym_short] = ACTIONS(877),
    [anon_sym_int] = ACTIONS(877),
    [anon_sym_long] = ACTIONS(877),
    [anon_sym_char] = ACTIONS(877),
    [anon_sym_float] = ACTIONS(877),
    [anon_sym_double] = ACTIONS(877),
    [sym_boolean_type] = ACTIONS(877),
    [sym_void_type] = ACTIONS(877),
    [sym_this] = ACTIONS(877),
    [sym_super] = ACTIONS(877),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [312] = {
    [ts_builtin_sym_end] = ACTIONS(879),
    [sym_identifier] = ACTIONS(881),
    [sym_decimal_integer_literal] = ACTIONS(881),
    [sym_hex_integer_literal] = ACTIONS(881),
    [sym_octal_integer_literal] = ACTIONS(881),
    [sym_binary_integer_literal] = ACTIONS(879),
    [sym_decimal_floating_point_literal] = ACTIONS(879),
    [sym_hex_floating_point_literal] = ACTIONS(881),
    [sym_true] = ACTIONS(881),
    [sym_false] = ACTIONS(881),
    [sym_character_literal] = ACTIONS(879),
    [anon_sym_DQUOTE] = ACTIONS(881),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(879),
    [anon_sym_RBRACE] = ACTIONS(879),
    [sym_null_literal] = ACTIONS(881),
    [anon_sym_LPAREN] = ACTIONS(879),
    [anon_sym_LT] = ACTIONS(879),
    [anon_sym_PLUS] = ACTIONS(881),
    [anon_sym_DASH] = ACTIONS(881),
    [anon_sym_final] = ACTIONS(881),
    [anon_sym_BANG] = ACTIONS(879),
    [anon_sym_TILDE] = ACTIONS(879),
    [anon_sym_PLUS_PLUS] = ACTIONS(879),
    [anon_sym_DASH_DASH] = ACTIONS(879),
    [anon_sym_new] = ACTIONS(881),
    [anon_sym_class] = ACTIONS(881),
    [anon_sym_switch] = ACTIONS(881),
    [anon_sym_LBRACE] = ACTIONS(879),
    [anon_sym_case] = ACTIONS(881),
    [anon_sym_default] = ACTIONS(881),
    [anon_sym_SEMI] = ACTIONS(879),
    [anon_sym_assert] = ACTIONS(881),
    [anon_sym_do] = ACTIONS(881),
    [anon_sym_while] = ACTIONS(881),
    [anon_sym_break] = ACTIONS(881),
    [anon_sym_continue] = ACTIONS(881),
    [anon_sym_return] = ACTIONS(881),
    [anon_sym_yield] = ACTIONS(881),
    [anon_sym_synchronized] = ACTIONS(881),
    [anon_sym_throw] = ACTIONS(881),
    [anon_sym_try] = ACTIONS(881),
    [anon_sym_if] = ACTIONS(881),
    [anon_sym_else] = ACTIONS(881),
    [anon_sym_for] = ACTIONS(881),
    [anon_sym_AT] = ACTIONS(881),
    [anon_sym_open] = ACTIONS(881),
    [anon_sym_module] = ACTIONS(881),
    [anon_sym_static] = ACTIONS(881),
    [anon_sym_with] = ACTIONS(881),
    [anon_sym_package] = ACTIONS(881),
    [anon_sym_import] = ACTIONS(881),
    [anon_sym_enum] = ACTIONS(881),
    [anon_sym_public] = ACTIONS(881),
    [anon_sym_protected] = ACTIONS(881),
    [anon_sym_private] = ACTIONS(881),
    [anon_sym_abstract] = ACTIONS(881),
    [anon_sym_strictfp] = ACTIONS(881),
    [anon_sym_native] = ACTIONS(881),
    [anon_sym_transient] = ACTIONS(881),
    [anon_sym_volatile] = ACTIONS(881),
    [anon_sym_sealed] = ACTIONS(881),
    [anon_sym_non_DASHsealed] = ACTIONS(879),
    [anon_sym_record] = ACTIONS(881),
    [anon_sym_ATinterface] = ACTIONS(879),
    [anon_sym_interface] = ACTIONS(881),
    [anon_sym_byte] = ACTIONS(881),
    [anon_sym_short] = ACTIONS(881),
    [anon_sym_int] = ACTIONS(881),
    [anon_sym_long] = ACTIONS(881),
    [anon_sym_char] = ACTIONS(881),
    [anon_sym_float] = ACTIONS(881),
    [anon_sym_double] = ACTIONS(881),
    [sym_boolean_type] = ACTIONS(881),
    [sym_void_type] = ACTIONS(881),
    [sym_this] = ACTIONS(881),
    [sym_super] = ACTIONS(881),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [313] = {
    [ts_builtin_sym_end] = ACTIONS(883),
    [sym_identifier] = ACTIONS(885),
    [sym_decimal_integer_literal] = ACTIONS(885),
    [sym_hex_integer_literal] = ACTIONS(885),
    [sym_octal_integer_literal] = ACTIONS(885),
    [sym_binary_integer_literal] = ACTIONS(883),
    [sym_decimal_floating_point_literal] = ACTIONS(883),
    [sym_hex_floating_point_literal] = ACTIONS(885),
    [sym_true] = ACTIONS(885),
    [sym_false] = ACTIONS(885),
    [sym_character_literal] = ACTIONS(883),
    [anon_sym_DQUOTE] = ACTIONS(885),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(883),
    [anon_sym_RBRACE] = ACTIONS(883),
    [sym_null_literal] = ACTIONS(885),
    [anon_sym_LPAREN] = ACTIONS(883),
    [anon_sym_LT] = ACTIONS(883),
    [anon_sym_PLUS] = ACTIONS(885),
    [anon_sym_DASH] = ACTIONS(885),
    [anon_sym_final] = ACTIONS(885),
    [anon_sym_BANG] = ACTIONS(883),
    [anon_sym_TILDE] = ACTIONS(883),
    [anon_sym_PLUS_PLUS] = ACTIONS(883),
    [anon_sym_DASH_DASH] = ACTIONS(883),
    [anon_sym_new] = ACTIONS(885),
    [anon_sym_class] = ACTIONS(885),
    [anon_sym_switch] = ACTIONS(885),
    [anon_sym_LBRACE] = ACTIONS(883),
    [anon_sym_case] = ACTIONS(885),
    [anon_sym_default] = ACTIONS(885),
    [anon_sym_SEMI] = ACTIONS(883),
    [anon_sym_assert] = ACTIONS(885),
    [anon_sym_do] = ACTIONS(885),
    [anon_sym_while] = ACTIONS(885),
    [anon_sym_break] = ACTIONS(885),
    [anon_sym_continue] = ACTIONS(885),
    [anon_sym_return] = ACTIONS(885),
    [anon_sym_yield] = ACTIONS(885),
    [anon_sym_synchronized] = ACTIONS(885),
    [anon_sym_throw] = ACTIONS(885),
    [anon_sym_try] = ACTIONS(885),
    [anon_sym_if] = ACTIONS(885),
    [anon_sym_else] = ACTIONS(885),
    [anon_sym_for] = ACTIONS(885),
    [anon_sym_AT] = ACTIONS(885),
    [anon_sym_open] = ACTIONS(885),
    [anon_sym_module] = ACTIONS(885),
    [anon_sym_static] = ACTIONS(885),
    [anon_sym_with] = ACTIONS(885),
    [anon_sym_package] = ACTIONS(885),
    [anon_sym_import] = ACTIONS(885),
    [anon_sym_enum] = ACTIONS(885),
    [anon_sym_public] = ACTIONS(885),
    [anon_sym_protected] = ACTIONS(885),
    [anon_sym_private] = ACTIONS(885),
    [anon_sym_abstract] = ACTIONS(885),
    [anon_sym_strictfp] = ACTIONS(885),
    [anon_sym_native] = ACTIONS(885),
    [anon_sym_transient] = ACTIONS(885),
    [anon_sym_volatile] = ACTIONS(885),
    [anon_sym_sealed] = ACTIONS(885),
    [anon_sym_non_DASHsealed] = ACTIONS(883),
    [anon_sym_record] = ACTIONS(885),
    [anon_sym_ATinterface] = ACTIONS(883),
    [anon_sym_interface] = ACTIONS(885),
    [anon_sym_byte] = ACTIONS(885),
    [anon_sym_short] = ACTIONS(885),
    [anon_sym_int] = ACTIONS(885),
    [anon_sym_long] = ACTIONS(885),
    [anon_sym_char] = ACTIONS(885),
    [anon_sym_float] = ACTIONS(885),
    [anon_sym_double] = ACTIONS(885),
    [sym_boolean_type] = ACTIONS(885),
    [sym_void_type] = ACTIONS(885),
    [sym_this] = ACTIONS(885),
    [sym_super] = ACTIONS(885),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [314] = {
    [ts_builtin_sym_end] = ACTIONS(887),
    [sym_identifier] = ACTIONS(889),
    [sym_decimal_integer_literal] = ACTIONS(889),
    [sym_hex_integer_literal] = ACTIONS(889),
    [sym_octal_integer_literal] = ACTIONS(889),
    [sym_binary_integer_literal] = ACTIONS(887),
    [sym_decimal_floating_point_literal] = ACTIONS(887),
    [sym_hex_floating_point_literal] = ACTIONS(889),
    [sym_true] = ACTIONS(889),
    [sym_false] = ACTIONS(889),
    [sym_character_literal] = ACTIONS(887),
    [anon_sym_DQUOTE] = ACTIONS(889),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(887),
    [anon_sym_RBRACE] = ACTIONS(887),
    [sym_null_literal] = ACTIONS(889),
    [anon_sym_LPAREN] = ACTIONS(887),
    [anon_sym_LT] = ACTIONS(887),
    [anon_sym_PLUS] = ACTIONS(889),
    [anon_sym_DASH] = ACTIONS(889),
    [anon_sym_final] = ACTIONS(889),
    [anon_sym_BANG] = ACTIONS(887),
    [anon_sym_TILDE] = ACTIONS(887),
    [anon_sym_PLUS_PLUS] = ACTIONS(887),
    [anon_sym_DASH_DASH] = ACTIONS(887),
    [anon_sym_new] = ACTIONS(889),
    [anon_sym_class] = ACTIONS(889),
    [anon_sym_switch] = ACTIONS(889),
    [anon_sym_LBRACE] = ACTIONS(887),
    [anon_sym_case] = ACTIONS(889),
    [anon_sym_default] = ACTIONS(889),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym_assert] = ACTIONS(889),
    [anon_sym_do] = ACTIONS(889),
    [anon_sym_while] = ACTIONS(889),
    [anon_sym_break] = ACTIONS(889),
    [anon_sym_continue] = ACTIONS(889),
    [anon_sym_return] = ACTIONS(889),
    [anon_sym_yield] = ACTIONS(889),
    [anon_sym_synchronized] = ACTIONS(889),
    [anon_sym_throw] = ACTIONS(889),
    [anon_sym_try] = ACTIONS(889),
    [anon_sym_if] = ACTIONS(889),
    [anon_sym_else] = ACTIONS(889),
    [anon_sym_for] = ACTIONS(889),
    [anon_sym_AT] = ACTIONS(889),
    [anon_sym_open] = ACTIONS(889),
    [anon_sym_module] = ACTIONS(889),
    [anon_sym_static] = ACTIONS(889),
    [anon_sym_with] = ACTIONS(889),
    [anon_sym_package] = ACTIONS(889),
    [anon_sym_import] = ACTIONS(889),
    [anon_sym_enum] = ACTIONS(889),
    [anon_sym_public] = ACTIONS(889),
    [anon_sym_protected] = ACTIONS(889),
    [anon_sym_private] = ACTIONS(889),
    [anon_sym_abstract] = ACTIONS(889),
    [anon_sym_strictfp] = ACTIONS(889),
    [anon_sym_native] = ACTIONS(889),
    [anon_sym_transient] = ACTIONS(889),
    [anon_sym_volatile] = ACTIONS(889),
    [anon_sym_sealed] = ACTIONS(889),
    [anon_sym_non_DASHsealed] = ACTIONS(887),
    [anon_sym_record] = ACTIONS(889),
    [anon_sym_ATinterface] = ACTIONS(887),
    [anon_sym_interface] = ACTIONS(889),
    [anon_sym_byte] = ACTIONS(889),
    [anon_sym_short] = ACTIONS(889),
    [anon_sym_int] = ACTIONS(889),
    [anon_sym_long] = ACTIONS(889),
    [anon_sym_char] = ACTIONS(889),
    [anon_sym_float] = ACTIONS(889),
    [anon_sym_double] = ACTIONS(889),
    [sym_boolean_type] = ACTIONS(889),
    [sym_void_type] = ACTIONS(889),
    [sym_this] = ACTIONS(889),
    [sym_super] = ACTIONS(889),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [315] = {
    [ts_builtin_sym_end] = ACTIONS(891),
    [sym_identifier] = ACTIONS(893),
    [sym_decimal_integer_literal] = ACTIONS(893),
    [sym_hex_integer_literal] = ACTIONS(893),
    [sym_octal_integer_literal] = ACTIONS(893),
    [sym_binary_integer_literal] = ACTIONS(891),
    [sym_decimal_floating_point_literal] = ACTIONS(891),
    [sym_hex_floating_point_literal] = ACTIONS(893),
    [sym_true] = ACTIONS(893),
    [sym_false] = ACTIONS(893),
    [sym_character_literal] = ACTIONS(891),
    [anon_sym_DQUOTE] = ACTIONS(893),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(891),
    [anon_sym_RBRACE] = ACTIONS(891),
    [sym_null_literal] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(891),
    [anon_sym_LT] = ACTIONS(891),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(893),
    [anon_sym_final] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(891),
    [anon_sym_TILDE] = ACTIONS(891),
    [anon_sym_PLUS_PLUS] = ACTIONS(891),
    [anon_sym_DASH_DASH] = ACTIONS(891),
    [anon_sym_new] = ACTIONS(893),
    [anon_sym_class] = ACTIONS(893),
    [anon_sym_switch] = ACTIONS(893),
    [anon_sym_LBRACE] = ACTIONS(891),
    [anon_sym_case] = ACTIONS(893),
    [anon_sym_default] = ACTIONS(893),
    [anon_sym_SEMI] = ACTIONS(891),
    [anon_sym_assert] = ACTIONS(893),
    [anon_sym_do] = ACTIONS(893),
    [anon_sym_while] = ACTIONS(893),
    [anon_sym_break] = ACTIONS(893),
    [anon_sym_continue] = ACTIONS(893),
    [anon_sym_return] = ACTIONS(893),
    [anon_sym_yield] = ACTIONS(893),
    [anon_sym_synchronized] = ACTIONS(893),
    [anon_sym_throw] = ACTIONS(893),
    [anon_sym_try] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(893),
    [anon_sym_for] = ACTIONS(893),
    [anon_sym_AT] = ACTIONS(893),
    [anon_sym_open] = ACTIONS(893),
    [anon_sym_module] = ACTIONS(893),
    [anon_sym_static] = ACTIONS(893),
    [anon_sym_with] = ACTIONS(893),
    [anon_sym_package] = ACTIONS(893),
    [anon_sym_import] = ACTIONS(893),
    [anon_sym_enum] = ACTIONS(893),
    [anon_sym_public] = ACTIONS(893),
    [anon_sym_protected] = ACTIONS(893),
    [anon_sym_private] = ACTIONS(893),
    [anon_sym_abstract] = ACTIONS(893),
    [anon_sym_strictfp] = ACTIONS(893),
    [anon_sym_native] = ACTIONS(893),
    [anon_sym_transient] = ACTIONS(893),
    [anon_sym_volatile] = ACTIONS(893),
    [anon_sym_sealed] = ACTIONS(893),
    [anon_sym_non_DASHsealed] = ACTIONS(891),
    [anon_sym_record] = ACTIONS(893),
    [anon_sym_ATinterface] = ACTIONS(891),
    [anon_sym_interface] = ACTIONS(893),
    [anon_sym_byte] = ACTIONS(893),
    [anon_sym_short] = ACTIONS(893),
    [anon_sym_int] = ACTIONS(893),
    [anon_sym_long] = ACTIONS(893),
    [anon_sym_char] = ACTIONS(893),
    [anon_sym_float] = ACTIONS(893),
    [anon_sym_double] = ACTIONS(893),
    [sym_boolean_type] = ACTIONS(893),
    [sym_void_type] = ACTIONS(893),
    [sym_this] = ACTIONS(893),
    [sym_super] = ACTIONS(893),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [316] = {
    [ts_builtin_sym_end] = ACTIONS(895),
    [sym_identifier] = ACTIONS(897),
    [sym_decimal_integer_literal] = ACTIONS(897),
    [sym_hex_integer_literal] = ACTIONS(897),
    [sym_octal_integer_literal] = ACTIONS(897),
    [sym_binary_integer_literal] = ACTIONS(895),
    [sym_decimal_floating_point_literal] = ACTIONS(895),
    [sym_hex_floating_point_literal] = ACTIONS(897),
    [sym_true] = ACTIONS(897),
    [sym_false] = ACTIONS(897),
    [sym_character_literal] = ACTIONS(895),
    [anon_sym_DQUOTE] = ACTIONS(897),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(895),
    [anon_sym_RBRACE] = ACTIONS(895),
    [sym_null_literal] = ACTIONS(897),
    [anon_sym_LPAREN] = ACTIONS(895),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_PLUS] = ACTIONS(897),
    [anon_sym_DASH] = ACTIONS(897),
    [anon_sym_final] = ACTIONS(897),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_PLUS_PLUS] = ACTIONS(895),
    [anon_sym_DASH_DASH] = ACTIONS(895),
    [anon_sym_new] = ACTIONS(897),
    [anon_sym_class] = ACTIONS(897),
    [anon_sym_switch] = ACTIONS(897),
    [anon_sym_LBRACE] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(897),
    [anon_sym_default] = ACTIONS(897),
    [anon_sym_SEMI] = ACTIONS(895),
    [anon_sym_assert] = ACTIONS(897),
    [anon_sym_do] = ACTIONS(897),
    [anon_sym_while] = ACTIONS(897),
    [anon_sym_break] = ACTIONS(897),
    [anon_sym_continue] = ACTIONS(897),
    [anon_sym_return] = ACTIONS(897),
    [anon_sym_yield] = ACTIONS(897),
    [anon_sym_synchronized] = ACTIONS(897),
    [anon_sym_throw] = ACTIONS(897),
    [anon_sym_try] = ACTIONS(897),
    [anon_sym_if] = ACTIONS(897),
    [anon_sym_else] = ACTIONS(897),
    [anon_sym_for] = ACTIONS(897),
    [anon_sym_AT] = ACTIONS(897),
    [anon_sym_open] = ACTIONS(897),
    [anon_sym_module] = ACTIONS(897),
    [anon_sym_static] = ACTIONS(897),
    [anon_sym_with] = ACTIONS(897),
    [anon_sym_package] = ACTIONS(897),
    [anon_sym_import] = ACTIONS(897),
    [anon_sym_enum] = ACTIONS(897),
    [anon_sym_public] = ACTIONS(897),
    [anon_sym_protected] = ACTIONS(897),
    [anon_sym_private] = ACTIONS(897),
    [anon_sym_abstract] = ACTIONS(897),
    [anon_sym_strictfp] = ACTIONS(897),
    [anon_sym_native] = ACTIONS(897),
    [anon_sym_transient] = ACTIONS(897),
    [anon_sym_volatile] = ACTIONS(897),
    [anon_sym_sealed] = ACTIONS(897),
    [anon_sym_non_DASHsealed] = ACTIONS(895),
    [anon_sym_record] = ACTIONS(897),
    [anon_sym_ATinterface] = ACTIONS(895),
    [anon_sym_interface] = ACTIONS(897),
    [anon_sym_byte] = ACTIONS(897),
    [anon_sym_short] = ACTIONS(897),
    [anon_sym_int] = ACTIONS(897),
    [anon_sym_long] = ACTIONS(897),
    [anon_sym_char] = ACTIONS(897),
    [anon_sym_float] = ACTIONS(897),
    [anon_sym_double] = ACTIONS(897),
    [sym_boolean_type] = ACTIONS(897),
    [sym_void_type] = ACTIONS(897),
    [sym_this] = ACTIONS(897),
    [sym_super] = ACTIONS(897),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [317] = {
    [ts_builtin_sym_end] = ACTIONS(899),
    [sym_identifier] = ACTIONS(901),
    [sym_decimal_integer_literal] = ACTIONS(901),
    [sym_hex_integer_literal] = ACTIONS(901),
    [sym_octal_integer_literal] = ACTIONS(901),
    [sym_binary_integer_literal] = ACTIONS(899),
    [sym_decimal_floating_point_literal] = ACTIONS(899),
    [sym_hex_floating_point_literal] = ACTIONS(901),
    [sym_true] = ACTIONS(901),
    [sym_false] = ACTIONS(901),
    [sym_character_literal] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(899),
    [anon_sym_RBRACE] = ACTIONS(899),
    [sym_null_literal] = ACTIONS(901),
    [anon_sym_LPAREN] = ACTIONS(899),
    [anon_sym_LT] = ACTIONS(899),
    [anon_sym_PLUS] = ACTIONS(901),
    [anon_sym_DASH] = ACTIONS(901),
    [anon_sym_final] = ACTIONS(901),
    [anon_sym_BANG] = ACTIONS(899),
    [anon_sym_TILDE] = ACTIONS(899),
    [anon_sym_PLUS_PLUS] = ACTIONS(899),
    [anon_sym_DASH_DASH] = ACTIONS(899),
    [anon_sym_new] = ACTIONS(901),
    [anon_sym_class] = ACTIONS(901),
    [anon_sym_switch] = ACTIONS(901),
    [anon_sym_LBRACE] = ACTIONS(899),
    [anon_sym_case] = ACTIONS(901),
    [anon_sym_default] = ACTIONS(901),
    [anon_sym_SEMI] = ACTIONS(899),
    [anon_sym_assert] = ACTIONS(901),
    [anon_sym_do] = ACTIONS(901),
    [anon_sym_while] = ACTIONS(901),
    [anon_sym_break] = ACTIONS(901),
    [anon_sym_continue] = ACTIONS(901),
    [anon_sym_return] = ACTIONS(901),
    [anon_sym_yield] = ACTIONS(901),
    [anon_sym_synchronized] = ACTIONS(901),
    [anon_sym_throw] = ACTIONS(901),
    [anon_sym_try] = ACTIONS(901),
    [anon_sym_if] = ACTIONS(901),
    [anon_sym_else] = ACTIONS(901),
    [anon_sym_for] = ACTIONS(901),
    [anon_sym_AT] = ACTIONS(901),
    [anon_sym_open] = ACTIONS(901),
    [anon_sym_module] = ACTIONS(901),
    [anon_sym_static] = ACTIONS(901),
    [anon_sym_with] = ACTIONS(901),
    [anon_sym_package] = ACTIONS(901),
    [anon_sym_import] = ACTIONS(901),
    [anon_sym_enum] = ACTIONS(901),
    [anon_sym_public] = ACTIONS(901),
    [anon_sym_protected] = ACTIONS(901),
    [anon_sym_private] = ACTIONS(901),
    [anon_sym_abstract] = ACTIONS(901),
    [anon_sym_strictfp] = ACTIONS(901),
    [anon_sym_native] = ACTIONS(901),
    [anon_sym_transient] = ACTIONS(901),
    [anon_sym_volatile] = ACTIONS(901),
    [anon_sym_sealed] = ACTIONS(901),
    [anon_sym_non_DASHsealed] = ACTIONS(899),
    [anon_sym_record] = ACTIONS(901),
    [anon_sym_ATinterface] = ACTIONS(899),
    [anon_sym_interface] = ACTIONS(901),
    [anon_sym_byte] = ACTIONS(901),
    [anon_sym_short] = ACTIONS(901),
    [anon_sym_int] = ACTIONS(901),
    [anon_sym_long] = ACTIONS(901),
    [anon_sym_char] = ACTIONS(901),
    [anon_sym_float] = ACTIONS(901),
    [anon_sym_double] = ACTIONS(901),
    [sym_boolean_type] = ACTIONS(901),
    [sym_void_type] = ACTIONS(901),
    [sym_this] = ACTIONS(901),
    [sym_super] = ACTIONS(901),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [318] = {
    [ts_builtin_sym_end] = ACTIONS(903),
    [sym_identifier] = ACTIONS(905),
    [sym_decimal_integer_literal] = ACTIONS(905),
    [sym_hex_integer_literal] = ACTIONS(905),
    [sym_octal_integer_literal] = ACTIONS(905),
    [sym_binary_integer_literal] = ACTIONS(903),
    [sym_decimal_floating_point_literal] = ACTIONS(903),
    [sym_hex_floating_point_literal] = ACTIONS(905),
    [sym_true] = ACTIONS(905),
    [sym_false] = ACTIONS(905),
    [sym_character_literal] = ACTIONS(903),
    [anon_sym_DQUOTE] = ACTIONS(905),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(903),
    [anon_sym_RBRACE] = ACTIONS(903),
    [sym_null_literal] = ACTIONS(905),
    [anon_sym_LPAREN] = ACTIONS(903),
    [anon_sym_LT] = ACTIONS(903),
    [anon_sym_PLUS] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(905),
    [anon_sym_final] = ACTIONS(905),
    [anon_sym_BANG] = ACTIONS(903),
    [anon_sym_TILDE] = ACTIONS(903),
    [anon_sym_PLUS_PLUS] = ACTIONS(903),
    [anon_sym_DASH_DASH] = ACTIONS(903),
    [anon_sym_new] = ACTIONS(905),
    [anon_sym_class] = ACTIONS(905),
    [anon_sym_switch] = ACTIONS(905),
    [anon_sym_LBRACE] = ACTIONS(903),
    [anon_sym_case] = ACTIONS(905),
    [anon_sym_default] = ACTIONS(905),
    [anon_sym_SEMI] = ACTIONS(903),
    [anon_sym_assert] = ACTIONS(905),
    [anon_sym_do] = ACTIONS(905),
    [anon_sym_while] = ACTIONS(905),
    [anon_sym_break] = ACTIONS(905),
    [anon_sym_continue] = ACTIONS(905),
    [anon_sym_return] = ACTIONS(905),
    [anon_sym_yield] = ACTIONS(905),
    [anon_sym_synchronized] = ACTIONS(905),
    [anon_sym_throw] = ACTIONS(905),
    [anon_sym_try] = ACTIONS(905),
    [anon_sym_if] = ACTIONS(905),
    [anon_sym_else] = ACTIONS(905),
    [anon_sym_for] = ACTIONS(905),
    [anon_sym_AT] = ACTIONS(905),
    [anon_sym_open] = ACTIONS(905),
    [anon_sym_module] = ACTIONS(905),
    [anon_sym_static] = ACTIONS(905),
    [anon_sym_with] = ACTIONS(905),
    [anon_sym_package] = ACTIONS(905),
    [anon_sym_import] = ACTIONS(905),
    [anon_sym_enum] = ACTIONS(905),
    [anon_sym_public] = ACTIONS(905),
    [anon_sym_protected] = ACTIONS(905),
    [anon_sym_private] = ACTIONS(905),
    [anon_sym_abstract] = ACTIONS(905),
    [anon_sym_strictfp] = ACTIONS(905),
    [anon_sym_native] = ACTIONS(905),
    [anon_sym_transient] = ACTIONS(905),
    [anon_sym_volatile] = ACTIONS(905),
    [anon_sym_sealed] = ACTIONS(905),
    [anon_sym_non_DASHsealed] = ACTIONS(903),
    [anon_sym_record] = ACTIONS(905),
    [anon_sym_ATinterface] = ACTIONS(903),
    [anon_sym_interface] = ACTIONS(905),
    [anon_sym_byte] = ACTIONS(905),
    [anon_sym_short] = ACTIONS(905),
    [anon_sym_int] = ACTIONS(905),
    [anon_sym_long] = ACTIONS(905),
    [anon_sym_char] = ACTIONS(905),
    [anon_sym_float] = ACTIONS(905),
    [anon_sym_double] = ACTIONS(905),
    [sym_boolean_type] = ACTIONS(905),
    [sym_void_type] = ACTIONS(905),
    [sym_this] = ACTIONS(905),
    [sym_super] = ACTIONS(905),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [319] = {
    [ts_builtin_sym_end] = ACTIONS(907),
    [sym_identifier] = ACTIONS(909),
    [sym_decimal_integer_literal] = ACTIONS(909),
    [sym_hex_integer_literal] = ACTIONS(909),
    [sym_octal_integer_literal] = ACTIONS(909),
    [sym_binary_integer_literal] = ACTIONS(907),
    [sym_decimal_floating_point_literal] = ACTIONS(907),
    [sym_hex_floating_point_literal] = ACTIONS(909),
    [sym_true] = ACTIONS(909),
    [sym_false] = ACTIONS(909),
    [sym_character_literal] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(909),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(907),
    [anon_sym_RBRACE] = ACTIONS(907),
    [sym_null_literal] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(907),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(909),
    [anon_sym_final] = ACTIONS(909),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(907),
    [anon_sym_DASH_DASH] = ACTIONS(907),
    [anon_sym_new] = ACTIONS(909),
    [anon_sym_class] = ACTIONS(909),
    [anon_sym_switch] = ACTIONS(909),
    [anon_sym_LBRACE] = ACTIONS(907),
    [anon_sym_case] = ACTIONS(909),
    [anon_sym_default] = ACTIONS(909),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_assert] = ACTIONS(909),
    [anon_sym_do] = ACTIONS(909),
    [anon_sym_while] = ACTIONS(909),
    [anon_sym_break] = ACTIONS(909),
    [anon_sym_continue] = ACTIONS(909),
    [anon_sym_return] = ACTIONS(909),
    [anon_sym_yield] = ACTIONS(909),
    [anon_sym_synchronized] = ACTIONS(909),
    [anon_sym_throw] = ACTIONS(909),
    [anon_sym_try] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(909),
    [anon_sym_for] = ACTIONS(909),
    [anon_sym_AT] = ACTIONS(909),
    [anon_sym_open] = ACTIONS(909),
    [anon_sym_module] = ACTIONS(909),
    [anon_sym_static] = ACTIONS(909),
    [anon_sym_with] = ACTIONS(909),
    [anon_sym_package] = ACTIONS(909),
    [anon_sym_import] = ACTIONS(909),
    [anon_sym_enum] = ACTIONS(909),
    [anon_sym_public] = ACTIONS(909),
    [anon_sym_protected] = ACTIONS(909),
    [anon_sym_private] = ACTIONS(909),
    [anon_sym_abstract] = ACTIONS(909),
    [anon_sym_strictfp] = ACTIONS(909),
    [anon_sym_native] = ACTIONS(909),
    [anon_sym_transient] = ACTIONS(909),
    [anon_sym_volatile] = ACTIONS(909),
    [anon_sym_sealed] = ACTIONS(909),
    [anon_sym_non_DASHsealed] = ACTIONS(907),
    [anon_sym_record] = ACTIONS(909),
    [anon_sym_ATinterface] = ACTIONS(907),
    [anon_sym_interface] = ACTIONS(909),
    [anon_sym_byte] = ACTIONS(909),
    [anon_sym_short] = ACTIONS(909),
    [anon_sym_int] = ACTIONS(909),
    [anon_sym_long] = ACTIONS(909),
    [anon_sym_char] = ACTIONS(909),
    [anon_sym_float] = ACTIONS(909),
    [anon_sym_double] = ACTIONS(909),
    [sym_boolean_type] = ACTIONS(909),
    [sym_void_type] = ACTIONS(909),
    [sym_this] = ACTIONS(909),
    [sym_super] = ACTIONS(909),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [320] = {
    [ts_builtin_sym_end] = ACTIONS(911),
    [sym_identifier] = ACTIONS(913),
    [sym_decimal_integer_literal] = ACTIONS(913),
    [sym_hex_integer_literal] = ACTIONS(913),
    [sym_octal_integer_literal] = ACTIONS(913),
    [sym_binary_integer_literal] = ACTIONS(911),
    [sym_decimal_floating_point_literal] = ACTIONS(911),
    [sym_hex_floating_point_literal] = ACTIONS(913),
    [sym_true] = ACTIONS(913),
    [sym_false] = ACTIONS(913),
    [sym_character_literal] = ACTIONS(911),
    [anon_sym_DQUOTE] = ACTIONS(913),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(911),
    [anon_sym_RBRACE] = ACTIONS(911),
    [sym_null_literal] = ACTIONS(913),
    [anon_sym_LPAREN] = ACTIONS(911),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_PLUS] = ACTIONS(913),
    [anon_sym_DASH] = ACTIONS(913),
    [anon_sym_final] = ACTIONS(913),
    [anon_sym_BANG] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_PLUS_PLUS] = ACTIONS(911),
    [anon_sym_DASH_DASH] = ACTIONS(911),
    [anon_sym_new] = ACTIONS(913),
    [anon_sym_class] = ACTIONS(913),
    [anon_sym_switch] = ACTIONS(913),
    [anon_sym_LBRACE] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(913),
    [anon_sym_default] = ACTIONS(913),
    [anon_sym_SEMI] = ACTIONS(911),
    [anon_sym_assert] = ACTIONS(913),
    [anon_sym_do] = ACTIONS(913),
    [anon_sym_while] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(913),
    [anon_sym_continue] = ACTIONS(913),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_yield] = ACTIONS(913),
    [anon_sym_synchronized] = ACTIONS(913),
    [anon_sym_throw] = ACTIONS(913),
    [anon_sym_try] = ACTIONS(913),
    [anon_sym_if] = ACTIONS(913),
    [anon_sym_else] = ACTIONS(913),
    [anon_sym_for] = ACTIONS(913),
    [anon_sym_AT] = ACTIONS(913),
    [anon_sym_open] = ACTIONS(913),
    [anon_sym_module] = ACTIONS(913),
    [anon_sym_static] = ACTIONS(913),
    [anon_sym_with] = ACTIONS(913),
    [anon_sym_package] = ACTIONS(913),
    [anon_sym_import] = ACTIONS(913),
    [anon_sym_enum] = ACTIONS(913),
    [anon_sym_public] = ACTIONS(913),
    [anon_sym_protected] = ACTIONS(913),
    [anon_sym_private] = ACTIONS(913),
    [anon_sym_abstract] = ACTIONS(913),
    [anon_sym_strictfp] = ACTIONS(913),
    [anon_sym_native] = ACTIONS(913),
    [anon_sym_transient] = ACTIONS(913),
    [anon_sym_volatile] = ACTIONS(913),
    [anon_sym_sealed] = ACTIONS(913),
    [anon_sym_non_DASHsealed] = ACTIONS(911),
    [anon_sym_record] = ACTIONS(913),
    [anon_sym_ATinterface] = ACTIONS(911),
    [anon_sym_interface] = ACTIONS(913),
    [anon_sym_byte] = ACTIONS(913),
    [anon_sym_short] = ACTIONS(913),
    [anon_sym_int] = ACTIONS(913),
    [anon_sym_long] = ACTIONS(913),
    [anon_sym_char] = ACTIONS(913),
    [anon_sym_float] = ACTIONS(913),
    [anon_sym_double] = ACTIONS(913),
    [sym_boolean_type] = ACTIONS(913),
    [sym_void_type] = ACTIONS(913),
    [sym_this] = ACTIONS(913),
    [sym_super] = ACTIONS(913),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [321] = {
    [ts_builtin_sym_end] = ACTIONS(915),
    [sym_identifier] = ACTIONS(917),
    [sym_decimal_integer_literal] = ACTIONS(917),
    [sym_hex_integer_literal] = ACTIONS(917),
    [sym_octal_integer_literal] = ACTIONS(917),
    [sym_binary_integer_literal] = ACTIONS(915),
    [sym_decimal_floating_point_literal] = ACTIONS(915),
    [sym_hex_floating_point_literal] = ACTIONS(917),
    [sym_true] = ACTIONS(917),
    [sym_false] = ACTIONS(917),
    [sym_character_literal] = ACTIONS(915),
    [anon_sym_DQUOTE] = ACTIONS(917),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(915),
    [anon_sym_RBRACE] = ACTIONS(915),
    [sym_null_literal] = ACTIONS(917),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_LT] = ACTIONS(915),
    [anon_sym_PLUS] = ACTIONS(917),
    [anon_sym_DASH] = ACTIONS(917),
    [anon_sym_final] = ACTIONS(917),
    [anon_sym_BANG] = ACTIONS(915),
    [anon_sym_TILDE] = ACTIONS(915),
    [anon_sym_PLUS_PLUS] = ACTIONS(915),
    [anon_sym_DASH_DASH] = ACTIONS(915),
    [anon_sym_new] = ACTIONS(917),
    [anon_sym_class] = ACTIONS(917),
    [anon_sym_switch] = ACTIONS(917),
    [anon_sym_LBRACE] = ACTIONS(915),
    [anon_sym_case] = ACTIONS(917),
    [anon_sym_default] = ACTIONS(917),
    [anon_sym_SEMI] = ACTIONS(915),
    [anon_sym_assert] = ACTIONS(917),
    [anon_sym_do] = ACTIONS(917),
    [anon_sym_while] = ACTIONS(917),
    [anon_sym_break] = ACTIONS(917),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_return] = ACTIONS(917),
    [anon_sym_yield] = ACTIONS(917),
    [anon_sym_synchronized] = ACTIONS(917),
    [anon_sym_throw] = ACTIONS(917),
    [anon_sym_try] = ACTIONS(917),
    [anon_sym_if] = ACTIONS(917),
    [anon_sym_else] = ACTIONS(917),
    [anon_sym_for] = ACTIONS(917),
    [anon_sym_AT] = ACTIONS(917),
    [anon_sym_open] = ACTIONS(917),
    [anon_sym_module] = ACTIONS(917),
    [anon_sym_static] = ACTIONS(917),
    [anon_sym_with] = ACTIONS(917),
    [anon_sym_package] = ACTIONS(917),
    [anon_sym_import] = ACTIONS(917),
    [anon_sym_enum] = ACTIONS(917),
    [anon_sym_public] = ACTIONS(917),
    [anon_sym_protected] = ACTIONS(917),
    [anon_sym_private] = ACTIONS(917),
    [anon_sym_abstract] = ACTIONS(917),
    [anon_sym_strictfp] = ACTIONS(917),
    [anon_sym_native] = ACTIONS(917),
    [anon_sym_transient] = ACTIONS(917),
    [anon_sym_volatile] = ACTIONS(917),
    [anon_sym_sealed] = ACTIONS(917),
    [anon_sym_non_DASHsealed] = ACTIONS(915),
    [anon_sym_record] = ACTIONS(917),
    [anon_sym_ATinterface] = ACTIONS(915),
    [anon_sym_interface] = ACTIONS(917),
    [anon_sym_byte] = ACTIONS(917),
    [anon_sym_short] = ACTIONS(917),
    [anon_sym_int] = ACTIONS(917),
    [anon_sym_long] = ACTIONS(917),
    [anon_sym_char] = ACTIONS(917),
    [anon_sym_float] = ACTIONS(917),
    [anon_sym_double] = ACTIONS(917),
    [sym_boolean_type] = ACTIONS(917),
    [sym_void_type] = ACTIONS(917),
    [sym_this] = ACTIONS(917),
    [sym_super] = ACTIONS(917),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [322] = {
    [ts_builtin_sym_end] = ACTIONS(919),
    [sym_identifier] = ACTIONS(921),
    [sym_decimal_integer_literal] = ACTIONS(921),
    [sym_hex_integer_literal] = ACTIONS(921),
    [sym_octal_integer_literal] = ACTIONS(921),
    [sym_binary_integer_literal] = ACTIONS(919),
    [sym_decimal_floating_point_literal] = ACTIONS(919),
    [sym_hex_floating_point_literal] = ACTIONS(921),
    [sym_true] = ACTIONS(921),
    [sym_false] = ACTIONS(921),
    [sym_character_literal] = ACTIONS(919),
    [anon_sym_DQUOTE] = ACTIONS(921),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(919),
    [anon_sym_RBRACE] = ACTIONS(919),
    [sym_null_literal] = ACTIONS(921),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_LT] = ACTIONS(919),
    [anon_sym_PLUS] = ACTIONS(921),
    [anon_sym_DASH] = ACTIONS(921),
    [anon_sym_final] = ACTIONS(921),
    [anon_sym_BANG] = ACTIONS(919),
    [anon_sym_TILDE] = ACTIONS(919),
    [anon_sym_PLUS_PLUS] = ACTIONS(919),
    [anon_sym_DASH_DASH] = ACTIONS(919),
    [anon_sym_new] = ACTIONS(921),
    [anon_sym_class] = ACTIONS(921),
    [anon_sym_switch] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(919),
    [anon_sym_case] = ACTIONS(921),
    [anon_sym_default] = ACTIONS(921),
    [anon_sym_SEMI] = ACTIONS(919),
    [anon_sym_assert] = ACTIONS(921),
    [anon_sym_do] = ACTIONS(921),
    [anon_sym_while] = ACTIONS(921),
    [anon_sym_break] = ACTIONS(921),
    [anon_sym_continue] = ACTIONS(921),
    [anon_sym_return] = ACTIONS(921),
    [anon_sym_yield] = ACTIONS(921),
    [anon_sym_synchronized] = ACTIONS(921),
    [anon_sym_throw] = ACTIONS(921),
    [anon_sym_try] = ACTIONS(921),
    [anon_sym_if] = ACTIONS(921),
    [anon_sym_else] = ACTIONS(921),
    [anon_sym_for] = ACTIONS(921),
    [anon_sym_AT] = ACTIONS(921),
    [anon_sym_open] = ACTIONS(921),
    [anon_sym_module] = ACTIONS(921),
    [anon_sym_static] = ACTIONS(921),
    [anon_sym_with] = ACTIONS(921),
    [anon_sym_package] = ACTIONS(921),
    [anon_sym_import] = ACTIONS(921),
    [anon_sym_enum] = ACTIONS(921),
    [anon_sym_public] = ACTIONS(921),
    [anon_sym_protected] = ACTIONS(921),
    [anon_sym_private] = ACTIONS(921),
    [anon_sym_abstract] = ACTIONS(921),
    [anon_sym_strictfp] = ACTIONS(921),
    [anon_sym_native] = ACTIONS(921),
    [anon_sym_transient] = ACTIONS(921),
    [anon_sym_volatile] = ACTIONS(921),
    [anon_sym_sealed] = ACTIONS(921),
    [anon_sym_non_DASHsealed] = ACTIONS(919),
    [anon_sym_record] = ACTIONS(921),
    [anon_sym_ATinterface] = ACTIONS(919),
    [anon_sym_interface] = ACTIONS(921),
    [anon_sym_byte] = ACTIONS(921),
    [anon_sym_short] = ACTIONS(921),
    [anon_sym_int] = ACTIONS(921),
    [anon_sym_long] = ACTIONS(921),
    [anon_sym_char] = ACTIONS(921),
    [anon_sym_float] = ACTIONS(921),
    [anon_sym_double] = ACTIONS(921),
    [sym_boolean_type] = ACTIONS(921),
    [sym_void_type] = ACTIONS(921),
    [sym_this] = ACTIONS(921),
    [sym_super] = ACTIONS(921),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [323] = {
    [ts_builtin_sym_end] = ACTIONS(923),
    [sym_identifier] = ACTIONS(925),
    [sym_decimal_integer_literal] = ACTIONS(925),
    [sym_hex_integer_literal] = ACTIONS(925),
    [sym_octal_integer_literal] = ACTIONS(925),
    [sym_binary_integer_literal] = ACTIONS(923),
    [sym_decimal_floating_point_literal] = ACTIONS(923),
    [sym_hex_floating_point_literal] = ACTIONS(925),
    [sym_true] = ACTIONS(925),
    [sym_false] = ACTIONS(925),
    [sym_character_literal] = ACTIONS(923),
    [anon_sym_DQUOTE] = ACTIONS(925),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [sym_null_literal] = ACTIONS(925),
    [anon_sym_LPAREN] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(925),
    [anon_sym_DASH] = ACTIONS(925),
    [anon_sym_final] = ACTIONS(925),
    [anon_sym_BANG] = ACTIONS(923),
    [anon_sym_TILDE] = ACTIONS(923),
    [anon_sym_PLUS_PLUS] = ACTIONS(923),
    [anon_sym_DASH_DASH] = ACTIONS(923),
    [anon_sym_new] = ACTIONS(925),
    [anon_sym_class] = ACTIONS(925),
    [anon_sym_switch] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_case] = ACTIONS(925),
    [anon_sym_default] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(923),
    [anon_sym_assert] = ACTIONS(925),
    [anon_sym_do] = ACTIONS(925),
    [anon_sym_while] = ACTIONS(925),
    [anon_sym_break] = ACTIONS(925),
    [anon_sym_continue] = ACTIONS(925),
    [anon_sym_return] = ACTIONS(925),
    [anon_sym_yield] = ACTIONS(925),
    [anon_sym_synchronized] = ACTIONS(925),
    [anon_sym_throw] = ACTIONS(925),
    [anon_sym_try] = ACTIONS(925),
    [anon_sym_if] = ACTIONS(925),
    [anon_sym_else] = ACTIONS(925),
    [anon_sym_for] = ACTIONS(925),
    [anon_sym_AT] = ACTIONS(925),
    [anon_sym_open] = ACTIONS(925),
    [anon_sym_module] = ACTIONS(925),
    [anon_sym_static] = ACTIONS(925),
    [anon_sym_with] = ACTIONS(925),
    [anon_sym_package] = ACTIONS(925),
    [anon_sym_import] = ACTIONS(925),
    [anon_sym_enum] = ACTIONS(925),
    [anon_sym_public] = ACTIONS(925),
    [anon_sym_protected] = ACTIONS(925),
    [anon_sym_private] = ACTIONS(925),
    [anon_sym_abstract] = ACTIONS(925),
    [anon_sym_strictfp] = ACTIONS(925),
    [anon_sym_native] = ACTIONS(925),
    [anon_sym_transient] = ACTIONS(925),
    [anon_sym_volatile] = ACTIONS(925),
    [anon_sym_sealed] = ACTIONS(925),
    [anon_sym_non_DASHsealed] = ACTIONS(923),
    [anon_sym_record] = ACTIONS(925),
    [anon_sym_ATinterface] = ACTIONS(923),
    [anon_sym_interface] = ACTIONS(925),
    [anon_sym_byte] = ACTIONS(925),
    [anon_sym_short] = ACTIONS(925),
    [anon_sym_int] = ACTIONS(925),
    [anon_sym_long] = ACTIONS(925),
    [anon_sym_char] = ACTIONS(925),
    [anon_sym_float] = ACTIONS(925),
    [anon_sym_double] = ACTIONS(925),
    [sym_boolean_type] = ACTIONS(925),
    [sym_void_type] = ACTIONS(925),
    [sym_this] = ACTIONS(925),
    [sym_super] = ACTIONS(925),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [324] = {
    [ts_builtin_sym_end] = ACTIONS(927),
    [sym_identifier] = ACTIONS(929),
    [sym_decimal_integer_literal] = ACTIONS(929),
    [sym_hex_integer_literal] = ACTIONS(929),
    [sym_octal_integer_literal] = ACTIONS(929),
    [sym_binary_integer_literal] = ACTIONS(927),
    [sym_decimal_floating_point_literal] = ACTIONS(927),
    [sym_hex_floating_point_literal] = ACTIONS(929),
    [sym_true] = ACTIONS(929),
    [sym_false] = ACTIONS(929),
    [sym_character_literal] = ACTIONS(927),
    [anon_sym_DQUOTE] = ACTIONS(929),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [sym_null_literal] = ACTIONS(929),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(927),
    [anon_sym_PLUS] = ACTIONS(929),
    [anon_sym_DASH] = ACTIONS(929),
    [anon_sym_final] = ACTIONS(929),
    [anon_sym_BANG] = ACTIONS(927),
    [anon_sym_TILDE] = ACTIONS(927),
    [anon_sym_PLUS_PLUS] = ACTIONS(927),
    [anon_sym_DASH_DASH] = ACTIONS(927),
    [anon_sym_new] = ACTIONS(929),
    [anon_sym_class] = ACTIONS(929),
    [anon_sym_switch] = ACTIONS(929),
    [anon_sym_LBRACE] = ACTIONS(927),
    [anon_sym_case] = ACTIONS(929),
    [anon_sym_default] = ACTIONS(929),
    [anon_sym_SEMI] = ACTIONS(927),
    [anon_sym_assert] = ACTIONS(929),
    [anon_sym_do] = ACTIONS(929),
    [anon_sym_while] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(929),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_return] = ACTIONS(929),
    [anon_sym_yield] = ACTIONS(929),
    [anon_sym_synchronized] = ACTIONS(929),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_try] = ACTIONS(929),
    [anon_sym_if] = ACTIONS(929),
    [anon_sym_else] = ACTIONS(929),
    [anon_sym_for] = ACTIONS(929),
    [anon_sym_AT] = ACTIONS(929),
    [anon_sym_open] = ACTIONS(929),
    [anon_sym_module] = ACTIONS(929),
    [anon_sym_static] = ACTIONS(929),
    [anon_sym_with] = ACTIONS(929),
    [anon_sym_package] = ACTIONS(929),
    [anon_sym_import] = ACTIONS(929),
    [anon_sym_enum] = ACTIONS(929),
    [anon_sym_public] = ACTIONS(929),
    [anon_sym_protected] = ACTIONS(929),
    [anon_sym_private] = ACTIONS(929),
    [anon_sym_abstract] = ACTIONS(929),
    [anon_sym_strictfp] = ACTIONS(929),
    [anon_sym_native] = ACTIONS(929),
    [anon_sym_transient] = ACTIONS(929),
    [anon_sym_volatile] = ACTIONS(929),
    [anon_sym_sealed] = ACTIONS(929),
    [anon_sym_non_DASHsealed] = ACTIONS(927),
    [anon_sym_record] = ACTIONS(929),
    [anon_sym_ATinterface] = ACTIONS(927),
    [anon_sym_interface] = ACTIONS(929),
    [anon_sym_byte] = ACTIONS(929),
    [anon_sym_short] = ACTIONS(929),
    [anon_sym_int] = ACTIONS(929),
    [anon_sym_long] = ACTIONS(929),
    [anon_sym_char] = ACTIONS(929),
    [anon_sym_float] = ACTIONS(929),
    [anon_sym_double] = ACTIONS(929),
    [sym_boolean_type] = ACTIONS(929),
    [sym_void_type] = ACTIONS(929),
    [sym_this] = ACTIONS(929),
    [sym_super] = ACTIONS(929),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [325] = {
    [ts_builtin_sym_end] = ACTIONS(931),
    [sym_identifier] = ACTIONS(933),
    [sym_decimal_integer_literal] = ACTIONS(933),
    [sym_hex_integer_literal] = ACTIONS(933),
    [sym_octal_integer_literal] = ACTIONS(933),
    [sym_binary_integer_literal] = ACTIONS(931),
    [sym_decimal_floating_point_literal] = ACTIONS(931),
    [sym_hex_floating_point_literal] = ACTIONS(933),
    [sym_true] = ACTIONS(933),
    [sym_false] = ACTIONS(933),
    [sym_character_literal] = ACTIONS(931),
    [anon_sym_DQUOTE] = ACTIONS(933),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(931),
    [anon_sym_RBRACE] = ACTIONS(931),
    [sym_null_literal] = ACTIONS(933),
    [anon_sym_LPAREN] = ACTIONS(931),
    [anon_sym_LT] = ACTIONS(931),
    [anon_sym_PLUS] = ACTIONS(933),
    [anon_sym_DASH] = ACTIONS(933),
    [anon_sym_final] = ACTIONS(933),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_PLUS_PLUS] = ACTIONS(931),
    [anon_sym_DASH_DASH] = ACTIONS(931),
    [anon_sym_new] = ACTIONS(933),
    [anon_sym_class] = ACTIONS(933),
    [anon_sym_switch] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(931),
    [anon_sym_case] = ACTIONS(933),
    [anon_sym_default] = ACTIONS(933),
    [anon_sym_SEMI] = ACTIONS(931),
    [anon_sym_assert] = ACTIONS(933),
    [anon_sym_do] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_break] = ACTIONS(933),
    [anon_sym_continue] = ACTIONS(933),
    [anon_sym_return] = ACTIONS(933),
    [anon_sym_yield] = ACTIONS(933),
    [anon_sym_synchronized] = ACTIONS(933),
    [anon_sym_throw] = ACTIONS(933),
    [anon_sym_try] = ACTIONS(933),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_else] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(933),
    [anon_sym_AT] = ACTIONS(933),
    [anon_sym_open] = ACTIONS(933),
    [anon_sym_module] = ACTIONS(933),
    [anon_sym_static] = ACTIONS(933),
    [anon_sym_with] = ACTIONS(933),
    [anon_sym_package] = ACTIONS(933),
    [anon_sym_import] = ACTIONS(933),
    [anon_sym_enum] = ACTIONS(933),
    [anon_sym_public] = ACTIONS(933),
    [anon_sym_protected] = ACTIONS(933),
    [anon_sym_private] = ACTIONS(933),
    [anon_sym_abstract] = ACTIONS(933),
    [anon_sym_strictfp] = ACTIONS(933),
    [anon_sym_native] = ACTIONS(933),
    [anon_sym_transient] = ACTIONS(933),
    [anon_sym_volatile] = ACTIONS(933),
    [anon_sym_sealed] = ACTIONS(933),
    [anon_sym_non_DASHsealed] = ACTIONS(931),
    [anon_sym_record] = ACTIONS(933),
    [anon_sym_ATinterface] = ACTIONS(931),
    [anon_sym_interface] = ACTIONS(933),
    [anon_sym_byte] = ACTIONS(933),
    [anon_sym_short] = ACTIONS(933),
    [anon_sym_int] = ACTIONS(933),
    [anon_sym_long] = ACTIONS(933),
    [anon_sym_char] = ACTIONS(933),
    [anon_sym_float] = ACTIONS(933),
    [anon_sym_double] = ACTIONS(933),
    [sym_boolean_type] = ACTIONS(933),
    [sym_void_type] = ACTIONS(933),
    [sym_this] = ACTIONS(933),
    [sym_super] = ACTIONS(933),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [326] = {
    [ts_builtin_sym_end] = ACTIONS(935),
    [sym_identifier] = ACTIONS(937),
    [sym_decimal_integer_literal] = ACTIONS(937),
    [sym_hex_integer_literal] = ACTIONS(937),
    [sym_octal_integer_literal] = ACTIONS(937),
    [sym_binary_integer_literal] = ACTIONS(935),
    [sym_decimal_floating_point_literal] = ACTIONS(935),
    [sym_hex_floating_point_literal] = ACTIONS(937),
    [sym_true] = ACTIONS(937),
    [sym_false] = ACTIONS(937),
    [sym_character_literal] = ACTIONS(935),
    [anon_sym_DQUOTE] = ACTIONS(937),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(935),
    [sym_null_literal] = ACTIONS(937),
    [anon_sym_LPAREN] = ACTIONS(935),
    [anon_sym_LT] = ACTIONS(935),
    [anon_sym_PLUS] = ACTIONS(937),
    [anon_sym_DASH] = ACTIONS(937),
    [anon_sym_final] = ACTIONS(937),
    [anon_sym_BANG] = ACTIONS(935),
    [anon_sym_TILDE] = ACTIONS(935),
    [anon_sym_PLUS_PLUS] = ACTIONS(935),
    [anon_sym_DASH_DASH] = ACTIONS(935),
    [anon_sym_new] = ACTIONS(937),
    [anon_sym_class] = ACTIONS(937),
    [anon_sym_switch] = ACTIONS(937),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_case] = ACTIONS(937),
    [anon_sym_default] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(935),
    [anon_sym_assert] = ACTIONS(937),
    [anon_sym_do] = ACTIONS(937),
    [anon_sym_while] = ACTIONS(937),
    [anon_sym_break] = ACTIONS(937),
    [anon_sym_continue] = ACTIONS(937),
    [anon_sym_return] = ACTIONS(937),
    [anon_sym_yield] = ACTIONS(937),
    [anon_sym_synchronized] = ACTIONS(937),
    [anon_sym_throw] = ACTIONS(937),
    [anon_sym_try] = ACTIONS(937),
    [anon_sym_if] = ACTIONS(937),
    [anon_sym_else] = ACTIONS(937),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_AT] = ACTIONS(937),
    [anon_sym_open] = ACTIONS(937),
    [anon_sym_module] = ACTIONS(937),
    [anon_sym_static] = ACTIONS(937),
    [anon_sym_with] = ACTIONS(937),
    [anon_sym_package] = ACTIONS(937),
    [anon_sym_import] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(937),
    [anon_sym_public] = ACTIONS(937),
    [anon_sym_protected] = ACTIONS(937),
    [anon_sym_private] = ACTIONS(937),
    [anon_sym_abstract] = ACTIONS(937),
    [anon_sym_strictfp] = ACTIONS(937),
    [anon_sym_native] = ACTIONS(937),
    [anon_sym_transient] = ACTIONS(937),
    [anon_sym_volatile] = ACTIONS(937),
    [anon_sym_sealed] = ACTIONS(937),
    [anon_sym_non_DASHsealed] = ACTIONS(935),
    [anon_sym_record] = ACTIONS(937),
    [anon_sym_ATinterface] = ACTIONS(935),
    [anon_sym_interface] = ACTIONS(937),
    [anon_sym_byte] = ACTIONS(937),
    [anon_sym_short] = ACTIONS(937),
    [anon_sym_int] = ACTIONS(937),
    [anon_sym_long] = ACTIONS(937),
    [anon_sym_char] = ACTIONS(937),
    [anon_sym_float] = ACTIONS(937),
    [anon_sym_double] = ACTIONS(937),
    [sym_boolean_type] = ACTIONS(937),
    [sym_void_type] = ACTIONS(937),
    [sym_this] = ACTIONS(937),
    [sym_super] = ACTIONS(937),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [327] = {
    [ts_builtin_sym_end] = ACTIONS(939),
    [sym_identifier] = ACTIONS(941),
    [sym_decimal_integer_literal] = ACTIONS(941),
    [sym_hex_integer_literal] = ACTIONS(941),
    [sym_octal_integer_literal] = ACTIONS(941),
    [sym_binary_integer_literal] = ACTIONS(939),
    [sym_decimal_floating_point_literal] = ACTIONS(939),
    [sym_hex_floating_point_literal] = ACTIONS(941),
    [sym_true] = ACTIONS(941),
    [sym_false] = ACTIONS(941),
    [sym_character_literal] = ACTIONS(939),
    [anon_sym_DQUOTE] = ACTIONS(941),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(939),
    [anon_sym_RBRACE] = ACTIONS(939),
    [sym_null_literal] = ACTIONS(941),
    [anon_sym_LPAREN] = ACTIONS(939),
    [anon_sym_LT] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(941),
    [anon_sym_DASH] = ACTIONS(941),
    [anon_sym_final] = ACTIONS(941),
    [anon_sym_BANG] = ACTIONS(939),
    [anon_sym_TILDE] = ACTIONS(939),
    [anon_sym_PLUS_PLUS] = ACTIONS(939),
    [anon_sym_DASH_DASH] = ACTIONS(939),
    [anon_sym_new] = ACTIONS(941),
    [anon_sym_class] = ACTIONS(941),
    [anon_sym_switch] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(939),
    [anon_sym_case] = ACTIONS(941),
    [anon_sym_default] = ACTIONS(941),
    [anon_sym_SEMI] = ACTIONS(939),
    [anon_sym_assert] = ACTIONS(941),
    [anon_sym_do] = ACTIONS(941),
    [anon_sym_while] = ACTIONS(941),
    [anon_sym_break] = ACTIONS(941),
    [anon_sym_continue] = ACTIONS(941),
    [anon_sym_return] = ACTIONS(941),
    [anon_sym_yield] = ACTIONS(941),
    [anon_sym_synchronized] = ACTIONS(941),
    [anon_sym_throw] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_if] = ACTIONS(941),
    [anon_sym_else] = ACTIONS(941),
    [anon_sym_for] = ACTIONS(941),
    [anon_sym_AT] = ACTIONS(941),
    [anon_sym_open] = ACTIONS(941),
    [anon_sym_module] = ACTIONS(941),
    [anon_sym_static] = ACTIONS(941),
    [anon_sym_with] = ACTIONS(941),
    [anon_sym_package] = ACTIONS(941),
    [anon_sym_import] = ACTIONS(941),
    [anon_sym_enum] = ACTIONS(941),
    [anon_sym_public] = ACTIONS(941),
    [anon_sym_protected] = ACTIONS(941),
    [anon_sym_private] = ACTIONS(941),
    [anon_sym_abstract] = ACTIONS(941),
    [anon_sym_strictfp] = ACTIONS(941),
    [anon_sym_native] = ACTIONS(941),
    [anon_sym_transient] = ACTIONS(941),
    [anon_sym_volatile] = ACTIONS(941),
    [anon_sym_sealed] = ACTIONS(941),
    [anon_sym_non_DASHsealed] = ACTIONS(939),
    [anon_sym_record] = ACTIONS(941),
    [anon_sym_ATinterface] = ACTIONS(939),
    [anon_sym_interface] = ACTIONS(941),
    [anon_sym_byte] = ACTIONS(941),
    [anon_sym_short] = ACTIONS(941),
    [anon_sym_int] = ACTIONS(941),
    [anon_sym_long] = ACTIONS(941),
    [anon_sym_char] = ACTIONS(941),
    [anon_sym_float] = ACTIONS(941),
    [anon_sym_double] = ACTIONS(941),
    [sym_boolean_type] = ACTIONS(941),
    [sym_void_type] = ACTIONS(941),
    [sym_this] = ACTIONS(941),
    [sym_super] = ACTIONS(941),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [328] = {
    [ts_builtin_sym_end] = ACTIONS(943),
    [sym_identifier] = ACTIONS(945),
    [sym_decimal_integer_literal] = ACTIONS(945),
    [sym_hex_integer_literal] = ACTIONS(945),
    [sym_octal_integer_literal] = ACTIONS(945),
    [sym_binary_integer_literal] = ACTIONS(943),
    [sym_decimal_floating_point_literal] = ACTIONS(943),
    [sym_hex_floating_point_literal] = ACTIONS(945),
    [sym_true] = ACTIONS(945),
    [sym_false] = ACTIONS(945),
    [sym_character_literal] = ACTIONS(943),
    [anon_sym_DQUOTE] = ACTIONS(945),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(943),
    [anon_sym_RBRACE] = ACTIONS(943),
    [sym_null_literal] = ACTIONS(945),
    [anon_sym_LPAREN] = ACTIONS(943),
    [anon_sym_LT] = ACTIONS(943),
    [anon_sym_PLUS] = ACTIONS(945),
    [anon_sym_DASH] = ACTIONS(945),
    [anon_sym_final] = ACTIONS(945),
    [anon_sym_BANG] = ACTIONS(943),
    [anon_sym_TILDE] = ACTIONS(943),
    [anon_sym_PLUS_PLUS] = ACTIONS(943),
    [anon_sym_DASH_DASH] = ACTIONS(943),
    [anon_sym_new] = ACTIONS(945),
    [anon_sym_class] = ACTIONS(945),
    [anon_sym_switch] = ACTIONS(945),
    [anon_sym_LBRACE] = ACTIONS(943),
    [anon_sym_case] = ACTIONS(945),
    [anon_sym_default] = ACTIONS(945),
    [anon_sym_SEMI] = ACTIONS(943),
    [anon_sym_assert] = ACTIONS(945),
    [anon_sym_do] = ACTIONS(945),
    [anon_sym_while] = ACTIONS(945),
    [anon_sym_break] = ACTIONS(945),
    [anon_sym_continue] = ACTIONS(945),
    [anon_sym_return] = ACTIONS(945),
    [anon_sym_yield] = ACTIONS(945),
    [anon_sym_synchronized] = ACTIONS(945),
    [anon_sym_throw] = ACTIONS(945),
    [anon_sym_try] = ACTIONS(945),
    [anon_sym_if] = ACTIONS(945),
    [anon_sym_else] = ACTIONS(945),
    [anon_sym_for] = ACTIONS(945),
    [anon_sym_AT] = ACTIONS(945),
    [anon_sym_open] = ACTIONS(945),
    [anon_sym_module] = ACTIONS(945),
    [anon_sym_static] = ACTIONS(945),
    [anon_sym_with] = ACTIONS(945),
    [anon_sym_package] = ACTIONS(945),
    [anon_sym_import] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(945),
    [anon_sym_public] = ACTIONS(945),
    [anon_sym_protected] = ACTIONS(945),
    [anon_sym_private] = ACTIONS(945),
    [anon_sym_abstract] = ACTIONS(945),
    [anon_sym_strictfp] = ACTIONS(945),
    [anon_sym_native] = ACTIONS(945),
    [anon_sym_transient] = ACTIONS(945),
    [anon_sym_volatile] = ACTIONS(945),
    [anon_sym_sealed] = ACTIONS(945),
    [anon_sym_non_DASHsealed] = ACTIONS(943),
    [anon_sym_record] = ACTIONS(945),
    [anon_sym_ATinterface] = ACTIONS(943),
    [anon_sym_interface] = ACTIONS(945),
    [anon_sym_byte] = ACTIONS(945),
    [anon_sym_short] = ACTIONS(945),
    [anon_sym_int] = ACTIONS(945),
    [anon_sym_long] = ACTIONS(945),
    [anon_sym_char] = ACTIONS(945),
    [anon_sym_float] = ACTIONS(945),
    [anon_sym_double] = ACTIONS(945),
    [sym_boolean_type] = ACTIONS(945),
    [sym_void_type] = ACTIONS(945),
    [sym_this] = ACTIONS(945),
    [sym_super] = ACTIONS(945),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [329] = {
    [ts_builtin_sym_end] = ACTIONS(947),
    [sym_identifier] = ACTIONS(949),
    [sym_decimal_integer_literal] = ACTIONS(949),
    [sym_hex_integer_literal] = ACTIONS(949),
    [sym_octal_integer_literal] = ACTIONS(949),
    [sym_binary_integer_literal] = ACTIONS(947),
    [sym_decimal_floating_point_literal] = ACTIONS(947),
    [sym_hex_floating_point_literal] = ACTIONS(949),
    [sym_true] = ACTIONS(949),
    [sym_false] = ACTIONS(949),
    [sym_character_literal] = ACTIONS(947),
    [anon_sym_DQUOTE] = ACTIONS(949),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(947),
    [anon_sym_RBRACE] = ACTIONS(947),
    [sym_null_literal] = ACTIONS(949),
    [anon_sym_LPAREN] = ACTIONS(947),
    [anon_sym_LT] = ACTIONS(947),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_final] = ACTIONS(949),
    [anon_sym_BANG] = ACTIONS(947),
    [anon_sym_TILDE] = ACTIONS(947),
    [anon_sym_PLUS_PLUS] = ACTIONS(947),
    [anon_sym_DASH_DASH] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(949),
    [anon_sym_class] = ACTIONS(949),
    [anon_sym_switch] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(947),
    [anon_sym_case] = ACTIONS(949),
    [anon_sym_default] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(947),
    [anon_sym_assert] = ACTIONS(949),
    [anon_sym_do] = ACTIONS(949),
    [anon_sym_while] = ACTIONS(949),
    [anon_sym_break] = ACTIONS(949),
    [anon_sym_continue] = ACTIONS(949),
    [anon_sym_return] = ACTIONS(949),
    [anon_sym_yield] = ACTIONS(949),
    [anon_sym_synchronized] = ACTIONS(949),
    [anon_sym_throw] = ACTIONS(949),
    [anon_sym_try] = ACTIONS(949),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_else] = ACTIONS(949),
    [anon_sym_for] = ACTIONS(949),
    [anon_sym_AT] = ACTIONS(949),
    [anon_sym_open] = ACTIONS(949),
    [anon_sym_module] = ACTIONS(949),
    [anon_sym_static] = ACTIONS(949),
    [anon_sym_with] = ACTIONS(949),
    [anon_sym_package] = ACTIONS(949),
    [anon_sym_import] = ACTIONS(949),
    [anon_sym_enum] = ACTIONS(949),
    [anon_sym_public] = ACTIONS(949),
    [anon_sym_protected] = ACTIONS(949),
    [anon_sym_private] = ACTIONS(949),
    [anon_sym_abstract] = ACTIONS(949),
    [anon_sym_strictfp] = ACTIONS(949),
    [anon_sym_native] = ACTIONS(949),
    [anon_sym_transient] = ACTIONS(949),
    [anon_sym_volatile] = ACTIONS(949),
    [anon_sym_sealed] = ACTIONS(949),
    [anon_sym_non_DASHsealed] = ACTIONS(947),
    [anon_sym_record] = ACTIONS(949),
    [anon_sym_ATinterface] = ACTIONS(947),
    [anon_sym_interface] = ACTIONS(949),
    [anon_sym_byte] = ACTIONS(949),
    [anon_sym_short] = ACTIONS(949),
    [anon_sym_int] = ACTIONS(949),
    [anon_sym_long] = ACTIONS(949),
    [anon_sym_char] = ACTIONS(949),
    [anon_sym_float] = ACTIONS(949),
    [anon_sym_double] = ACTIONS(949),
    [sym_boolean_type] = ACTIONS(949),
    [sym_void_type] = ACTIONS(949),
    [sym_this] = ACTIONS(949),
    [sym_super] = ACTIONS(949),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [330] = {
    [ts_builtin_sym_end] = ACTIONS(951),
    [sym_identifier] = ACTIONS(953),
    [sym_decimal_integer_literal] = ACTIONS(953),
    [sym_hex_integer_literal] = ACTIONS(953),
    [sym_octal_integer_literal] = ACTIONS(953),
    [sym_binary_integer_literal] = ACTIONS(951),
    [sym_decimal_floating_point_literal] = ACTIONS(951),
    [sym_hex_floating_point_literal] = ACTIONS(953),
    [sym_true] = ACTIONS(953),
    [sym_false] = ACTIONS(953),
    [sym_character_literal] = ACTIONS(951),
    [anon_sym_DQUOTE] = ACTIONS(953),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [sym_null_literal] = ACTIONS(953),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(953),
    [anon_sym_DASH] = ACTIONS(953),
    [anon_sym_final] = ACTIONS(953),
    [anon_sym_BANG] = ACTIONS(951),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(953),
    [anon_sym_class] = ACTIONS(953),
    [anon_sym_switch] = ACTIONS(953),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_case] = ACTIONS(953),
    [anon_sym_default] = ACTIONS(953),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_assert] = ACTIONS(953),
    [anon_sym_do] = ACTIONS(953),
    [anon_sym_while] = ACTIONS(953),
    [anon_sym_break] = ACTIONS(953),
    [anon_sym_continue] = ACTIONS(953),
    [anon_sym_return] = ACTIONS(953),
    [anon_sym_yield] = ACTIONS(953),
    [anon_sym_synchronized] = ACTIONS(953),
    [anon_sym_throw] = ACTIONS(953),
    [anon_sym_try] = ACTIONS(953),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_else] = ACTIONS(953),
    [anon_sym_for] = ACTIONS(953),
    [anon_sym_AT] = ACTIONS(953),
    [anon_sym_open] = ACTIONS(953),
    [anon_sym_module] = ACTIONS(953),
    [anon_sym_static] = ACTIONS(953),
    [anon_sym_with] = ACTIONS(953),
    [anon_sym_package] = ACTIONS(953),
    [anon_sym_import] = ACTIONS(953),
    [anon_sym_enum] = ACTIONS(953),
    [anon_sym_public] = ACTIONS(953),
    [anon_sym_protected] = ACTIONS(953),
    [anon_sym_private] = ACTIONS(953),
    [anon_sym_abstract] = ACTIONS(953),
    [anon_sym_strictfp] = ACTIONS(953),
    [anon_sym_native] = ACTIONS(953),
    [anon_sym_transient] = ACTIONS(953),
    [anon_sym_volatile] = ACTIONS(953),
    [anon_sym_sealed] = ACTIONS(953),
    [anon_sym_non_DASHsealed] = ACTIONS(951),
    [anon_sym_record] = ACTIONS(953),
    [anon_sym_ATinterface] = ACTIONS(951),
    [anon_sym_interface] = ACTIONS(953),
    [anon_sym_byte] = ACTIONS(953),
    [anon_sym_short] = ACTIONS(953),
    [anon_sym_int] = ACTIONS(953),
    [anon_sym_long] = ACTIONS(953),
    [anon_sym_char] = ACTIONS(953),
    [anon_sym_float] = ACTIONS(953),
    [anon_sym_double] = ACTIONS(953),
    [sym_boolean_type] = ACTIONS(953),
    [sym_void_type] = ACTIONS(953),
    [sym_this] = ACTIONS(953),
    [sym_super] = ACTIONS(953),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [331] = {
    [ts_builtin_sym_end] = ACTIONS(955),
    [sym_identifier] = ACTIONS(957),
    [sym_decimal_integer_literal] = ACTIONS(957),
    [sym_hex_integer_literal] = ACTIONS(957),
    [sym_octal_integer_literal] = ACTIONS(957),
    [sym_binary_integer_literal] = ACTIONS(955),
    [sym_decimal_floating_point_literal] = ACTIONS(955),
    [sym_hex_floating_point_literal] = ACTIONS(957),
    [sym_true] = ACTIONS(957),
    [sym_false] = ACTIONS(957),
    [sym_character_literal] = ACTIONS(955),
    [anon_sym_DQUOTE] = ACTIONS(957),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(955),
    [anon_sym_RBRACE] = ACTIONS(955),
    [sym_null_literal] = ACTIONS(957),
    [anon_sym_LPAREN] = ACTIONS(955),
    [anon_sym_LT] = ACTIONS(955),
    [anon_sym_PLUS] = ACTIONS(957),
    [anon_sym_DASH] = ACTIONS(957),
    [anon_sym_final] = ACTIONS(957),
    [anon_sym_BANG] = ACTIONS(955),
    [anon_sym_TILDE] = ACTIONS(955),
    [anon_sym_PLUS_PLUS] = ACTIONS(955),
    [anon_sym_DASH_DASH] = ACTIONS(955),
    [anon_sym_new] = ACTIONS(957),
    [anon_sym_class] = ACTIONS(957),
    [anon_sym_switch] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(955),
    [anon_sym_case] = ACTIONS(957),
    [anon_sym_default] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(955),
    [anon_sym_assert] = ACTIONS(957),
    [anon_sym_do] = ACTIONS(957),
    [anon_sym_while] = ACTIONS(957),
    [anon_sym_break] = ACTIONS(957),
    [anon_sym_continue] = ACTIONS(957),
    [anon_sym_return] = ACTIONS(957),
    [anon_sym_yield] = ACTIONS(957),
    [anon_sym_synchronized] = ACTIONS(957),
    [anon_sym_throw] = ACTIONS(957),
    [anon_sym_try] = ACTIONS(957),
    [anon_sym_if] = ACTIONS(957),
    [anon_sym_else] = ACTIONS(957),
    [anon_sym_for] = ACTIONS(957),
    [anon_sym_AT] = ACTIONS(957),
    [anon_sym_open] = ACTIONS(957),
    [anon_sym_module] = ACTIONS(957),
    [anon_sym_static] = ACTIONS(957),
    [anon_sym_with] = ACTIONS(957),
    [anon_sym_package] = ACTIONS(957),
    [anon_sym_import] = ACTIONS(957),
    [anon_sym_enum] = ACTIONS(957),
    [anon_sym_public] = ACTIONS(957),
    [anon_sym_protected] = ACTIONS(957),
    [anon_sym_private] = ACTIONS(957),
    [anon_sym_abstract] = ACTIONS(957),
    [anon_sym_strictfp] = ACTIONS(957),
    [anon_sym_native] = ACTIONS(957),
    [anon_sym_transient] = ACTIONS(957),
    [anon_sym_volatile] = ACTIONS(957),
    [anon_sym_sealed] = ACTIONS(957),
    [anon_sym_non_DASHsealed] = ACTIONS(955),
    [anon_sym_record] = ACTIONS(957),
    [anon_sym_ATinterface] = ACTIONS(955),
    [anon_sym_interface] = ACTIONS(957),
    [anon_sym_byte] = ACTIONS(957),
    [anon_sym_short] = ACTIONS(957),
    [anon_sym_int] = ACTIONS(957),
    [anon_sym_long] = ACTIONS(957),
    [anon_sym_char] = ACTIONS(957),
    [anon_sym_float] = ACTIONS(957),
    [anon_sym_double] = ACTIONS(957),
    [sym_boolean_type] = ACTIONS(957),
    [sym_void_type] = ACTIONS(957),
    [sym_this] = ACTIONS(957),
    [sym_super] = ACTIONS(957),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [332] = {
    [ts_builtin_sym_end] = ACTIONS(959),
    [sym_identifier] = ACTIONS(961),
    [sym_decimal_integer_literal] = ACTIONS(961),
    [sym_hex_integer_literal] = ACTIONS(961),
    [sym_octal_integer_literal] = ACTIONS(961),
    [sym_binary_integer_literal] = ACTIONS(959),
    [sym_decimal_floating_point_literal] = ACTIONS(959),
    [sym_hex_floating_point_literal] = ACTIONS(961),
    [sym_true] = ACTIONS(961),
    [sym_false] = ACTIONS(961),
    [sym_character_literal] = ACTIONS(959),
    [anon_sym_DQUOTE] = ACTIONS(961),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(959),
    [anon_sym_RBRACE] = ACTIONS(959),
    [sym_null_literal] = ACTIONS(961),
    [anon_sym_LPAREN] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(961),
    [anon_sym_DASH] = ACTIONS(961),
    [anon_sym_final] = ACTIONS(961),
    [anon_sym_BANG] = ACTIONS(959),
    [anon_sym_TILDE] = ACTIONS(959),
    [anon_sym_PLUS_PLUS] = ACTIONS(959),
    [anon_sym_DASH_DASH] = ACTIONS(959),
    [anon_sym_new] = ACTIONS(961),
    [anon_sym_class] = ACTIONS(961),
    [anon_sym_switch] = ACTIONS(961),
    [anon_sym_LBRACE] = ACTIONS(959),
    [anon_sym_case] = ACTIONS(961),
    [anon_sym_default] = ACTIONS(961),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_assert] = ACTIONS(961),
    [anon_sym_do] = ACTIONS(961),
    [anon_sym_while] = ACTIONS(961),
    [anon_sym_break] = ACTIONS(961),
    [anon_sym_continue] = ACTIONS(961),
    [anon_sym_return] = ACTIONS(961),
    [anon_sym_yield] = ACTIONS(961),
    [anon_sym_synchronized] = ACTIONS(961),
    [anon_sym_throw] = ACTIONS(961),
    [anon_sym_try] = ACTIONS(961),
    [anon_sym_if] = ACTIONS(961),
    [anon_sym_else] = ACTIONS(961),
    [anon_sym_for] = ACTIONS(961),
    [anon_sym_AT] = ACTIONS(961),
    [anon_sym_open] = ACTIONS(961),
    [anon_sym_module] = ACTIONS(961),
    [anon_sym_static] = ACTIONS(961),
    [anon_sym_with] = ACTIONS(961),
    [anon_sym_package] = ACTIONS(961),
    [anon_sym_import] = ACTIONS(961),
    [anon_sym_enum] = ACTIONS(961),
    [anon_sym_public] = ACTIONS(961),
    [anon_sym_protected] = ACTIONS(961),
    [anon_sym_private] = ACTIONS(961),
    [anon_sym_abstract] = ACTIONS(961),
    [anon_sym_strictfp] = ACTIONS(961),
    [anon_sym_native] = ACTIONS(961),
    [anon_sym_transient] = ACTIONS(961),
    [anon_sym_volatile] = ACTIONS(961),
    [anon_sym_sealed] = ACTIONS(961),
    [anon_sym_non_DASHsealed] = ACTIONS(959),
    [anon_sym_record] = ACTIONS(961),
    [anon_sym_ATinterface] = ACTIONS(959),
    [anon_sym_interface] = ACTIONS(961),
    [anon_sym_byte] = ACTIONS(961),
    [anon_sym_short] = ACTIONS(961),
    [anon_sym_int] = ACTIONS(961),
    [anon_sym_long] = ACTIONS(961),
    [anon_sym_char] = ACTIONS(961),
    [anon_sym_float] = ACTIONS(961),
    [anon_sym_double] = ACTIONS(961),
    [sym_boolean_type] = ACTIONS(961),
    [sym_void_type] = ACTIONS(961),
    [sym_this] = ACTIONS(961),
    [sym_super] = ACTIONS(961),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [333] = {
    [ts_builtin_sym_end] = ACTIONS(963),
    [sym_identifier] = ACTIONS(965),
    [sym_decimal_integer_literal] = ACTIONS(965),
    [sym_hex_integer_literal] = ACTIONS(965),
    [sym_octal_integer_literal] = ACTIONS(965),
    [sym_binary_integer_literal] = ACTIONS(963),
    [sym_decimal_floating_point_literal] = ACTIONS(963),
    [sym_hex_floating_point_literal] = ACTIONS(965),
    [sym_true] = ACTIONS(965),
    [sym_false] = ACTIONS(965),
    [sym_character_literal] = ACTIONS(963),
    [anon_sym_DQUOTE] = ACTIONS(965),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(963),
    [anon_sym_RBRACE] = ACTIONS(963),
    [sym_null_literal] = ACTIONS(965),
    [anon_sym_LPAREN] = ACTIONS(963),
    [anon_sym_LT] = ACTIONS(963),
    [anon_sym_PLUS] = ACTIONS(965),
    [anon_sym_DASH] = ACTIONS(965),
    [anon_sym_final] = ACTIONS(965),
    [anon_sym_BANG] = ACTIONS(963),
    [anon_sym_TILDE] = ACTIONS(963),
    [anon_sym_PLUS_PLUS] = ACTIONS(963),
    [anon_sym_DASH_DASH] = ACTIONS(963),
    [anon_sym_new] = ACTIONS(965),
    [anon_sym_class] = ACTIONS(965),
    [anon_sym_switch] = ACTIONS(965),
    [anon_sym_LBRACE] = ACTIONS(963),
    [anon_sym_case] = ACTIONS(965),
    [anon_sym_default] = ACTIONS(965),
    [anon_sym_SEMI] = ACTIONS(963),
    [anon_sym_assert] = ACTIONS(965),
    [anon_sym_do] = ACTIONS(965),
    [anon_sym_while] = ACTIONS(965),
    [anon_sym_break] = ACTIONS(965),
    [anon_sym_continue] = ACTIONS(965),
    [anon_sym_return] = ACTIONS(965),
    [anon_sym_yield] = ACTIONS(965),
    [anon_sym_synchronized] = ACTIONS(965),
    [anon_sym_throw] = ACTIONS(965),
    [anon_sym_try] = ACTIONS(965),
    [anon_sym_if] = ACTIONS(965),
    [anon_sym_else] = ACTIONS(965),
    [anon_sym_for] = ACTIONS(965),
    [anon_sym_AT] = ACTIONS(965),
    [anon_sym_open] = ACTIONS(965),
    [anon_sym_module] = ACTIONS(965),
    [anon_sym_static] = ACTIONS(965),
    [anon_sym_with] = ACTIONS(965),
    [anon_sym_package] = ACTIONS(965),
    [anon_sym_import] = ACTIONS(965),
    [anon_sym_enum] = ACTIONS(965),
    [anon_sym_public] = ACTIONS(965),
    [anon_sym_protected] = ACTIONS(965),
    [anon_sym_private] = ACTIONS(965),
    [anon_sym_abstract] = ACTIONS(965),
    [anon_sym_strictfp] = ACTIONS(965),
    [anon_sym_native] = ACTIONS(965),
    [anon_sym_transient] = ACTIONS(965),
    [anon_sym_volatile] = ACTIONS(965),
    [anon_sym_sealed] = ACTIONS(965),
    [anon_sym_non_DASHsealed] = ACTIONS(963),
    [anon_sym_record] = ACTIONS(965),
    [anon_sym_ATinterface] = ACTIONS(963),
    [anon_sym_interface] = ACTIONS(965),
    [anon_sym_byte] = ACTIONS(965),
    [anon_sym_short] = ACTIONS(965),
    [anon_sym_int] = ACTIONS(965),
    [anon_sym_long] = ACTIONS(965),
    [anon_sym_char] = ACTIONS(965),
    [anon_sym_float] = ACTIONS(965),
    [anon_sym_double] = ACTIONS(965),
    [sym_boolean_type] = ACTIONS(965),
    [sym_void_type] = ACTIONS(965),
    [sym_this] = ACTIONS(965),
    [sym_super] = ACTIONS(965),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [334] = {
    [ts_builtin_sym_end] = ACTIONS(967),
    [sym_identifier] = ACTIONS(969),
    [sym_decimal_integer_literal] = ACTIONS(969),
    [sym_hex_integer_literal] = ACTIONS(969),
    [sym_octal_integer_literal] = ACTIONS(969),
    [sym_binary_integer_literal] = ACTIONS(967),
    [sym_decimal_floating_point_literal] = ACTIONS(967),
    [sym_hex_floating_point_literal] = ACTIONS(969),
    [sym_true] = ACTIONS(969),
    [sym_false] = ACTIONS(969),
    [sym_character_literal] = ACTIONS(967),
    [anon_sym_DQUOTE] = ACTIONS(969),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(967),
    [anon_sym_RBRACE] = ACTIONS(967),
    [sym_null_literal] = ACTIONS(969),
    [anon_sym_LPAREN] = ACTIONS(967),
    [anon_sym_LT] = ACTIONS(967),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_final] = ACTIONS(969),
    [anon_sym_BANG] = ACTIONS(967),
    [anon_sym_TILDE] = ACTIONS(967),
    [anon_sym_PLUS_PLUS] = ACTIONS(967),
    [anon_sym_DASH_DASH] = ACTIONS(967),
    [anon_sym_new] = ACTIONS(969),
    [anon_sym_class] = ACTIONS(969),
    [anon_sym_switch] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(967),
    [anon_sym_case] = ACTIONS(969),
    [anon_sym_default] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_assert] = ACTIONS(969),
    [anon_sym_do] = ACTIONS(969),
    [anon_sym_while] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(969),
    [anon_sym_continue] = ACTIONS(969),
    [anon_sym_return] = ACTIONS(969),
    [anon_sym_yield] = ACTIONS(969),
    [anon_sym_synchronized] = ACTIONS(969),
    [anon_sym_throw] = ACTIONS(969),
    [anon_sym_try] = ACTIONS(969),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_else] = ACTIONS(969),
    [anon_sym_for] = ACTIONS(969),
    [anon_sym_AT] = ACTIONS(969),
    [anon_sym_open] = ACTIONS(969),
    [anon_sym_module] = ACTIONS(969),
    [anon_sym_static] = ACTIONS(969),
    [anon_sym_with] = ACTIONS(969),
    [anon_sym_package] = ACTIONS(969),
    [anon_sym_import] = ACTIONS(969),
    [anon_sym_enum] = ACTIONS(969),
    [anon_sym_public] = ACTIONS(969),
    [anon_sym_protected] = ACTIONS(969),
    [anon_sym_private] = ACTIONS(969),
    [anon_sym_abstract] = ACTIONS(969),
    [anon_sym_strictfp] = ACTIONS(969),
    [anon_sym_native] = ACTIONS(969),
    [anon_sym_transient] = ACTIONS(969),
    [anon_sym_volatile] = ACTIONS(969),
    [anon_sym_sealed] = ACTIONS(969),
    [anon_sym_non_DASHsealed] = ACTIONS(967),
    [anon_sym_record] = ACTIONS(969),
    [anon_sym_ATinterface] = ACTIONS(967),
    [anon_sym_interface] = ACTIONS(969),
    [anon_sym_byte] = ACTIONS(969),
    [anon_sym_short] = ACTIONS(969),
    [anon_sym_int] = ACTIONS(969),
    [anon_sym_long] = ACTIONS(969),
    [anon_sym_char] = ACTIONS(969),
    [anon_sym_float] = ACTIONS(969),
    [anon_sym_double] = ACTIONS(969),
    [sym_boolean_type] = ACTIONS(969),
    [sym_void_type] = ACTIONS(969),
    [sym_this] = ACTIONS(969),
    [sym_super] = ACTIONS(969),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [335] = {
    [ts_builtin_sym_end] = ACTIONS(971),
    [sym_identifier] = ACTIONS(973),
    [sym_decimal_integer_literal] = ACTIONS(973),
    [sym_hex_integer_literal] = ACTIONS(973),
    [sym_octal_integer_literal] = ACTIONS(973),
    [sym_binary_integer_literal] = ACTIONS(971),
    [sym_decimal_floating_point_literal] = ACTIONS(971),
    [sym_hex_floating_point_literal] = ACTIONS(973),
    [sym_true] = ACTIONS(973),
    [sym_false] = ACTIONS(973),
    [sym_character_literal] = ACTIONS(971),
    [anon_sym_DQUOTE] = ACTIONS(973),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [sym_null_literal] = ACTIONS(973),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(973),
    [anon_sym_DASH] = ACTIONS(973),
    [anon_sym_final] = ACTIONS(973),
    [anon_sym_BANG] = ACTIONS(971),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(973),
    [anon_sym_class] = ACTIONS(973),
    [anon_sym_switch] = ACTIONS(973),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_case] = ACTIONS(973),
    [anon_sym_default] = ACTIONS(973),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_assert] = ACTIONS(973),
    [anon_sym_do] = ACTIONS(973),
    [anon_sym_while] = ACTIONS(973),
    [anon_sym_break] = ACTIONS(973),
    [anon_sym_continue] = ACTIONS(973),
    [anon_sym_return] = ACTIONS(973),
    [anon_sym_yield] = ACTIONS(973),
    [anon_sym_synchronized] = ACTIONS(973),
    [anon_sym_throw] = ACTIONS(973),
    [anon_sym_try] = ACTIONS(973),
    [anon_sym_if] = ACTIONS(973),
    [anon_sym_else] = ACTIONS(973),
    [anon_sym_for] = ACTIONS(973),
    [anon_sym_AT] = ACTIONS(973),
    [anon_sym_open] = ACTIONS(973),
    [anon_sym_module] = ACTIONS(973),
    [anon_sym_static] = ACTIONS(973),
    [anon_sym_with] = ACTIONS(973),
    [anon_sym_package] = ACTIONS(973),
    [anon_sym_import] = ACTIONS(973),
    [anon_sym_enum] = ACTIONS(973),
    [anon_sym_public] = ACTIONS(973),
    [anon_sym_protected] = ACTIONS(973),
    [anon_sym_private] = ACTIONS(973),
    [anon_sym_abstract] = ACTIONS(973),
    [anon_sym_strictfp] = ACTIONS(973),
    [anon_sym_native] = ACTIONS(973),
    [anon_sym_transient] = ACTIONS(973),
    [anon_sym_volatile] = ACTIONS(973),
    [anon_sym_sealed] = ACTIONS(973),
    [anon_sym_non_DASHsealed] = ACTIONS(971),
    [anon_sym_record] = ACTIONS(973),
    [anon_sym_ATinterface] = ACTIONS(971),
    [anon_sym_interface] = ACTIONS(973),
    [anon_sym_byte] = ACTIONS(973),
    [anon_sym_short] = ACTIONS(973),
    [anon_sym_int] = ACTIONS(973),
    [anon_sym_long] = ACTIONS(973),
    [anon_sym_char] = ACTIONS(973),
    [anon_sym_float] = ACTIONS(973),
    [anon_sym_double] = ACTIONS(973),
    [sym_boolean_type] = ACTIONS(973),
    [sym_void_type] = ACTIONS(973),
    [sym_this] = ACTIONS(973),
    [sym_super] = ACTIONS(973),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [336] = {
    [ts_builtin_sym_end] = ACTIONS(975),
    [sym_identifier] = ACTIONS(977),
    [sym_decimal_integer_literal] = ACTIONS(977),
    [sym_hex_integer_literal] = ACTIONS(977),
    [sym_octal_integer_literal] = ACTIONS(977),
    [sym_binary_integer_literal] = ACTIONS(975),
    [sym_decimal_floating_point_literal] = ACTIONS(975),
    [sym_hex_floating_point_literal] = ACTIONS(977),
    [sym_true] = ACTIONS(977),
    [sym_false] = ACTIONS(977),
    [sym_character_literal] = ACTIONS(975),
    [anon_sym_DQUOTE] = ACTIONS(977),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(975),
    [anon_sym_RBRACE] = ACTIONS(975),
    [sym_null_literal] = ACTIONS(977),
    [anon_sym_LPAREN] = ACTIONS(975),
    [anon_sym_LT] = ACTIONS(975),
    [anon_sym_PLUS] = ACTIONS(977),
    [anon_sym_DASH] = ACTIONS(977),
    [anon_sym_final] = ACTIONS(977),
    [anon_sym_BANG] = ACTIONS(975),
    [anon_sym_TILDE] = ACTIONS(975),
    [anon_sym_PLUS_PLUS] = ACTIONS(975),
    [anon_sym_DASH_DASH] = ACTIONS(975),
    [anon_sym_new] = ACTIONS(977),
    [anon_sym_class] = ACTIONS(977),
    [anon_sym_switch] = ACTIONS(977),
    [anon_sym_LBRACE] = ACTIONS(975),
    [anon_sym_case] = ACTIONS(977),
    [anon_sym_default] = ACTIONS(977),
    [anon_sym_SEMI] = ACTIONS(975),
    [anon_sym_assert] = ACTIONS(977),
    [anon_sym_do] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(977),
    [anon_sym_break] = ACTIONS(977),
    [anon_sym_continue] = ACTIONS(977),
    [anon_sym_return] = ACTIONS(977),
    [anon_sym_yield] = ACTIONS(977),
    [anon_sym_synchronized] = ACTIONS(977),
    [anon_sym_throw] = ACTIONS(977),
    [anon_sym_try] = ACTIONS(977),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_else] = ACTIONS(977),
    [anon_sym_for] = ACTIONS(977),
    [anon_sym_AT] = ACTIONS(977),
    [anon_sym_open] = ACTIONS(977),
    [anon_sym_module] = ACTIONS(977),
    [anon_sym_static] = ACTIONS(977),
    [anon_sym_with] = ACTIONS(977),
    [anon_sym_package] = ACTIONS(977),
    [anon_sym_import] = ACTIONS(977),
    [anon_sym_enum] = ACTIONS(977),
    [anon_sym_public] = ACTIONS(977),
    [anon_sym_protected] = ACTIONS(977),
    [anon_sym_private] = ACTIONS(977),
    [anon_sym_abstract] = ACTIONS(977),
    [anon_sym_strictfp] = ACTIONS(977),
    [anon_sym_native] = ACTIONS(977),
    [anon_sym_transient] = ACTIONS(977),
    [anon_sym_volatile] = ACTIONS(977),
    [anon_sym_sealed] = ACTIONS(977),
    [anon_sym_non_DASHsealed] = ACTIONS(975),
    [anon_sym_record] = ACTIONS(977),
    [anon_sym_ATinterface] = ACTIONS(975),
    [anon_sym_interface] = ACTIONS(977),
    [anon_sym_byte] = ACTIONS(977),
    [anon_sym_short] = ACTIONS(977),
    [anon_sym_int] = ACTIONS(977),
    [anon_sym_long] = ACTIONS(977),
    [anon_sym_char] = ACTIONS(977),
    [anon_sym_float] = ACTIONS(977),
    [anon_sym_double] = ACTIONS(977),
    [sym_boolean_type] = ACTIONS(977),
    [sym_void_type] = ACTIONS(977),
    [sym_this] = ACTIONS(977),
    [sym_super] = ACTIONS(977),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [337] = {
    [ts_builtin_sym_end] = ACTIONS(979),
    [sym_identifier] = ACTIONS(981),
    [sym_decimal_integer_literal] = ACTIONS(981),
    [sym_hex_integer_literal] = ACTIONS(981),
    [sym_octal_integer_literal] = ACTIONS(981),
    [sym_binary_integer_literal] = ACTIONS(979),
    [sym_decimal_floating_point_literal] = ACTIONS(979),
    [sym_hex_floating_point_literal] = ACTIONS(981),
    [sym_true] = ACTIONS(981),
    [sym_false] = ACTIONS(981),
    [sym_character_literal] = ACTIONS(979),
    [anon_sym_DQUOTE] = ACTIONS(981),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(979),
    [anon_sym_RBRACE] = ACTIONS(979),
    [sym_null_literal] = ACTIONS(981),
    [anon_sym_LPAREN] = ACTIONS(979),
    [anon_sym_LT] = ACTIONS(979),
    [anon_sym_PLUS] = ACTIONS(981),
    [anon_sym_DASH] = ACTIONS(981),
    [anon_sym_final] = ACTIONS(981),
    [anon_sym_BANG] = ACTIONS(979),
    [anon_sym_TILDE] = ACTIONS(979),
    [anon_sym_PLUS_PLUS] = ACTIONS(979),
    [anon_sym_DASH_DASH] = ACTIONS(979),
    [anon_sym_new] = ACTIONS(981),
    [anon_sym_class] = ACTIONS(981),
    [anon_sym_switch] = ACTIONS(981),
    [anon_sym_LBRACE] = ACTIONS(979),
    [anon_sym_case] = ACTIONS(981),
    [anon_sym_default] = ACTIONS(981),
    [anon_sym_SEMI] = ACTIONS(979),
    [anon_sym_assert] = ACTIONS(981),
    [anon_sym_do] = ACTIONS(981),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_break] = ACTIONS(981),
    [anon_sym_continue] = ACTIONS(981),
    [anon_sym_return] = ACTIONS(981),
    [anon_sym_yield] = ACTIONS(981),
    [anon_sym_synchronized] = ACTIONS(981),
    [anon_sym_throw] = ACTIONS(981),
    [anon_sym_try] = ACTIONS(981),
    [anon_sym_if] = ACTIONS(981),
    [anon_sym_else] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_AT] = ACTIONS(981),
    [anon_sym_open] = ACTIONS(981),
    [anon_sym_module] = ACTIONS(981),
    [anon_sym_static] = ACTIONS(981),
    [anon_sym_with] = ACTIONS(981),
    [anon_sym_package] = ACTIONS(981),
    [anon_sym_import] = ACTIONS(981),
    [anon_sym_enum] = ACTIONS(981),
    [anon_sym_public] = ACTIONS(981),
    [anon_sym_protected] = ACTIONS(981),
    [anon_sym_private] = ACTIONS(981),
    [anon_sym_abstract] = ACTIONS(981),
    [anon_sym_strictfp] = ACTIONS(981),
    [anon_sym_native] = ACTIONS(981),
    [anon_sym_transient] = ACTIONS(981),
    [anon_sym_volatile] = ACTIONS(981),
    [anon_sym_sealed] = ACTIONS(981),
    [anon_sym_non_DASHsealed] = ACTIONS(979),
    [anon_sym_record] = ACTIONS(981),
    [anon_sym_ATinterface] = ACTIONS(979),
    [anon_sym_interface] = ACTIONS(981),
    [anon_sym_byte] = ACTIONS(981),
    [anon_sym_short] = ACTIONS(981),
    [anon_sym_int] = ACTIONS(981),
    [anon_sym_long] = ACTIONS(981),
    [anon_sym_char] = ACTIONS(981),
    [anon_sym_float] = ACTIONS(981),
    [anon_sym_double] = ACTIONS(981),
    [sym_boolean_type] = ACTIONS(981),
    [sym_void_type] = ACTIONS(981),
    [sym_this] = ACTIONS(981),
    [sym_super] = ACTIONS(981),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [338] = {
    [ts_builtin_sym_end] = ACTIONS(983),
    [sym_identifier] = ACTIONS(985),
    [sym_decimal_integer_literal] = ACTIONS(985),
    [sym_hex_integer_literal] = ACTIONS(985),
    [sym_octal_integer_literal] = ACTIONS(985),
    [sym_binary_integer_literal] = ACTIONS(983),
    [sym_decimal_floating_point_literal] = ACTIONS(983),
    [sym_hex_floating_point_literal] = ACTIONS(985),
    [sym_true] = ACTIONS(985),
    [sym_false] = ACTIONS(985),
    [sym_character_literal] = ACTIONS(983),
    [anon_sym_DQUOTE] = ACTIONS(985),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(983),
    [anon_sym_RBRACE] = ACTIONS(983),
    [sym_null_literal] = ACTIONS(985),
    [anon_sym_LPAREN] = ACTIONS(983),
    [anon_sym_LT] = ACTIONS(983),
    [anon_sym_PLUS] = ACTIONS(985),
    [anon_sym_DASH] = ACTIONS(985),
    [anon_sym_final] = ACTIONS(985),
    [anon_sym_BANG] = ACTIONS(983),
    [anon_sym_TILDE] = ACTIONS(983),
    [anon_sym_PLUS_PLUS] = ACTIONS(983),
    [anon_sym_DASH_DASH] = ACTIONS(983),
    [anon_sym_new] = ACTIONS(985),
    [anon_sym_class] = ACTIONS(985),
    [anon_sym_switch] = ACTIONS(985),
    [anon_sym_LBRACE] = ACTIONS(983),
    [anon_sym_case] = ACTIONS(985),
    [anon_sym_default] = ACTIONS(985),
    [anon_sym_SEMI] = ACTIONS(983),
    [anon_sym_assert] = ACTIONS(985),
    [anon_sym_do] = ACTIONS(985),
    [anon_sym_while] = ACTIONS(985),
    [anon_sym_break] = ACTIONS(985),
    [anon_sym_continue] = ACTIONS(985),
    [anon_sym_return] = ACTIONS(985),
    [anon_sym_yield] = ACTIONS(985),
    [anon_sym_synchronized] = ACTIONS(985),
    [anon_sym_throw] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(985),
    [anon_sym_if] = ACTIONS(985),
    [anon_sym_else] = ACTIONS(985),
    [anon_sym_for] = ACTIONS(985),
    [anon_sym_AT] = ACTIONS(985),
    [anon_sym_open] = ACTIONS(985),
    [anon_sym_module] = ACTIONS(985),
    [anon_sym_static] = ACTIONS(985),
    [anon_sym_with] = ACTIONS(985),
    [anon_sym_package] = ACTIONS(985),
    [anon_sym_import] = ACTIONS(985),
    [anon_sym_enum] = ACTIONS(985),
    [anon_sym_public] = ACTIONS(985),
    [anon_sym_protected] = ACTIONS(985),
    [anon_sym_private] = ACTIONS(985),
    [anon_sym_abstract] = ACTIONS(985),
    [anon_sym_strictfp] = ACTIONS(985),
    [anon_sym_native] = ACTIONS(985),
    [anon_sym_transient] = ACTIONS(985),
    [anon_sym_volatile] = ACTIONS(985),
    [anon_sym_sealed] = ACTIONS(985),
    [anon_sym_non_DASHsealed] = ACTIONS(983),
    [anon_sym_record] = ACTIONS(985),
    [anon_sym_ATinterface] = ACTIONS(983),
    [anon_sym_interface] = ACTIONS(985),
    [anon_sym_byte] = ACTIONS(985),
    [anon_sym_short] = ACTIONS(985),
    [anon_sym_int] = ACTIONS(985),
    [anon_sym_long] = ACTIONS(985),
    [anon_sym_char] = ACTIONS(985),
    [anon_sym_float] = ACTIONS(985),
    [anon_sym_double] = ACTIONS(985),
    [sym_boolean_type] = ACTIONS(985),
    [sym_void_type] = ACTIONS(985),
    [sym_this] = ACTIONS(985),
    [sym_super] = ACTIONS(985),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [339] = {
    [ts_builtin_sym_end] = ACTIONS(987),
    [sym_identifier] = ACTIONS(989),
    [sym_decimal_integer_literal] = ACTIONS(989),
    [sym_hex_integer_literal] = ACTIONS(989),
    [sym_octal_integer_literal] = ACTIONS(989),
    [sym_binary_integer_literal] = ACTIONS(987),
    [sym_decimal_floating_point_literal] = ACTIONS(987),
    [sym_hex_floating_point_literal] = ACTIONS(989),
    [sym_true] = ACTIONS(989),
    [sym_false] = ACTIONS(989),
    [sym_character_literal] = ACTIONS(987),
    [anon_sym_DQUOTE] = ACTIONS(989),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(987),
    [anon_sym_RBRACE] = ACTIONS(987),
    [sym_null_literal] = ACTIONS(989),
    [anon_sym_LPAREN] = ACTIONS(987),
    [anon_sym_LT] = ACTIONS(987),
    [anon_sym_PLUS] = ACTIONS(989),
    [anon_sym_DASH] = ACTIONS(989),
    [anon_sym_final] = ACTIONS(989),
    [anon_sym_BANG] = ACTIONS(987),
    [anon_sym_TILDE] = ACTIONS(987),
    [anon_sym_PLUS_PLUS] = ACTIONS(987),
    [anon_sym_DASH_DASH] = ACTIONS(987),
    [anon_sym_new] = ACTIONS(989),
    [anon_sym_class] = ACTIONS(989),
    [anon_sym_switch] = ACTIONS(989),
    [anon_sym_LBRACE] = ACTIONS(987),
    [anon_sym_case] = ACTIONS(989),
    [anon_sym_default] = ACTIONS(989),
    [anon_sym_SEMI] = ACTIONS(987),
    [anon_sym_assert] = ACTIONS(989),
    [anon_sym_do] = ACTIONS(989),
    [anon_sym_while] = ACTIONS(989),
    [anon_sym_break] = ACTIONS(989),
    [anon_sym_continue] = ACTIONS(989),
    [anon_sym_return] = ACTIONS(989),
    [anon_sym_yield] = ACTIONS(989),
    [anon_sym_synchronized] = ACTIONS(989),
    [anon_sym_throw] = ACTIONS(989),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_if] = ACTIONS(989),
    [anon_sym_else] = ACTIONS(989),
    [anon_sym_for] = ACTIONS(989),
    [anon_sym_AT] = ACTIONS(989),
    [anon_sym_open] = ACTIONS(989),
    [anon_sym_module] = ACTIONS(989),
    [anon_sym_static] = ACTIONS(989),
    [anon_sym_with] = ACTIONS(989),
    [anon_sym_package] = ACTIONS(989),
    [anon_sym_import] = ACTIONS(989),
    [anon_sym_enum] = ACTIONS(989),
    [anon_sym_public] = ACTIONS(989),
    [anon_sym_protected] = ACTIONS(989),
    [anon_sym_private] = ACTIONS(989),
    [anon_sym_abstract] = ACTIONS(989),
    [anon_sym_strictfp] = ACTIONS(989),
    [anon_sym_native] = ACTIONS(989),
    [anon_sym_transient] = ACTIONS(989),
    [anon_sym_volatile] = ACTIONS(989),
    [anon_sym_sealed] = ACTIONS(989),
    [anon_sym_non_DASHsealed] = ACTIONS(987),
    [anon_sym_record] = ACTIONS(989),
    [anon_sym_ATinterface] = ACTIONS(987),
    [anon_sym_interface] = ACTIONS(989),
    [anon_sym_byte] = ACTIONS(989),
    [anon_sym_short] = ACTIONS(989),
    [anon_sym_int] = ACTIONS(989),
    [anon_sym_long] = ACTIONS(989),
    [anon_sym_char] = ACTIONS(989),
    [anon_sym_float] = ACTIONS(989),
    [anon_sym_double] = ACTIONS(989),
    [sym_boolean_type] = ACTIONS(989),
    [sym_void_type] = ACTIONS(989),
    [sym_this] = ACTIONS(989),
    [sym_super] = ACTIONS(989),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [340] = {
    [ts_builtin_sym_end] = ACTIONS(991),
    [sym_identifier] = ACTIONS(993),
    [sym_decimal_integer_literal] = ACTIONS(993),
    [sym_hex_integer_literal] = ACTIONS(993),
    [sym_octal_integer_literal] = ACTIONS(993),
    [sym_binary_integer_literal] = ACTIONS(991),
    [sym_decimal_floating_point_literal] = ACTIONS(991),
    [sym_hex_floating_point_literal] = ACTIONS(993),
    [sym_true] = ACTIONS(993),
    [sym_false] = ACTIONS(993),
    [sym_character_literal] = ACTIONS(991),
    [anon_sym_DQUOTE] = ACTIONS(993),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(991),
    [anon_sym_RBRACE] = ACTIONS(991),
    [sym_null_literal] = ACTIONS(993),
    [anon_sym_LPAREN] = ACTIONS(991),
    [anon_sym_LT] = ACTIONS(991),
    [anon_sym_PLUS] = ACTIONS(993),
    [anon_sym_DASH] = ACTIONS(993),
    [anon_sym_final] = ACTIONS(993),
    [anon_sym_BANG] = ACTIONS(991),
    [anon_sym_TILDE] = ACTIONS(991),
    [anon_sym_PLUS_PLUS] = ACTIONS(991),
    [anon_sym_DASH_DASH] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(993),
    [anon_sym_class] = ACTIONS(993),
    [anon_sym_switch] = ACTIONS(993),
    [anon_sym_LBRACE] = ACTIONS(991),
    [anon_sym_case] = ACTIONS(993),
    [anon_sym_default] = ACTIONS(993),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_assert] = ACTIONS(993),
    [anon_sym_do] = ACTIONS(993),
    [anon_sym_while] = ACTIONS(993),
    [anon_sym_break] = ACTIONS(993),
    [anon_sym_continue] = ACTIONS(993),
    [anon_sym_return] = ACTIONS(993),
    [anon_sym_yield] = ACTIONS(993),
    [anon_sym_synchronized] = ACTIONS(993),
    [anon_sym_throw] = ACTIONS(993),
    [anon_sym_try] = ACTIONS(993),
    [anon_sym_if] = ACTIONS(993),
    [anon_sym_else] = ACTIONS(993),
    [anon_sym_for] = ACTIONS(993),
    [anon_sym_AT] = ACTIONS(993),
    [anon_sym_open] = ACTIONS(993),
    [anon_sym_module] = ACTIONS(993),
    [anon_sym_static] = ACTIONS(993),
    [anon_sym_with] = ACTIONS(993),
    [anon_sym_package] = ACTIONS(993),
    [anon_sym_import] = ACTIONS(993),
    [anon_sym_enum] = ACTIONS(993),
    [anon_sym_public] = ACTIONS(993),
    [anon_sym_protected] = ACTIONS(993),
    [anon_sym_private] = ACTIONS(993),
    [anon_sym_abstract] = ACTIONS(993),
    [anon_sym_strictfp] = ACTIONS(993),
    [anon_sym_native] = ACTIONS(993),
    [anon_sym_transient] = ACTIONS(993),
    [anon_sym_volatile] = ACTIONS(993),
    [anon_sym_sealed] = ACTIONS(993),
    [anon_sym_non_DASHsealed] = ACTIONS(991),
    [anon_sym_record] = ACTIONS(993),
    [anon_sym_ATinterface] = ACTIONS(991),
    [anon_sym_interface] = ACTIONS(993),
    [anon_sym_byte] = ACTIONS(993),
    [anon_sym_short] = ACTIONS(993),
    [anon_sym_int] = ACTIONS(993),
    [anon_sym_long] = ACTIONS(993),
    [anon_sym_char] = ACTIONS(993),
    [anon_sym_float] = ACTIONS(993),
    [anon_sym_double] = ACTIONS(993),
    [sym_boolean_type] = ACTIONS(993),
    [sym_void_type] = ACTIONS(993),
    [sym_this] = ACTIONS(993),
    [sym_super] = ACTIONS(993),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [341] = {
    [ts_builtin_sym_end] = ACTIONS(995),
    [sym_identifier] = ACTIONS(997),
    [sym_decimal_integer_literal] = ACTIONS(997),
    [sym_hex_integer_literal] = ACTIONS(997),
    [sym_octal_integer_literal] = ACTIONS(997),
    [sym_binary_integer_literal] = ACTIONS(995),
    [sym_decimal_floating_point_literal] = ACTIONS(995),
    [sym_hex_floating_point_literal] = ACTIONS(997),
    [sym_true] = ACTIONS(997),
    [sym_false] = ACTIONS(997),
    [sym_character_literal] = ACTIONS(995),
    [anon_sym_DQUOTE] = ACTIONS(997),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(995),
    [anon_sym_RBRACE] = ACTIONS(995),
    [sym_null_literal] = ACTIONS(997),
    [anon_sym_LPAREN] = ACTIONS(995),
    [anon_sym_LT] = ACTIONS(995),
    [anon_sym_PLUS] = ACTIONS(997),
    [anon_sym_DASH] = ACTIONS(997),
    [anon_sym_final] = ACTIONS(997),
    [anon_sym_BANG] = ACTIONS(995),
    [anon_sym_TILDE] = ACTIONS(995),
    [anon_sym_PLUS_PLUS] = ACTIONS(995),
    [anon_sym_DASH_DASH] = ACTIONS(995),
    [anon_sym_new] = ACTIONS(997),
    [anon_sym_class] = ACTIONS(997),
    [anon_sym_switch] = ACTIONS(997),
    [anon_sym_LBRACE] = ACTIONS(995),
    [anon_sym_case] = ACTIONS(997),
    [anon_sym_default] = ACTIONS(997),
    [anon_sym_SEMI] = ACTIONS(995),
    [anon_sym_assert] = ACTIONS(997),
    [anon_sym_do] = ACTIONS(997),
    [anon_sym_while] = ACTIONS(997),
    [anon_sym_break] = ACTIONS(997),
    [anon_sym_continue] = ACTIONS(997),
    [anon_sym_return] = ACTIONS(997),
    [anon_sym_yield] = ACTIONS(997),
    [anon_sym_synchronized] = ACTIONS(997),
    [anon_sym_throw] = ACTIONS(997),
    [anon_sym_try] = ACTIONS(997),
    [anon_sym_if] = ACTIONS(997),
    [anon_sym_else] = ACTIONS(997),
    [anon_sym_for] = ACTIONS(997),
    [anon_sym_AT] = ACTIONS(997),
    [anon_sym_open] = ACTIONS(997),
    [anon_sym_module] = ACTIONS(997),
    [anon_sym_static] = ACTIONS(997),
    [anon_sym_with] = ACTIONS(997),
    [anon_sym_package] = ACTIONS(997),
    [anon_sym_import] = ACTIONS(997),
    [anon_sym_enum] = ACTIONS(997),
    [anon_sym_public] = ACTIONS(997),
    [anon_sym_protected] = ACTIONS(997),
    [anon_sym_private] = ACTIONS(997),
    [anon_sym_abstract] = ACTIONS(997),
    [anon_sym_strictfp] = ACTIONS(997),
    [anon_sym_native] = ACTIONS(997),
    [anon_sym_transient] = ACTIONS(997),
    [anon_sym_volatile] = ACTIONS(997),
    [anon_sym_sealed] = ACTIONS(997),
    [anon_sym_non_DASHsealed] = ACTIONS(995),
    [anon_sym_record] = ACTIONS(997),
    [anon_sym_ATinterface] = ACTIONS(995),
    [anon_sym_interface] = ACTIONS(997),
    [anon_sym_byte] = ACTIONS(997),
    [anon_sym_short] = ACTIONS(997),
    [anon_sym_int] = ACTIONS(997),
    [anon_sym_long] = ACTIONS(997),
    [anon_sym_char] = ACTIONS(997),
    [anon_sym_float] = ACTIONS(997),
    [anon_sym_double] = ACTIONS(997),
    [sym_boolean_type] = ACTIONS(997),
    [sym_void_type] = ACTIONS(997),
    [sym_this] = ACTIONS(997),
    [sym_super] = ACTIONS(997),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [342] = {
    [ts_builtin_sym_end] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [sym_decimal_integer_literal] = ACTIONS(1001),
    [sym_hex_integer_literal] = ACTIONS(1001),
    [sym_octal_integer_literal] = ACTIONS(1001),
    [sym_binary_integer_literal] = ACTIONS(999),
    [sym_decimal_floating_point_literal] = ACTIONS(999),
    [sym_hex_floating_point_literal] = ACTIONS(1001),
    [sym_true] = ACTIONS(1001),
    [sym_false] = ACTIONS(1001),
    [sym_character_literal] = ACTIONS(999),
    [anon_sym_DQUOTE] = ACTIONS(1001),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(999),
    [anon_sym_RBRACE] = ACTIONS(999),
    [sym_null_literal] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(999),
    [anon_sym_LT] = ACTIONS(999),
    [anon_sym_PLUS] = ACTIONS(1001),
    [anon_sym_DASH] = ACTIONS(1001),
    [anon_sym_final] = ACTIONS(1001),
    [anon_sym_BANG] = ACTIONS(999),
    [anon_sym_TILDE] = ACTIONS(999),
    [anon_sym_PLUS_PLUS] = ACTIONS(999),
    [anon_sym_DASH_DASH] = ACTIONS(999),
    [anon_sym_new] = ACTIONS(1001),
    [anon_sym_class] = ACTIONS(1001),
    [anon_sym_switch] = ACTIONS(1001),
    [anon_sym_LBRACE] = ACTIONS(999),
    [anon_sym_case] = ACTIONS(1001),
    [anon_sym_default] = ACTIONS(1001),
    [anon_sym_SEMI] = ACTIONS(999),
    [anon_sym_assert] = ACTIONS(1001),
    [anon_sym_do] = ACTIONS(1001),
    [anon_sym_while] = ACTIONS(1001),
    [anon_sym_break] = ACTIONS(1001),
    [anon_sym_continue] = ACTIONS(1001),
    [anon_sym_return] = ACTIONS(1001),
    [anon_sym_yield] = ACTIONS(1001),
    [anon_sym_synchronized] = ACTIONS(1001),
    [anon_sym_throw] = ACTIONS(1001),
    [anon_sym_try] = ACTIONS(1001),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_else] = ACTIONS(1001),
    [anon_sym_for] = ACTIONS(1001),
    [anon_sym_AT] = ACTIONS(1001),
    [anon_sym_open] = ACTIONS(1001),
    [anon_sym_module] = ACTIONS(1001),
    [anon_sym_static] = ACTIONS(1001),
    [anon_sym_with] = ACTIONS(1001),
    [anon_sym_package] = ACTIONS(1001),
    [anon_sym_import] = ACTIONS(1001),
    [anon_sym_enum] = ACTIONS(1001),
    [anon_sym_public] = ACTIONS(1001),
    [anon_sym_protected] = ACTIONS(1001),
    [anon_sym_private] = ACTIONS(1001),
    [anon_sym_abstract] = ACTIONS(1001),
    [anon_sym_strictfp] = ACTIONS(1001),
    [anon_sym_native] = ACTIONS(1001),
    [anon_sym_transient] = ACTIONS(1001),
    [anon_sym_volatile] = ACTIONS(1001),
    [anon_sym_sealed] = ACTIONS(1001),
    [anon_sym_non_DASHsealed] = ACTIONS(999),
    [anon_sym_record] = ACTIONS(1001),
    [anon_sym_ATinterface] = ACTIONS(999),
    [anon_sym_interface] = ACTIONS(1001),
    [anon_sym_byte] = ACTIONS(1001),
    [anon_sym_short] = ACTIONS(1001),
    [anon_sym_int] = ACTIONS(1001),
    [anon_sym_long] = ACTIONS(1001),
    [anon_sym_char] = ACTIONS(1001),
    [anon_sym_float] = ACTIONS(1001),
    [anon_sym_double] = ACTIONS(1001),
    [sym_boolean_type] = ACTIONS(1001),
    [sym_void_type] = ACTIONS(1001),
    [sym_this] = ACTIONS(1001),
    [sym_super] = ACTIONS(1001),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [343] = {
    [ts_builtin_sym_end] = ACTIONS(1003),
    [sym_identifier] = ACTIONS(1005),
    [sym_decimal_integer_literal] = ACTIONS(1005),
    [sym_hex_integer_literal] = ACTIONS(1005),
    [sym_octal_integer_literal] = ACTIONS(1005),
    [sym_binary_integer_literal] = ACTIONS(1003),
    [sym_decimal_floating_point_literal] = ACTIONS(1003),
    [sym_hex_floating_point_literal] = ACTIONS(1005),
    [sym_true] = ACTIONS(1005),
    [sym_false] = ACTIONS(1005),
    [sym_character_literal] = ACTIONS(1003),
    [anon_sym_DQUOTE] = ACTIONS(1005),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1003),
    [anon_sym_RBRACE] = ACTIONS(1003),
    [sym_null_literal] = ACTIONS(1005),
    [anon_sym_LPAREN] = ACTIONS(1003),
    [anon_sym_LT] = ACTIONS(1003),
    [anon_sym_PLUS] = ACTIONS(1005),
    [anon_sym_DASH] = ACTIONS(1005),
    [anon_sym_final] = ACTIONS(1005),
    [anon_sym_BANG] = ACTIONS(1003),
    [anon_sym_TILDE] = ACTIONS(1003),
    [anon_sym_PLUS_PLUS] = ACTIONS(1003),
    [anon_sym_DASH_DASH] = ACTIONS(1003),
    [anon_sym_new] = ACTIONS(1005),
    [anon_sym_class] = ACTIONS(1005),
    [anon_sym_switch] = ACTIONS(1005),
    [anon_sym_LBRACE] = ACTIONS(1003),
    [anon_sym_case] = ACTIONS(1005),
    [anon_sym_default] = ACTIONS(1005),
    [anon_sym_SEMI] = ACTIONS(1003),
    [anon_sym_assert] = ACTIONS(1005),
    [anon_sym_do] = ACTIONS(1005),
    [anon_sym_while] = ACTIONS(1005),
    [anon_sym_break] = ACTIONS(1005),
    [anon_sym_continue] = ACTIONS(1005),
    [anon_sym_return] = ACTIONS(1005),
    [anon_sym_yield] = ACTIONS(1005),
    [anon_sym_synchronized] = ACTIONS(1005),
    [anon_sym_throw] = ACTIONS(1005),
    [anon_sym_try] = ACTIONS(1005),
    [anon_sym_if] = ACTIONS(1005),
    [anon_sym_else] = ACTIONS(1005),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_AT] = ACTIONS(1005),
    [anon_sym_open] = ACTIONS(1005),
    [anon_sym_module] = ACTIONS(1005),
    [anon_sym_static] = ACTIONS(1005),
    [anon_sym_with] = ACTIONS(1005),
    [anon_sym_package] = ACTIONS(1005),
    [anon_sym_import] = ACTIONS(1005),
    [anon_sym_enum] = ACTIONS(1005),
    [anon_sym_public] = ACTIONS(1005),
    [anon_sym_protected] = ACTIONS(1005),
    [anon_sym_private] = ACTIONS(1005),
    [anon_sym_abstract] = ACTIONS(1005),
    [anon_sym_strictfp] = ACTIONS(1005),
    [anon_sym_native] = ACTIONS(1005),
    [anon_sym_transient] = ACTIONS(1005),
    [anon_sym_volatile] = ACTIONS(1005),
    [anon_sym_sealed] = ACTIONS(1005),
    [anon_sym_non_DASHsealed] = ACTIONS(1003),
    [anon_sym_record] = ACTIONS(1005),
    [anon_sym_ATinterface] = ACTIONS(1003),
    [anon_sym_interface] = ACTIONS(1005),
    [anon_sym_byte] = ACTIONS(1005),
    [anon_sym_short] = ACTIONS(1005),
    [anon_sym_int] = ACTIONS(1005),
    [anon_sym_long] = ACTIONS(1005),
    [anon_sym_char] = ACTIONS(1005),
    [anon_sym_float] = ACTIONS(1005),
    [anon_sym_double] = ACTIONS(1005),
    [sym_boolean_type] = ACTIONS(1005),
    [sym_void_type] = ACTIONS(1005),
    [sym_this] = ACTIONS(1005),
    [sym_super] = ACTIONS(1005),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [344] = {
    [ts_builtin_sym_end] = ACTIONS(1007),
    [sym_identifier] = ACTIONS(1009),
    [sym_decimal_integer_literal] = ACTIONS(1009),
    [sym_hex_integer_literal] = ACTIONS(1009),
    [sym_octal_integer_literal] = ACTIONS(1009),
    [sym_binary_integer_literal] = ACTIONS(1007),
    [sym_decimal_floating_point_literal] = ACTIONS(1007),
    [sym_hex_floating_point_literal] = ACTIONS(1009),
    [sym_true] = ACTIONS(1009),
    [sym_false] = ACTIONS(1009),
    [sym_character_literal] = ACTIONS(1007),
    [anon_sym_DQUOTE] = ACTIONS(1009),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1007),
    [anon_sym_RBRACE] = ACTIONS(1007),
    [sym_null_literal] = ACTIONS(1009),
    [anon_sym_LPAREN] = ACTIONS(1007),
    [anon_sym_LT] = ACTIONS(1007),
    [anon_sym_PLUS] = ACTIONS(1009),
    [anon_sym_DASH] = ACTIONS(1009),
    [anon_sym_final] = ACTIONS(1009),
    [anon_sym_BANG] = ACTIONS(1007),
    [anon_sym_TILDE] = ACTIONS(1007),
    [anon_sym_PLUS_PLUS] = ACTIONS(1007),
    [anon_sym_DASH_DASH] = ACTIONS(1007),
    [anon_sym_new] = ACTIONS(1009),
    [anon_sym_class] = ACTIONS(1009),
    [anon_sym_switch] = ACTIONS(1009),
    [anon_sym_LBRACE] = ACTIONS(1007),
    [anon_sym_case] = ACTIONS(1009),
    [anon_sym_default] = ACTIONS(1009),
    [anon_sym_SEMI] = ACTIONS(1007),
    [anon_sym_assert] = ACTIONS(1009),
    [anon_sym_do] = ACTIONS(1009),
    [anon_sym_while] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_continue] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1009),
    [anon_sym_yield] = ACTIONS(1009),
    [anon_sym_synchronized] = ACTIONS(1009),
    [anon_sym_throw] = ACTIONS(1009),
    [anon_sym_try] = ACTIONS(1009),
    [anon_sym_if] = ACTIONS(1009),
    [anon_sym_else] = ACTIONS(1009),
    [anon_sym_for] = ACTIONS(1009),
    [anon_sym_AT] = ACTIONS(1009),
    [anon_sym_open] = ACTIONS(1009),
    [anon_sym_module] = ACTIONS(1009),
    [anon_sym_static] = ACTIONS(1009),
    [anon_sym_with] = ACTIONS(1009),
    [anon_sym_package] = ACTIONS(1009),
    [anon_sym_import] = ACTIONS(1009),
    [anon_sym_enum] = ACTIONS(1009),
    [anon_sym_public] = ACTIONS(1009),
    [anon_sym_protected] = ACTIONS(1009),
    [anon_sym_private] = ACTIONS(1009),
    [anon_sym_abstract] = ACTIONS(1009),
    [anon_sym_strictfp] = ACTIONS(1009),
    [anon_sym_native] = ACTIONS(1009),
    [anon_sym_transient] = ACTIONS(1009),
    [anon_sym_volatile] = ACTIONS(1009),
    [anon_sym_sealed] = ACTIONS(1009),
    [anon_sym_non_DASHsealed] = ACTIONS(1007),
    [anon_sym_record] = ACTIONS(1009),
    [anon_sym_ATinterface] = ACTIONS(1007),
    [anon_sym_interface] = ACTIONS(1009),
    [anon_sym_byte] = ACTIONS(1009),
    [anon_sym_short] = ACTIONS(1009),
    [anon_sym_int] = ACTIONS(1009),
    [anon_sym_long] = ACTIONS(1009),
    [anon_sym_char] = ACTIONS(1009),
    [anon_sym_float] = ACTIONS(1009),
    [anon_sym_double] = ACTIONS(1009),
    [sym_boolean_type] = ACTIONS(1009),
    [sym_void_type] = ACTIONS(1009),
    [sym_this] = ACTIONS(1009),
    [sym_super] = ACTIONS(1009),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [345] = {
    [ts_builtin_sym_end] = ACTIONS(1011),
    [sym_identifier] = ACTIONS(1013),
    [sym_decimal_integer_literal] = ACTIONS(1013),
    [sym_hex_integer_literal] = ACTIONS(1013),
    [sym_octal_integer_literal] = ACTIONS(1013),
    [sym_binary_integer_literal] = ACTIONS(1011),
    [sym_decimal_floating_point_literal] = ACTIONS(1011),
    [sym_hex_floating_point_literal] = ACTIONS(1013),
    [sym_true] = ACTIONS(1013),
    [sym_false] = ACTIONS(1013),
    [sym_character_literal] = ACTIONS(1011),
    [anon_sym_DQUOTE] = ACTIONS(1013),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1011),
    [anon_sym_RBRACE] = ACTIONS(1011),
    [sym_null_literal] = ACTIONS(1013),
    [anon_sym_LPAREN] = ACTIONS(1011),
    [anon_sym_LT] = ACTIONS(1011),
    [anon_sym_PLUS] = ACTIONS(1013),
    [anon_sym_DASH] = ACTIONS(1013),
    [anon_sym_final] = ACTIONS(1013),
    [anon_sym_BANG] = ACTIONS(1011),
    [anon_sym_TILDE] = ACTIONS(1011),
    [anon_sym_PLUS_PLUS] = ACTIONS(1011),
    [anon_sym_DASH_DASH] = ACTIONS(1011),
    [anon_sym_new] = ACTIONS(1013),
    [anon_sym_class] = ACTIONS(1013),
    [anon_sym_switch] = ACTIONS(1013),
    [anon_sym_LBRACE] = ACTIONS(1011),
    [anon_sym_case] = ACTIONS(1013),
    [anon_sym_default] = ACTIONS(1013),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_assert] = ACTIONS(1013),
    [anon_sym_do] = ACTIONS(1013),
    [anon_sym_while] = ACTIONS(1013),
    [anon_sym_break] = ACTIONS(1013),
    [anon_sym_continue] = ACTIONS(1013),
    [anon_sym_return] = ACTIONS(1013),
    [anon_sym_yield] = ACTIONS(1013),
    [anon_sym_synchronized] = ACTIONS(1013),
    [anon_sym_throw] = ACTIONS(1013),
    [anon_sym_try] = ACTIONS(1013),
    [anon_sym_if] = ACTIONS(1013),
    [anon_sym_else] = ACTIONS(1013),
    [anon_sym_for] = ACTIONS(1013),
    [anon_sym_AT] = ACTIONS(1013),
    [anon_sym_open] = ACTIONS(1013),
    [anon_sym_module] = ACTIONS(1013),
    [anon_sym_static] = ACTIONS(1013),
    [anon_sym_with] = ACTIONS(1013),
    [anon_sym_package] = ACTIONS(1013),
    [anon_sym_import] = ACTIONS(1013),
    [anon_sym_enum] = ACTIONS(1013),
    [anon_sym_public] = ACTIONS(1013),
    [anon_sym_protected] = ACTIONS(1013),
    [anon_sym_private] = ACTIONS(1013),
    [anon_sym_abstract] = ACTIONS(1013),
    [anon_sym_strictfp] = ACTIONS(1013),
    [anon_sym_native] = ACTIONS(1013),
    [anon_sym_transient] = ACTIONS(1013),
    [anon_sym_volatile] = ACTIONS(1013),
    [anon_sym_sealed] = ACTIONS(1013),
    [anon_sym_non_DASHsealed] = ACTIONS(1011),
    [anon_sym_record] = ACTIONS(1013),
    [anon_sym_ATinterface] = ACTIONS(1011),
    [anon_sym_interface] = ACTIONS(1013),
    [anon_sym_byte] = ACTIONS(1013),
    [anon_sym_short] = ACTIONS(1013),
    [anon_sym_int] = ACTIONS(1013),
    [anon_sym_long] = ACTIONS(1013),
    [anon_sym_char] = ACTIONS(1013),
    [anon_sym_float] = ACTIONS(1013),
    [anon_sym_double] = ACTIONS(1013),
    [sym_boolean_type] = ACTIONS(1013),
    [sym_void_type] = ACTIONS(1013),
    [sym_this] = ACTIONS(1013),
    [sym_super] = ACTIONS(1013),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [346] = {
    [ts_builtin_sym_end] = ACTIONS(1015),
    [sym_identifier] = ACTIONS(1017),
    [sym_decimal_integer_literal] = ACTIONS(1017),
    [sym_hex_integer_literal] = ACTIONS(1017),
    [sym_octal_integer_literal] = ACTIONS(1017),
    [sym_binary_integer_literal] = ACTIONS(1015),
    [sym_decimal_floating_point_literal] = ACTIONS(1015),
    [sym_hex_floating_point_literal] = ACTIONS(1017),
    [sym_true] = ACTIONS(1017),
    [sym_false] = ACTIONS(1017),
    [sym_character_literal] = ACTIONS(1015),
    [anon_sym_DQUOTE] = ACTIONS(1017),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1015),
    [anon_sym_RBRACE] = ACTIONS(1015),
    [sym_null_literal] = ACTIONS(1017),
    [anon_sym_LPAREN] = ACTIONS(1015),
    [anon_sym_LT] = ACTIONS(1015),
    [anon_sym_PLUS] = ACTIONS(1017),
    [anon_sym_DASH] = ACTIONS(1017),
    [anon_sym_final] = ACTIONS(1017),
    [anon_sym_BANG] = ACTIONS(1015),
    [anon_sym_TILDE] = ACTIONS(1015),
    [anon_sym_PLUS_PLUS] = ACTIONS(1015),
    [anon_sym_DASH_DASH] = ACTIONS(1015),
    [anon_sym_new] = ACTIONS(1017),
    [anon_sym_class] = ACTIONS(1017),
    [anon_sym_switch] = ACTIONS(1017),
    [anon_sym_LBRACE] = ACTIONS(1015),
    [anon_sym_case] = ACTIONS(1017),
    [anon_sym_default] = ACTIONS(1017),
    [anon_sym_SEMI] = ACTIONS(1015),
    [anon_sym_assert] = ACTIONS(1017),
    [anon_sym_do] = ACTIONS(1017),
    [anon_sym_while] = ACTIONS(1017),
    [anon_sym_break] = ACTIONS(1017),
    [anon_sym_continue] = ACTIONS(1017),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_yield] = ACTIONS(1017),
    [anon_sym_synchronized] = ACTIONS(1017),
    [anon_sym_throw] = ACTIONS(1017),
    [anon_sym_try] = ACTIONS(1017),
    [anon_sym_if] = ACTIONS(1017),
    [anon_sym_else] = ACTIONS(1017),
    [anon_sym_for] = ACTIONS(1017),
    [anon_sym_AT] = ACTIONS(1017),
    [anon_sym_open] = ACTIONS(1017),
    [anon_sym_module] = ACTIONS(1017),
    [anon_sym_static] = ACTIONS(1017),
    [anon_sym_with] = ACTIONS(1017),
    [anon_sym_package] = ACTIONS(1017),
    [anon_sym_import] = ACTIONS(1017),
    [anon_sym_enum] = ACTIONS(1017),
    [anon_sym_public] = ACTIONS(1017),
    [anon_sym_protected] = ACTIONS(1017),
    [anon_sym_private] = ACTIONS(1017),
    [anon_sym_abstract] = ACTIONS(1017),
    [anon_sym_strictfp] = ACTIONS(1017),
    [anon_sym_native] = ACTIONS(1017),
    [anon_sym_transient] = ACTIONS(1017),
    [anon_sym_volatile] = ACTIONS(1017),
    [anon_sym_sealed] = ACTIONS(1017),
    [anon_sym_non_DASHsealed] = ACTIONS(1015),
    [anon_sym_record] = ACTIONS(1017),
    [anon_sym_ATinterface] = ACTIONS(1015),
    [anon_sym_interface] = ACTIONS(1017),
    [anon_sym_byte] = ACTIONS(1017),
    [anon_sym_short] = ACTIONS(1017),
    [anon_sym_int] = ACTIONS(1017),
    [anon_sym_long] = ACTIONS(1017),
    [anon_sym_char] = ACTIONS(1017),
    [anon_sym_float] = ACTIONS(1017),
    [anon_sym_double] = ACTIONS(1017),
    [sym_boolean_type] = ACTIONS(1017),
    [sym_void_type] = ACTIONS(1017),
    [sym_this] = ACTIONS(1017),
    [sym_super] = ACTIONS(1017),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [347] = {
    [ts_builtin_sym_end] = ACTIONS(1019),
    [sym_identifier] = ACTIONS(1021),
    [sym_decimal_integer_literal] = ACTIONS(1021),
    [sym_hex_integer_literal] = ACTIONS(1021),
    [sym_octal_integer_literal] = ACTIONS(1021),
    [sym_binary_integer_literal] = ACTIONS(1019),
    [sym_decimal_floating_point_literal] = ACTIONS(1019),
    [sym_hex_floating_point_literal] = ACTIONS(1021),
    [sym_true] = ACTIONS(1021),
    [sym_false] = ACTIONS(1021),
    [sym_character_literal] = ACTIONS(1019),
    [anon_sym_DQUOTE] = ACTIONS(1021),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1019),
    [anon_sym_RBRACE] = ACTIONS(1019),
    [sym_null_literal] = ACTIONS(1021),
    [anon_sym_LPAREN] = ACTIONS(1019),
    [anon_sym_LT] = ACTIONS(1019),
    [anon_sym_PLUS] = ACTIONS(1021),
    [anon_sym_DASH] = ACTIONS(1021),
    [anon_sym_final] = ACTIONS(1021),
    [anon_sym_BANG] = ACTIONS(1019),
    [anon_sym_TILDE] = ACTIONS(1019),
    [anon_sym_PLUS_PLUS] = ACTIONS(1019),
    [anon_sym_DASH_DASH] = ACTIONS(1019),
    [anon_sym_new] = ACTIONS(1021),
    [anon_sym_class] = ACTIONS(1021),
    [anon_sym_switch] = ACTIONS(1021),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_case] = ACTIONS(1021),
    [anon_sym_default] = ACTIONS(1021),
    [anon_sym_SEMI] = ACTIONS(1019),
    [anon_sym_assert] = ACTIONS(1021),
    [anon_sym_do] = ACTIONS(1021),
    [anon_sym_while] = ACTIONS(1021),
    [anon_sym_break] = ACTIONS(1021),
    [anon_sym_continue] = ACTIONS(1021),
    [anon_sym_return] = ACTIONS(1021),
    [anon_sym_yield] = ACTIONS(1021),
    [anon_sym_synchronized] = ACTIONS(1021),
    [anon_sym_throw] = ACTIONS(1021),
    [anon_sym_try] = ACTIONS(1021),
    [anon_sym_if] = ACTIONS(1021),
    [anon_sym_else] = ACTIONS(1021),
    [anon_sym_for] = ACTIONS(1021),
    [anon_sym_AT] = ACTIONS(1021),
    [anon_sym_open] = ACTIONS(1021),
    [anon_sym_module] = ACTIONS(1021),
    [anon_sym_static] = ACTIONS(1021),
    [anon_sym_with] = ACTIONS(1021),
    [anon_sym_package] = ACTIONS(1021),
    [anon_sym_import] = ACTIONS(1021),
    [anon_sym_enum] = ACTIONS(1021),
    [anon_sym_public] = ACTIONS(1021),
    [anon_sym_protected] = ACTIONS(1021),
    [anon_sym_private] = ACTIONS(1021),
    [anon_sym_abstract] = ACTIONS(1021),
    [anon_sym_strictfp] = ACTIONS(1021),
    [anon_sym_native] = ACTIONS(1021),
    [anon_sym_transient] = ACTIONS(1021),
    [anon_sym_volatile] = ACTIONS(1021),
    [anon_sym_sealed] = ACTIONS(1021),
    [anon_sym_non_DASHsealed] = ACTIONS(1019),
    [anon_sym_record] = ACTIONS(1021),
    [anon_sym_ATinterface] = ACTIONS(1019),
    [anon_sym_interface] = ACTIONS(1021),
    [anon_sym_byte] = ACTIONS(1021),
    [anon_sym_short] = ACTIONS(1021),
    [anon_sym_int] = ACTIONS(1021),
    [anon_sym_long] = ACTIONS(1021),
    [anon_sym_char] = ACTIONS(1021),
    [anon_sym_float] = ACTIONS(1021),
    [anon_sym_double] = ACTIONS(1021),
    [sym_boolean_type] = ACTIONS(1021),
    [sym_void_type] = ACTIONS(1021),
    [sym_this] = ACTIONS(1021),
    [sym_super] = ACTIONS(1021),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [348] = {
    [ts_builtin_sym_end] = ACTIONS(1023),
    [sym_identifier] = ACTIONS(1025),
    [sym_decimal_integer_literal] = ACTIONS(1025),
    [sym_hex_integer_literal] = ACTIONS(1025),
    [sym_octal_integer_literal] = ACTIONS(1025),
    [sym_binary_integer_literal] = ACTIONS(1023),
    [sym_decimal_floating_point_literal] = ACTIONS(1023),
    [sym_hex_floating_point_literal] = ACTIONS(1025),
    [sym_true] = ACTIONS(1025),
    [sym_false] = ACTIONS(1025),
    [sym_character_literal] = ACTIONS(1023),
    [anon_sym_DQUOTE] = ACTIONS(1025),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1023),
    [anon_sym_RBRACE] = ACTIONS(1023),
    [sym_null_literal] = ACTIONS(1025),
    [anon_sym_LPAREN] = ACTIONS(1023),
    [anon_sym_LT] = ACTIONS(1023),
    [anon_sym_PLUS] = ACTIONS(1025),
    [anon_sym_DASH] = ACTIONS(1025),
    [anon_sym_final] = ACTIONS(1025),
    [anon_sym_BANG] = ACTIONS(1023),
    [anon_sym_TILDE] = ACTIONS(1023),
    [anon_sym_PLUS_PLUS] = ACTIONS(1023),
    [anon_sym_DASH_DASH] = ACTIONS(1023),
    [anon_sym_new] = ACTIONS(1025),
    [anon_sym_class] = ACTIONS(1025),
    [anon_sym_switch] = ACTIONS(1025),
    [anon_sym_LBRACE] = ACTIONS(1023),
    [anon_sym_case] = ACTIONS(1025),
    [anon_sym_default] = ACTIONS(1025),
    [anon_sym_SEMI] = ACTIONS(1023),
    [anon_sym_assert] = ACTIONS(1025),
    [anon_sym_do] = ACTIONS(1025),
    [anon_sym_while] = ACTIONS(1025),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_continue] = ACTIONS(1025),
    [anon_sym_return] = ACTIONS(1025),
    [anon_sym_yield] = ACTIONS(1025),
    [anon_sym_synchronized] = ACTIONS(1025),
    [anon_sym_throw] = ACTIONS(1025),
    [anon_sym_try] = ACTIONS(1025),
    [anon_sym_if] = ACTIONS(1025),
    [anon_sym_else] = ACTIONS(1025),
    [anon_sym_for] = ACTIONS(1025),
    [anon_sym_AT] = ACTIONS(1025),
    [anon_sym_open] = ACTIONS(1025),
    [anon_sym_module] = ACTIONS(1025),
    [anon_sym_static] = ACTIONS(1025),
    [anon_sym_with] = ACTIONS(1025),
    [anon_sym_package] = ACTIONS(1025),
    [anon_sym_import] = ACTIONS(1025),
    [anon_sym_enum] = ACTIONS(1025),
    [anon_sym_public] = ACTIONS(1025),
    [anon_sym_protected] = ACTIONS(1025),
    [anon_sym_private] = ACTIONS(1025),
    [anon_sym_abstract] = ACTIONS(1025),
    [anon_sym_strictfp] = ACTIONS(1025),
    [anon_sym_native] = ACTIONS(1025),
    [anon_sym_transient] = ACTIONS(1025),
    [anon_sym_volatile] = ACTIONS(1025),
    [anon_sym_sealed] = ACTIONS(1025),
    [anon_sym_non_DASHsealed] = ACTIONS(1023),
    [anon_sym_record] = ACTIONS(1025),
    [anon_sym_ATinterface] = ACTIONS(1023),
    [anon_sym_interface] = ACTIONS(1025),
    [anon_sym_byte] = ACTIONS(1025),
    [anon_sym_short] = ACTIONS(1025),
    [anon_sym_int] = ACTIONS(1025),
    [anon_sym_long] = ACTIONS(1025),
    [anon_sym_char] = ACTIONS(1025),
    [anon_sym_float] = ACTIONS(1025),
    [anon_sym_double] = ACTIONS(1025),
    [sym_boolean_type] = ACTIONS(1025),
    [sym_void_type] = ACTIONS(1025),
    [sym_this] = ACTIONS(1025),
    [sym_super] = ACTIONS(1025),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [349] = {
    [ts_builtin_sym_end] = ACTIONS(1027),
    [sym_identifier] = ACTIONS(1029),
    [sym_decimal_integer_literal] = ACTIONS(1029),
    [sym_hex_integer_literal] = ACTIONS(1029),
    [sym_octal_integer_literal] = ACTIONS(1029),
    [sym_binary_integer_literal] = ACTIONS(1027),
    [sym_decimal_floating_point_literal] = ACTIONS(1027),
    [sym_hex_floating_point_literal] = ACTIONS(1029),
    [sym_true] = ACTIONS(1029),
    [sym_false] = ACTIONS(1029),
    [sym_character_literal] = ACTIONS(1027),
    [anon_sym_DQUOTE] = ACTIONS(1029),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1027),
    [anon_sym_RBRACE] = ACTIONS(1027),
    [sym_null_literal] = ACTIONS(1029),
    [anon_sym_LPAREN] = ACTIONS(1027),
    [anon_sym_LT] = ACTIONS(1027),
    [anon_sym_PLUS] = ACTIONS(1029),
    [anon_sym_DASH] = ACTIONS(1029),
    [anon_sym_final] = ACTIONS(1029),
    [anon_sym_BANG] = ACTIONS(1027),
    [anon_sym_TILDE] = ACTIONS(1027),
    [anon_sym_PLUS_PLUS] = ACTIONS(1027),
    [anon_sym_DASH_DASH] = ACTIONS(1027),
    [anon_sym_new] = ACTIONS(1029),
    [anon_sym_class] = ACTIONS(1029),
    [anon_sym_switch] = ACTIONS(1029),
    [anon_sym_LBRACE] = ACTIONS(1027),
    [anon_sym_case] = ACTIONS(1029),
    [anon_sym_default] = ACTIONS(1029),
    [anon_sym_SEMI] = ACTIONS(1027),
    [anon_sym_assert] = ACTIONS(1029),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1029),
    [anon_sym_break] = ACTIONS(1029),
    [anon_sym_continue] = ACTIONS(1029),
    [anon_sym_return] = ACTIONS(1029),
    [anon_sym_yield] = ACTIONS(1029),
    [anon_sym_synchronized] = ACTIONS(1029),
    [anon_sym_throw] = ACTIONS(1029),
    [anon_sym_try] = ACTIONS(1029),
    [anon_sym_if] = ACTIONS(1029),
    [anon_sym_else] = ACTIONS(1029),
    [anon_sym_for] = ACTIONS(1029),
    [anon_sym_AT] = ACTIONS(1029),
    [anon_sym_open] = ACTIONS(1029),
    [anon_sym_module] = ACTIONS(1029),
    [anon_sym_static] = ACTIONS(1029),
    [anon_sym_with] = ACTIONS(1029),
    [anon_sym_package] = ACTIONS(1029),
    [anon_sym_import] = ACTIONS(1029),
    [anon_sym_enum] = ACTIONS(1029),
    [anon_sym_public] = ACTIONS(1029),
    [anon_sym_protected] = ACTIONS(1029),
    [anon_sym_private] = ACTIONS(1029),
    [anon_sym_abstract] = ACTIONS(1029),
    [anon_sym_strictfp] = ACTIONS(1029),
    [anon_sym_native] = ACTIONS(1029),
    [anon_sym_transient] = ACTIONS(1029),
    [anon_sym_volatile] = ACTIONS(1029),
    [anon_sym_sealed] = ACTIONS(1029),
    [anon_sym_non_DASHsealed] = ACTIONS(1027),
    [anon_sym_record] = ACTIONS(1029),
    [anon_sym_ATinterface] = ACTIONS(1027),
    [anon_sym_interface] = ACTIONS(1029),
    [anon_sym_byte] = ACTIONS(1029),
    [anon_sym_short] = ACTIONS(1029),
    [anon_sym_int] = ACTIONS(1029),
    [anon_sym_long] = ACTIONS(1029),
    [anon_sym_char] = ACTIONS(1029),
    [anon_sym_float] = ACTIONS(1029),
    [anon_sym_double] = ACTIONS(1029),
    [sym_boolean_type] = ACTIONS(1029),
    [sym_void_type] = ACTIONS(1029),
    [sym_this] = ACTIONS(1029),
    [sym_super] = ACTIONS(1029),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [350] = {
    [ts_builtin_sym_end] = ACTIONS(1031),
    [sym_identifier] = ACTIONS(1033),
    [sym_decimal_integer_literal] = ACTIONS(1033),
    [sym_hex_integer_literal] = ACTIONS(1033),
    [sym_octal_integer_literal] = ACTIONS(1033),
    [sym_binary_integer_literal] = ACTIONS(1031),
    [sym_decimal_floating_point_literal] = ACTIONS(1031),
    [sym_hex_floating_point_literal] = ACTIONS(1033),
    [sym_true] = ACTIONS(1033),
    [sym_false] = ACTIONS(1033),
    [sym_character_literal] = ACTIONS(1031),
    [anon_sym_DQUOTE] = ACTIONS(1033),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1031),
    [anon_sym_RBRACE] = ACTIONS(1031),
    [sym_null_literal] = ACTIONS(1033),
    [anon_sym_LPAREN] = ACTIONS(1031),
    [anon_sym_LT] = ACTIONS(1031),
    [anon_sym_PLUS] = ACTIONS(1033),
    [anon_sym_DASH] = ACTIONS(1033),
    [anon_sym_final] = ACTIONS(1033),
    [anon_sym_BANG] = ACTIONS(1031),
    [anon_sym_TILDE] = ACTIONS(1031),
    [anon_sym_PLUS_PLUS] = ACTIONS(1031),
    [anon_sym_DASH_DASH] = ACTIONS(1031),
    [anon_sym_new] = ACTIONS(1033),
    [anon_sym_class] = ACTIONS(1033),
    [anon_sym_switch] = ACTIONS(1033),
    [anon_sym_LBRACE] = ACTIONS(1031),
    [anon_sym_case] = ACTIONS(1033),
    [anon_sym_default] = ACTIONS(1033),
    [anon_sym_SEMI] = ACTIONS(1031),
    [anon_sym_assert] = ACTIONS(1033),
    [anon_sym_do] = ACTIONS(1033),
    [anon_sym_while] = ACTIONS(1033),
    [anon_sym_break] = ACTIONS(1033),
    [anon_sym_continue] = ACTIONS(1033),
    [anon_sym_return] = ACTIONS(1033),
    [anon_sym_yield] = ACTIONS(1033),
    [anon_sym_synchronized] = ACTIONS(1033),
    [anon_sym_throw] = ACTIONS(1033),
    [anon_sym_try] = ACTIONS(1033),
    [anon_sym_if] = ACTIONS(1033),
    [anon_sym_else] = ACTIONS(1033),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_AT] = ACTIONS(1033),
    [anon_sym_open] = ACTIONS(1033),
    [anon_sym_module] = ACTIONS(1033),
    [anon_sym_static] = ACTIONS(1033),
    [anon_sym_with] = ACTIONS(1033),
    [anon_sym_package] = ACTIONS(1033),
    [anon_sym_import] = ACTIONS(1033),
    [anon_sym_enum] = ACTIONS(1033),
    [anon_sym_public] = ACTIONS(1033),
    [anon_sym_protected] = ACTIONS(1033),
    [anon_sym_private] = ACTIONS(1033),
    [anon_sym_abstract] = ACTIONS(1033),
    [anon_sym_strictfp] = ACTIONS(1033),
    [anon_sym_native] = ACTIONS(1033),
    [anon_sym_transient] = ACTIONS(1033),
    [anon_sym_volatile] = ACTIONS(1033),
    [anon_sym_sealed] = ACTIONS(1033),
    [anon_sym_non_DASHsealed] = ACTIONS(1031),
    [anon_sym_record] = ACTIONS(1033),
    [anon_sym_ATinterface] = ACTIONS(1031),
    [anon_sym_interface] = ACTIONS(1033),
    [anon_sym_byte] = ACTIONS(1033),
    [anon_sym_short] = ACTIONS(1033),
    [anon_sym_int] = ACTIONS(1033),
    [anon_sym_long] = ACTIONS(1033),
    [anon_sym_char] = ACTIONS(1033),
    [anon_sym_float] = ACTIONS(1033),
    [anon_sym_double] = ACTIONS(1033),
    [sym_boolean_type] = ACTIONS(1033),
    [sym_void_type] = ACTIONS(1033),
    [sym_this] = ACTIONS(1033),
    [sym_super] = ACTIONS(1033),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [351] = {
    [ts_builtin_sym_end] = ACTIONS(1035),
    [sym_identifier] = ACTIONS(1037),
    [sym_decimal_integer_literal] = ACTIONS(1037),
    [sym_hex_integer_literal] = ACTIONS(1037),
    [sym_octal_integer_literal] = ACTIONS(1037),
    [sym_binary_integer_literal] = ACTIONS(1035),
    [sym_decimal_floating_point_literal] = ACTIONS(1035),
    [sym_hex_floating_point_literal] = ACTIONS(1037),
    [sym_true] = ACTIONS(1037),
    [sym_false] = ACTIONS(1037),
    [sym_character_literal] = ACTIONS(1035),
    [anon_sym_DQUOTE] = ACTIONS(1037),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1035),
    [anon_sym_RBRACE] = ACTIONS(1035),
    [sym_null_literal] = ACTIONS(1037),
    [anon_sym_LPAREN] = ACTIONS(1035),
    [anon_sym_LT] = ACTIONS(1035),
    [anon_sym_PLUS] = ACTIONS(1037),
    [anon_sym_DASH] = ACTIONS(1037),
    [anon_sym_final] = ACTIONS(1037),
    [anon_sym_BANG] = ACTIONS(1035),
    [anon_sym_TILDE] = ACTIONS(1035),
    [anon_sym_PLUS_PLUS] = ACTIONS(1035),
    [anon_sym_DASH_DASH] = ACTIONS(1035),
    [anon_sym_new] = ACTIONS(1037),
    [anon_sym_class] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1037),
    [anon_sym_LBRACE] = ACTIONS(1035),
    [anon_sym_case] = ACTIONS(1037),
    [anon_sym_default] = ACTIONS(1037),
    [anon_sym_SEMI] = ACTIONS(1035),
    [anon_sym_assert] = ACTIONS(1037),
    [anon_sym_do] = ACTIONS(1037),
    [anon_sym_while] = ACTIONS(1037),
    [anon_sym_break] = ACTIONS(1037),
    [anon_sym_continue] = ACTIONS(1037),
    [anon_sym_return] = ACTIONS(1037),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_synchronized] = ACTIONS(1037),
    [anon_sym_throw] = ACTIONS(1037),
    [anon_sym_try] = ACTIONS(1037),
    [anon_sym_if] = ACTIONS(1037),
    [anon_sym_else] = ACTIONS(1037),
    [anon_sym_for] = ACTIONS(1037),
    [anon_sym_AT] = ACTIONS(1037),
    [anon_sym_open] = ACTIONS(1037),
    [anon_sym_module] = ACTIONS(1037),
    [anon_sym_static] = ACTIONS(1037),
    [anon_sym_with] = ACTIONS(1037),
    [anon_sym_package] = ACTIONS(1037),
    [anon_sym_import] = ACTIONS(1037),
    [anon_sym_enum] = ACTIONS(1037),
    [anon_sym_public] = ACTIONS(1037),
    [anon_sym_protected] = ACTIONS(1037),
    [anon_sym_private] = ACTIONS(1037),
    [anon_sym_abstract] = ACTIONS(1037),
    [anon_sym_strictfp] = ACTIONS(1037),
    [anon_sym_native] = ACTIONS(1037),
    [anon_sym_transient] = ACTIONS(1037),
    [anon_sym_volatile] = ACTIONS(1037),
    [anon_sym_sealed] = ACTIONS(1037),
    [anon_sym_non_DASHsealed] = ACTIONS(1035),
    [anon_sym_record] = ACTIONS(1037),
    [anon_sym_ATinterface] = ACTIONS(1035),
    [anon_sym_interface] = ACTIONS(1037),
    [anon_sym_byte] = ACTIONS(1037),
    [anon_sym_short] = ACTIONS(1037),
    [anon_sym_int] = ACTIONS(1037),
    [anon_sym_long] = ACTIONS(1037),
    [anon_sym_char] = ACTIONS(1037),
    [anon_sym_float] = ACTIONS(1037),
    [anon_sym_double] = ACTIONS(1037),
    [sym_boolean_type] = ACTIONS(1037),
    [sym_void_type] = ACTIONS(1037),
    [sym_this] = ACTIONS(1037),
    [sym_super] = ACTIONS(1037),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [352] = {
    [ts_builtin_sym_end] = ACTIONS(1039),
    [sym_identifier] = ACTIONS(1041),
    [sym_decimal_integer_literal] = ACTIONS(1041),
    [sym_hex_integer_literal] = ACTIONS(1041),
    [sym_octal_integer_literal] = ACTIONS(1041),
    [sym_binary_integer_literal] = ACTIONS(1039),
    [sym_decimal_floating_point_literal] = ACTIONS(1039),
    [sym_hex_floating_point_literal] = ACTIONS(1041),
    [sym_true] = ACTIONS(1041),
    [sym_false] = ACTIONS(1041),
    [sym_character_literal] = ACTIONS(1039),
    [anon_sym_DQUOTE] = ACTIONS(1041),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1039),
    [anon_sym_RBRACE] = ACTIONS(1039),
    [sym_null_literal] = ACTIONS(1041),
    [anon_sym_LPAREN] = ACTIONS(1039),
    [anon_sym_LT] = ACTIONS(1039),
    [anon_sym_PLUS] = ACTIONS(1041),
    [anon_sym_DASH] = ACTIONS(1041),
    [anon_sym_final] = ACTIONS(1041),
    [anon_sym_BANG] = ACTIONS(1039),
    [anon_sym_TILDE] = ACTIONS(1039),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
    [anon_sym_class] = ACTIONS(1041),
    [anon_sym_switch] = ACTIONS(1041),
    [anon_sym_LBRACE] = ACTIONS(1039),
    [anon_sym_case] = ACTIONS(1041),
    [anon_sym_default] = ACTIONS(1041),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_assert] = ACTIONS(1041),
    [anon_sym_do] = ACTIONS(1041),
    [anon_sym_while] = ACTIONS(1041),
    [anon_sym_break] = ACTIONS(1041),
    [anon_sym_continue] = ACTIONS(1041),
    [anon_sym_return] = ACTIONS(1041),
    [anon_sym_yield] = ACTIONS(1041),
    [anon_sym_synchronized] = ACTIONS(1041),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1041),
    [anon_sym_if] = ACTIONS(1041),
    [anon_sym_else] = ACTIONS(1041),
    [anon_sym_for] = ACTIONS(1041),
    [anon_sym_AT] = ACTIONS(1041),
    [anon_sym_open] = ACTIONS(1041),
    [anon_sym_module] = ACTIONS(1041),
    [anon_sym_static] = ACTIONS(1041),
    [anon_sym_with] = ACTIONS(1041),
    [anon_sym_package] = ACTIONS(1041),
    [anon_sym_import] = ACTIONS(1041),
    [anon_sym_enum] = ACTIONS(1041),
    [anon_sym_public] = ACTIONS(1041),
    [anon_sym_protected] = ACTIONS(1041),
    [anon_sym_private] = ACTIONS(1041),
    [anon_sym_abstract] = ACTIONS(1041),
    [anon_sym_strictfp] = ACTIONS(1041),
    [anon_sym_native] = ACTIONS(1041),
    [anon_sym_transient] = ACTIONS(1041),
    [anon_sym_volatile] = ACTIONS(1041),
    [anon_sym_sealed] = ACTIONS(1041),
    [anon_sym_non_DASHsealed] = ACTIONS(1039),
    [anon_sym_record] = ACTIONS(1041),
    [anon_sym_ATinterface] = ACTIONS(1039),
    [anon_sym_interface] = ACTIONS(1041),
    [anon_sym_byte] = ACTIONS(1041),
    [anon_sym_short] = ACTIONS(1041),
    [anon_sym_int] = ACTIONS(1041),
    [anon_sym_long] = ACTIONS(1041),
    [anon_sym_char] = ACTIONS(1041),
    [anon_sym_float] = ACTIONS(1041),
    [anon_sym_double] = ACTIONS(1041),
    [sym_boolean_type] = ACTIONS(1041),
    [sym_void_type] = ACTIONS(1041),
    [sym_this] = ACTIONS(1041),
    [sym_super] = ACTIONS(1041),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [353] = {
    [ts_builtin_sym_end] = ACTIONS(1043),
    [sym_identifier] = ACTIONS(1045),
    [sym_decimal_integer_literal] = ACTIONS(1045),
    [sym_hex_integer_literal] = ACTIONS(1045),
    [sym_octal_integer_literal] = ACTIONS(1045),
    [sym_binary_integer_literal] = ACTIONS(1043),
    [sym_decimal_floating_point_literal] = ACTIONS(1043),
    [sym_hex_floating_point_literal] = ACTIONS(1045),
    [sym_true] = ACTIONS(1045),
    [sym_false] = ACTIONS(1045),
    [sym_character_literal] = ACTIONS(1043),
    [anon_sym_DQUOTE] = ACTIONS(1045),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(1043),
    [sym_null_literal] = ACTIONS(1045),
    [anon_sym_LPAREN] = ACTIONS(1043),
    [anon_sym_LT] = ACTIONS(1043),
    [anon_sym_PLUS] = ACTIONS(1045),
    [anon_sym_DASH] = ACTIONS(1045),
    [anon_sym_final] = ACTIONS(1045),
    [anon_sym_BANG] = ACTIONS(1043),
    [anon_sym_TILDE] = ACTIONS(1043),
    [anon_sym_PLUS_PLUS] = ACTIONS(1043),
    [anon_sym_DASH_DASH] = ACTIONS(1043),
    [anon_sym_new] = ACTIONS(1045),
    [anon_sym_class] = ACTIONS(1045),
    [anon_sym_switch] = ACTIONS(1045),
    [anon_sym_LBRACE] = ACTIONS(1043),
    [anon_sym_case] = ACTIONS(1045),
    [anon_sym_default] = ACTIONS(1045),
    [anon_sym_SEMI] = ACTIONS(1043),
    [anon_sym_assert] = ACTIONS(1045),
    [anon_sym_do] = ACTIONS(1045),
    [anon_sym_while] = ACTIONS(1045),
    [anon_sym_break] = ACTIONS(1045),
    [anon_sym_continue] = ACTIONS(1045),
    [anon_sym_return] = ACTIONS(1045),
    [anon_sym_yield] = ACTIONS(1045),
    [anon_sym_synchronized] = ACTIONS(1045),
    [anon_sym_throw] = ACTIONS(1045),
    [anon_sym_try] = ACTIONS(1045),
    [anon_sym_if] = ACTIONS(1045),
    [anon_sym_else] = ACTIONS(1045),
    [anon_sym_for] = ACTIONS(1045),
    [anon_sym_AT] = ACTIONS(1045),
    [anon_sym_open] = ACTIONS(1045),
    [anon_sym_module] = ACTIONS(1045),
    [anon_sym_static] = ACTIONS(1045),
    [anon_sym_with] = ACTIONS(1045),
    [anon_sym_package] = ACTIONS(1045),
    [anon_sym_import] = ACTIONS(1045),
    [anon_sym_enum] = ACTIONS(1045),
    [anon_sym_public] = ACTIONS(1045),
    [anon_sym_protected] = ACTIONS(1045),
    [anon_sym_private] = ACTIONS(1045),
    [anon_sym_abstract] = ACTIONS(1045),
    [anon_sym_strictfp] = ACTIONS(1045),
    [anon_sym_native] = ACTIONS(1045),
    [anon_sym_transient] = ACTIONS(1045),
    [anon_sym_volatile] = ACTIONS(1045),
    [anon_sym_sealed] = ACTIONS(1045),
    [anon_sym_non_DASHsealed] = ACTIONS(1043),
    [anon_sym_record] = ACTIONS(1045),
    [anon_sym_ATinterface] = ACTIONS(1043),
    [anon_sym_interface] = ACTIONS(1045),
    [anon_sym_byte] = ACTIONS(1045),
    [anon_sym_short] = ACTIONS(1045),
    [anon_sym_int] = ACTIONS(1045),
    [anon_sym_long] = ACTIONS(1045),
    [anon_sym_char] = ACTIONS(1045),
    [anon_sym_float] = ACTIONS(1045),
    [anon_sym_double] = ACTIONS(1045),
    [sym_boolean_type] = ACTIONS(1045),
    [sym_void_type] = ACTIONS(1045),
    [sym_this] = ACTIONS(1045),
    [sym_super] = ACTIONS(1045),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [354] = {
    [ts_builtin_sym_end] = ACTIONS(1047),
    [sym_identifier] = ACTIONS(1049),
    [sym_decimal_integer_literal] = ACTIONS(1049),
    [sym_hex_integer_literal] = ACTIONS(1049),
    [sym_octal_integer_literal] = ACTIONS(1049),
    [sym_binary_integer_literal] = ACTIONS(1047),
    [sym_decimal_floating_point_literal] = ACTIONS(1047),
    [sym_hex_floating_point_literal] = ACTIONS(1049),
    [sym_true] = ACTIONS(1049),
    [sym_false] = ACTIONS(1049),
    [sym_character_literal] = ACTIONS(1047),
    [anon_sym_DQUOTE] = ACTIONS(1049),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1047),
    [anon_sym_RBRACE] = ACTIONS(1047),
    [sym_null_literal] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(1047),
    [anon_sym_LT] = ACTIONS(1047),
    [anon_sym_PLUS] = ACTIONS(1049),
    [anon_sym_DASH] = ACTIONS(1049),
    [anon_sym_final] = ACTIONS(1049),
    [anon_sym_BANG] = ACTIONS(1047),
    [anon_sym_TILDE] = ACTIONS(1047),
    [anon_sym_PLUS_PLUS] = ACTIONS(1047),
    [anon_sym_DASH_DASH] = ACTIONS(1047),
    [anon_sym_new] = ACTIONS(1049),
    [anon_sym_class] = ACTIONS(1049),
    [anon_sym_switch] = ACTIONS(1049),
    [anon_sym_LBRACE] = ACTIONS(1047),
    [anon_sym_case] = ACTIONS(1049),
    [anon_sym_default] = ACTIONS(1049),
    [anon_sym_SEMI] = ACTIONS(1047),
    [anon_sym_assert] = ACTIONS(1049),
    [anon_sym_do] = ACTIONS(1049),
    [anon_sym_while] = ACTIONS(1049),
    [anon_sym_break] = ACTIONS(1049),
    [anon_sym_continue] = ACTIONS(1049),
    [anon_sym_return] = ACTIONS(1049),
    [anon_sym_yield] = ACTIONS(1049),
    [anon_sym_synchronized] = ACTIONS(1049),
    [anon_sym_throw] = ACTIONS(1049),
    [anon_sym_try] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_else] = ACTIONS(1049),
    [anon_sym_for] = ACTIONS(1049),
    [anon_sym_AT] = ACTIONS(1049),
    [anon_sym_open] = ACTIONS(1049),
    [anon_sym_module] = ACTIONS(1049),
    [anon_sym_static] = ACTIONS(1049),
    [anon_sym_with] = ACTIONS(1049),
    [anon_sym_package] = ACTIONS(1049),
    [anon_sym_import] = ACTIONS(1049),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_public] = ACTIONS(1049),
    [anon_sym_protected] = ACTIONS(1049),
    [anon_sym_private] = ACTIONS(1049),
    [anon_sym_abstract] = ACTIONS(1049),
    [anon_sym_strictfp] = ACTIONS(1049),
    [anon_sym_native] = ACTIONS(1049),
    [anon_sym_transient] = ACTIONS(1049),
    [anon_sym_volatile] = ACTIONS(1049),
    [anon_sym_sealed] = ACTIONS(1049),
    [anon_sym_non_DASHsealed] = ACTIONS(1047),
    [anon_sym_record] = ACTIONS(1049),
    [anon_sym_ATinterface] = ACTIONS(1047),
    [anon_sym_interface] = ACTIONS(1049),
    [anon_sym_byte] = ACTIONS(1049),
    [anon_sym_short] = ACTIONS(1049),
    [anon_sym_int] = ACTIONS(1049),
    [anon_sym_long] = ACTIONS(1049),
    [anon_sym_char] = ACTIONS(1049),
    [anon_sym_float] = ACTIONS(1049),
    [anon_sym_double] = ACTIONS(1049),
    [sym_boolean_type] = ACTIONS(1049),
    [sym_void_type] = ACTIONS(1049),
    [sym_this] = ACTIONS(1049),
    [sym_super] = ACTIONS(1049),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [355] = {
    [ts_builtin_sym_end] = ACTIONS(1051),
    [sym_identifier] = ACTIONS(1053),
    [sym_decimal_integer_literal] = ACTIONS(1053),
    [sym_hex_integer_literal] = ACTIONS(1053),
    [sym_octal_integer_literal] = ACTIONS(1053),
    [sym_binary_integer_literal] = ACTIONS(1051),
    [sym_decimal_floating_point_literal] = ACTIONS(1051),
    [sym_hex_floating_point_literal] = ACTIONS(1053),
    [sym_true] = ACTIONS(1053),
    [sym_false] = ACTIONS(1053),
    [sym_character_literal] = ACTIONS(1051),
    [anon_sym_DQUOTE] = ACTIONS(1053),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1051),
    [anon_sym_RBRACE] = ACTIONS(1051),
    [sym_null_literal] = ACTIONS(1053),
    [anon_sym_LPAREN] = ACTIONS(1051),
    [anon_sym_LT] = ACTIONS(1051),
    [anon_sym_PLUS] = ACTIONS(1053),
    [anon_sym_DASH] = ACTIONS(1053),
    [anon_sym_final] = ACTIONS(1053),
    [anon_sym_BANG] = ACTIONS(1051),
    [anon_sym_TILDE] = ACTIONS(1051),
    [anon_sym_PLUS_PLUS] = ACTIONS(1051),
    [anon_sym_DASH_DASH] = ACTIONS(1051),
    [anon_sym_new] = ACTIONS(1053),
    [anon_sym_class] = ACTIONS(1053),
    [anon_sym_switch] = ACTIONS(1053),
    [anon_sym_LBRACE] = ACTIONS(1051),
    [anon_sym_case] = ACTIONS(1053),
    [anon_sym_default] = ACTIONS(1053),
    [anon_sym_SEMI] = ACTIONS(1051),
    [anon_sym_assert] = ACTIONS(1053),
    [anon_sym_do] = ACTIONS(1053),
    [anon_sym_while] = ACTIONS(1053),
    [anon_sym_break] = ACTIONS(1053),
    [anon_sym_continue] = ACTIONS(1053),
    [anon_sym_return] = ACTIONS(1053),
    [anon_sym_yield] = ACTIONS(1053),
    [anon_sym_synchronized] = ACTIONS(1053),
    [anon_sym_throw] = ACTIONS(1053),
    [anon_sym_try] = ACTIONS(1053),
    [anon_sym_if] = ACTIONS(1053),
    [anon_sym_else] = ACTIONS(1053),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_AT] = ACTIONS(1053),
    [anon_sym_open] = ACTIONS(1053),
    [anon_sym_module] = ACTIONS(1053),
    [anon_sym_static] = ACTIONS(1053),
    [anon_sym_with] = ACTIONS(1053),
    [anon_sym_package] = ACTIONS(1053),
    [anon_sym_import] = ACTIONS(1053),
    [anon_sym_enum] = ACTIONS(1053),
    [anon_sym_public] = ACTIONS(1053),
    [anon_sym_protected] = ACTIONS(1053),
    [anon_sym_private] = ACTIONS(1053),
    [anon_sym_abstract] = ACTIONS(1053),
    [anon_sym_strictfp] = ACTIONS(1053),
    [anon_sym_native] = ACTIONS(1053),
    [anon_sym_transient] = ACTIONS(1053),
    [anon_sym_volatile] = ACTIONS(1053),
    [anon_sym_sealed] = ACTIONS(1053),
    [anon_sym_non_DASHsealed] = ACTIONS(1051),
    [anon_sym_record] = ACTIONS(1053),
    [anon_sym_ATinterface] = ACTIONS(1051),
    [anon_sym_interface] = ACTIONS(1053),
    [anon_sym_byte] = ACTIONS(1053),
    [anon_sym_short] = ACTIONS(1053),
    [anon_sym_int] = ACTIONS(1053),
    [anon_sym_long] = ACTIONS(1053),
    [anon_sym_char] = ACTIONS(1053),
    [anon_sym_float] = ACTIONS(1053),
    [anon_sym_double] = ACTIONS(1053),
    [sym_boolean_type] = ACTIONS(1053),
    [sym_void_type] = ACTIONS(1053),
    [sym_this] = ACTIONS(1053),
    [sym_super] = ACTIONS(1053),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [356] = {
    [ts_builtin_sym_end] = ACTIONS(1055),
    [sym_identifier] = ACTIONS(1057),
    [sym_decimal_integer_literal] = ACTIONS(1057),
    [sym_hex_integer_literal] = ACTIONS(1057),
    [sym_octal_integer_literal] = ACTIONS(1057),
    [sym_binary_integer_literal] = ACTIONS(1055),
    [sym_decimal_floating_point_literal] = ACTIONS(1055),
    [sym_hex_floating_point_literal] = ACTIONS(1057),
    [sym_true] = ACTIONS(1057),
    [sym_false] = ACTIONS(1057),
    [sym_character_literal] = ACTIONS(1055),
    [anon_sym_DQUOTE] = ACTIONS(1057),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1055),
    [anon_sym_RBRACE] = ACTIONS(1055),
    [sym_null_literal] = ACTIONS(1057),
    [anon_sym_LPAREN] = ACTIONS(1055),
    [anon_sym_LT] = ACTIONS(1055),
    [anon_sym_PLUS] = ACTIONS(1057),
    [anon_sym_DASH] = ACTIONS(1057),
    [anon_sym_final] = ACTIONS(1057),
    [anon_sym_BANG] = ACTIONS(1055),
    [anon_sym_TILDE] = ACTIONS(1055),
    [anon_sym_PLUS_PLUS] = ACTIONS(1055),
    [anon_sym_DASH_DASH] = ACTIONS(1055),
    [anon_sym_new] = ACTIONS(1057),
    [anon_sym_class] = ACTIONS(1057),
    [anon_sym_switch] = ACTIONS(1057),
    [anon_sym_LBRACE] = ACTIONS(1055),
    [anon_sym_case] = ACTIONS(1057),
    [anon_sym_default] = ACTIONS(1057),
    [anon_sym_SEMI] = ACTIONS(1055),
    [anon_sym_assert] = ACTIONS(1057),
    [anon_sym_do] = ACTIONS(1057),
    [anon_sym_while] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_continue] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1057),
    [anon_sym_yield] = ACTIONS(1057),
    [anon_sym_synchronized] = ACTIONS(1057),
    [anon_sym_throw] = ACTIONS(1057),
    [anon_sym_try] = ACTIONS(1057),
    [anon_sym_if] = ACTIONS(1057),
    [anon_sym_else] = ACTIONS(1057),
    [anon_sym_for] = ACTIONS(1057),
    [anon_sym_AT] = ACTIONS(1057),
    [anon_sym_open] = ACTIONS(1057),
    [anon_sym_module] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(1057),
    [anon_sym_with] = ACTIONS(1057),
    [anon_sym_package] = ACTIONS(1057),
    [anon_sym_import] = ACTIONS(1057),
    [anon_sym_enum] = ACTIONS(1057),
    [anon_sym_public] = ACTIONS(1057),
    [anon_sym_protected] = ACTIONS(1057),
    [anon_sym_private] = ACTIONS(1057),
    [anon_sym_abstract] = ACTIONS(1057),
    [anon_sym_strictfp] = ACTIONS(1057),
    [anon_sym_native] = ACTIONS(1057),
    [anon_sym_transient] = ACTIONS(1057),
    [anon_sym_volatile] = ACTIONS(1057),
    [anon_sym_sealed] = ACTIONS(1057),
    [anon_sym_non_DASHsealed] = ACTIONS(1055),
    [anon_sym_record] = ACTIONS(1057),
    [anon_sym_ATinterface] = ACTIONS(1055),
    [anon_sym_interface] = ACTIONS(1057),
    [anon_sym_byte] = ACTIONS(1057),
    [anon_sym_short] = ACTIONS(1057),
    [anon_sym_int] = ACTIONS(1057),
    [anon_sym_long] = ACTIONS(1057),
    [anon_sym_char] = ACTIONS(1057),
    [anon_sym_float] = ACTIONS(1057),
    [anon_sym_double] = ACTIONS(1057),
    [sym_boolean_type] = ACTIONS(1057),
    [sym_void_type] = ACTIONS(1057),
    [sym_this] = ACTIONS(1057),
    [sym_super] = ACTIONS(1057),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [357] = {
    [ts_builtin_sym_end] = ACTIONS(1059),
    [sym_identifier] = ACTIONS(1061),
    [sym_decimal_integer_literal] = ACTIONS(1061),
    [sym_hex_integer_literal] = ACTIONS(1061),
    [sym_octal_integer_literal] = ACTIONS(1061),
    [sym_binary_integer_literal] = ACTIONS(1059),
    [sym_decimal_floating_point_literal] = ACTIONS(1059),
    [sym_hex_floating_point_literal] = ACTIONS(1061),
    [sym_true] = ACTIONS(1061),
    [sym_false] = ACTIONS(1061),
    [sym_character_literal] = ACTIONS(1059),
    [anon_sym_DQUOTE] = ACTIONS(1061),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1059),
    [anon_sym_RBRACE] = ACTIONS(1059),
    [sym_null_literal] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(1059),
    [anon_sym_LT] = ACTIONS(1059),
    [anon_sym_PLUS] = ACTIONS(1061),
    [anon_sym_DASH] = ACTIONS(1061),
    [anon_sym_final] = ACTIONS(1061),
    [anon_sym_BANG] = ACTIONS(1059),
    [anon_sym_TILDE] = ACTIONS(1059),
    [anon_sym_PLUS_PLUS] = ACTIONS(1059),
    [anon_sym_DASH_DASH] = ACTIONS(1059),
    [anon_sym_new] = ACTIONS(1061),
    [anon_sym_class] = ACTIONS(1061),
    [anon_sym_switch] = ACTIONS(1061),
    [anon_sym_LBRACE] = ACTIONS(1059),
    [anon_sym_case] = ACTIONS(1061),
    [anon_sym_default] = ACTIONS(1061),
    [anon_sym_SEMI] = ACTIONS(1059),
    [anon_sym_assert] = ACTIONS(1061),
    [anon_sym_do] = ACTIONS(1061),
    [anon_sym_while] = ACTIONS(1061),
    [anon_sym_break] = ACTIONS(1061),
    [anon_sym_continue] = ACTIONS(1061),
    [anon_sym_return] = ACTIONS(1061),
    [anon_sym_yield] = ACTIONS(1061),
    [anon_sym_synchronized] = ACTIONS(1061),
    [anon_sym_throw] = ACTIONS(1061),
    [anon_sym_try] = ACTIONS(1061),
    [anon_sym_if] = ACTIONS(1061),
    [anon_sym_else] = ACTIONS(1061),
    [anon_sym_for] = ACTIONS(1061),
    [anon_sym_AT] = ACTIONS(1061),
    [anon_sym_open] = ACTIONS(1061),
    [anon_sym_module] = ACTIONS(1061),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_with] = ACTIONS(1061),
    [anon_sym_package] = ACTIONS(1061),
    [anon_sym_import] = ACTIONS(1061),
    [anon_sym_enum] = ACTIONS(1061),
    [anon_sym_public] = ACTIONS(1061),
    [anon_sym_protected] = ACTIONS(1061),
    [anon_sym_private] = ACTIONS(1061),
    [anon_sym_abstract] = ACTIONS(1061),
    [anon_sym_strictfp] = ACTIONS(1061),
    [anon_sym_native] = ACTIONS(1061),
    [anon_sym_transient] = ACTIONS(1061),
    [anon_sym_volatile] = ACTIONS(1061),
    [anon_sym_sealed] = ACTIONS(1061),
    [anon_sym_non_DASHsealed] = ACTIONS(1059),
    [anon_sym_record] = ACTIONS(1061),
    [anon_sym_ATinterface] = ACTIONS(1059),
    [anon_sym_interface] = ACTIONS(1061),
    [anon_sym_byte] = ACTIONS(1061),
    [anon_sym_short] = ACTIONS(1061),
    [anon_sym_int] = ACTIONS(1061),
    [anon_sym_long] = ACTIONS(1061),
    [anon_sym_char] = ACTIONS(1061),
    [anon_sym_float] = ACTIONS(1061),
    [anon_sym_double] = ACTIONS(1061),
    [sym_boolean_type] = ACTIONS(1061),
    [sym_void_type] = ACTIONS(1061),
    [sym_this] = ACTIONS(1061),
    [sym_super] = ACTIONS(1061),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [358] = {
    [ts_builtin_sym_end] = ACTIONS(1063),
    [sym_identifier] = ACTIONS(1065),
    [sym_decimal_integer_literal] = ACTIONS(1065),
    [sym_hex_integer_literal] = ACTIONS(1065),
    [sym_octal_integer_literal] = ACTIONS(1065),
    [sym_binary_integer_literal] = ACTIONS(1063),
    [sym_decimal_floating_point_literal] = ACTIONS(1063),
    [sym_hex_floating_point_literal] = ACTIONS(1065),
    [sym_true] = ACTIONS(1065),
    [sym_false] = ACTIONS(1065),
    [sym_character_literal] = ACTIONS(1063),
    [anon_sym_DQUOTE] = ACTIONS(1065),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1063),
    [anon_sym_RBRACE] = ACTIONS(1063),
    [sym_null_literal] = ACTIONS(1065),
    [anon_sym_LPAREN] = ACTIONS(1063),
    [anon_sym_LT] = ACTIONS(1063),
    [anon_sym_PLUS] = ACTIONS(1065),
    [anon_sym_DASH] = ACTIONS(1065),
    [anon_sym_final] = ACTIONS(1065),
    [anon_sym_BANG] = ACTIONS(1063),
    [anon_sym_TILDE] = ACTIONS(1063),
    [anon_sym_PLUS_PLUS] = ACTIONS(1063),
    [anon_sym_DASH_DASH] = ACTIONS(1063),
    [anon_sym_new] = ACTIONS(1065),
    [anon_sym_class] = ACTIONS(1065),
    [anon_sym_switch] = ACTIONS(1065),
    [anon_sym_LBRACE] = ACTIONS(1063),
    [anon_sym_case] = ACTIONS(1065),
    [anon_sym_default] = ACTIONS(1065),
    [anon_sym_SEMI] = ACTIONS(1063),
    [anon_sym_assert] = ACTIONS(1065),
    [anon_sym_do] = ACTIONS(1065),
    [anon_sym_while] = ACTIONS(1065),
    [anon_sym_break] = ACTIONS(1065),
    [anon_sym_continue] = ACTIONS(1065),
    [anon_sym_return] = ACTIONS(1065),
    [anon_sym_yield] = ACTIONS(1065),
    [anon_sym_synchronized] = ACTIONS(1065),
    [anon_sym_throw] = ACTIONS(1065),
    [anon_sym_try] = ACTIONS(1065),
    [anon_sym_if] = ACTIONS(1065),
    [anon_sym_else] = ACTIONS(1065),
    [anon_sym_for] = ACTIONS(1065),
    [anon_sym_AT] = ACTIONS(1065),
    [anon_sym_open] = ACTIONS(1065),
    [anon_sym_module] = ACTIONS(1065),
    [anon_sym_static] = ACTIONS(1065),
    [anon_sym_with] = ACTIONS(1065),
    [anon_sym_package] = ACTIONS(1065),
    [anon_sym_import] = ACTIONS(1065),
    [anon_sym_enum] = ACTIONS(1065),
    [anon_sym_public] = ACTIONS(1065),
    [anon_sym_protected] = ACTIONS(1065),
    [anon_sym_private] = ACTIONS(1065),
    [anon_sym_abstract] = ACTIONS(1065),
    [anon_sym_strictfp] = ACTIONS(1065),
    [anon_sym_native] = ACTIONS(1065),
    [anon_sym_transient] = ACTIONS(1065),
    [anon_sym_volatile] = ACTIONS(1065),
    [anon_sym_sealed] = ACTIONS(1065),
    [anon_sym_non_DASHsealed] = ACTIONS(1063),
    [anon_sym_record] = ACTIONS(1065),
    [anon_sym_ATinterface] = ACTIONS(1063),
    [anon_sym_interface] = ACTIONS(1065),
    [anon_sym_byte] = ACTIONS(1065),
    [anon_sym_short] = ACTIONS(1065),
    [anon_sym_int] = ACTIONS(1065),
    [anon_sym_long] = ACTIONS(1065),
    [anon_sym_char] = ACTIONS(1065),
    [anon_sym_float] = ACTIONS(1065),
    [anon_sym_double] = ACTIONS(1065),
    [sym_boolean_type] = ACTIONS(1065),
    [sym_void_type] = ACTIONS(1065),
    [sym_this] = ACTIONS(1065),
    [sym_super] = ACTIONS(1065),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [359] = {
    [ts_builtin_sym_end] = ACTIONS(1067),
    [sym_identifier] = ACTIONS(1069),
    [sym_decimal_integer_literal] = ACTIONS(1069),
    [sym_hex_integer_literal] = ACTIONS(1069),
    [sym_octal_integer_literal] = ACTIONS(1069),
    [sym_binary_integer_literal] = ACTIONS(1067),
    [sym_decimal_floating_point_literal] = ACTIONS(1067),
    [sym_hex_floating_point_literal] = ACTIONS(1069),
    [sym_true] = ACTIONS(1069),
    [sym_false] = ACTIONS(1069),
    [sym_character_literal] = ACTIONS(1067),
    [anon_sym_DQUOTE] = ACTIONS(1069),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1067),
    [anon_sym_RBRACE] = ACTIONS(1067),
    [sym_null_literal] = ACTIONS(1069),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_LT] = ACTIONS(1067),
    [anon_sym_PLUS] = ACTIONS(1069),
    [anon_sym_DASH] = ACTIONS(1069),
    [anon_sym_final] = ACTIONS(1069),
    [anon_sym_BANG] = ACTIONS(1067),
    [anon_sym_TILDE] = ACTIONS(1067),
    [anon_sym_PLUS_PLUS] = ACTIONS(1067),
    [anon_sym_DASH_DASH] = ACTIONS(1067),
    [anon_sym_new] = ACTIONS(1069),
    [anon_sym_class] = ACTIONS(1069),
    [anon_sym_switch] = ACTIONS(1069),
    [anon_sym_LBRACE] = ACTIONS(1067),
    [anon_sym_case] = ACTIONS(1069),
    [anon_sym_default] = ACTIONS(1069),
    [anon_sym_SEMI] = ACTIONS(1067),
    [anon_sym_assert] = ACTIONS(1069),
    [anon_sym_do] = ACTIONS(1069),
    [anon_sym_while] = ACTIONS(1069),
    [anon_sym_break] = ACTIONS(1069),
    [anon_sym_continue] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_yield] = ACTIONS(1069),
    [anon_sym_synchronized] = ACTIONS(1069),
    [anon_sym_throw] = ACTIONS(1069),
    [anon_sym_try] = ACTIONS(1069),
    [anon_sym_if] = ACTIONS(1069),
    [anon_sym_else] = ACTIONS(1069),
    [anon_sym_for] = ACTIONS(1069),
    [anon_sym_AT] = ACTIONS(1069),
    [anon_sym_open] = ACTIONS(1069),
    [anon_sym_module] = ACTIONS(1069),
    [anon_sym_static] = ACTIONS(1069),
    [anon_sym_with] = ACTIONS(1069),
    [anon_sym_package] = ACTIONS(1069),
    [anon_sym_import] = ACTIONS(1069),
    [anon_sym_enum] = ACTIONS(1069),
    [anon_sym_public] = ACTIONS(1069),
    [anon_sym_protected] = ACTIONS(1069),
    [anon_sym_private] = ACTIONS(1069),
    [anon_sym_abstract] = ACTIONS(1069),
    [anon_sym_strictfp] = ACTIONS(1069),
    [anon_sym_native] = ACTIONS(1069),
    [anon_sym_transient] = ACTIONS(1069),
    [anon_sym_volatile] = ACTIONS(1069),
    [anon_sym_sealed] = ACTIONS(1069),
    [anon_sym_non_DASHsealed] = ACTIONS(1067),
    [anon_sym_record] = ACTIONS(1069),
    [anon_sym_ATinterface] = ACTIONS(1067),
    [anon_sym_interface] = ACTIONS(1069),
    [anon_sym_byte] = ACTIONS(1069),
    [anon_sym_short] = ACTIONS(1069),
    [anon_sym_int] = ACTIONS(1069),
    [anon_sym_long] = ACTIONS(1069),
    [anon_sym_char] = ACTIONS(1069),
    [anon_sym_float] = ACTIONS(1069),
    [anon_sym_double] = ACTIONS(1069),
    [sym_boolean_type] = ACTIONS(1069),
    [sym_void_type] = ACTIONS(1069),
    [sym_this] = ACTIONS(1069),
    [sym_super] = ACTIONS(1069),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [360] = {
    [ts_builtin_sym_end] = ACTIONS(1071),
    [sym_identifier] = ACTIONS(1073),
    [sym_decimal_integer_literal] = ACTIONS(1073),
    [sym_hex_integer_literal] = ACTIONS(1073),
    [sym_octal_integer_literal] = ACTIONS(1073),
    [sym_binary_integer_literal] = ACTIONS(1071),
    [sym_decimal_floating_point_literal] = ACTIONS(1071),
    [sym_hex_floating_point_literal] = ACTIONS(1073),
    [sym_true] = ACTIONS(1073),
    [sym_false] = ACTIONS(1073),
    [sym_character_literal] = ACTIONS(1071),
    [anon_sym_DQUOTE] = ACTIONS(1073),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1071),
    [anon_sym_RBRACE] = ACTIONS(1071),
    [sym_null_literal] = ACTIONS(1073),
    [anon_sym_LPAREN] = ACTIONS(1071),
    [anon_sym_LT] = ACTIONS(1071),
    [anon_sym_PLUS] = ACTIONS(1073),
    [anon_sym_DASH] = ACTIONS(1073),
    [anon_sym_final] = ACTIONS(1073),
    [anon_sym_BANG] = ACTIONS(1071),
    [anon_sym_TILDE] = ACTIONS(1071),
    [anon_sym_PLUS_PLUS] = ACTIONS(1071),
    [anon_sym_DASH_DASH] = ACTIONS(1071),
    [anon_sym_new] = ACTIONS(1073),
    [anon_sym_class] = ACTIONS(1073),
    [anon_sym_switch] = ACTIONS(1073),
    [anon_sym_LBRACE] = ACTIONS(1071),
    [anon_sym_case] = ACTIONS(1073),
    [anon_sym_default] = ACTIONS(1073),
    [anon_sym_SEMI] = ACTIONS(1071),
    [anon_sym_assert] = ACTIONS(1073),
    [anon_sym_do] = ACTIONS(1073),
    [anon_sym_while] = ACTIONS(1073),
    [anon_sym_break] = ACTIONS(1073),
    [anon_sym_continue] = ACTIONS(1073),
    [anon_sym_return] = ACTIONS(1073),
    [anon_sym_yield] = ACTIONS(1073),
    [anon_sym_synchronized] = ACTIONS(1073),
    [anon_sym_throw] = ACTIONS(1073),
    [anon_sym_try] = ACTIONS(1073),
    [anon_sym_if] = ACTIONS(1073),
    [anon_sym_else] = ACTIONS(1073),
    [anon_sym_for] = ACTIONS(1073),
    [anon_sym_AT] = ACTIONS(1073),
    [anon_sym_open] = ACTIONS(1073),
    [anon_sym_module] = ACTIONS(1073),
    [anon_sym_static] = ACTIONS(1073),
    [anon_sym_with] = ACTIONS(1073),
    [anon_sym_package] = ACTIONS(1073),
    [anon_sym_import] = ACTIONS(1073),
    [anon_sym_enum] = ACTIONS(1073),
    [anon_sym_public] = ACTIONS(1073),
    [anon_sym_protected] = ACTIONS(1073),
    [anon_sym_private] = ACTIONS(1073),
    [anon_sym_abstract] = ACTIONS(1073),
    [anon_sym_strictfp] = ACTIONS(1073),
    [anon_sym_native] = ACTIONS(1073),
    [anon_sym_transient] = ACTIONS(1073),
    [anon_sym_volatile] = ACTIONS(1073),
    [anon_sym_sealed] = ACTIONS(1073),
    [anon_sym_non_DASHsealed] = ACTIONS(1071),
    [anon_sym_record] = ACTIONS(1073),
    [anon_sym_ATinterface] = ACTIONS(1071),
    [anon_sym_interface] = ACTIONS(1073),
    [anon_sym_byte] = ACTIONS(1073),
    [anon_sym_short] = ACTIONS(1073),
    [anon_sym_int] = ACTIONS(1073),
    [anon_sym_long] = ACTIONS(1073),
    [anon_sym_char] = ACTIONS(1073),
    [anon_sym_float] = ACTIONS(1073),
    [anon_sym_double] = ACTIONS(1073),
    [sym_boolean_type] = ACTIONS(1073),
    [sym_void_type] = ACTIONS(1073),
    [sym_this] = ACTIONS(1073),
    [sym_super] = ACTIONS(1073),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [361] = {
    [ts_builtin_sym_end] = ACTIONS(1075),
    [sym_identifier] = ACTIONS(1077),
    [sym_decimal_integer_literal] = ACTIONS(1077),
    [sym_hex_integer_literal] = ACTIONS(1077),
    [sym_octal_integer_literal] = ACTIONS(1077),
    [sym_binary_integer_literal] = ACTIONS(1075),
    [sym_decimal_floating_point_literal] = ACTIONS(1075),
    [sym_hex_floating_point_literal] = ACTIONS(1077),
    [sym_true] = ACTIONS(1077),
    [sym_false] = ACTIONS(1077),
    [sym_character_literal] = ACTIONS(1075),
    [anon_sym_DQUOTE] = ACTIONS(1077),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1075),
    [anon_sym_RBRACE] = ACTIONS(1075),
    [sym_null_literal] = ACTIONS(1077),
    [anon_sym_LPAREN] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1075),
    [anon_sym_PLUS] = ACTIONS(1077),
    [anon_sym_DASH] = ACTIONS(1077),
    [anon_sym_final] = ACTIONS(1077),
    [anon_sym_BANG] = ACTIONS(1075),
    [anon_sym_TILDE] = ACTIONS(1075),
    [anon_sym_PLUS_PLUS] = ACTIONS(1075),
    [anon_sym_DASH_DASH] = ACTIONS(1075),
    [anon_sym_new] = ACTIONS(1077),
    [anon_sym_class] = ACTIONS(1077),
    [anon_sym_switch] = ACTIONS(1077),
    [anon_sym_LBRACE] = ACTIONS(1075),
    [anon_sym_case] = ACTIONS(1077),
    [anon_sym_default] = ACTIONS(1077),
    [anon_sym_SEMI] = ACTIONS(1075),
    [anon_sym_assert] = ACTIONS(1077),
    [anon_sym_do] = ACTIONS(1077),
    [anon_sym_while] = ACTIONS(1077),
    [anon_sym_break] = ACTIONS(1077),
    [anon_sym_continue] = ACTIONS(1077),
    [anon_sym_return] = ACTIONS(1077),
    [anon_sym_yield] = ACTIONS(1077),
    [anon_sym_synchronized] = ACTIONS(1077),
    [anon_sym_throw] = ACTIONS(1077),
    [anon_sym_try] = ACTIONS(1077),
    [anon_sym_if] = ACTIONS(1077),
    [anon_sym_else] = ACTIONS(1077),
    [anon_sym_for] = ACTIONS(1077),
    [anon_sym_AT] = ACTIONS(1077),
    [anon_sym_open] = ACTIONS(1077),
    [anon_sym_module] = ACTIONS(1077),
    [anon_sym_static] = ACTIONS(1077),
    [anon_sym_with] = ACTIONS(1077),
    [anon_sym_package] = ACTIONS(1077),
    [anon_sym_import] = ACTIONS(1077),
    [anon_sym_enum] = ACTIONS(1077),
    [anon_sym_public] = ACTIONS(1077),
    [anon_sym_protected] = ACTIONS(1077),
    [anon_sym_private] = ACTIONS(1077),
    [anon_sym_abstract] = ACTIONS(1077),
    [anon_sym_strictfp] = ACTIONS(1077),
    [anon_sym_native] = ACTIONS(1077),
    [anon_sym_transient] = ACTIONS(1077),
    [anon_sym_volatile] = ACTIONS(1077),
    [anon_sym_sealed] = ACTIONS(1077),
    [anon_sym_non_DASHsealed] = ACTIONS(1075),
    [anon_sym_record] = ACTIONS(1077),
    [anon_sym_ATinterface] = ACTIONS(1075),
    [anon_sym_interface] = ACTIONS(1077),
    [anon_sym_byte] = ACTIONS(1077),
    [anon_sym_short] = ACTIONS(1077),
    [anon_sym_int] = ACTIONS(1077),
    [anon_sym_long] = ACTIONS(1077),
    [anon_sym_char] = ACTIONS(1077),
    [anon_sym_float] = ACTIONS(1077),
    [anon_sym_double] = ACTIONS(1077),
    [sym_boolean_type] = ACTIONS(1077),
    [sym_void_type] = ACTIONS(1077),
    [sym_this] = ACTIONS(1077),
    [sym_super] = ACTIONS(1077),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [362] = {
    [ts_builtin_sym_end] = ACTIONS(1079),
    [sym_identifier] = ACTIONS(1081),
    [sym_decimal_integer_literal] = ACTIONS(1081),
    [sym_hex_integer_literal] = ACTIONS(1081),
    [sym_octal_integer_literal] = ACTIONS(1081),
    [sym_binary_integer_literal] = ACTIONS(1079),
    [sym_decimal_floating_point_literal] = ACTIONS(1079),
    [sym_hex_floating_point_literal] = ACTIONS(1081),
    [sym_true] = ACTIONS(1081),
    [sym_false] = ACTIONS(1081),
    [sym_character_literal] = ACTIONS(1079),
    [anon_sym_DQUOTE] = ACTIONS(1081),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1079),
    [anon_sym_RBRACE] = ACTIONS(1079),
    [sym_null_literal] = ACTIONS(1081),
    [anon_sym_LPAREN] = ACTIONS(1079),
    [anon_sym_LT] = ACTIONS(1079),
    [anon_sym_PLUS] = ACTIONS(1081),
    [anon_sym_DASH] = ACTIONS(1081),
    [anon_sym_final] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1079),
    [anon_sym_TILDE] = ACTIONS(1079),
    [anon_sym_PLUS_PLUS] = ACTIONS(1079),
    [anon_sym_DASH_DASH] = ACTIONS(1079),
    [anon_sym_new] = ACTIONS(1081),
    [anon_sym_class] = ACTIONS(1081),
    [anon_sym_switch] = ACTIONS(1081),
    [anon_sym_LBRACE] = ACTIONS(1079),
    [anon_sym_case] = ACTIONS(1081),
    [anon_sym_default] = ACTIONS(1081),
    [anon_sym_SEMI] = ACTIONS(1079),
    [anon_sym_assert] = ACTIONS(1081),
    [anon_sym_do] = ACTIONS(1081),
    [anon_sym_while] = ACTIONS(1081),
    [anon_sym_break] = ACTIONS(1081),
    [anon_sym_continue] = ACTIONS(1081),
    [anon_sym_return] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1081),
    [anon_sym_synchronized] = ACTIONS(1081),
    [anon_sym_throw] = ACTIONS(1081),
    [anon_sym_try] = ACTIONS(1081),
    [anon_sym_if] = ACTIONS(1081),
    [anon_sym_else] = ACTIONS(1081),
    [anon_sym_for] = ACTIONS(1081),
    [anon_sym_AT] = ACTIONS(1081),
    [anon_sym_open] = ACTIONS(1081),
    [anon_sym_module] = ACTIONS(1081),
    [anon_sym_static] = ACTIONS(1081),
    [anon_sym_with] = ACTIONS(1081),
    [anon_sym_package] = ACTIONS(1081),
    [anon_sym_import] = ACTIONS(1081),
    [anon_sym_enum] = ACTIONS(1081),
    [anon_sym_public] = ACTIONS(1081),
    [anon_sym_protected] = ACTIONS(1081),
    [anon_sym_private] = ACTIONS(1081),
    [anon_sym_abstract] = ACTIONS(1081),
    [anon_sym_strictfp] = ACTIONS(1081),
    [anon_sym_native] = ACTIONS(1081),
    [anon_sym_transient] = ACTIONS(1081),
    [anon_sym_volatile] = ACTIONS(1081),
    [anon_sym_sealed] = ACTIONS(1081),
    [anon_sym_non_DASHsealed] = ACTIONS(1079),
    [anon_sym_record] = ACTIONS(1081),
    [anon_sym_ATinterface] = ACTIONS(1079),
    [anon_sym_interface] = ACTIONS(1081),
    [anon_sym_byte] = ACTIONS(1081),
    [anon_sym_short] = ACTIONS(1081),
    [anon_sym_int] = ACTIONS(1081),
    [anon_sym_long] = ACTIONS(1081),
    [anon_sym_char] = ACTIONS(1081),
    [anon_sym_float] = ACTIONS(1081),
    [anon_sym_double] = ACTIONS(1081),
    [sym_boolean_type] = ACTIONS(1081),
    [sym_void_type] = ACTIONS(1081),
    [sym_this] = ACTIONS(1081),
    [sym_super] = ACTIONS(1081),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [363] = {
    [ts_builtin_sym_end] = ACTIONS(1083),
    [sym_identifier] = ACTIONS(1085),
    [sym_decimal_integer_literal] = ACTIONS(1085),
    [sym_hex_integer_literal] = ACTIONS(1085),
    [sym_octal_integer_literal] = ACTIONS(1085),
    [sym_binary_integer_literal] = ACTIONS(1083),
    [sym_decimal_floating_point_literal] = ACTIONS(1083),
    [sym_hex_floating_point_literal] = ACTIONS(1085),
    [sym_true] = ACTIONS(1085),
    [sym_false] = ACTIONS(1085),
    [sym_character_literal] = ACTIONS(1083),
    [anon_sym_DQUOTE] = ACTIONS(1085),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1083),
    [anon_sym_RBRACE] = ACTIONS(1083),
    [sym_null_literal] = ACTIONS(1085),
    [anon_sym_LPAREN] = ACTIONS(1083),
    [anon_sym_LT] = ACTIONS(1083),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_final] = ACTIONS(1085),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_new] = ACTIONS(1085),
    [anon_sym_class] = ACTIONS(1085),
    [anon_sym_switch] = ACTIONS(1085),
    [anon_sym_LBRACE] = ACTIONS(1083),
    [anon_sym_case] = ACTIONS(1085),
    [anon_sym_default] = ACTIONS(1085),
    [anon_sym_SEMI] = ACTIONS(1083),
    [anon_sym_assert] = ACTIONS(1085),
    [anon_sym_do] = ACTIONS(1085),
    [anon_sym_while] = ACTIONS(1085),
    [anon_sym_break] = ACTIONS(1085),
    [anon_sym_continue] = ACTIONS(1085),
    [anon_sym_return] = ACTIONS(1085),
    [anon_sym_yield] = ACTIONS(1085),
    [anon_sym_synchronized] = ACTIONS(1085),
    [anon_sym_throw] = ACTIONS(1085),
    [anon_sym_try] = ACTIONS(1085),
    [anon_sym_if] = ACTIONS(1085),
    [anon_sym_else] = ACTIONS(1085),
    [anon_sym_for] = ACTIONS(1085),
    [anon_sym_AT] = ACTIONS(1085),
    [anon_sym_open] = ACTIONS(1085),
    [anon_sym_module] = ACTIONS(1085),
    [anon_sym_static] = ACTIONS(1085),
    [anon_sym_with] = ACTIONS(1085),
    [anon_sym_package] = ACTIONS(1085),
    [anon_sym_import] = ACTIONS(1085),
    [anon_sym_enum] = ACTIONS(1085),
    [anon_sym_public] = ACTIONS(1085),
    [anon_sym_protected] = ACTIONS(1085),
    [anon_sym_private] = ACTIONS(1085),
    [anon_sym_abstract] = ACTIONS(1085),
    [anon_sym_strictfp] = ACTIONS(1085),
    [anon_sym_native] = ACTIONS(1085),
    [anon_sym_transient] = ACTIONS(1085),
    [anon_sym_volatile] = ACTIONS(1085),
    [anon_sym_sealed] = ACTIONS(1085),
    [anon_sym_non_DASHsealed] = ACTIONS(1083),
    [anon_sym_record] = ACTIONS(1085),
    [anon_sym_ATinterface] = ACTIONS(1083),
    [anon_sym_interface] = ACTIONS(1085),
    [anon_sym_byte] = ACTIONS(1085),
    [anon_sym_short] = ACTIONS(1085),
    [anon_sym_int] = ACTIONS(1085),
    [anon_sym_long] = ACTIONS(1085),
    [anon_sym_char] = ACTIONS(1085),
    [anon_sym_float] = ACTIONS(1085),
    [anon_sym_double] = ACTIONS(1085),
    [sym_boolean_type] = ACTIONS(1085),
    [sym_void_type] = ACTIONS(1085),
    [sym_this] = ACTIONS(1085),
    [sym_super] = ACTIONS(1085),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [364] = {
    [ts_builtin_sym_end] = ACTIONS(1087),
    [sym_identifier] = ACTIONS(1089),
    [sym_decimal_integer_literal] = ACTIONS(1089),
    [sym_hex_integer_literal] = ACTIONS(1089),
    [sym_octal_integer_literal] = ACTIONS(1089),
    [sym_binary_integer_literal] = ACTIONS(1087),
    [sym_decimal_floating_point_literal] = ACTIONS(1087),
    [sym_hex_floating_point_literal] = ACTIONS(1089),
    [sym_true] = ACTIONS(1089),
    [sym_false] = ACTIONS(1089),
    [sym_character_literal] = ACTIONS(1087),
    [anon_sym_DQUOTE] = ACTIONS(1089),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1087),
    [anon_sym_RBRACE] = ACTIONS(1087),
    [sym_null_literal] = ACTIONS(1089),
    [anon_sym_LPAREN] = ACTIONS(1087),
    [anon_sym_LT] = ACTIONS(1087),
    [anon_sym_PLUS] = ACTIONS(1089),
    [anon_sym_DASH] = ACTIONS(1089),
    [anon_sym_final] = ACTIONS(1089),
    [anon_sym_BANG] = ACTIONS(1087),
    [anon_sym_TILDE] = ACTIONS(1087),
    [anon_sym_PLUS_PLUS] = ACTIONS(1087),
    [anon_sym_DASH_DASH] = ACTIONS(1087),
    [anon_sym_new] = ACTIONS(1089),
    [anon_sym_class] = ACTIONS(1089),
    [anon_sym_switch] = ACTIONS(1089),
    [anon_sym_LBRACE] = ACTIONS(1087),
    [anon_sym_case] = ACTIONS(1089),
    [anon_sym_default] = ACTIONS(1089),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_assert] = ACTIONS(1089),
    [anon_sym_do] = ACTIONS(1089),
    [anon_sym_while] = ACTIONS(1089),
    [anon_sym_break] = ACTIONS(1089),
    [anon_sym_continue] = ACTIONS(1089),
    [anon_sym_return] = ACTIONS(1089),
    [anon_sym_yield] = ACTIONS(1089),
    [anon_sym_synchronized] = ACTIONS(1089),
    [anon_sym_throw] = ACTIONS(1089),
    [anon_sym_try] = ACTIONS(1089),
    [anon_sym_if] = ACTIONS(1089),
    [anon_sym_else] = ACTIONS(1089),
    [anon_sym_for] = ACTIONS(1089),
    [anon_sym_AT] = ACTIONS(1089),
    [anon_sym_open] = ACTIONS(1089),
    [anon_sym_module] = ACTIONS(1089),
    [anon_sym_static] = ACTIONS(1089),
    [anon_sym_with] = ACTIONS(1089),
    [anon_sym_package] = ACTIONS(1089),
    [anon_sym_import] = ACTIONS(1089),
    [anon_sym_enum] = ACTIONS(1089),
    [anon_sym_public] = ACTIONS(1089),
    [anon_sym_protected] = ACTIONS(1089),
    [anon_sym_private] = ACTIONS(1089),
    [anon_sym_abstract] = ACTIONS(1089),
    [anon_sym_strictfp] = ACTIONS(1089),
    [anon_sym_native] = ACTIONS(1089),
    [anon_sym_transient] = ACTIONS(1089),
    [anon_sym_volatile] = ACTIONS(1089),
    [anon_sym_sealed] = ACTIONS(1089),
    [anon_sym_non_DASHsealed] = ACTIONS(1087),
    [anon_sym_record] = ACTIONS(1089),
    [anon_sym_ATinterface] = ACTIONS(1087),
    [anon_sym_interface] = ACTIONS(1089),
    [anon_sym_byte] = ACTIONS(1089),
    [anon_sym_short] = ACTIONS(1089),
    [anon_sym_int] = ACTIONS(1089),
    [anon_sym_long] = ACTIONS(1089),
    [anon_sym_char] = ACTIONS(1089),
    [anon_sym_float] = ACTIONS(1089),
    [anon_sym_double] = ACTIONS(1089),
    [sym_boolean_type] = ACTIONS(1089),
    [sym_void_type] = ACTIONS(1089),
    [sym_this] = ACTIONS(1089),
    [sym_super] = ACTIONS(1089),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [365] = {
    [ts_builtin_sym_end] = ACTIONS(1091),
    [sym_identifier] = ACTIONS(1093),
    [sym_decimal_integer_literal] = ACTIONS(1093),
    [sym_hex_integer_literal] = ACTIONS(1093),
    [sym_octal_integer_literal] = ACTIONS(1093),
    [sym_binary_integer_literal] = ACTIONS(1091),
    [sym_decimal_floating_point_literal] = ACTIONS(1091),
    [sym_hex_floating_point_literal] = ACTIONS(1093),
    [sym_true] = ACTIONS(1093),
    [sym_false] = ACTIONS(1093),
    [sym_character_literal] = ACTIONS(1091),
    [anon_sym_DQUOTE] = ACTIONS(1093),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1091),
    [anon_sym_RBRACE] = ACTIONS(1091),
    [sym_null_literal] = ACTIONS(1093),
    [anon_sym_LPAREN] = ACTIONS(1091),
    [anon_sym_LT] = ACTIONS(1091),
    [anon_sym_PLUS] = ACTIONS(1093),
    [anon_sym_DASH] = ACTIONS(1093),
    [anon_sym_final] = ACTIONS(1093),
    [anon_sym_BANG] = ACTIONS(1091),
    [anon_sym_TILDE] = ACTIONS(1091),
    [anon_sym_PLUS_PLUS] = ACTIONS(1091),
    [anon_sym_DASH_DASH] = ACTIONS(1091),
    [anon_sym_new] = ACTIONS(1093),
    [anon_sym_class] = ACTIONS(1093),
    [anon_sym_switch] = ACTIONS(1093),
    [anon_sym_LBRACE] = ACTIONS(1091),
    [anon_sym_case] = ACTIONS(1093),
    [anon_sym_default] = ACTIONS(1093),
    [anon_sym_SEMI] = ACTIONS(1091),
    [anon_sym_assert] = ACTIONS(1093),
    [anon_sym_do] = ACTIONS(1093),
    [anon_sym_while] = ACTIONS(1093),
    [anon_sym_break] = ACTIONS(1093),
    [anon_sym_continue] = ACTIONS(1093),
    [anon_sym_return] = ACTIONS(1093),
    [anon_sym_yield] = ACTIONS(1093),
    [anon_sym_synchronized] = ACTIONS(1093),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_try] = ACTIONS(1093),
    [anon_sym_if] = ACTIONS(1093),
    [anon_sym_else] = ACTIONS(1093),
    [anon_sym_for] = ACTIONS(1093),
    [anon_sym_AT] = ACTIONS(1093),
    [anon_sym_open] = ACTIONS(1093),
    [anon_sym_module] = ACTIONS(1093),
    [anon_sym_static] = ACTIONS(1093),
    [anon_sym_with] = ACTIONS(1093),
    [anon_sym_package] = ACTIONS(1093),
    [anon_sym_import] = ACTIONS(1093),
    [anon_sym_enum] = ACTIONS(1093),
    [anon_sym_public] = ACTIONS(1093),
    [anon_sym_protected] = ACTIONS(1093),
    [anon_sym_private] = ACTIONS(1093),
    [anon_sym_abstract] = ACTIONS(1093),
    [anon_sym_strictfp] = ACTIONS(1093),
    [anon_sym_native] = ACTIONS(1093),
    [anon_sym_transient] = ACTIONS(1093),
    [anon_sym_volatile] = ACTIONS(1093),
    [anon_sym_sealed] = ACTIONS(1093),
    [anon_sym_non_DASHsealed] = ACTIONS(1091),
    [anon_sym_record] = ACTIONS(1093),
    [anon_sym_ATinterface] = ACTIONS(1091),
    [anon_sym_interface] = ACTIONS(1093),
    [anon_sym_byte] = ACTIONS(1093),
    [anon_sym_short] = ACTIONS(1093),
    [anon_sym_int] = ACTIONS(1093),
    [anon_sym_long] = ACTIONS(1093),
    [anon_sym_char] = ACTIONS(1093),
    [anon_sym_float] = ACTIONS(1093),
    [anon_sym_double] = ACTIONS(1093),
    [sym_boolean_type] = ACTIONS(1093),
    [sym_void_type] = ACTIONS(1093),
    [sym_this] = ACTIONS(1093),
    [sym_super] = ACTIONS(1093),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [366] = {
    [ts_builtin_sym_end] = ACTIONS(1095),
    [sym_identifier] = ACTIONS(1097),
    [sym_decimal_integer_literal] = ACTIONS(1097),
    [sym_hex_integer_literal] = ACTIONS(1097),
    [sym_octal_integer_literal] = ACTIONS(1097),
    [sym_binary_integer_literal] = ACTIONS(1095),
    [sym_decimal_floating_point_literal] = ACTIONS(1095),
    [sym_hex_floating_point_literal] = ACTIONS(1097),
    [sym_true] = ACTIONS(1097),
    [sym_false] = ACTIONS(1097),
    [sym_character_literal] = ACTIONS(1095),
    [anon_sym_DQUOTE] = ACTIONS(1097),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1095),
    [anon_sym_RBRACE] = ACTIONS(1095),
    [sym_null_literal] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(1095),
    [anon_sym_LT] = ACTIONS(1095),
    [anon_sym_PLUS] = ACTIONS(1097),
    [anon_sym_DASH] = ACTIONS(1097),
    [anon_sym_final] = ACTIONS(1097),
    [anon_sym_BANG] = ACTIONS(1095),
    [anon_sym_TILDE] = ACTIONS(1095),
    [anon_sym_PLUS_PLUS] = ACTIONS(1095),
    [anon_sym_DASH_DASH] = ACTIONS(1095),
    [anon_sym_new] = ACTIONS(1097),
    [anon_sym_class] = ACTIONS(1097),
    [anon_sym_switch] = ACTIONS(1097),
    [anon_sym_LBRACE] = ACTIONS(1095),
    [anon_sym_case] = ACTIONS(1097),
    [anon_sym_default] = ACTIONS(1097),
    [anon_sym_SEMI] = ACTIONS(1095),
    [anon_sym_assert] = ACTIONS(1097),
    [anon_sym_do] = ACTIONS(1097),
    [anon_sym_while] = ACTIONS(1097),
    [anon_sym_break] = ACTIONS(1097),
    [anon_sym_continue] = ACTIONS(1097),
    [anon_sym_return] = ACTIONS(1097),
    [anon_sym_yield] = ACTIONS(1097),
    [anon_sym_synchronized] = ACTIONS(1097),
    [anon_sym_throw] = ACTIONS(1097),
    [anon_sym_try] = ACTIONS(1097),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_else] = ACTIONS(1097),
    [anon_sym_for] = ACTIONS(1097),
    [anon_sym_AT] = ACTIONS(1097),
    [anon_sym_open] = ACTIONS(1097),
    [anon_sym_module] = ACTIONS(1097),
    [anon_sym_static] = ACTIONS(1097),
    [anon_sym_with] = ACTIONS(1097),
    [anon_sym_package] = ACTIONS(1097),
    [anon_sym_import] = ACTIONS(1097),
    [anon_sym_enum] = ACTIONS(1097),
    [anon_sym_public] = ACTIONS(1097),
    [anon_sym_protected] = ACTIONS(1097),
    [anon_sym_private] = ACTIONS(1097),
    [anon_sym_abstract] = ACTIONS(1097),
    [anon_sym_strictfp] = ACTIONS(1097),
    [anon_sym_native] = ACTIONS(1097),
    [anon_sym_transient] = ACTIONS(1097),
    [anon_sym_volatile] = ACTIONS(1097),
    [anon_sym_sealed] = ACTIONS(1097),
    [anon_sym_non_DASHsealed] = ACTIONS(1095),
    [anon_sym_record] = ACTIONS(1097),
    [anon_sym_ATinterface] = ACTIONS(1095),
    [anon_sym_interface] = ACTIONS(1097),
    [anon_sym_byte] = ACTIONS(1097),
    [anon_sym_short] = ACTIONS(1097),
    [anon_sym_int] = ACTIONS(1097),
    [anon_sym_long] = ACTIONS(1097),
    [anon_sym_char] = ACTIONS(1097),
    [anon_sym_float] = ACTIONS(1097),
    [anon_sym_double] = ACTIONS(1097),
    [sym_boolean_type] = ACTIONS(1097),
    [sym_void_type] = ACTIONS(1097),
    [sym_this] = ACTIONS(1097),
    [sym_super] = ACTIONS(1097),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [367] = {
    [ts_builtin_sym_end] = ACTIONS(1099),
    [sym_identifier] = ACTIONS(1101),
    [sym_decimal_integer_literal] = ACTIONS(1101),
    [sym_hex_integer_literal] = ACTIONS(1101),
    [sym_octal_integer_literal] = ACTIONS(1101),
    [sym_binary_integer_literal] = ACTIONS(1099),
    [sym_decimal_floating_point_literal] = ACTIONS(1099),
    [sym_hex_floating_point_literal] = ACTIONS(1101),
    [sym_true] = ACTIONS(1101),
    [sym_false] = ACTIONS(1101),
    [sym_character_literal] = ACTIONS(1099),
    [anon_sym_DQUOTE] = ACTIONS(1101),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1099),
    [anon_sym_RBRACE] = ACTIONS(1099),
    [sym_null_literal] = ACTIONS(1101),
    [anon_sym_LPAREN] = ACTIONS(1099),
    [anon_sym_LT] = ACTIONS(1099),
    [anon_sym_PLUS] = ACTIONS(1101),
    [anon_sym_DASH] = ACTIONS(1101),
    [anon_sym_final] = ACTIONS(1101),
    [anon_sym_BANG] = ACTIONS(1099),
    [anon_sym_TILDE] = ACTIONS(1099),
    [anon_sym_PLUS_PLUS] = ACTIONS(1099),
    [anon_sym_DASH_DASH] = ACTIONS(1099),
    [anon_sym_new] = ACTIONS(1101),
    [anon_sym_class] = ACTIONS(1101),
    [anon_sym_switch] = ACTIONS(1101),
    [anon_sym_LBRACE] = ACTIONS(1099),
    [anon_sym_case] = ACTIONS(1101),
    [anon_sym_default] = ACTIONS(1101),
    [anon_sym_SEMI] = ACTIONS(1099),
    [anon_sym_assert] = ACTIONS(1101),
    [anon_sym_do] = ACTIONS(1101),
    [anon_sym_while] = ACTIONS(1101),
    [anon_sym_break] = ACTIONS(1101),
    [anon_sym_continue] = ACTIONS(1101),
    [anon_sym_return] = ACTIONS(1101),
    [anon_sym_yield] = ACTIONS(1101),
    [anon_sym_synchronized] = ACTIONS(1101),
    [anon_sym_throw] = ACTIONS(1101),
    [anon_sym_try] = ACTIONS(1101),
    [anon_sym_if] = ACTIONS(1101),
    [anon_sym_else] = ACTIONS(1101),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_AT] = ACTIONS(1101),
    [anon_sym_open] = ACTIONS(1101),
    [anon_sym_module] = ACTIONS(1101),
    [anon_sym_static] = ACTIONS(1101),
    [anon_sym_with] = ACTIONS(1101),
    [anon_sym_package] = ACTIONS(1101),
    [anon_sym_import] = ACTIONS(1101),
    [anon_sym_enum] = ACTIONS(1101),
    [anon_sym_public] = ACTIONS(1101),
    [anon_sym_protected] = ACTIONS(1101),
    [anon_sym_private] = ACTIONS(1101),
    [anon_sym_abstract] = ACTIONS(1101),
    [anon_sym_strictfp] = ACTIONS(1101),
    [anon_sym_native] = ACTIONS(1101),
    [anon_sym_transient] = ACTIONS(1101),
    [anon_sym_volatile] = ACTIONS(1101),
    [anon_sym_sealed] = ACTIONS(1101),
    [anon_sym_non_DASHsealed] = ACTIONS(1099),
    [anon_sym_record] = ACTIONS(1101),
    [anon_sym_ATinterface] = ACTIONS(1099),
    [anon_sym_interface] = ACTIONS(1101),
    [anon_sym_byte] = ACTIONS(1101),
    [anon_sym_short] = ACTIONS(1101),
    [anon_sym_int] = ACTIONS(1101),
    [anon_sym_long] = ACTIONS(1101),
    [anon_sym_char] = ACTIONS(1101),
    [anon_sym_float] = ACTIONS(1101),
    [anon_sym_double] = ACTIONS(1101),
    [sym_boolean_type] = ACTIONS(1101),
    [sym_void_type] = ACTIONS(1101),
    [sym_this] = ACTIONS(1101),
    [sym_super] = ACTIONS(1101),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [368] = {
    [ts_builtin_sym_end] = ACTIONS(1103),
    [sym_identifier] = ACTIONS(1105),
    [sym_decimal_integer_literal] = ACTIONS(1105),
    [sym_hex_integer_literal] = ACTIONS(1105),
    [sym_octal_integer_literal] = ACTIONS(1105),
    [sym_binary_integer_literal] = ACTIONS(1103),
    [sym_decimal_floating_point_literal] = ACTIONS(1103),
    [sym_hex_floating_point_literal] = ACTIONS(1105),
    [sym_true] = ACTIONS(1105),
    [sym_false] = ACTIONS(1105),
    [sym_character_literal] = ACTIONS(1103),
    [anon_sym_DQUOTE] = ACTIONS(1105),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1103),
    [anon_sym_RBRACE] = ACTIONS(1103),
    [sym_null_literal] = ACTIONS(1105),
    [anon_sym_LPAREN] = ACTIONS(1103),
    [anon_sym_LT] = ACTIONS(1103),
    [anon_sym_PLUS] = ACTIONS(1105),
    [anon_sym_DASH] = ACTIONS(1105),
    [anon_sym_final] = ACTIONS(1105),
    [anon_sym_BANG] = ACTIONS(1103),
    [anon_sym_TILDE] = ACTIONS(1103),
    [anon_sym_PLUS_PLUS] = ACTIONS(1103),
    [anon_sym_DASH_DASH] = ACTIONS(1103),
    [anon_sym_new] = ACTIONS(1105),
    [anon_sym_class] = ACTIONS(1105),
    [anon_sym_switch] = ACTIONS(1105),
    [anon_sym_LBRACE] = ACTIONS(1103),
    [anon_sym_case] = ACTIONS(1105),
    [anon_sym_default] = ACTIONS(1105),
    [anon_sym_SEMI] = ACTIONS(1103),
    [anon_sym_assert] = ACTIONS(1105),
    [anon_sym_do] = ACTIONS(1105),
    [anon_sym_while] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_continue] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1105),
    [anon_sym_yield] = ACTIONS(1105),
    [anon_sym_synchronized] = ACTIONS(1105),
    [anon_sym_throw] = ACTIONS(1105),
    [anon_sym_try] = ACTIONS(1105),
    [anon_sym_if] = ACTIONS(1105),
    [anon_sym_else] = ACTIONS(1105),
    [anon_sym_for] = ACTIONS(1105),
    [anon_sym_AT] = ACTIONS(1105),
    [anon_sym_open] = ACTIONS(1105),
    [anon_sym_module] = ACTIONS(1105),
    [anon_sym_static] = ACTIONS(1105),
    [anon_sym_with] = ACTIONS(1105),
    [anon_sym_package] = ACTIONS(1105),
    [anon_sym_import] = ACTIONS(1105),
    [anon_sym_enum] = ACTIONS(1105),
    [anon_sym_public] = ACTIONS(1105),
    [anon_sym_protected] = ACTIONS(1105),
    [anon_sym_private] = ACTIONS(1105),
    [anon_sym_abstract] = ACTIONS(1105),
    [anon_sym_strictfp] = ACTIONS(1105),
    [anon_sym_native] = ACTIONS(1105),
    [anon_sym_transient] = ACTIONS(1105),
    [anon_sym_volatile] = ACTIONS(1105),
    [anon_sym_sealed] = ACTIONS(1105),
    [anon_sym_non_DASHsealed] = ACTIONS(1103),
    [anon_sym_record] = ACTIONS(1105),
    [anon_sym_ATinterface] = ACTIONS(1103),
    [anon_sym_interface] = ACTIONS(1105),
    [anon_sym_byte] = ACTIONS(1105),
    [anon_sym_short] = ACTIONS(1105),
    [anon_sym_int] = ACTIONS(1105),
    [anon_sym_long] = ACTIONS(1105),
    [anon_sym_char] = ACTIONS(1105),
    [anon_sym_float] = ACTIONS(1105),
    [anon_sym_double] = ACTIONS(1105),
    [sym_boolean_type] = ACTIONS(1105),
    [sym_void_type] = ACTIONS(1105),
    [sym_this] = ACTIONS(1105),
    [sym_super] = ACTIONS(1105),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [369] = {
    [ts_builtin_sym_end] = ACTIONS(1107),
    [sym_identifier] = ACTIONS(1109),
    [sym_decimal_integer_literal] = ACTIONS(1109),
    [sym_hex_integer_literal] = ACTIONS(1109),
    [sym_octal_integer_literal] = ACTIONS(1109),
    [sym_binary_integer_literal] = ACTIONS(1107),
    [sym_decimal_floating_point_literal] = ACTIONS(1107),
    [sym_hex_floating_point_literal] = ACTIONS(1109),
    [sym_true] = ACTIONS(1109),
    [sym_false] = ACTIONS(1109),
    [sym_character_literal] = ACTIONS(1107),
    [anon_sym_DQUOTE] = ACTIONS(1109),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1107),
    [anon_sym_RBRACE] = ACTIONS(1107),
    [sym_null_literal] = ACTIONS(1109),
    [anon_sym_LPAREN] = ACTIONS(1107),
    [anon_sym_LT] = ACTIONS(1107),
    [anon_sym_PLUS] = ACTIONS(1109),
    [anon_sym_DASH] = ACTIONS(1109),
    [anon_sym_final] = ACTIONS(1109),
    [anon_sym_BANG] = ACTIONS(1107),
    [anon_sym_TILDE] = ACTIONS(1107),
    [anon_sym_PLUS_PLUS] = ACTIONS(1107),
    [anon_sym_DASH_DASH] = ACTIONS(1107),
    [anon_sym_new] = ACTIONS(1109),
    [anon_sym_class] = ACTIONS(1109),
    [anon_sym_switch] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1107),
    [anon_sym_case] = ACTIONS(1109),
    [anon_sym_default] = ACTIONS(1109),
    [anon_sym_SEMI] = ACTIONS(1107),
    [anon_sym_assert] = ACTIONS(1109),
    [anon_sym_do] = ACTIONS(1109),
    [anon_sym_while] = ACTIONS(1109),
    [anon_sym_break] = ACTIONS(1109),
    [anon_sym_continue] = ACTIONS(1109),
    [anon_sym_return] = ACTIONS(1109),
    [anon_sym_yield] = ACTIONS(1109),
    [anon_sym_synchronized] = ACTIONS(1109),
    [anon_sym_throw] = ACTIONS(1109),
    [anon_sym_try] = ACTIONS(1109),
    [anon_sym_if] = ACTIONS(1109),
    [anon_sym_else] = ACTIONS(1109),
    [anon_sym_for] = ACTIONS(1109),
    [anon_sym_AT] = ACTIONS(1109),
    [anon_sym_open] = ACTIONS(1109),
    [anon_sym_module] = ACTIONS(1109),
    [anon_sym_static] = ACTIONS(1109),
    [anon_sym_with] = ACTIONS(1109),
    [anon_sym_package] = ACTIONS(1109),
    [anon_sym_import] = ACTIONS(1109),
    [anon_sym_enum] = ACTIONS(1109),
    [anon_sym_public] = ACTIONS(1109),
    [anon_sym_protected] = ACTIONS(1109),
    [anon_sym_private] = ACTIONS(1109),
    [anon_sym_abstract] = ACTIONS(1109),
    [anon_sym_strictfp] = ACTIONS(1109),
    [anon_sym_native] = ACTIONS(1109),
    [anon_sym_transient] = ACTIONS(1109),
    [anon_sym_volatile] = ACTIONS(1109),
    [anon_sym_sealed] = ACTIONS(1109),
    [anon_sym_non_DASHsealed] = ACTIONS(1107),
    [anon_sym_record] = ACTIONS(1109),
    [anon_sym_ATinterface] = ACTIONS(1107),
    [anon_sym_interface] = ACTIONS(1109),
    [anon_sym_byte] = ACTIONS(1109),
    [anon_sym_short] = ACTIONS(1109),
    [anon_sym_int] = ACTIONS(1109),
    [anon_sym_long] = ACTIONS(1109),
    [anon_sym_char] = ACTIONS(1109),
    [anon_sym_float] = ACTIONS(1109),
    [anon_sym_double] = ACTIONS(1109),
    [sym_boolean_type] = ACTIONS(1109),
    [sym_void_type] = ACTIONS(1109),
    [sym_this] = ACTIONS(1109),
    [sym_super] = ACTIONS(1109),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [370] = {
    [ts_builtin_sym_end] = ACTIONS(1111),
    [sym_identifier] = ACTIONS(1113),
    [sym_decimal_integer_literal] = ACTIONS(1113),
    [sym_hex_integer_literal] = ACTIONS(1113),
    [sym_octal_integer_literal] = ACTIONS(1113),
    [sym_binary_integer_literal] = ACTIONS(1111),
    [sym_decimal_floating_point_literal] = ACTIONS(1111),
    [sym_hex_floating_point_literal] = ACTIONS(1113),
    [sym_true] = ACTIONS(1113),
    [sym_false] = ACTIONS(1113),
    [sym_character_literal] = ACTIONS(1111),
    [anon_sym_DQUOTE] = ACTIONS(1113),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1111),
    [anon_sym_RBRACE] = ACTIONS(1111),
    [sym_null_literal] = ACTIONS(1113),
    [anon_sym_LPAREN] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1111),
    [anon_sym_PLUS] = ACTIONS(1113),
    [anon_sym_DASH] = ACTIONS(1113),
    [anon_sym_final] = ACTIONS(1113),
    [anon_sym_BANG] = ACTIONS(1111),
    [anon_sym_TILDE] = ACTIONS(1111),
    [anon_sym_PLUS_PLUS] = ACTIONS(1111),
    [anon_sym_DASH_DASH] = ACTIONS(1111),
    [anon_sym_new] = ACTIONS(1113),
    [anon_sym_class] = ACTIONS(1113),
    [anon_sym_switch] = ACTIONS(1113),
    [anon_sym_LBRACE] = ACTIONS(1111),
    [anon_sym_case] = ACTIONS(1113),
    [anon_sym_default] = ACTIONS(1113),
    [anon_sym_SEMI] = ACTIONS(1111),
    [anon_sym_assert] = ACTIONS(1113),
    [anon_sym_do] = ACTIONS(1113),
    [anon_sym_while] = ACTIONS(1113),
    [anon_sym_break] = ACTIONS(1113),
    [anon_sym_continue] = ACTIONS(1113),
    [anon_sym_return] = ACTIONS(1113),
    [anon_sym_yield] = ACTIONS(1113),
    [anon_sym_synchronized] = ACTIONS(1113),
    [anon_sym_throw] = ACTIONS(1113),
    [anon_sym_try] = ACTIONS(1113),
    [anon_sym_if] = ACTIONS(1113),
    [anon_sym_else] = ACTIONS(1113),
    [anon_sym_for] = ACTIONS(1113),
    [anon_sym_AT] = ACTIONS(1113),
    [anon_sym_open] = ACTIONS(1113),
    [anon_sym_module] = ACTIONS(1113),
    [anon_sym_static] = ACTIONS(1113),
    [anon_sym_with] = ACTIONS(1113),
    [anon_sym_package] = ACTIONS(1113),
    [anon_sym_import] = ACTIONS(1113),
    [anon_sym_enum] = ACTIONS(1113),
    [anon_sym_public] = ACTIONS(1113),
    [anon_sym_protected] = ACTIONS(1113),
    [anon_sym_private] = ACTIONS(1113),
    [anon_sym_abstract] = ACTIONS(1113),
    [anon_sym_strictfp] = ACTIONS(1113),
    [anon_sym_native] = ACTIONS(1113),
    [anon_sym_transient] = ACTIONS(1113),
    [anon_sym_volatile] = ACTIONS(1113),
    [anon_sym_sealed] = ACTIONS(1113),
    [anon_sym_non_DASHsealed] = ACTIONS(1111),
    [anon_sym_record] = ACTIONS(1113),
    [anon_sym_ATinterface] = ACTIONS(1111),
    [anon_sym_interface] = ACTIONS(1113),
    [anon_sym_byte] = ACTIONS(1113),
    [anon_sym_short] = ACTIONS(1113),
    [anon_sym_int] = ACTIONS(1113),
    [anon_sym_long] = ACTIONS(1113),
    [anon_sym_char] = ACTIONS(1113),
    [anon_sym_float] = ACTIONS(1113),
    [anon_sym_double] = ACTIONS(1113),
    [sym_boolean_type] = ACTIONS(1113),
    [sym_void_type] = ACTIONS(1113),
    [sym_this] = ACTIONS(1113),
    [sym_super] = ACTIONS(1113),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [371] = {
    [ts_builtin_sym_end] = ACTIONS(1115),
    [sym_identifier] = ACTIONS(1117),
    [sym_decimal_integer_literal] = ACTIONS(1117),
    [sym_hex_integer_literal] = ACTIONS(1117),
    [sym_octal_integer_literal] = ACTIONS(1117),
    [sym_binary_integer_literal] = ACTIONS(1115),
    [sym_decimal_floating_point_literal] = ACTIONS(1115),
    [sym_hex_floating_point_literal] = ACTIONS(1117),
    [sym_true] = ACTIONS(1117),
    [sym_false] = ACTIONS(1117),
    [sym_character_literal] = ACTIONS(1115),
    [anon_sym_DQUOTE] = ACTIONS(1117),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1115),
    [anon_sym_RBRACE] = ACTIONS(1115),
    [sym_null_literal] = ACTIONS(1117),
    [anon_sym_LPAREN] = ACTIONS(1115),
    [anon_sym_LT] = ACTIONS(1115),
    [anon_sym_PLUS] = ACTIONS(1117),
    [anon_sym_DASH] = ACTIONS(1117),
    [anon_sym_final] = ACTIONS(1117),
    [anon_sym_BANG] = ACTIONS(1115),
    [anon_sym_TILDE] = ACTIONS(1115),
    [anon_sym_PLUS_PLUS] = ACTIONS(1115),
    [anon_sym_DASH_DASH] = ACTIONS(1115),
    [anon_sym_new] = ACTIONS(1117),
    [anon_sym_class] = ACTIONS(1117),
    [anon_sym_switch] = ACTIONS(1117),
    [anon_sym_LBRACE] = ACTIONS(1115),
    [anon_sym_case] = ACTIONS(1117),
    [anon_sym_default] = ACTIONS(1117),
    [anon_sym_SEMI] = ACTIONS(1115),
    [anon_sym_assert] = ACTIONS(1117),
    [anon_sym_do] = ACTIONS(1117),
    [anon_sym_while] = ACTIONS(1117),
    [anon_sym_break] = ACTIONS(1117),
    [anon_sym_continue] = ACTIONS(1117),
    [anon_sym_return] = ACTIONS(1117),
    [anon_sym_yield] = ACTIONS(1117),
    [anon_sym_synchronized] = ACTIONS(1117),
    [anon_sym_throw] = ACTIONS(1117),
    [anon_sym_try] = ACTIONS(1117),
    [anon_sym_if] = ACTIONS(1117),
    [anon_sym_else] = ACTIONS(1117),
    [anon_sym_for] = ACTIONS(1117),
    [anon_sym_AT] = ACTIONS(1117),
    [anon_sym_open] = ACTIONS(1117),
    [anon_sym_module] = ACTIONS(1117),
    [anon_sym_static] = ACTIONS(1117),
    [anon_sym_with] = ACTIONS(1117),
    [anon_sym_package] = ACTIONS(1117),
    [anon_sym_import] = ACTIONS(1117),
    [anon_sym_enum] = ACTIONS(1117),
    [anon_sym_public] = ACTIONS(1117),
    [anon_sym_protected] = ACTIONS(1117),
    [anon_sym_private] = ACTIONS(1117),
    [anon_sym_abstract] = ACTIONS(1117),
    [anon_sym_strictfp] = ACTIONS(1117),
    [anon_sym_native] = ACTIONS(1117),
    [anon_sym_transient] = ACTIONS(1117),
    [anon_sym_volatile] = ACTIONS(1117),
    [anon_sym_sealed] = ACTIONS(1117),
    [anon_sym_non_DASHsealed] = ACTIONS(1115),
    [anon_sym_record] = ACTIONS(1117),
    [anon_sym_ATinterface] = ACTIONS(1115),
    [anon_sym_interface] = ACTIONS(1117),
    [anon_sym_byte] = ACTIONS(1117),
    [anon_sym_short] = ACTIONS(1117),
    [anon_sym_int] = ACTIONS(1117),
    [anon_sym_long] = ACTIONS(1117),
    [anon_sym_char] = ACTIONS(1117),
    [anon_sym_float] = ACTIONS(1117),
    [anon_sym_double] = ACTIONS(1117),
    [sym_boolean_type] = ACTIONS(1117),
    [sym_void_type] = ACTIONS(1117),
    [sym_this] = ACTIONS(1117),
    [sym_super] = ACTIONS(1117),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [372] = {
    [ts_builtin_sym_end] = ACTIONS(1119),
    [sym_identifier] = ACTIONS(1121),
    [sym_decimal_integer_literal] = ACTIONS(1121),
    [sym_hex_integer_literal] = ACTIONS(1121),
    [sym_octal_integer_literal] = ACTIONS(1121),
    [sym_binary_integer_literal] = ACTIONS(1119),
    [sym_decimal_floating_point_literal] = ACTIONS(1119),
    [sym_hex_floating_point_literal] = ACTIONS(1121),
    [sym_true] = ACTIONS(1121),
    [sym_false] = ACTIONS(1121),
    [sym_character_literal] = ACTIONS(1119),
    [anon_sym_DQUOTE] = ACTIONS(1121),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1119),
    [anon_sym_RBRACE] = ACTIONS(1119),
    [sym_null_literal] = ACTIONS(1121),
    [anon_sym_LPAREN] = ACTIONS(1119),
    [anon_sym_LT] = ACTIONS(1119),
    [anon_sym_PLUS] = ACTIONS(1121),
    [anon_sym_DASH] = ACTIONS(1121),
    [anon_sym_final] = ACTIONS(1121),
    [anon_sym_BANG] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(1119),
    [anon_sym_PLUS_PLUS] = ACTIONS(1119),
    [anon_sym_DASH_DASH] = ACTIONS(1119),
    [anon_sym_new] = ACTIONS(1121),
    [anon_sym_class] = ACTIONS(1121),
    [anon_sym_switch] = ACTIONS(1121),
    [anon_sym_LBRACE] = ACTIONS(1119),
    [anon_sym_case] = ACTIONS(1121),
    [anon_sym_default] = ACTIONS(1121),
    [anon_sym_SEMI] = ACTIONS(1119),
    [anon_sym_assert] = ACTIONS(1121),
    [anon_sym_do] = ACTIONS(1121),
    [anon_sym_while] = ACTIONS(1121),
    [anon_sym_break] = ACTIONS(1121),
    [anon_sym_continue] = ACTIONS(1121),
    [anon_sym_return] = ACTIONS(1121),
    [anon_sym_yield] = ACTIONS(1121),
    [anon_sym_synchronized] = ACTIONS(1121),
    [anon_sym_throw] = ACTIONS(1121),
    [anon_sym_try] = ACTIONS(1121),
    [anon_sym_if] = ACTIONS(1121),
    [anon_sym_else] = ACTIONS(1121),
    [anon_sym_for] = ACTIONS(1121),
    [anon_sym_AT] = ACTIONS(1121),
    [anon_sym_open] = ACTIONS(1121),
    [anon_sym_module] = ACTIONS(1121),
    [anon_sym_static] = ACTIONS(1121),
    [anon_sym_with] = ACTIONS(1121),
    [anon_sym_package] = ACTIONS(1121),
    [anon_sym_import] = ACTIONS(1121),
    [anon_sym_enum] = ACTIONS(1121),
    [anon_sym_public] = ACTIONS(1121),
    [anon_sym_protected] = ACTIONS(1121),
    [anon_sym_private] = ACTIONS(1121),
    [anon_sym_abstract] = ACTIONS(1121),
    [anon_sym_strictfp] = ACTIONS(1121),
    [anon_sym_native] = ACTIONS(1121),
    [anon_sym_transient] = ACTIONS(1121),
    [anon_sym_volatile] = ACTIONS(1121),
    [anon_sym_sealed] = ACTIONS(1121),
    [anon_sym_non_DASHsealed] = ACTIONS(1119),
    [anon_sym_record] = ACTIONS(1121),
    [anon_sym_ATinterface] = ACTIONS(1119),
    [anon_sym_interface] = ACTIONS(1121),
    [anon_sym_byte] = ACTIONS(1121),
    [anon_sym_short] = ACTIONS(1121),
    [anon_sym_int] = ACTIONS(1121),
    [anon_sym_long] = ACTIONS(1121),
    [anon_sym_char] = ACTIONS(1121),
    [anon_sym_float] = ACTIONS(1121),
    [anon_sym_double] = ACTIONS(1121),
    [sym_boolean_type] = ACTIONS(1121),
    [sym_void_type] = ACTIONS(1121),
    [sym_this] = ACTIONS(1121),
    [sym_super] = ACTIONS(1121),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [373] = {
    [ts_builtin_sym_end] = ACTIONS(1123),
    [sym_identifier] = ACTIONS(1125),
    [sym_decimal_integer_literal] = ACTIONS(1125),
    [sym_hex_integer_literal] = ACTIONS(1125),
    [sym_octal_integer_literal] = ACTIONS(1125),
    [sym_binary_integer_literal] = ACTIONS(1123),
    [sym_decimal_floating_point_literal] = ACTIONS(1123),
    [sym_hex_floating_point_literal] = ACTIONS(1125),
    [sym_true] = ACTIONS(1125),
    [sym_false] = ACTIONS(1125),
    [sym_character_literal] = ACTIONS(1123),
    [anon_sym_DQUOTE] = ACTIONS(1125),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1123),
    [anon_sym_RBRACE] = ACTIONS(1123),
    [sym_null_literal] = ACTIONS(1125),
    [anon_sym_LPAREN] = ACTIONS(1123),
    [anon_sym_LT] = ACTIONS(1123),
    [anon_sym_PLUS] = ACTIONS(1125),
    [anon_sym_DASH] = ACTIONS(1125),
    [anon_sym_final] = ACTIONS(1125),
    [anon_sym_BANG] = ACTIONS(1123),
    [anon_sym_TILDE] = ACTIONS(1123),
    [anon_sym_PLUS_PLUS] = ACTIONS(1123),
    [anon_sym_DASH_DASH] = ACTIONS(1123),
    [anon_sym_new] = ACTIONS(1125),
    [anon_sym_class] = ACTIONS(1125),
    [anon_sym_switch] = ACTIONS(1125),
    [anon_sym_LBRACE] = ACTIONS(1123),
    [anon_sym_case] = ACTIONS(1125),
    [anon_sym_default] = ACTIONS(1125),
    [anon_sym_SEMI] = ACTIONS(1123),
    [anon_sym_assert] = ACTIONS(1125),
    [anon_sym_do] = ACTIONS(1125),
    [anon_sym_while] = ACTIONS(1125),
    [anon_sym_break] = ACTIONS(1125),
    [anon_sym_continue] = ACTIONS(1125),
    [anon_sym_return] = ACTIONS(1125),
    [anon_sym_yield] = ACTIONS(1125),
    [anon_sym_synchronized] = ACTIONS(1125),
    [anon_sym_throw] = ACTIONS(1125),
    [anon_sym_try] = ACTIONS(1125),
    [anon_sym_if] = ACTIONS(1125),
    [anon_sym_else] = ACTIONS(1125),
    [anon_sym_for] = ACTIONS(1125),
    [anon_sym_AT] = ACTIONS(1125),
    [anon_sym_open] = ACTIONS(1125),
    [anon_sym_module] = ACTIONS(1125),
    [anon_sym_static] = ACTIONS(1125),
    [anon_sym_with] = ACTIONS(1125),
    [anon_sym_package] = ACTIONS(1125),
    [anon_sym_import] = ACTIONS(1125),
    [anon_sym_enum] = ACTIONS(1125),
    [anon_sym_public] = ACTIONS(1125),
    [anon_sym_protected] = ACTIONS(1125),
    [anon_sym_private] = ACTIONS(1125),
    [anon_sym_abstract] = ACTIONS(1125),
    [anon_sym_strictfp] = ACTIONS(1125),
    [anon_sym_native] = ACTIONS(1125),
    [anon_sym_transient] = ACTIONS(1125),
    [anon_sym_volatile] = ACTIONS(1125),
    [anon_sym_sealed] = ACTIONS(1125),
    [anon_sym_non_DASHsealed] = ACTIONS(1123),
    [anon_sym_record] = ACTIONS(1125),
    [anon_sym_ATinterface] = ACTIONS(1123),
    [anon_sym_interface] = ACTIONS(1125),
    [anon_sym_byte] = ACTIONS(1125),
    [anon_sym_short] = ACTIONS(1125),
    [anon_sym_int] = ACTIONS(1125),
    [anon_sym_long] = ACTIONS(1125),
    [anon_sym_char] = ACTIONS(1125),
    [anon_sym_float] = ACTIONS(1125),
    [anon_sym_double] = ACTIONS(1125),
    [sym_boolean_type] = ACTIONS(1125),
    [sym_void_type] = ACTIONS(1125),
    [sym_this] = ACTIONS(1125),
    [sym_super] = ACTIONS(1125),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [374] = {
    [ts_builtin_sym_end] = ACTIONS(1127),
    [sym_identifier] = ACTIONS(1129),
    [sym_decimal_integer_literal] = ACTIONS(1129),
    [sym_hex_integer_literal] = ACTIONS(1129),
    [sym_octal_integer_literal] = ACTIONS(1129),
    [sym_binary_integer_literal] = ACTIONS(1127),
    [sym_decimal_floating_point_literal] = ACTIONS(1127),
    [sym_hex_floating_point_literal] = ACTIONS(1129),
    [sym_true] = ACTIONS(1129),
    [sym_false] = ACTIONS(1129),
    [sym_character_literal] = ACTIONS(1127),
    [anon_sym_DQUOTE] = ACTIONS(1129),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1127),
    [anon_sym_RBRACE] = ACTIONS(1127),
    [sym_null_literal] = ACTIONS(1129),
    [anon_sym_LPAREN] = ACTIONS(1127),
    [anon_sym_LT] = ACTIONS(1127),
    [anon_sym_PLUS] = ACTIONS(1129),
    [anon_sym_DASH] = ACTIONS(1129),
    [anon_sym_final] = ACTIONS(1129),
    [anon_sym_BANG] = ACTIONS(1127),
    [anon_sym_TILDE] = ACTIONS(1127),
    [anon_sym_PLUS_PLUS] = ACTIONS(1127),
    [anon_sym_DASH_DASH] = ACTIONS(1127),
    [anon_sym_new] = ACTIONS(1129),
    [anon_sym_class] = ACTIONS(1129),
    [anon_sym_switch] = ACTIONS(1129),
    [anon_sym_LBRACE] = ACTIONS(1127),
    [anon_sym_case] = ACTIONS(1129),
    [anon_sym_default] = ACTIONS(1129),
    [anon_sym_SEMI] = ACTIONS(1127),
    [anon_sym_assert] = ACTIONS(1129),
    [anon_sym_do] = ACTIONS(1129),
    [anon_sym_while] = ACTIONS(1129),
    [anon_sym_break] = ACTIONS(1129),
    [anon_sym_continue] = ACTIONS(1129),
    [anon_sym_return] = ACTIONS(1129),
    [anon_sym_yield] = ACTIONS(1129),
    [anon_sym_synchronized] = ACTIONS(1129),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_try] = ACTIONS(1129),
    [anon_sym_if] = ACTIONS(1129),
    [anon_sym_else] = ACTIONS(1129),
    [anon_sym_for] = ACTIONS(1129),
    [anon_sym_AT] = ACTIONS(1129),
    [anon_sym_open] = ACTIONS(1129),
    [anon_sym_module] = ACTIONS(1129),
    [anon_sym_static] = ACTIONS(1129),
    [anon_sym_with] = ACTIONS(1129),
    [anon_sym_package] = ACTIONS(1129),
    [anon_sym_import] = ACTIONS(1129),
    [anon_sym_enum] = ACTIONS(1129),
    [anon_sym_public] = ACTIONS(1129),
    [anon_sym_protected] = ACTIONS(1129),
    [anon_sym_private] = ACTIONS(1129),
    [anon_sym_abstract] = ACTIONS(1129),
    [anon_sym_strictfp] = ACTIONS(1129),
    [anon_sym_native] = ACTIONS(1129),
    [anon_sym_transient] = ACTIONS(1129),
    [anon_sym_volatile] = ACTIONS(1129),
    [anon_sym_sealed] = ACTIONS(1129),
    [anon_sym_non_DASHsealed] = ACTIONS(1127),
    [anon_sym_record] = ACTIONS(1129),
    [anon_sym_ATinterface] = ACTIONS(1127),
    [anon_sym_interface] = ACTIONS(1129),
    [anon_sym_byte] = ACTIONS(1129),
    [anon_sym_short] = ACTIONS(1129),
    [anon_sym_int] = ACTIONS(1129),
    [anon_sym_long] = ACTIONS(1129),
    [anon_sym_char] = ACTIONS(1129),
    [anon_sym_float] = ACTIONS(1129),
    [anon_sym_double] = ACTIONS(1129),
    [sym_boolean_type] = ACTIONS(1129),
    [sym_void_type] = ACTIONS(1129),
    [sym_this] = ACTIONS(1129),
    [sym_super] = ACTIONS(1129),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [375] = {
    [ts_builtin_sym_end] = ACTIONS(1131),
    [sym_identifier] = ACTIONS(1133),
    [sym_decimal_integer_literal] = ACTIONS(1133),
    [sym_hex_integer_literal] = ACTIONS(1133),
    [sym_octal_integer_literal] = ACTIONS(1133),
    [sym_binary_integer_literal] = ACTIONS(1131),
    [sym_decimal_floating_point_literal] = ACTIONS(1131),
    [sym_hex_floating_point_literal] = ACTIONS(1133),
    [sym_true] = ACTIONS(1133),
    [sym_false] = ACTIONS(1133),
    [sym_character_literal] = ACTIONS(1131),
    [anon_sym_DQUOTE] = ACTIONS(1133),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1131),
    [anon_sym_RBRACE] = ACTIONS(1131),
    [sym_null_literal] = ACTIONS(1133),
    [anon_sym_LPAREN] = ACTIONS(1131),
    [anon_sym_LT] = ACTIONS(1131),
    [anon_sym_PLUS] = ACTIONS(1133),
    [anon_sym_DASH] = ACTIONS(1133),
    [anon_sym_final] = ACTIONS(1133),
    [anon_sym_BANG] = ACTIONS(1131),
    [anon_sym_TILDE] = ACTIONS(1131),
    [anon_sym_PLUS_PLUS] = ACTIONS(1131),
    [anon_sym_DASH_DASH] = ACTIONS(1131),
    [anon_sym_new] = ACTIONS(1133),
    [anon_sym_class] = ACTIONS(1133),
    [anon_sym_switch] = ACTIONS(1133),
    [anon_sym_LBRACE] = ACTIONS(1131),
    [anon_sym_case] = ACTIONS(1133),
    [anon_sym_default] = ACTIONS(1133),
    [anon_sym_SEMI] = ACTIONS(1131),
    [anon_sym_assert] = ACTIONS(1133),
    [anon_sym_do] = ACTIONS(1133),
    [anon_sym_while] = ACTIONS(1133),
    [anon_sym_break] = ACTIONS(1133),
    [anon_sym_continue] = ACTIONS(1133),
    [anon_sym_return] = ACTIONS(1133),
    [anon_sym_yield] = ACTIONS(1133),
    [anon_sym_synchronized] = ACTIONS(1133),
    [anon_sym_throw] = ACTIONS(1133),
    [anon_sym_try] = ACTIONS(1133),
    [anon_sym_if] = ACTIONS(1133),
    [anon_sym_else] = ACTIONS(1133),
    [anon_sym_for] = ACTIONS(1133),
    [anon_sym_AT] = ACTIONS(1133),
    [anon_sym_open] = ACTIONS(1133),
    [anon_sym_module] = ACTIONS(1133),
    [anon_sym_static] = ACTIONS(1133),
    [anon_sym_with] = ACTIONS(1133),
    [anon_sym_package] = ACTIONS(1133),
    [anon_sym_import] = ACTIONS(1133),
    [anon_sym_enum] = ACTIONS(1133),
    [anon_sym_public] = ACTIONS(1133),
    [anon_sym_protected] = ACTIONS(1133),
    [anon_sym_private] = ACTIONS(1133),
    [anon_sym_abstract] = ACTIONS(1133),
    [anon_sym_strictfp] = ACTIONS(1133),
    [anon_sym_native] = ACTIONS(1133),
    [anon_sym_transient] = ACTIONS(1133),
    [anon_sym_volatile] = ACTIONS(1133),
    [anon_sym_sealed] = ACTIONS(1133),
    [anon_sym_non_DASHsealed] = ACTIONS(1131),
    [anon_sym_record] = ACTIONS(1133),
    [anon_sym_ATinterface] = ACTIONS(1131),
    [anon_sym_interface] = ACTIONS(1133),
    [anon_sym_byte] = ACTIONS(1133),
    [anon_sym_short] = ACTIONS(1133),
    [anon_sym_int] = ACTIONS(1133),
    [anon_sym_long] = ACTIONS(1133),
    [anon_sym_char] = ACTIONS(1133),
    [anon_sym_float] = ACTIONS(1133),
    [anon_sym_double] = ACTIONS(1133),
    [sym_boolean_type] = ACTIONS(1133),
    [sym_void_type] = ACTIONS(1133),
    [sym_this] = ACTIONS(1133),
    [sym_super] = ACTIONS(1133),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [376] = {
    [ts_builtin_sym_end] = ACTIONS(1135),
    [sym_identifier] = ACTIONS(1137),
    [sym_decimal_integer_literal] = ACTIONS(1137),
    [sym_hex_integer_literal] = ACTIONS(1137),
    [sym_octal_integer_literal] = ACTIONS(1137),
    [sym_binary_integer_literal] = ACTIONS(1135),
    [sym_decimal_floating_point_literal] = ACTIONS(1135),
    [sym_hex_floating_point_literal] = ACTIONS(1137),
    [sym_true] = ACTIONS(1137),
    [sym_false] = ACTIONS(1137),
    [sym_character_literal] = ACTIONS(1135),
    [anon_sym_DQUOTE] = ACTIONS(1137),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1135),
    [anon_sym_RBRACE] = ACTIONS(1135),
    [sym_null_literal] = ACTIONS(1137),
    [anon_sym_LPAREN] = ACTIONS(1135),
    [anon_sym_LT] = ACTIONS(1135),
    [anon_sym_PLUS] = ACTIONS(1137),
    [anon_sym_DASH] = ACTIONS(1137),
    [anon_sym_final] = ACTIONS(1137),
    [anon_sym_BANG] = ACTIONS(1135),
    [anon_sym_TILDE] = ACTIONS(1135),
    [anon_sym_PLUS_PLUS] = ACTIONS(1135),
    [anon_sym_DASH_DASH] = ACTIONS(1135),
    [anon_sym_new] = ACTIONS(1137),
    [anon_sym_class] = ACTIONS(1137),
    [anon_sym_switch] = ACTIONS(1137),
    [anon_sym_LBRACE] = ACTIONS(1135),
    [anon_sym_case] = ACTIONS(1137),
    [anon_sym_default] = ACTIONS(1137),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_assert] = ACTIONS(1137),
    [anon_sym_do] = ACTIONS(1137),
    [anon_sym_while] = ACTIONS(1137),
    [anon_sym_break] = ACTIONS(1137),
    [anon_sym_continue] = ACTIONS(1137),
    [anon_sym_return] = ACTIONS(1137),
    [anon_sym_yield] = ACTIONS(1137),
    [anon_sym_synchronized] = ACTIONS(1137),
    [anon_sym_throw] = ACTIONS(1137),
    [anon_sym_try] = ACTIONS(1137),
    [anon_sym_if] = ACTIONS(1137),
    [anon_sym_else] = ACTIONS(1137),
    [anon_sym_for] = ACTIONS(1137),
    [anon_sym_AT] = ACTIONS(1137),
    [anon_sym_open] = ACTIONS(1137),
    [anon_sym_module] = ACTIONS(1137),
    [anon_sym_static] = ACTIONS(1137),
    [anon_sym_with] = ACTIONS(1137),
    [anon_sym_package] = ACTIONS(1137),
    [anon_sym_import] = ACTIONS(1137),
    [anon_sym_enum] = ACTIONS(1137),
    [anon_sym_public] = ACTIONS(1137),
    [anon_sym_protected] = ACTIONS(1137),
    [anon_sym_private] = ACTIONS(1137),
    [anon_sym_abstract] = ACTIONS(1137),
    [anon_sym_strictfp] = ACTIONS(1137),
    [anon_sym_native] = ACTIONS(1137),
    [anon_sym_transient] = ACTIONS(1137),
    [anon_sym_volatile] = ACTIONS(1137),
    [anon_sym_sealed] = ACTIONS(1137),
    [anon_sym_non_DASHsealed] = ACTIONS(1135),
    [anon_sym_record] = ACTIONS(1137),
    [anon_sym_ATinterface] = ACTIONS(1135),
    [anon_sym_interface] = ACTIONS(1137),
    [anon_sym_byte] = ACTIONS(1137),
    [anon_sym_short] = ACTIONS(1137),
    [anon_sym_int] = ACTIONS(1137),
    [anon_sym_long] = ACTIONS(1137),
    [anon_sym_char] = ACTIONS(1137),
    [anon_sym_float] = ACTIONS(1137),
    [anon_sym_double] = ACTIONS(1137),
    [sym_boolean_type] = ACTIONS(1137),
    [sym_void_type] = ACTIONS(1137),
    [sym_this] = ACTIONS(1137),
    [sym_super] = ACTIONS(1137),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [377] = {
    [ts_builtin_sym_end] = ACTIONS(1139),
    [sym_identifier] = ACTIONS(1141),
    [sym_decimal_integer_literal] = ACTIONS(1141),
    [sym_hex_integer_literal] = ACTIONS(1141),
    [sym_octal_integer_literal] = ACTIONS(1141),
    [sym_binary_integer_literal] = ACTIONS(1139),
    [sym_decimal_floating_point_literal] = ACTIONS(1139),
    [sym_hex_floating_point_literal] = ACTIONS(1141),
    [sym_true] = ACTIONS(1141),
    [sym_false] = ACTIONS(1141),
    [sym_character_literal] = ACTIONS(1139),
    [anon_sym_DQUOTE] = ACTIONS(1141),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1139),
    [anon_sym_RBRACE] = ACTIONS(1139),
    [sym_null_literal] = ACTIONS(1141),
    [anon_sym_LPAREN] = ACTIONS(1139),
    [anon_sym_LT] = ACTIONS(1139),
    [anon_sym_PLUS] = ACTIONS(1141),
    [anon_sym_DASH] = ACTIONS(1141),
    [anon_sym_final] = ACTIONS(1141),
    [anon_sym_BANG] = ACTIONS(1139),
    [anon_sym_TILDE] = ACTIONS(1139),
    [anon_sym_PLUS_PLUS] = ACTIONS(1139),
    [anon_sym_DASH_DASH] = ACTIONS(1139),
    [anon_sym_new] = ACTIONS(1141),
    [anon_sym_class] = ACTIONS(1141),
    [anon_sym_switch] = ACTIONS(1141),
    [anon_sym_LBRACE] = ACTIONS(1139),
    [anon_sym_case] = ACTIONS(1141),
    [anon_sym_default] = ACTIONS(1141),
    [anon_sym_SEMI] = ACTIONS(1139),
    [anon_sym_assert] = ACTIONS(1141),
    [anon_sym_do] = ACTIONS(1141),
    [anon_sym_while] = ACTIONS(1141),
    [anon_sym_break] = ACTIONS(1141),
    [anon_sym_continue] = ACTIONS(1141),
    [anon_sym_return] = ACTIONS(1141),
    [anon_sym_yield] = ACTIONS(1141),
    [anon_sym_synchronized] = ACTIONS(1141),
    [anon_sym_throw] = ACTIONS(1141),
    [anon_sym_try] = ACTIONS(1141),
    [anon_sym_if] = ACTIONS(1141),
    [anon_sym_else] = ACTIONS(1141),
    [anon_sym_for] = ACTIONS(1141),
    [anon_sym_AT] = ACTIONS(1141),
    [anon_sym_open] = ACTIONS(1141),
    [anon_sym_module] = ACTIONS(1141),
    [anon_sym_static] = ACTIONS(1141),
    [anon_sym_with] = ACTIONS(1141),
    [anon_sym_package] = ACTIONS(1141),
    [anon_sym_import] = ACTIONS(1141),
    [anon_sym_enum] = ACTIONS(1141),
    [anon_sym_public] = ACTIONS(1141),
    [anon_sym_protected] = ACTIONS(1141),
    [anon_sym_private] = ACTIONS(1141),
    [anon_sym_abstract] = ACTIONS(1141),
    [anon_sym_strictfp] = ACTIONS(1141),
    [anon_sym_native] = ACTIONS(1141),
    [anon_sym_transient] = ACTIONS(1141),
    [anon_sym_volatile] = ACTIONS(1141),
    [anon_sym_sealed] = ACTIONS(1141),
    [anon_sym_non_DASHsealed] = ACTIONS(1139),
    [anon_sym_record] = ACTIONS(1141),
    [anon_sym_ATinterface] = ACTIONS(1139),
    [anon_sym_interface] = ACTIONS(1141),
    [anon_sym_byte] = ACTIONS(1141),
    [anon_sym_short] = ACTIONS(1141),
    [anon_sym_int] = ACTIONS(1141),
    [anon_sym_long] = ACTIONS(1141),
    [anon_sym_char] = ACTIONS(1141),
    [anon_sym_float] = ACTIONS(1141),
    [anon_sym_double] = ACTIONS(1141),
    [sym_boolean_type] = ACTIONS(1141),
    [sym_void_type] = ACTIONS(1141),
    [sym_this] = ACTIONS(1141),
    [sym_super] = ACTIONS(1141),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [378] = {
    [ts_builtin_sym_end] = ACTIONS(1143),
    [sym_identifier] = ACTIONS(1145),
    [sym_decimal_integer_literal] = ACTIONS(1145),
    [sym_hex_integer_literal] = ACTIONS(1145),
    [sym_octal_integer_literal] = ACTIONS(1145),
    [sym_binary_integer_literal] = ACTIONS(1143),
    [sym_decimal_floating_point_literal] = ACTIONS(1143),
    [sym_hex_floating_point_literal] = ACTIONS(1145),
    [sym_true] = ACTIONS(1145),
    [sym_false] = ACTIONS(1145),
    [sym_character_literal] = ACTIONS(1143),
    [anon_sym_DQUOTE] = ACTIONS(1145),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1143),
    [anon_sym_RBRACE] = ACTIONS(1143),
    [sym_null_literal] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(1143),
    [anon_sym_LT] = ACTIONS(1143),
    [anon_sym_PLUS] = ACTIONS(1145),
    [anon_sym_DASH] = ACTIONS(1145),
    [anon_sym_final] = ACTIONS(1145),
    [anon_sym_BANG] = ACTIONS(1143),
    [anon_sym_TILDE] = ACTIONS(1143),
    [anon_sym_PLUS_PLUS] = ACTIONS(1143),
    [anon_sym_DASH_DASH] = ACTIONS(1143),
    [anon_sym_new] = ACTIONS(1145),
    [anon_sym_class] = ACTIONS(1145),
    [anon_sym_switch] = ACTIONS(1145),
    [anon_sym_LBRACE] = ACTIONS(1143),
    [anon_sym_case] = ACTIONS(1145),
    [anon_sym_default] = ACTIONS(1145),
    [anon_sym_SEMI] = ACTIONS(1143),
    [anon_sym_assert] = ACTIONS(1145),
    [anon_sym_do] = ACTIONS(1145),
    [anon_sym_while] = ACTIONS(1145),
    [anon_sym_break] = ACTIONS(1145),
    [anon_sym_continue] = ACTIONS(1145),
    [anon_sym_return] = ACTIONS(1145),
    [anon_sym_yield] = ACTIONS(1145),
    [anon_sym_synchronized] = ACTIONS(1145),
    [anon_sym_throw] = ACTIONS(1145),
    [anon_sym_try] = ACTIONS(1145),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_else] = ACTIONS(1145),
    [anon_sym_for] = ACTIONS(1145),
    [anon_sym_AT] = ACTIONS(1145),
    [anon_sym_open] = ACTIONS(1145),
    [anon_sym_module] = ACTIONS(1145),
    [anon_sym_static] = ACTIONS(1145),
    [anon_sym_with] = ACTIONS(1145),
    [anon_sym_package] = ACTIONS(1145),
    [anon_sym_import] = ACTIONS(1145),
    [anon_sym_enum] = ACTIONS(1145),
    [anon_sym_public] = ACTIONS(1145),
    [anon_sym_protected] = ACTIONS(1145),
    [anon_sym_private] = ACTIONS(1145),
    [anon_sym_abstract] = ACTIONS(1145),
    [anon_sym_strictfp] = ACTIONS(1145),
    [anon_sym_native] = ACTIONS(1145),
    [anon_sym_transient] = ACTIONS(1145),
    [anon_sym_volatile] = ACTIONS(1145),
    [anon_sym_sealed] = ACTIONS(1145),
    [anon_sym_non_DASHsealed] = ACTIONS(1143),
    [anon_sym_record] = ACTIONS(1145),
    [anon_sym_ATinterface] = ACTIONS(1143),
    [anon_sym_interface] = ACTIONS(1145),
    [anon_sym_byte] = ACTIONS(1145),
    [anon_sym_short] = ACTIONS(1145),
    [anon_sym_int] = ACTIONS(1145),
    [anon_sym_long] = ACTIONS(1145),
    [anon_sym_char] = ACTIONS(1145),
    [anon_sym_float] = ACTIONS(1145),
    [anon_sym_double] = ACTIONS(1145),
    [sym_boolean_type] = ACTIONS(1145),
    [sym_void_type] = ACTIONS(1145),
    [sym_this] = ACTIONS(1145),
    [sym_super] = ACTIONS(1145),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [379] = {
    [ts_builtin_sym_end] = ACTIONS(1147),
    [sym_identifier] = ACTIONS(1149),
    [sym_decimal_integer_literal] = ACTIONS(1149),
    [sym_hex_integer_literal] = ACTIONS(1149),
    [sym_octal_integer_literal] = ACTIONS(1149),
    [sym_binary_integer_literal] = ACTIONS(1147),
    [sym_decimal_floating_point_literal] = ACTIONS(1147),
    [sym_hex_floating_point_literal] = ACTIONS(1149),
    [sym_true] = ACTIONS(1149),
    [sym_false] = ACTIONS(1149),
    [sym_character_literal] = ACTIONS(1147),
    [anon_sym_DQUOTE] = ACTIONS(1149),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1147),
    [anon_sym_RBRACE] = ACTIONS(1147),
    [sym_null_literal] = ACTIONS(1149),
    [anon_sym_LPAREN] = ACTIONS(1147),
    [anon_sym_LT] = ACTIONS(1147),
    [anon_sym_PLUS] = ACTIONS(1149),
    [anon_sym_DASH] = ACTIONS(1149),
    [anon_sym_final] = ACTIONS(1149),
    [anon_sym_BANG] = ACTIONS(1147),
    [anon_sym_TILDE] = ACTIONS(1147),
    [anon_sym_PLUS_PLUS] = ACTIONS(1147),
    [anon_sym_DASH_DASH] = ACTIONS(1147),
    [anon_sym_new] = ACTIONS(1149),
    [anon_sym_class] = ACTIONS(1149),
    [anon_sym_switch] = ACTIONS(1149),
    [anon_sym_LBRACE] = ACTIONS(1147),
    [anon_sym_case] = ACTIONS(1149),
    [anon_sym_default] = ACTIONS(1149),
    [anon_sym_SEMI] = ACTIONS(1147),
    [anon_sym_assert] = ACTIONS(1149),
    [anon_sym_do] = ACTIONS(1149),
    [anon_sym_while] = ACTIONS(1149),
    [anon_sym_break] = ACTIONS(1149),
    [anon_sym_continue] = ACTIONS(1149),
    [anon_sym_return] = ACTIONS(1149),
    [anon_sym_yield] = ACTIONS(1149),
    [anon_sym_synchronized] = ACTIONS(1149),
    [anon_sym_throw] = ACTIONS(1149),
    [anon_sym_try] = ACTIONS(1149),
    [anon_sym_if] = ACTIONS(1149),
    [anon_sym_else] = ACTIONS(1149),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_AT] = ACTIONS(1149),
    [anon_sym_open] = ACTIONS(1149),
    [anon_sym_module] = ACTIONS(1149),
    [anon_sym_static] = ACTIONS(1149),
    [anon_sym_with] = ACTIONS(1149),
    [anon_sym_package] = ACTIONS(1149),
    [anon_sym_import] = ACTIONS(1149),
    [anon_sym_enum] = ACTIONS(1149),
    [anon_sym_public] = ACTIONS(1149),
    [anon_sym_protected] = ACTIONS(1149),
    [anon_sym_private] = ACTIONS(1149),
    [anon_sym_abstract] = ACTIONS(1149),
    [anon_sym_strictfp] = ACTIONS(1149),
    [anon_sym_native] = ACTIONS(1149),
    [anon_sym_transient] = ACTIONS(1149),
    [anon_sym_volatile] = ACTIONS(1149),
    [anon_sym_sealed] = ACTIONS(1149),
    [anon_sym_non_DASHsealed] = ACTIONS(1147),
    [anon_sym_record] = ACTIONS(1149),
    [anon_sym_ATinterface] = ACTIONS(1147),
    [anon_sym_interface] = ACTIONS(1149),
    [anon_sym_byte] = ACTIONS(1149),
    [anon_sym_short] = ACTIONS(1149),
    [anon_sym_int] = ACTIONS(1149),
    [anon_sym_long] = ACTIONS(1149),
    [anon_sym_char] = ACTIONS(1149),
    [anon_sym_float] = ACTIONS(1149),
    [anon_sym_double] = ACTIONS(1149),
    [sym_boolean_type] = ACTIONS(1149),
    [sym_void_type] = ACTIONS(1149),
    [sym_this] = ACTIONS(1149),
    [sym_super] = ACTIONS(1149),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [380] = {
    [ts_builtin_sym_end] = ACTIONS(1151),
    [sym_identifier] = ACTIONS(1153),
    [sym_decimal_integer_literal] = ACTIONS(1153),
    [sym_hex_integer_literal] = ACTIONS(1153),
    [sym_octal_integer_literal] = ACTIONS(1153),
    [sym_binary_integer_literal] = ACTIONS(1151),
    [sym_decimal_floating_point_literal] = ACTIONS(1151),
    [sym_hex_floating_point_literal] = ACTIONS(1153),
    [sym_true] = ACTIONS(1153),
    [sym_false] = ACTIONS(1153),
    [sym_character_literal] = ACTIONS(1151),
    [anon_sym_DQUOTE] = ACTIONS(1153),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1151),
    [anon_sym_RBRACE] = ACTIONS(1151),
    [sym_null_literal] = ACTIONS(1153),
    [anon_sym_LPAREN] = ACTIONS(1151),
    [anon_sym_LT] = ACTIONS(1151),
    [anon_sym_PLUS] = ACTIONS(1153),
    [anon_sym_DASH] = ACTIONS(1153),
    [anon_sym_final] = ACTIONS(1153),
    [anon_sym_BANG] = ACTIONS(1151),
    [anon_sym_TILDE] = ACTIONS(1151),
    [anon_sym_PLUS_PLUS] = ACTIONS(1151),
    [anon_sym_DASH_DASH] = ACTIONS(1151),
    [anon_sym_new] = ACTIONS(1153),
    [anon_sym_class] = ACTIONS(1153),
    [anon_sym_switch] = ACTIONS(1153),
    [anon_sym_LBRACE] = ACTIONS(1151),
    [anon_sym_case] = ACTIONS(1153),
    [anon_sym_default] = ACTIONS(1153),
    [anon_sym_SEMI] = ACTIONS(1151),
    [anon_sym_assert] = ACTIONS(1153),
    [anon_sym_do] = ACTIONS(1153),
    [anon_sym_while] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_continue] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1153),
    [anon_sym_yield] = ACTIONS(1153),
    [anon_sym_synchronized] = ACTIONS(1153),
    [anon_sym_throw] = ACTIONS(1153),
    [anon_sym_try] = ACTIONS(1153),
    [anon_sym_if] = ACTIONS(1153),
    [anon_sym_else] = ACTIONS(1153),
    [anon_sym_for] = ACTIONS(1153),
    [anon_sym_AT] = ACTIONS(1153),
    [anon_sym_open] = ACTIONS(1153),
    [anon_sym_module] = ACTIONS(1153),
    [anon_sym_static] = ACTIONS(1153),
    [anon_sym_with] = ACTIONS(1153),
    [anon_sym_package] = ACTIONS(1153),
    [anon_sym_import] = ACTIONS(1153),
    [anon_sym_enum] = ACTIONS(1153),
    [anon_sym_public] = ACTIONS(1153),
    [anon_sym_protected] = ACTIONS(1153),
    [anon_sym_private] = ACTIONS(1153),
    [anon_sym_abstract] = ACTIONS(1153),
    [anon_sym_strictfp] = ACTIONS(1153),
    [anon_sym_native] = ACTIONS(1153),
    [anon_sym_transient] = ACTIONS(1153),
    [anon_sym_volatile] = ACTIONS(1153),
    [anon_sym_sealed] = ACTIONS(1153),
    [anon_sym_non_DASHsealed] = ACTIONS(1151),
    [anon_sym_record] = ACTIONS(1153),
    [anon_sym_ATinterface] = ACTIONS(1151),
    [anon_sym_interface] = ACTIONS(1153),
    [anon_sym_byte] = ACTIONS(1153),
    [anon_sym_short] = ACTIONS(1153),
    [anon_sym_int] = ACTIONS(1153),
    [anon_sym_long] = ACTIONS(1153),
    [anon_sym_char] = ACTIONS(1153),
    [anon_sym_float] = ACTIONS(1153),
    [anon_sym_double] = ACTIONS(1153),
    [sym_boolean_type] = ACTIONS(1153),
    [sym_void_type] = ACTIONS(1153),
    [sym_this] = ACTIONS(1153),
    [sym_super] = ACTIONS(1153),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [381] = {
    [ts_builtin_sym_end] = ACTIONS(1155),
    [sym_identifier] = ACTIONS(1157),
    [sym_decimal_integer_literal] = ACTIONS(1157),
    [sym_hex_integer_literal] = ACTIONS(1157),
    [sym_octal_integer_literal] = ACTIONS(1157),
    [sym_binary_integer_literal] = ACTIONS(1155),
    [sym_decimal_floating_point_literal] = ACTIONS(1155),
    [sym_hex_floating_point_literal] = ACTIONS(1157),
    [sym_true] = ACTIONS(1157),
    [sym_false] = ACTIONS(1157),
    [sym_character_literal] = ACTIONS(1155),
    [anon_sym_DQUOTE] = ACTIONS(1157),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1155),
    [anon_sym_RBRACE] = ACTIONS(1155),
    [sym_null_literal] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1155),
    [anon_sym_LT] = ACTIONS(1155),
    [anon_sym_PLUS] = ACTIONS(1157),
    [anon_sym_DASH] = ACTIONS(1157),
    [anon_sym_final] = ACTIONS(1157),
    [anon_sym_BANG] = ACTIONS(1155),
    [anon_sym_TILDE] = ACTIONS(1155),
    [anon_sym_PLUS_PLUS] = ACTIONS(1155),
    [anon_sym_DASH_DASH] = ACTIONS(1155),
    [anon_sym_new] = ACTIONS(1157),
    [anon_sym_class] = ACTIONS(1157),
    [anon_sym_switch] = ACTIONS(1157),
    [anon_sym_LBRACE] = ACTIONS(1155),
    [anon_sym_case] = ACTIONS(1157),
    [anon_sym_default] = ACTIONS(1157),
    [anon_sym_SEMI] = ACTIONS(1155),
    [anon_sym_assert] = ACTIONS(1157),
    [anon_sym_do] = ACTIONS(1157),
    [anon_sym_while] = ACTIONS(1157),
    [anon_sym_break] = ACTIONS(1157),
    [anon_sym_continue] = ACTIONS(1157),
    [anon_sym_return] = ACTIONS(1157),
    [anon_sym_yield] = ACTIONS(1157),
    [anon_sym_synchronized] = ACTIONS(1157),
    [anon_sym_throw] = ACTIONS(1157),
    [anon_sym_try] = ACTIONS(1157),
    [anon_sym_if] = ACTIONS(1157),
    [anon_sym_else] = ACTIONS(1157),
    [anon_sym_for] = ACTIONS(1157),
    [anon_sym_AT] = ACTIONS(1157),
    [anon_sym_open] = ACTIONS(1157),
    [anon_sym_module] = ACTIONS(1157),
    [anon_sym_static] = ACTIONS(1157),
    [anon_sym_with] = ACTIONS(1157),
    [anon_sym_package] = ACTIONS(1157),
    [anon_sym_import] = ACTIONS(1157),
    [anon_sym_enum] = ACTIONS(1157),
    [anon_sym_public] = ACTIONS(1157),
    [anon_sym_protected] = ACTIONS(1157),
    [anon_sym_private] = ACTIONS(1157),
    [anon_sym_abstract] = ACTIONS(1157),
    [anon_sym_strictfp] = ACTIONS(1157),
    [anon_sym_native] = ACTIONS(1157),
    [anon_sym_transient] = ACTIONS(1157),
    [anon_sym_volatile] = ACTIONS(1157),
    [anon_sym_sealed] = ACTIONS(1157),
    [anon_sym_non_DASHsealed] = ACTIONS(1155),
    [anon_sym_record] = ACTIONS(1157),
    [anon_sym_ATinterface] = ACTIONS(1155),
    [anon_sym_interface] = ACTIONS(1157),
    [anon_sym_byte] = ACTIONS(1157),
    [anon_sym_short] = ACTIONS(1157),
    [anon_sym_int] = ACTIONS(1157),
    [anon_sym_long] = ACTIONS(1157),
    [anon_sym_char] = ACTIONS(1157),
    [anon_sym_float] = ACTIONS(1157),
    [anon_sym_double] = ACTIONS(1157),
    [sym_boolean_type] = ACTIONS(1157),
    [sym_void_type] = ACTIONS(1157),
    [sym_this] = ACTIONS(1157),
    [sym_super] = ACTIONS(1157),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [382] = {
    [ts_builtin_sym_end] = ACTIONS(1159),
    [sym_identifier] = ACTIONS(1161),
    [sym_decimal_integer_literal] = ACTIONS(1161),
    [sym_hex_integer_literal] = ACTIONS(1161),
    [sym_octal_integer_literal] = ACTIONS(1161),
    [sym_binary_integer_literal] = ACTIONS(1159),
    [sym_decimal_floating_point_literal] = ACTIONS(1159),
    [sym_hex_floating_point_literal] = ACTIONS(1161),
    [sym_true] = ACTIONS(1161),
    [sym_false] = ACTIONS(1161),
    [sym_character_literal] = ACTIONS(1159),
    [anon_sym_DQUOTE] = ACTIONS(1161),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1159),
    [anon_sym_RBRACE] = ACTIONS(1159),
    [sym_null_literal] = ACTIONS(1161),
    [anon_sym_LPAREN] = ACTIONS(1159),
    [anon_sym_LT] = ACTIONS(1159),
    [anon_sym_PLUS] = ACTIONS(1161),
    [anon_sym_DASH] = ACTIONS(1161),
    [anon_sym_final] = ACTIONS(1161),
    [anon_sym_BANG] = ACTIONS(1159),
    [anon_sym_TILDE] = ACTIONS(1159),
    [anon_sym_PLUS_PLUS] = ACTIONS(1159),
    [anon_sym_DASH_DASH] = ACTIONS(1159),
    [anon_sym_new] = ACTIONS(1161),
    [anon_sym_class] = ACTIONS(1161),
    [anon_sym_switch] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(1159),
    [anon_sym_case] = ACTIONS(1161),
    [anon_sym_default] = ACTIONS(1161),
    [anon_sym_SEMI] = ACTIONS(1159),
    [anon_sym_assert] = ACTIONS(1161),
    [anon_sym_do] = ACTIONS(1161),
    [anon_sym_while] = ACTIONS(1161),
    [anon_sym_break] = ACTIONS(1161),
    [anon_sym_continue] = ACTIONS(1161),
    [anon_sym_return] = ACTIONS(1161),
    [anon_sym_yield] = ACTIONS(1161),
    [anon_sym_synchronized] = ACTIONS(1161),
    [anon_sym_throw] = ACTIONS(1161),
    [anon_sym_try] = ACTIONS(1161),
    [anon_sym_if] = ACTIONS(1161),
    [anon_sym_else] = ACTIONS(1161),
    [anon_sym_for] = ACTIONS(1161),
    [anon_sym_AT] = ACTIONS(1161),
    [anon_sym_open] = ACTIONS(1161),
    [anon_sym_module] = ACTIONS(1161),
    [anon_sym_static] = ACTIONS(1161),
    [anon_sym_with] = ACTIONS(1161),
    [anon_sym_package] = ACTIONS(1161),
    [anon_sym_import] = ACTIONS(1161),
    [anon_sym_enum] = ACTIONS(1161),
    [anon_sym_public] = ACTIONS(1161),
    [anon_sym_protected] = ACTIONS(1161),
    [anon_sym_private] = ACTIONS(1161),
    [anon_sym_abstract] = ACTIONS(1161),
    [anon_sym_strictfp] = ACTIONS(1161),
    [anon_sym_native] = ACTIONS(1161),
    [anon_sym_transient] = ACTIONS(1161),
    [anon_sym_volatile] = ACTIONS(1161),
    [anon_sym_sealed] = ACTIONS(1161),
    [anon_sym_non_DASHsealed] = ACTIONS(1159),
    [anon_sym_record] = ACTIONS(1161),
    [anon_sym_ATinterface] = ACTIONS(1159),
    [anon_sym_interface] = ACTIONS(1161),
    [anon_sym_byte] = ACTIONS(1161),
    [anon_sym_short] = ACTIONS(1161),
    [anon_sym_int] = ACTIONS(1161),
    [anon_sym_long] = ACTIONS(1161),
    [anon_sym_char] = ACTIONS(1161),
    [anon_sym_float] = ACTIONS(1161),
    [anon_sym_double] = ACTIONS(1161),
    [sym_boolean_type] = ACTIONS(1161),
    [sym_void_type] = ACTIONS(1161),
    [sym_this] = ACTIONS(1161),
    [sym_super] = ACTIONS(1161),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [383] = {
    [ts_builtin_sym_end] = ACTIONS(1163),
    [sym_identifier] = ACTIONS(1165),
    [sym_decimal_integer_literal] = ACTIONS(1165),
    [sym_hex_integer_literal] = ACTIONS(1165),
    [sym_octal_integer_literal] = ACTIONS(1165),
    [sym_binary_integer_literal] = ACTIONS(1163),
    [sym_decimal_floating_point_literal] = ACTIONS(1163),
    [sym_hex_floating_point_literal] = ACTIONS(1165),
    [sym_true] = ACTIONS(1165),
    [sym_false] = ACTIONS(1165),
    [sym_character_literal] = ACTIONS(1163),
    [anon_sym_DQUOTE] = ACTIONS(1165),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1163),
    [anon_sym_RBRACE] = ACTIONS(1163),
    [sym_null_literal] = ACTIONS(1165),
    [anon_sym_LPAREN] = ACTIONS(1163),
    [anon_sym_LT] = ACTIONS(1163),
    [anon_sym_PLUS] = ACTIONS(1165),
    [anon_sym_DASH] = ACTIONS(1165),
    [anon_sym_final] = ACTIONS(1165),
    [anon_sym_BANG] = ACTIONS(1163),
    [anon_sym_TILDE] = ACTIONS(1163),
    [anon_sym_PLUS_PLUS] = ACTIONS(1163),
    [anon_sym_DASH_DASH] = ACTIONS(1163),
    [anon_sym_new] = ACTIONS(1165),
    [anon_sym_class] = ACTIONS(1165),
    [anon_sym_switch] = ACTIONS(1165),
    [anon_sym_LBRACE] = ACTIONS(1163),
    [anon_sym_case] = ACTIONS(1165),
    [anon_sym_default] = ACTIONS(1165),
    [anon_sym_SEMI] = ACTIONS(1163),
    [anon_sym_assert] = ACTIONS(1165),
    [anon_sym_do] = ACTIONS(1165),
    [anon_sym_while] = ACTIONS(1165),
    [anon_sym_break] = ACTIONS(1165),
    [anon_sym_continue] = ACTIONS(1165),
    [anon_sym_return] = ACTIONS(1165),
    [anon_sym_yield] = ACTIONS(1165),
    [anon_sym_synchronized] = ACTIONS(1165),
    [anon_sym_throw] = ACTIONS(1165),
    [anon_sym_try] = ACTIONS(1165),
    [anon_sym_if] = ACTIONS(1165),
    [anon_sym_else] = ACTIONS(1165),
    [anon_sym_for] = ACTIONS(1165),
    [anon_sym_AT] = ACTIONS(1165),
    [anon_sym_open] = ACTIONS(1165),
    [anon_sym_module] = ACTIONS(1165),
    [anon_sym_static] = ACTIONS(1165),
    [anon_sym_with] = ACTIONS(1165),
    [anon_sym_package] = ACTIONS(1165),
    [anon_sym_import] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1165),
    [anon_sym_public] = ACTIONS(1165),
    [anon_sym_protected] = ACTIONS(1165),
    [anon_sym_private] = ACTIONS(1165),
    [anon_sym_abstract] = ACTIONS(1165),
    [anon_sym_strictfp] = ACTIONS(1165),
    [anon_sym_native] = ACTIONS(1165),
    [anon_sym_transient] = ACTIONS(1165),
    [anon_sym_volatile] = ACTIONS(1165),
    [anon_sym_sealed] = ACTIONS(1165),
    [anon_sym_non_DASHsealed] = ACTIONS(1163),
    [anon_sym_record] = ACTIONS(1165),
    [anon_sym_ATinterface] = ACTIONS(1163),
    [anon_sym_interface] = ACTIONS(1165),
    [anon_sym_byte] = ACTIONS(1165),
    [anon_sym_short] = ACTIONS(1165),
    [anon_sym_int] = ACTIONS(1165),
    [anon_sym_long] = ACTIONS(1165),
    [anon_sym_char] = ACTIONS(1165),
    [anon_sym_float] = ACTIONS(1165),
    [anon_sym_double] = ACTIONS(1165),
    [sym_boolean_type] = ACTIONS(1165),
    [sym_void_type] = ACTIONS(1165),
    [sym_this] = ACTIONS(1165),
    [sym_super] = ACTIONS(1165),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [384] = {
    [ts_builtin_sym_end] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1169),
    [sym_decimal_integer_literal] = ACTIONS(1169),
    [sym_hex_integer_literal] = ACTIONS(1169),
    [sym_octal_integer_literal] = ACTIONS(1169),
    [sym_binary_integer_literal] = ACTIONS(1167),
    [sym_decimal_floating_point_literal] = ACTIONS(1167),
    [sym_hex_floating_point_literal] = ACTIONS(1169),
    [sym_true] = ACTIONS(1169),
    [sym_false] = ACTIONS(1169),
    [sym_character_literal] = ACTIONS(1167),
    [anon_sym_DQUOTE] = ACTIONS(1169),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1167),
    [anon_sym_RBRACE] = ACTIONS(1167),
    [sym_null_literal] = ACTIONS(1169),
    [anon_sym_LPAREN] = ACTIONS(1167),
    [anon_sym_LT] = ACTIONS(1167),
    [anon_sym_PLUS] = ACTIONS(1169),
    [anon_sym_DASH] = ACTIONS(1169),
    [anon_sym_final] = ACTIONS(1169),
    [anon_sym_BANG] = ACTIONS(1167),
    [anon_sym_TILDE] = ACTIONS(1167),
    [anon_sym_PLUS_PLUS] = ACTIONS(1167),
    [anon_sym_DASH_DASH] = ACTIONS(1167),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_class] = ACTIONS(1169),
    [anon_sym_switch] = ACTIONS(1169),
    [anon_sym_LBRACE] = ACTIONS(1167),
    [anon_sym_case] = ACTIONS(1169),
    [anon_sym_default] = ACTIONS(1169),
    [anon_sym_SEMI] = ACTIONS(1167),
    [anon_sym_assert] = ACTIONS(1169),
    [anon_sym_do] = ACTIONS(1169),
    [anon_sym_while] = ACTIONS(1169),
    [anon_sym_break] = ACTIONS(1169),
    [anon_sym_continue] = ACTIONS(1169),
    [anon_sym_return] = ACTIONS(1169),
    [anon_sym_yield] = ACTIONS(1169),
    [anon_sym_synchronized] = ACTIONS(1169),
    [anon_sym_throw] = ACTIONS(1169),
    [anon_sym_try] = ACTIONS(1169),
    [anon_sym_if] = ACTIONS(1169),
    [anon_sym_else] = ACTIONS(1169),
    [anon_sym_for] = ACTIONS(1169),
    [anon_sym_AT] = ACTIONS(1169),
    [anon_sym_open] = ACTIONS(1169),
    [anon_sym_module] = ACTIONS(1169),
    [anon_sym_static] = ACTIONS(1169),
    [anon_sym_with] = ACTIONS(1169),
    [anon_sym_package] = ACTIONS(1169),
    [anon_sym_import] = ACTIONS(1169),
    [anon_sym_enum] = ACTIONS(1169),
    [anon_sym_public] = ACTIONS(1169),
    [anon_sym_protected] = ACTIONS(1169),
    [anon_sym_private] = ACTIONS(1169),
    [anon_sym_abstract] = ACTIONS(1169),
    [anon_sym_strictfp] = ACTIONS(1169),
    [anon_sym_native] = ACTIONS(1169),
    [anon_sym_transient] = ACTIONS(1169),
    [anon_sym_volatile] = ACTIONS(1169),
    [anon_sym_sealed] = ACTIONS(1169),
    [anon_sym_non_DASHsealed] = ACTIONS(1167),
    [anon_sym_record] = ACTIONS(1169),
    [anon_sym_ATinterface] = ACTIONS(1167),
    [anon_sym_interface] = ACTIONS(1169),
    [anon_sym_byte] = ACTIONS(1169),
    [anon_sym_short] = ACTIONS(1169),
    [anon_sym_int] = ACTIONS(1169),
    [anon_sym_long] = ACTIONS(1169),
    [anon_sym_char] = ACTIONS(1169),
    [anon_sym_float] = ACTIONS(1169),
    [anon_sym_double] = ACTIONS(1169),
    [sym_boolean_type] = ACTIONS(1169),
    [sym_void_type] = ACTIONS(1169),
    [sym_this] = ACTIONS(1169),
    [sym_super] = ACTIONS(1169),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [385] = {
    [ts_builtin_sym_end] = ACTIONS(1171),
    [sym_identifier] = ACTIONS(1173),
    [sym_decimal_integer_literal] = ACTIONS(1173),
    [sym_hex_integer_literal] = ACTIONS(1173),
    [sym_octal_integer_literal] = ACTIONS(1173),
    [sym_binary_integer_literal] = ACTIONS(1171),
    [sym_decimal_floating_point_literal] = ACTIONS(1171),
    [sym_hex_floating_point_literal] = ACTIONS(1173),
    [sym_true] = ACTIONS(1173),
    [sym_false] = ACTIONS(1173),
    [sym_character_literal] = ACTIONS(1171),
    [anon_sym_DQUOTE] = ACTIONS(1173),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1171),
    [anon_sym_RBRACE] = ACTIONS(1171),
    [sym_null_literal] = ACTIONS(1173),
    [anon_sym_LPAREN] = ACTIONS(1171),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_PLUS] = ACTIONS(1173),
    [anon_sym_DASH] = ACTIONS(1173),
    [anon_sym_final] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1171),
    [anon_sym_TILDE] = ACTIONS(1171),
    [anon_sym_PLUS_PLUS] = ACTIONS(1171),
    [anon_sym_DASH_DASH] = ACTIONS(1171),
    [anon_sym_new] = ACTIONS(1173),
    [anon_sym_class] = ACTIONS(1173),
    [anon_sym_switch] = ACTIONS(1173),
    [anon_sym_LBRACE] = ACTIONS(1171),
    [anon_sym_case] = ACTIONS(1173),
    [anon_sym_default] = ACTIONS(1173),
    [anon_sym_SEMI] = ACTIONS(1171),
    [anon_sym_assert] = ACTIONS(1173),
    [anon_sym_do] = ACTIONS(1173),
    [anon_sym_while] = ACTIONS(1173),
    [anon_sym_break] = ACTIONS(1173),
    [anon_sym_continue] = ACTIONS(1173),
    [anon_sym_return] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(1173),
    [anon_sym_synchronized] = ACTIONS(1173),
    [anon_sym_throw] = ACTIONS(1173),
    [anon_sym_try] = ACTIONS(1173),
    [anon_sym_if] = ACTIONS(1173),
    [anon_sym_else] = ACTIONS(1173),
    [anon_sym_for] = ACTIONS(1173),
    [anon_sym_AT] = ACTIONS(1173),
    [anon_sym_open] = ACTIONS(1173),
    [anon_sym_module] = ACTIONS(1173),
    [anon_sym_static] = ACTIONS(1173),
    [anon_sym_with] = ACTIONS(1173),
    [anon_sym_package] = ACTIONS(1173),
    [anon_sym_import] = ACTIONS(1173),
    [anon_sym_enum] = ACTIONS(1173),
    [anon_sym_public] = ACTIONS(1173),
    [anon_sym_protected] = ACTIONS(1173),
    [anon_sym_private] = ACTIONS(1173),
    [anon_sym_abstract] = ACTIONS(1173),
    [anon_sym_strictfp] = ACTIONS(1173),
    [anon_sym_native] = ACTIONS(1173),
    [anon_sym_transient] = ACTIONS(1173),
    [anon_sym_volatile] = ACTIONS(1173),
    [anon_sym_sealed] = ACTIONS(1173),
    [anon_sym_non_DASHsealed] = ACTIONS(1171),
    [anon_sym_record] = ACTIONS(1173),
    [anon_sym_ATinterface] = ACTIONS(1171),
    [anon_sym_interface] = ACTIONS(1173),
    [anon_sym_byte] = ACTIONS(1173),
    [anon_sym_short] = ACTIONS(1173),
    [anon_sym_int] = ACTIONS(1173),
    [anon_sym_long] = ACTIONS(1173),
    [anon_sym_char] = ACTIONS(1173),
    [anon_sym_float] = ACTIONS(1173),
    [anon_sym_double] = ACTIONS(1173),
    [sym_boolean_type] = ACTIONS(1173),
    [sym_void_type] = ACTIONS(1173),
    [sym_this] = ACTIONS(1173),
    [sym_super] = ACTIONS(1173),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [386] = {
    [ts_builtin_sym_end] = ACTIONS(1175),
    [sym_identifier] = ACTIONS(1177),
    [sym_decimal_integer_literal] = ACTIONS(1177),
    [sym_hex_integer_literal] = ACTIONS(1177),
    [sym_octal_integer_literal] = ACTIONS(1177),
    [sym_binary_integer_literal] = ACTIONS(1175),
    [sym_decimal_floating_point_literal] = ACTIONS(1175),
    [sym_hex_floating_point_literal] = ACTIONS(1177),
    [sym_true] = ACTIONS(1177),
    [sym_false] = ACTIONS(1177),
    [sym_character_literal] = ACTIONS(1175),
    [anon_sym_DQUOTE] = ACTIONS(1177),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1175),
    [anon_sym_RBRACE] = ACTIONS(1175),
    [sym_null_literal] = ACTIONS(1177),
    [anon_sym_LPAREN] = ACTIONS(1175),
    [anon_sym_LT] = ACTIONS(1175),
    [anon_sym_PLUS] = ACTIONS(1177),
    [anon_sym_DASH] = ACTIONS(1177),
    [anon_sym_final] = ACTIONS(1177),
    [anon_sym_BANG] = ACTIONS(1175),
    [anon_sym_TILDE] = ACTIONS(1175),
    [anon_sym_PLUS_PLUS] = ACTIONS(1175),
    [anon_sym_DASH_DASH] = ACTIONS(1175),
    [anon_sym_new] = ACTIONS(1177),
    [anon_sym_class] = ACTIONS(1177),
    [anon_sym_switch] = ACTIONS(1177),
    [anon_sym_LBRACE] = ACTIONS(1175),
    [anon_sym_case] = ACTIONS(1177),
    [anon_sym_default] = ACTIONS(1177),
    [anon_sym_SEMI] = ACTIONS(1175),
    [anon_sym_assert] = ACTIONS(1177),
    [anon_sym_do] = ACTIONS(1177),
    [anon_sym_while] = ACTIONS(1177),
    [anon_sym_break] = ACTIONS(1177),
    [anon_sym_continue] = ACTIONS(1177),
    [anon_sym_return] = ACTIONS(1177),
    [anon_sym_yield] = ACTIONS(1177),
    [anon_sym_synchronized] = ACTIONS(1177),
    [anon_sym_throw] = ACTIONS(1177),
    [anon_sym_try] = ACTIONS(1177),
    [anon_sym_if] = ACTIONS(1177),
    [anon_sym_else] = ACTIONS(1177),
    [anon_sym_for] = ACTIONS(1177),
    [anon_sym_AT] = ACTIONS(1177),
    [anon_sym_open] = ACTIONS(1177),
    [anon_sym_module] = ACTIONS(1177),
    [anon_sym_static] = ACTIONS(1177),
    [anon_sym_with] = ACTIONS(1177),
    [anon_sym_package] = ACTIONS(1177),
    [anon_sym_import] = ACTIONS(1177),
    [anon_sym_enum] = ACTIONS(1177),
    [anon_sym_public] = ACTIONS(1177),
    [anon_sym_protected] = ACTIONS(1177),
    [anon_sym_private] = ACTIONS(1177),
    [anon_sym_abstract] = ACTIONS(1177),
    [anon_sym_strictfp] = ACTIONS(1177),
    [anon_sym_native] = ACTIONS(1177),
    [anon_sym_transient] = ACTIONS(1177),
    [anon_sym_volatile] = ACTIONS(1177),
    [anon_sym_sealed] = ACTIONS(1177),
    [anon_sym_non_DASHsealed] = ACTIONS(1175),
    [anon_sym_record] = ACTIONS(1177),
    [anon_sym_ATinterface] = ACTIONS(1175),
    [anon_sym_interface] = ACTIONS(1177),
    [anon_sym_byte] = ACTIONS(1177),
    [anon_sym_short] = ACTIONS(1177),
    [anon_sym_int] = ACTIONS(1177),
    [anon_sym_long] = ACTIONS(1177),
    [anon_sym_char] = ACTIONS(1177),
    [anon_sym_float] = ACTIONS(1177),
    [anon_sym_double] = ACTIONS(1177),
    [sym_boolean_type] = ACTIONS(1177),
    [sym_void_type] = ACTIONS(1177),
    [sym_this] = ACTIONS(1177),
    [sym_super] = ACTIONS(1177),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [387] = {
    [ts_builtin_sym_end] = ACTIONS(1179),
    [sym_identifier] = ACTIONS(1181),
    [sym_decimal_integer_literal] = ACTIONS(1181),
    [sym_hex_integer_literal] = ACTIONS(1181),
    [sym_octal_integer_literal] = ACTIONS(1181),
    [sym_binary_integer_literal] = ACTIONS(1179),
    [sym_decimal_floating_point_literal] = ACTIONS(1179),
    [sym_hex_floating_point_literal] = ACTIONS(1181),
    [sym_true] = ACTIONS(1181),
    [sym_false] = ACTIONS(1181),
    [sym_character_literal] = ACTIONS(1179),
    [anon_sym_DQUOTE] = ACTIONS(1181),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1179),
    [anon_sym_RBRACE] = ACTIONS(1179),
    [sym_null_literal] = ACTIONS(1181),
    [anon_sym_LPAREN] = ACTIONS(1179),
    [anon_sym_LT] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1181),
    [anon_sym_DASH] = ACTIONS(1181),
    [anon_sym_final] = ACTIONS(1181),
    [anon_sym_BANG] = ACTIONS(1179),
    [anon_sym_TILDE] = ACTIONS(1179),
    [anon_sym_PLUS_PLUS] = ACTIONS(1179),
    [anon_sym_DASH_DASH] = ACTIONS(1179),
    [anon_sym_new] = ACTIONS(1181),
    [anon_sym_class] = ACTIONS(1181),
    [anon_sym_switch] = ACTIONS(1181),
    [anon_sym_LBRACE] = ACTIONS(1179),
    [anon_sym_case] = ACTIONS(1181),
    [anon_sym_default] = ACTIONS(1181),
    [anon_sym_SEMI] = ACTIONS(1179),
    [anon_sym_assert] = ACTIONS(1181),
    [anon_sym_do] = ACTIONS(1181),
    [anon_sym_while] = ACTIONS(1181),
    [anon_sym_break] = ACTIONS(1181),
    [anon_sym_continue] = ACTIONS(1181),
    [anon_sym_return] = ACTIONS(1181),
    [anon_sym_yield] = ACTIONS(1181),
    [anon_sym_synchronized] = ACTIONS(1181),
    [anon_sym_throw] = ACTIONS(1181),
    [anon_sym_try] = ACTIONS(1181),
    [anon_sym_if] = ACTIONS(1181),
    [anon_sym_else] = ACTIONS(1181),
    [anon_sym_for] = ACTIONS(1181),
    [anon_sym_AT] = ACTIONS(1181),
    [anon_sym_open] = ACTIONS(1181),
    [anon_sym_module] = ACTIONS(1181),
    [anon_sym_static] = ACTIONS(1181),
    [anon_sym_with] = ACTIONS(1181),
    [anon_sym_package] = ACTIONS(1181),
    [anon_sym_import] = ACTIONS(1181),
    [anon_sym_enum] = ACTIONS(1181),
    [anon_sym_public] = ACTIONS(1181),
    [anon_sym_protected] = ACTIONS(1181),
    [anon_sym_private] = ACTIONS(1181),
    [anon_sym_abstract] = ACTIONS(1181),
    [anon_sym_strictfp] = ACTIONS(1181),
    [anon_sym_native] = ACTIONS(1181),
    [anon_sym_transient] = ACTIONS(1181),
    [anon_sym_volatile] = ACTIONS(1181),
    [anon_sym_sealed] = ACTIONS(1181),
    [anon_sym_non_DASHsealed] = ACTIONS(1179),
    [anon_sym_record] = ACTIONS(1181),
    [anon_sym_ATinterface] = ACTIONS(1179),
    [anon_sym_interface] = ACTIONS(1181),
    [anon_sym_byte] = ACTIONS(1181),
    [anon_sym_short] = ACTIONS(1181),
    [anon_sym_int] = ACTIONS(1181),
    [anon_sym_long] = ACTIONS(1181),
    [anon_sym_char] = ACTIONS(1181),
    [anon_sym_float] = ACTIONS(1181),
    [anon_sym_double] = ACTIONS(1181),
    [sym_boolean_type] = ACTIONS(1181),
    [sym_void_type] = ACTIONS(1181),
    [sym_this] = ACTIONS(1181),
    [sym_super] = ACTIONS(1181),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [388] = {
    [sym_switch_label] = STATE(1315),
    [aux_sym_switch_block_statement_group_repeat1] = STATE(388),
    [sym_identifier] = ACTIONS(1183),
    [sym_decimal_integer_literal] = ACTIONS(1183),
    [sym_hex_integer_literal] = ACTIONS(1183),
    [sym_octal_integer_literal] = ACTIONS(1183),
    [sym_binary_integer_literal] = ACTIONS(1185),
    [sym_decimal_floating_point_literal] = ACTIONS(1185),
    [sym_hex_floating_point_literal] = ACTIONS(1183),
    [sym_true] = ACTIONS(1183),
    [sym_false] = ACTIONS(1183),
    [sym_character_literal] = ACTIONS(1185),
    [anon_sym_DQUOTE] = ACTIONS(1183),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1185),
    [anon_sym_RBRACE] = ACTIONS(1185),
    [sym_null_literal] = ACTIONS(1183),
    [anon_sym_LPAREN] = ACTIONS(1185),
    [anon_sym_PLUS] = ACTIONS(1183),
    [anon_sym_DASH] = ACTIONS(1183),
    [anon_sym_final] = ACTIONS(1183),
    [anon_sym_BANG] = ACTIONS(1185),
    [anon_sym_TILDE] = ACTIONS(1185),
    [anon_sym_PLUS_PLUS] = ACTIONS(1185),
    [anon_sym_DASH_DASH] = ACTIONS(1185),
    [anon_sym_new] = ACTIONS(1183),
    [anon_sym_class] = ACTIONS(1183),
    [anon_sym_switch] = ACTIONS(1183),
    [anon_sym_LBRACE] = ACTIONS(1185),
    [anon_sym_case] = ACTIONS(1187),
    [anon_sym_default] = ACTIONS(1190),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_assert] = ACTIONS(1183),
    [anon_sym_do] = ACTIONS(1183),
    [anon_sym_while] = ACTIONS(1183),
    [anon_sym_break] = ACTIONS(1183),
    [anon_sym_continue] = ACTIONS(1183),
    [anon_sym_return] = ACTIONS(1183),
    [anon_sym_yield] = ACTIONS(1183),
    [anon_sym_synchronized] = ACTIONS(1183),
    [anon_sym_throw] = ACTIONS(1183),
    [anon_sym_try] = ACTIONS(1183),
    [anon_sym_if] = ACTIONS(1183),
    [anon_sym_for] = ACTIONS(1183),
    [anon_sym_AT] = ACTIONS(1183),
    [anon_sym_open] = ACTIONS(1183),
    [anon_sym_module] = ACTIONS(1183),
    [anon_sym_static] = ACTIONS(1183),
    [anon_sym_with] = ACTIONS(1183),
    [anon_sym_package] = ACTIONS(1183),
    [anon_sym_import] = ACTIONS(1183),
    [anon_sym_enum] = ACTIONS(1183),
    [anon_sym_public] = ACTIONS(1183),
    [anon_sym_protected] = ACTIONS(1183),
    [anon_sym_private] = ACTIONS(1183),
    [anon_sym_abstract] = ACTIONS(1183),
    [anon_sym_strictfp] = ACTIONS(1183),
    [anon_sym_native] = ACTIONS(1183),
    [anon_sym_transient] = ACTIONS(1183),
    [anon_sym_volatile] = ACTIONS(1183),
    [anon_sym_sealed] = ACTIONS(1183),
    [anon_sym_non_DASHsealed] = ACTIONS(1185),
    [anon_sym_record] = ACTIONS(1183),
    [anon_sym_ATinterface] = ACTIONS(1185),
    [anon_sym_interface] = ACTIONS(1183),
    [anon_sym_byte] = ACTIONS(1183),
    [anon_sym_short] = ACTIONS(1183),
    [anon_sym_int] = ACTIONS(1183),
    [anon_sym_long] = ACTIONS(1183),
    [anon_sym_char] = ACTIONS(1183),
    [anon_sym_float] = ACTIONS(1183),
    [anon_sym_double] = ACTIONS(1183),
    [sym_boolean_type] = ACTIONS(1183),
    [sym_void_type] = ACTIONS(1183),
    [sym_this] = ACTIONS(1183),
    [sym_super] = ACTIONS(1183),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [389] = {
    [ts_builtin_sym_end] = ACTIONS(1193),
    [sym_identifier] = ACTIONS(1195),
    [sym_decimal_integer_literal] = ACTIONS(1195),
    [sym_hex_integer_literal] = ACTIONS(1195),
    [sym_octal_integer_literal] = ACTIONS(1195),
    [sym_binary_integer_literal] = ACTIONS(1193),
    [sym_decimal_floating_point_literal] = ACTIONS(1193),
    [sym_hex_floating_point_literal] = ACTIONS(1195),
    [sym_true] = ACTIONS(1195),
    [sym_false] = ACTIONS(1195),
    [sym_character_literal] = ACTIONS(1193),
    [anon_sym_DQUOTE] = ACTIONS(1195),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1193),
    [anon_sym_RBRACE] = ACTIONS(1193),
    [sym_null_literal] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(1193),
    [anon_sym_LT] = ACTIONS(1193),
    [anon_sym_PLUS] = ACTIONS(1195),
    [anon_sym_DASH] = ACTIONS(1195),
    [anon_sym_final] = ACTIONS(1195),
    [anon_sym_BANG] = ACTIONS(1193),
    [anon_sym_TILDE] = ACTIONS(1193),
    [anon_sym_PLUS_PLUS] = ACTIONS(1193),
    [anon_sym_DASH_DASH] = ACTIONS(1193),
    [anon_sym_new] = ACTIONS(1195),
    [anon_sym_class] = ACTIONS(1195),
    [anon_sym_switch] = ACTIONS(1195),
    [anon_sym_LBRACE] = ACTIONS(1193),
    [anon_sym_default] = ACTIONS(1195),
    [anon_sym_SEMI] = ACTIONS(1193),
    [anon_sym_assert] = ACTIONS(1195),
    [anon_sym_do] = ACTIONS(1195),
    [anon_sym_while] = ACTIONS(1195),
    [anon_sym_break] = ACTIONS(1195),
    [anon_sym_continue] = ACTIONS(1195),
    [anon_sym_return] = ACTIONS(1195),
    [anon_sym_yield] = ACTIONS(1195),
    [anon_sym_synchronized] = ACTIONS(1195),
    [anon_sym_throw] = ACTIONS(1195),
    [anon_sym_try] = ACTIONS(1195),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_for] = ACTIONS(1195),
    [anon_sym_AT] = ACTIONS(1195),
    [anon_sym_open] = ACTIONS(1195),
    [anon_sym_module] = ACTIONS(1195),
    [anon_sym_static] = ACTIONS(1195),
    [anon_sym_with] = ACTIONS(1195),
    [anon_sym_package] = ACTIONS(1195),
    [anon_sym_import] = ACTIONS(1195),
    [anon_sym_enum] = ACTIONS(1195),
    [anon_sym_public] = ACTIONS(1195),
    [anon_sym_protected] = ACTIONS(1195),
    [anon_sym_private] = ACTIONS(1195),
    [anon_sym_abstract] = ACTIONS(1195),
    [anon_sym_strictfp] = ACTIONS(1195),
    [anon_sym_native] = ACTIONS(1195),
    [anon_sym_transient] = ACTIONS(1195),
    [anon_sym_volatile] = ACTIONS(1195),
    [anon_sym_sealed] = ACTIONS(1195),
    [anon_sym_non_DASHsealed] = ACTIONS(1193),
    [anon_sym_record] = ACTIONS(1195),
    [anon_sym_ATinterface] = ACTIONS(1193),
    [anon_sym_interface] = ACTIONS(1195),
    [anon_sym_byte] = ACTIONS(1195),
    [anon_sym_short] = ACTIONS(1195),
    [anon_sym_int] = ACTIONS(1195),
    [anon_sym_long] = ACTIONS(1195),
    [anon_sym_char] = ACTIONS(1195),
    [anon_sym_float] = ACTIONS(1195),
    [anon_sym_double] = ACTIONS(1195),
    [sym_boolean_type] = ACTIONS(1195),
    [sym_void_type] = ACTIONS(1195),
    [sym_this] = ACTIONS(1195),
    [sym_super] = ACTIONS(1195),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [390] = {
    [ts_builtin_sym_end] = ACTIONS(1197),
    [sym_identifier] = ACTIONS(1199),
    [sym_decimal_integer_literal] = ACTIONS(1199),
    [sym_hex_integer_literal] = ACTIONS(1199),
    [sym_octal_integer_literal] = ACTIONS(1199),
    [sym_binary_integer_literal] = ACTIONS(1197),
    [sym_decimal_floating_point_literal] = ACTIONS(1197),
    [sym_hex_floating_point_literal] = ACTIONS(1199),
    [sym_true] = ACTIONS(1199),
    [sym_false] = ACTIONS(1199),
    [sym_character_literal] = ACTIONS(1197),
    [anon_sym_DQUOTE] = ACTIONS(1199),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1197),
    [sym_null_literal] = ACTIONS(1199),
    [anon_sym_LPAREN] = ACTIONS(1197),
    [anon_sym_LT] = ACTIONS(1197),
    [anon_sym_PLUS] = ACTIONS(1199),
    [anon_sym_DASH] = ACTIONS(1199),
    [anon_sym_final] = ACTIONS(1199),
    [anon_sym_BANG] = ACTIONS(1197),
    [anon_sym_TILDE] = ACTIONS(1197),
    [anon_sym_PLUS_PLUS] = ACTIONS(1197),
    [anon_sym_DASH_DASH] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_class] = ACTIONS(1199),
    [anon_sym_switch] = ACTIONS(1199),
    [anon_sym_LBRACE] = ACTIONS(1197),
    [anon_sym_default] = ACTIONS(1199),
    [anon_sym_SEMI] = ACTIONS(1197),
    [anon_sym_assert] = ACTIONS(1199),
    [anon_sym_do] = ACTIONS(1199),
    [anon_sym_while] = ACTIONS(1199),
    [anon_sym_break] = ACTIONS(1199),
    [anon_sym_continue] = ACTIONS(1199),
    [anon_sym_return] = ACTIONS(1199),
    [anon_sym_yield] = ACTIONS(1199),
    [anon_sym_synchronized] = ACTIONS(1199),
    [anon_sym_throw] = ACTIONS(1199),
    [anon_sym_try] = ACTIONS(1199),
    [anon_sym_if] = ACTIONS(1199),
    [anon_sym_else] = ACTIONS(1201),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_AT] = ACTIONS(1199),
    [anon_sym_open] = ACTIONS(1199),
    [anon_sym_module] = ACTIONS(1199),
    [anon_sym_static] = ACTIONS(1199),
    [anon_sym_with] = ACTIONS(1199),
    [anon_sym_package] = ACTIONS(1199),
    [anon_sym_import] = ACTIONS(1199),
    [anon_sym_enum] = ACTIONS(1199),
    [anon_sym_public] = ACTIONS(1199),
    [anon_sym_protected] = ACTIONS(1199),
    [anon_sym_private] = ACTIONS(1199),
    [anon_sym_abstract] = ACTIONS(1199),
    [anon_sym_strictfp] = ACTIONS(1199),
    [anon_sym_native] = ACTIONS(1199),
    [anon_sym_transient] = ACTIONS(1199),
    [anon_sym_volatile] = ACTIONS(1199),
    [anon_sym_sealed] = ACTIONS(1199),
    [anon_sym_non_DASHsealed] = ACTIONS(1197),
    [anon_sym_record] = ACTIONS(1199),
    [anon_sym_ATinterface] = ACTIONS(1197),
    [anon_sym_interface] = ACTIONS(1199),
    [anon_sym_byte] = ACTIONS(1199),
    [anon_sym_short] = ACTIONS(1199),
    [anon_sym_int] = ACTIONS(1199),
    [anon_sym_long] = ACTIONS(1199),
    [anon_sym_char] = ACTIONS(1199),
    [anon_sym_float] = ACTIONS(1199),
    [anon_sym_double] = ACTIONS(1199),
    [sym_boolean_type] = ACTIONS(1199),
    [sym_void_type] = ACTIONS(1199),
    [sym_this] = ACTIONS(1199),
    [sym_super] = ACTIONS(1199),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [391] = {
    [ts_builtin_sym_end] = ACTIONS(1203),
    [sym_identifier] = ACTIONS(1205),
    [sym_decimal_integer_literal] = ACTIONS(1205),
    [sym_hex_integer_literal] = ACTIONS(1205),
    [sym_octal_integer_literal] = ACTIONS(1205),
    [sym_binary_integer_literal] = ACTIONS(1203),
    [sym_decimal_floating_point_literal] = ACTIONS(1203),
    [sym_hex_floating_point_literal] = ACTIONS(1205),
    [sym_true] = ACTIONS(1205),
    [sym_false] = ACTIONS(1205),
    [sym_character_literal] = ACTIONS(1203),
    [anon_sym_DQUOTE] = ACTIONS(1205),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1203),
    [anon_sym_RBRACE] = ACTIONS(1203),
    [sym_null_literal] = ACTIONS(1205),
    [anon_sym_LPAREN] = ACTIONS(1203),
    [anon_sym_LT] = ACTIONS(1203),
    [anon_sym_PLUS] = ACTIONS(1205),
    [anon_sym_DASH] = ACTIONS(1205),
    [anon_sym_final] = ACTIONS(1205),
    [anon_sym_BANG] = ACTIONS(1203),
    [anon_sym_TILDE] = ACTIONS(1203),
    [anon_sym_PLUS_PLUS] = ACTIONS(1203),
    [anon_sym_DASH_DASH] = ACTIONS(1203),
    [anon_sym_new] = ACTIONS(1205),
    [anon_sym_class] = ACTIONS(1205),
    [anon_sym_switch] = ACTIONS(1205),
    [anon_sym_LBRACE] = ACTIONS(1203),
    [anon_sym_default] = ACTIONS(1205),
    [anon_sym_SEMI] = ACTIONS(1203),
    [anon_sym_assert] = ACTIONS(1205),
    [anon_sym_do] = ACTIONS(1205),
    [anon_sym_while] = ACTIONS(1205),
    [anon_sym_break] = ACTIONS(1205),
    [anon_sym_continue] = ACTIONS(1205),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_yield] = ACTIONS(1205),
    [anon_sym_synchronized] = ACTIONS(1205),
    [anon_sym_throw] = ACTIONS(1205),
    [anon_sym_try] = ACTIONS(1205),
    [anon_sym_if] = ACTIONS(1205),
    [anon_sym_for] = ACTIONS(1205),
    [anon_sym_AT] = ACTIONS(1205),
    [anon_sym_open] = ACTIONS(1205),
    [anon_sym_module] = ACTIONS(1205),
    [anon_sym_static] = ACTIONS(1205),
    [anon_sym_with] = ACTIONS(1205),
    [anon_sym_package] = ACTIONS(1205),
    [anon_sym_import] = ACTIONS(1205),
    [anon_sym_enum] = ACTIONS(1205),
    [anon_sym_public] = ACTIONS(1205),
    [anon_sym_protected] = ACTIONS(1205),
    [anon_sym_private] = ACTIONS(1205),
    [anon_sym_abstract] = ACTIONS(1205),
    [anon_sym_strictfp] = ACTIONS(1205),
    [anon_sym_native] = ACTIONS(1205),
    [anon_sym_transient] = ACTIONS(1205),
    [anon_sym_volatile] = ACTIONS(1205),
    [anon_sym_sealed] = ACTIONS(1205),
    [anon_sym_non_DASHsealed] = ACTIONS(1203),
    [anon_sym_record] = ACTIONS(1205),
    [anon_sym_ATinterface] = ACTIONS(1203),
    [anon_sym_interface] = ACTIONS(1205),
    [anon_sym_byte] = ACTIONS(1205),
    [anon_sym_short] = ACTIONS(1205),
    [anon_sym_int] = ACTIONS(1205),
    [anon_sym_long] = ACTIONS(1205),
    [anon_sym_char] = ACTIONS(1205),
    [anon_sym_float] = ACTIONS(1205),
    [anon_sym_double] = ACTIONS(1205),
    [sym_boolean_type] = ACTIONS(1205),
    [sym_void_type] = ACTIONS(1205),
    [sym_this] = ACTIONS(1205),
    [sym_super] = ACTIONS(1205),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [392] = {
    [sym_identifier] = ACTIONS(1199),
    [sym_decimal_integer_literal] = ACTIONS(1199),
    [sym_hex_integer_literal] = ACTIONS(1199),
    [sym_octal_integer_literal] = ACTIONS(1199),
    [sym_binary_integer_literal] = ACTIONS(1197),
    [sym_decimal_floating_point_literal] = ACTIONS(1197),
    [sym_hex_floating_point_literal] = ACTIONS(1199),
    [sym_true] = ACTIONS(1199),
    [sym_false] = ACTIONS(1199),
    [sym_character_literal] = ACTIONS(1197),
    [anon_sym_DQUOTE] = ACTIONS(1199),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1197),
    [anon_sym_RBRACE] = ACTIONS(1197),
    [sym_null_literal] = ACTIONS(1199),
    [anon_sym_LPAREN] = ACTIONS(1197),
    [anon_sym_PLUS] = ACTIONS(1199),
    [anon_sym_DASH] = ACTIONS(1199),
    [anon_sym_final] = ACTIONS(1199),
    [anon_sym_BANG] = ACTIONS(1197),
    [anon_sym_TILDE] = ACTIONS(1197),
    [anon_sym_PLUS_PLUS] = ACTIONS(1197),
    [anon_sym_DASH_DASH] = ACTIONS(1197),
    [anon_sym_new] = ACTIONS(1199),
    [anon_sym_class] = ACTIONS(1199),
    [anon_sym_switch] = ACTIONS(1199),
    [anon_sym_LBRACE] = ACTIONS(1197),
    [anon_sym_case] = ACTIONS(1199),
    [anon_sym_default] = ACTIONS(1199),
    [anon_sym_SEMI] = ACTIONS(1197),
    [anon_sym_assert] = ACTIONS(1199),
    [anon_sym_do] = ACTIONS(1199),
    [anon_sym_while] = ACTIONS(1199),
    [anon_sym_break] = ACTIONS(1199),
    [anon_sym_continue] = ACTIONS(1199),
    [anon_sym_return] = ACTIONS(1199),
    [anon_sym_yield] = ACTIONS(1199),
    [anon_sym_synchronized] = ACTIONS(1199),
    [anon_sym_throw] = ACTIONS(1199),
    [anon_sym_try] = ACTIONS(1199),
    [anon_sym_if] = ACTIONS(1199),
    [anon_sym_else] = ACTIONS(1207),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_AT] = ACTIONS(1199),
    [anon_sym_open] = ACTIONS(1199),
    [anon_sym_module] = ACTIONS(1199),
    [anon_sym_static] = ACTIONS(1199),
    [anon_sym_with] = ACTIONS(1199),
    [anon_sym_package] = ACTIONS(1199),
    [anon_sym_import] = ACTIONS(1199),
    [anon_sym_enum] = ACTIONS(1199),
    [anon_sym_public] = ACTIONS(1199),
    [anon_sym_protected] = ACTIONS(1199),
    [anon_sym_private] = ACTIONS(1199),
    [anon_sym_abstract] = ACTIONS(1199),
    [anon_sym_strictfp] = ACTIONS(1199),
    [anon_sym_native] = ACTIONS(1199),
    [anon_sym_transient] = ACTIONS(1199),
    [anon_sym_volatile] = ACTIONS(1199),
    [anon_sym_sealed] = ACTIONS(1199),
    [anon_sym_non_DASHsealed] = ACTIONS(1197),
    [anon_sym_record] = ACTIONS(1199),
    [anon_sym_ATinterface] = ACTIONS(1197),
    [anon_sym_interface] = ACTIONS(1199),
    [anon_sym_byte] = ACTIONS(1199),
    [anon_sym_short] = ACTIONS(1199),
    [anon_sym_int] = ACTIONS(1199),
    [anon_sym_long] = ACTIONS(1199),
    [anon_sym_char] = ACTIONS(1199),
    [anon_sym_float] = ACTIONS(1199),
    [anon_sym_double] = ACTIONS(1199),
    [sym_boolean_type] = ACTIONS(1199),
    [sym_void_type] = ACTIONS(1199),
    [sym_this] = ACTIONS(1199),
    [sym_super] = ACTIONS(1199),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [393] = {
    [ts_builtin_sym_end] = ACTIONS(1209),
    [sym_identifier] = ACTIONS(1211),
    [sym_decimal_integer_literal] = ACTIONS(1211),
    [sym_hex_integer_literal] = ACTIONS(1211),
    [sym_octal_integer_literal] = ACTIONS(1211),
    [sym_binary_integer_literal] = ACTIONS(1209),
    [sym_decimal_floating_point_literal] = ACTIONS(1209),
    [sym_hex_floating_point_literal] = ACTIONS(1211),
    [sym_true] = ACTIONS(1211),
    [sym_false] = ACTIONS(1211),
    [sym_character_literal] = ACTIONS(1209),
    [anon_sym_DQUOTE] = ACTIONS(1211),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1209),
    [anon_sym_RBRACE] = ACTIONS(1209),
    [sym_null_literal] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1209),
    [anon_sym_LT] = ACTIONS(1209),
    [anon_sym_PLUS] = ACTIONS(1211),
    [anon_sym_DASH] = ACTIONS(1211),
    [anon_sym_final] = ACTIONS(1211),
    [anon_sym_BANG] = ACTIONS(1209),
    [anon_sym_TILDE] = ACTIONS(1209),
    [anon_sym_PLUS_PLUS] = ACTIONS(1209),
    [anon_sym_DASH_DASH] = ACTIONS(1209),
    [anon_sym_new] = ACTIONS(1211),
    [anon_sym_class] = ACTIONS(1211),
    [anon_sym_switch] = ACTIONS(1211),
    [anon_sym_LBRACE] = ACTIONS(1209),
    [anon_sym_default] = ACTIONS(1211),
    [anon_sym_SEMI] = ACTIONS(1209),
    [anon_sym_assert] = ACTIONS(1211),
    [anon_sym_do] = ACTIONS(1211),
    [anon_sym_while] = ACTIONS(1211),
    [anon_sym_break] = ACTIONS(1211),
    [anon_sym_continue] = ACTIONS(1211),
    [anon_sym_return] = ACTIONS(1211),
    [anon_sym_yield] = ACTIONS(1211),
    [anon_sym_synchronized] = ACTIONS(1211),
    [anon_sym_throw] = ACTIONS(1211),
    [anon_sym_try] = ACTIONS(1211),
    [anon_sym_if] = ACTIONS(1211),
    [anon_sym_for] = ACTIONS(1211),
    [anon_sym_AT] = ACTIONS(1211),
    [anon_sym_open] = ACTIONS(1211),
    [anon_sym_module] = ACTIONS(1211),
    [anon_sym_static] = ACTIONS(1211),
    [anon_sym_with] = ACTIONS(1211),
    [anon_sym_package] = ACTIONS(1211),
    [anon_sym_import] = ACTIONS(1211),
    [anon_sym_enum] = ACTIONS(1211),
    [anon_sym_public] = ACTIONS(1211),
    [anon_sym_protected] = ACTIONS(1211),
    [anon_sym_private] = ACTIONS(1211),
    [anon_sym_abstract] = ACTIONS(1211),
    [anon_sym_strictfp] = ACTIONS(1211),
    [anon_sym_native] = ACTIONS(1211),
    [anon_sym_transient] = ACTIONS(1211),
    [anon_sym_volatile] = ACTIONS(1211),
    [anon_sym_sealed] = ACTIONS(1211),
    [anon_sym_non_DASHsealed] = ACTIONS(1209),
    [anon_sym_record] = ACTIONS(1211),
    [anon_sym_ATinterface] = ACTIONS(1209),
    [anon_sym_interface] = ACTIONS(1211),
    [anon_sym_byte] = ACTIONS(1211),
    [anon_sym_short] = ACTIONS(1211),
    [anon_sym_int] = ACTIONS(1211),
    [anon_sym_long] = ACTIONS(1211),
    [anon_sym_char] = ACTIONS(1211),
    [anon_sym_float] = ACTIONS(1211),
    [anon_sym_double] = ACTIONS(1211),
    [sym_boolean_type] = ACTIONS(1211),
    [sym_void_type] = ACTIONS(1211),
    [sym_this] = ACTIONS(1211),
    [sym_super] = ACTIONS(1211),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [394] = {
    [ts_builtin_sym_end] = ACTIONS(1213),
    [sym_identifier] = ACTIONS(1215),
    [sym_decimal_integer_literal] = ACTIONS(1215),
    [sym_hex_integer_literal] = ACTIONS(1215),
    [sym_octal_integer_literal] = ACTIONS(1215),
    [sym_binary_integer_literal] = ACTIONS(1213),
    [sym_decimal_floating_point_literal] = ACTIONS(1213),
    [sym_hex_floating_point_literal] = ACTIONS(1215),
    [sym_true] = ACTIONS(1215),
    [sym_false] = ACTIONS(1215),
    [sym_character_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1213),
    [anon_sym_RBRACE] = ACTIONS(1213),
    [sym_null_literal] = ACTIONS(1215),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_LT] = ACTIONS(1213),
    [anon_sym_PLUS] = ACTIONS(1215),
    [anon_sym_DASH] = ACTIONS(1215),
    [anon_sym_final] = ACTIONS(1215),
    [anon_sym_BANG] = ACTIONS(1213),
    [anon_sym_TILDE] = ACTIONS(1213),
    [anon_sym_PLUS_PLUS] = ACTIONS(1213),
    [anon_sym_DASH_DASH] = ACTIONS(1213),
    [anon_sym_new] = ACTIONS(1215),
    [anon_sym_class] = ACTIONS(1215),
    [anon_sym_switch] = ACTIONS(1215),
    [anon_sym_LBRACE] = ACTIONS(1213),
    [anon_sym_default] = ACTIONS(1215),
    [anon_sym_SEMI] = ACTIONS(1213),
    [anon_sym_assert] = ACTIONS(1215),
    [anon_sym_do] = ACTIONS(1215),
    [anon_sym_while] = ACTIONS(1215),
    [anon_sym_break] = ACTIONS(1215),
    [anon_sym_continue] = ACTIONS(1215),
    [anon_sym_return] = ACTIONS(1215),
    [anon_sym_yield] = ACTIONS(1215),
    [anon_sym_synchronized] = ACTIONS(1215),
    [anon_sym_throw] = ACTIONS(1215),
    [anon_sym_try] = ACTIONS(1215),
    [anon_sym_if] = ACTIONS(1215),
    [anon_sym_for] = ACTIONS(1215),
    [anon_sym_AT] = ACTIONS(1215),
    [anon_sym_open] = ACTIONS(1215),
    [anon_sym_module] = ACTIONS(1215),
    [anon_sym_static] = ACTIONS(1215),
    [anon_sym_with] = ACTIONS(1215),
    [anon_sym_package] = ACTIONS(1215),
    [anon_sym_import] = ACTIONS(1215),
    [anon_sym_enum] = ACTIONS(1215),
    [anon_sym_public] = ACTIONS(1215),
    [anon_sym_protected] = ACTIONS(1215),
    [anon_sym_private] = ACTIONS(1215),
    [anon_sym_abstract] = ACTIONS(1215),
    [anon_sym_strictfp] = ACTIONS(1215),
    [anon_sym_native] = ACTIONS(1215),
    [anon_sym_transient] = ACTIONS(1215),
    [anon_sym_volatile] = ACTIONS(1215),
    [anon_sym_sealed] = ACTIONS(1215),
    [anon_sym_non_DASHsealed] = ACTIONS(1213),
    [anon_sym_record] = ACTIONS(1215),
    [anon_sym_ATinterface] = ACTIONS(1213),
    [anon_sym_interface] = ACTIONS(1215),
    [anon_sym_byte] = ACTIONS(1215),
    [anon_sym_short] = ACTIONS(1215),
    [anon_sym_int] = ACTIONS(1215),
    [anon_sym_long] = ACTIONS(1215),
    [anon_sym_char] = ACTIONS(1215),
    [anon_sym_float] = ACTIONS(1215),
    [anon_sym_double] = ACTIONS(1215),
    [sym_boolean_type] = ACTIONS(1215),
    [sym_void_type] = ACTIONS(1215),
    [sym_this] = ACTIONS(1215),
    [sym_super] = ACTIONS(1215),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [395] = {
    [sym_identifier] = ACTIONS(1183),
    [sym_decimal_integer_literal] = ACTIONS(1183),
    [sym_hex_integer_literal] = ACTIONS(1183),
    [sym_octal_integer_literal] = ACTIONS(1183),
    [sym_binary_integer_literal] = ACTIONS(1185),
    [sym_decimal_floating_point_literal] = ACTIONS(1185),
    [sym_hex_floating_point_literal] = ACTIONS(1183),
    [sym_true] = ACTIONS(1183),
    [sym_false] = ACTIONS(1183),
    [sym_character_literal] = ACTIONS(1185),
    [anon_sym_DQUOTE] = ACTIONS(1183),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1185),
    [anon_sym_RBRACE] = ACTIONS(1185),
    [sym_null_literal] = ACTIONS(1183),
    [anon_sym_LPAREN] = ACTIONS(1185),
    [anon_sym_PLUS] = ACTIONS(1183),
    [anon_sym_DASH] = ACTIONS(1183),
    [anon_sym_final] = ACTIONS(1183),
    [anon_sym_BANG] = ACTIONS(1185),
    [anon_sym_TILDE] = ACTIONS(1185),
    [anon_sym_PLUS_PLUS] = ACTIONS(1185),
    [anon_sym_DASH_DASH] = ACTIONS(1185),
    [anon_sym_new] = ACTIONS(1183),
    [anon_sym_class] = ACTIONS(1183),
    [anon_sym_switch] = ACTIONS(1183),
    [anon_sym_LBRACE] = ACTIONS(1185),
    [anon_sym_case] = ACTIONS(1183),
    [anon_sym_default] = ACTIONS(1183),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_assert] = ACTIONS(1183),
    [anon_sym_do] = ACTIONS(1183),
    [anon_sym_while] = ACTIONS(1183),
    [anon_sym_break] = ACTIONS(1183),
    [anon_sym_continue] = ACTIONS(1183),
    [anon_sym_return] = ACTIONS(1183),
    [anon_sym_yield] = ACTIONS(1183),
    [anon_sym_synchronized] = ACTIONS(1183),
    [anon_sym_throw] = ACTIONS(1183),
    [anon_sym_try] = ACTIONS(1183),
    [anon_sym_if] = ACTIONS(1183),
    [anon_sym_for] = ACTIONS(1183),
    [anon_sym_AT] = ACTIONS(1183),
    [anon_sym_open] = ACTIONS(1183),
    [anon_sym_module] = ACTIONS(1183),
    [anon_sym_static] = ACTIONS(1183),
    [anon_sym_with] = ACTIONS(1183),
    [anon_sym_package] = ACTIONS(1183),
    [anon_sym_import] = ACTIONS(1183),
    [anon_sym_enum] = ACTIONS(1183),
    [anon_sym_public] = ACTIONS(1183),
    [anon_sym_protected] = ACTIONS(1183),
    [anon_sym_private] = ACTIONS(1183),
    [anon_sym_abstract] = ACTIONS(1183),
    [anon_sym_strictfp] = ACTIONS(1183),
    [anon_sym_native] = ACTIONS(1183),
    [anon_sym_transient] = ACTIONS(1183),
    [anon_sym_volatile] = ACTIONS(1183),
    [anon_sym_sealed] = ACTIONS(1183),
    [anon_sym_non_DASHsealed] = ACTIONS(1185),
    [anon_sym_record] = ACTIONS(1183),
    [anon_sym_ATinterface] = ACTIONS(1185),
    [anon_sym_interface] = ACTIONS(1183),
    [anon_sym_byte] = ACTIONS(1183),
    [anon_sym_short] = ACTIONS(1183),
    [anon_sym_int] = ACTIONS(1183),
    [anon_sym_long] = ACTIONS(1183),
    [anon_sym_char] = ACTIONS(1183),
    [anon_sym_float] = ACTIONS(1183),
    [anon_sym_double] = ACTIONS(1183),
    [sym_boolean_type] = ACTIONS(1183),
    [sym_void_type] = ACTIONS(1183),
    [sym_this] = ACTIONS(1183),
    [sym_super] = ACTIONS(1183),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [396] = {
    [sym_identifier] = ACTIONS(1217),
    [sym_decimal_integer_literal] = ACTIONS(1217),
    [sym_hex_integer_literal] = ACTIONS(1217),
    [sym_octal_integer_literal] = ACTIONS(1217),
    [sym_binary_integer_literal] = ACTIONS(1219),
    [sym_decimal_floating_point_literal] = ACTIONS(1219),
    [sym_hex_floating_point_literal] = ACTIONS(1217),
    [sym_true] = ACTIONS(1217),
    [sym_false] = ACTIONS(1217),
    [sym_character_literal] = ACTIONS(1219),
    [anon_sym_DQUOTE] = ACTIONS(1217),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1219),
    [anon_sym_RBRACE] = ACTIONS(1219),
    [sym_null_literal] = ACTIONS(1217),
    [anon_sym_LPAREN] = ACTIONS(1219),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(1217),
    [anon_sym_final] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1219),
    [anon_sym_TILDE] = ACTIONS(1219),
    [anon_sym_PLUS_PLUS] = ACTIONS(1219),
    [anon_sym_DASH_DASH] = ACTIONS(1219),
    [anon_sym_new] = ACTIONS(1217),
    [anon_sym_class] = ACTIONS(1217),
    [anon_sym_switch] = ACTIONS(1217),
    [anon_sym_LBRACE] = ACTIONS(1219),
    [anon_sym_default] = ACTIONS(1217),
    [anon_sym_SEMI] = ACTIONS(1219),
    [anon_sym_assert] = ACTIONS(1217),
    [anon_sym_do] = ACTIONS(1217),
    [anon_sym_while] = ACTIONS(1217),
    [anon_sym_break] = ACTIONS(1217),
    [anon_sym_continue] = ACTIONS(1217),
    [anon_sym_return] = ACTIONS(1217),
    [anon_sym_yield] = ACTIONS(1217),
    [anon_sym_synchronized] = ACTIONS(1217),
    [anon_sym_throw] = ACTIONS(1217),
    [anon_sym_try] = ACTIONS(1217),
    [anon_sym_if] = ACTIONS(1217),
    [anon_sym_for] = ACTIONS(1217),
    [anon_sym_AT] = ACTIONS(1217),
    [anon_sym_open] = ACTIONS(1217),
    [anon_sym_module] = ACTIONS(1217),
    [anon_sym_static] = ACTIONS(1217),
    [anon_sym_with] = ACTIONS(1217),
    [anon_sym_package] = ACTIONS(1217),
    [anon_sym_import] = ACTIONS(1217),
    [anon_sym_enum] = ACTIONS(1217),
    [anon_sym_public] = ACTIONS(1217),
    [anon_sym_protected] = ACTIONS(1217),
    [anon_sym_private] = ACTIONS(1217),
    [anon_sym_abstract] = ACTIONS(1217),
    [anon_sym_strictfp] = ACTIONS(1217),
    [anon_sym_native] = ACTIONS(1217),
    [anon_sym_transient] = ACTIONS(1217),
    [anon_sym_volatile] = ACTIONS(1217),
    [anon_sym_sealed] = ACTIONS(1217),
    [anon_sym_non_DASHsealed] = ACTIONS(1219),
    [anon_sym_record] = ACTIONS(1217),
    [anon_sym_ATinterface] = ACTIONS(1219),
    [anon_sym_interface] = ACTIONS(1217),
    [anon_sym_byte] = ACTIONS(1217),
    [anon_sym_short] = ACTIONS(1217),
    [anon_sym_int] = ACTIONS(1217),
    [anon_sym_long] = ACTIONS(1217),
    [anon_sym_char] = ACTIONS(1217),
    [anon_sym_float] = ACTIONS(1217),
    [anon_sym_double] = ACTIONS(1217),
    [sym_boolean_type] = ACTIONS(1217),
    [sym_void_type] = ACTIONS(1217),
    [sym_this] = ACTIONS(1217),
    [sym_super] = ACTIONS(1217),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [397] = {
    [sym_identifier] = ACTIONS(1221),
    [sym_decimal_integer_literal] = ACTIONS(1221),
    [sym_hex_integer_literal] = ACTIONS(1221),
    [sym_octal_integer_literal] = ACTIONS(1221),
    [sym_binary_integer_literal] = ACTIONS(1223),
    [sym_decimal_floating_point_literal] = ACTIONS(1223),
    [sym_hex_floating_point_literal] = ACTIONS(1221),
    [sym_true] = ACTIONS(1221),
    [sym_false] = ACTIONS(1221),
    [sym_character_literal] = ACTIONS(1223),
    [anon_sym_DQUOTE] = ACTIONS(1221),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1223),
    [anon_sym_RBRACE] = ACTIONS(1223),
    [sym_null_literal] = ACTIONS(1221),
    [anon_sym_LPAREN] = ACTIONS(1223),
    [anon_sym_PLUS] = ACTIONS(1221),
    [anon_sym_DASH] = ACTIONS(1221),
    [anon_sym_final] = ACTIONS(1221),
    [anon_sym_BANG] = ACTIONS(1223),
    [anon_sym_TILDE] = ACTIONS(1223),
    [anon_sym_PLUS_PLUS] = ACTIONS(1223),
    [anon_sym_DASH_DASH] = ACTIONS(1223),
    [anon_sym_new] = ACTIONS(1221),
    [anon_sym_class] = ACTIONS(1221),
    [anon_sym_switch] = ACTIONS(1221),
    [anon_sym_LBRACE] = ACTIONS(1223),
    [anon_sym_default] = ACTIONS(1221),
    [anon_sym_SEMI] = ACTIONS(1223),
    [anon_sym_assert] = ACTIONS(1221),
    [anon_sym_do] = ACTIONS(1221),
    [anon_sym_while] = ACTIONS(1221),
    [anon_sym_break] = ACTIONS(1221),
    [anon_sym_continue] = ACTIONS(1221),
    [anon_sym_return] = ACTIONS(1221),
    [anon_sym_yield] = ACTIONS(1221),
    [anon_sym_synchronized] = ACTIONS(1221),
    [anon_sym_throw] = ACTIONS(1221),
    [anon_sym_try] = ACTIONS(1221),
    [anon_sym_if] = ACTIONS(1221),
    [anon_sym_for] = ACTIONS(1221),
    [anon_sym_AT] = ACTIONS(1221),
    [anon_sym_open] = ACTIONS(1221),
    [anon_sym_module] = ACTIONS(1221),
    [anon_sym_static] = ACTIONS(1221),
    [anon_sym_with] = ACTIONS(1221),
    [anon_sym_package] = ACTIONS(1221),
    [anon_sym_import] = ACTIONS(1221),
    [anon_sym_enum] = ACTIONS(1221),
    [anon_sym_public] = ACTIONS(1221),
    [anon_sym_protected] = ACTIONS(1221),
    [anon_sym_private] = ACTIONS(1221),
    [anon_sym_abstract] = ACTIONS(1221),
    [anon_sym_strictfp] = ACTIONS(1221),
    [anon_sym_native] = ACTIONS(1221),
    [anon_sym_transient] = ACTIONS(1221),
    [anon_sym_volatile] = ACTIONS(1221),
    [anon_sym_sealed] = ACTIONS(1221),
    [anon_sym_non_DASHsealed] = ACTIONS(1223),
    [anon_sym_record] = ACTIONS(1221),
    [anon_sym_ATinterface] = ACTIONS(1223),
    [anon_sym_interface] = ACTIONS(1221),
    [anon_sym_byte] = ACTIONS(1221),
    [anon_sym_short] = ACTIONS(1221),
    [anon_sym_int] = ACTIONS(1221),
    [anon_sym_long] = ACTIONS(1221),
    [anon_sym_char] = ACTIONS(1221),
    [anon_sym_float] = ACTIONS(1221),
    [anon_sym_double] = ACTIONS(1221),
    [sym_boolean_type] = ACTIONS(1221),
    [sym_void_type] = ACTIONS(1221),
    [sym_this] = ACTIONS(1221),
    [sym_super] = ACTIONS(1221),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [398] = {
    [sym_identifier] = ACTIONS(1225),
    [sym_decimal_integer_literal] = ACTIONS(1225),
    [sym_hex_integer_literal] = ACTIONS(1225),
    [sym_octal_integer_literal] = ACTIONS(1225),
    [sym_binary_integer_literal] = ACTIONS(1227),
    [sym_decimal_floating_point_literal] = ACTIONS(1227),
    [sym_hex_floating_point_literal] = ACTIONS(1225),
    [sym_true] = ACTIONS(1225),
    [sym_false] = ACTIONS(1225),
    [sym_character_literal] = ACTIONS(1227),
    [anon_sym_DQUOTE] = ACTIONS(1225),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1227),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [sym_null_literal] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_PLUS] = ACTIONS(1225),
    [anon_sym_DASH] = ACTIONS(1225),
    [anon_sym_final] = ACTIONS(1225),
    [anon_sym_BANG] = ACTIONS(1227),
    [anon_sym_TILDE] = ACTIONS(1227),
    [anon_sym_PLUS_PLUS] = ACTIONS(1227),
    [anon_sym_DASH_DASH] = ACTIONS(1227),
    [anon_sym_new] = ACTIONS(1225),
    [anon_sym_class] = ACTIONS(1225),
    [anon_sym_switch] = ACTIONS(1225),
    [anon_sym_LBRACE] = ACTIONS(1227),
    [anon_sym_default] = ACTIONS(1225),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_assert] = ACTIONS(1225),
    [anon_sym_do] = ACTIONS(1225),
    [anon_sym_while] = ACTIONS(1225),
    [anon_sym_break] = ACTIONS(1225),
    [anon_sym_continue] = ACTIONS(1225),
    [anon_sym_return] = ACTIONS(1225),
    [anon_sym_yield] = ACTIONS(1225),
    [anon_sym_synchronized] = ACTIONS(1225),
    [anon_sym_throw] = ACTIONS(1225),
    [anon_sym_try] = ACTIONS(1225),
    [anon_sym_if] = ACTIONS(1225),
    [anon_sym_for] = ACTIONS(1225),
    [anon_sym_AT] = ACTIONS(1225),
    [anon_sym_open] = ACTIONS(1225),
    [anon_sym_module] = ACTIONS(1225),
    [anon_sym_static] = ACTIONS(1225),
    [anon_sym_with] = ACTIONS(1225),
    [anon_sym_package] = ACTIONS(1225),
    [anon_sym_import] = ACTIONS(1225),
    [anon_sym_enum] = ACTIONS(1225),
    [anon_sym_public] = ACTIONS(1225),
    [anon_sym_protected] = ACTIONS(1225),
    [anon_sym_private] = ACTIONS(1225),
    [anon_sym_abstract] = ACTIONS(1225),
    [anon_sym_strictfp] = ACTIONS(1225),
    [anon_sym_native] = ACTIONS(1225),
    [anon_sym_transient] = ACTIONS(1225),
    [anon_sym_volatile] = ACTIONS(1225),
    [anon_sym_sealed] = ACTIONS(1225),
    [anon_sym_non_DASHsealed] = ACTIONS(1227),
    [anon_sym_record] = ACTIONS(1225),
    [anon_sym_ATinterface] = ACTIONS(1227),
    [anon_sym_interface] = ACTIONS(1225),
    [anon_sym_byte] = ACTIONS(1225),
    [anon_sym_short] = ACTIONS(1225),
    [anon_sym_int] = ACTIONS(1225),
    [anon_sym_long] = ACTIONS(1225),
    [anon_sym_char] = ACTIONS(1225),
    [anon_sym_float] = ACTIONS(1225),
    [anon_sym_double] = ACTIONS(1225),
    [sym_boolean_type] = ACTIONS(1225),
    [sym_void_type] = ACTIONS(1225),
    [sym_this] = ACTIONS(1225),
    [sym_super] = ACTIONS(1225),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [399] = {
    [sym_identifier] = ACTIONS(1229),
    [sym_decimal_integer_literal] = ACTIONS(1229),
    [sym_hex_integer_literal] = ACTIONS(1229),
    [sym_octal_integer_literal] = ACTIONS(1229),
    [sym_binary_integer_literal] = ACTIONS(1231),
    [sym_decimal_floating_point_literal] = ACTIONS(1231),
    [sym_hex_floating_point_literal] = ACTIONS(1229),
    [sym_true] = ACTIONS(1229),
    [sym_false] = ACTIONS(1229),
    [sym_character_literal] = ACTIONS(1231),
    [anon_sym_DQUOTE] = ACTIONS(1229),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1231),
    [anon_sym_RBRACE] = ACTIONS(1231),
    [sym_null_literal] = ACTIONS(1229),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_PLUS] = ACTIONS(1229),
    [anon_sym_DASH] = ACTIONS(1229),
    [anon_sym_final] = ACTIONS(1229),
    [anon_sym_BANG] = ACTIONS(1231),
    [anon_sym_TILDE] = ACTIONS(1231),
    [anon_sym_PLUS_PLUS] = ACTIONS(1231),
    [anon_sym_DASH_DASH] = ACTIONS(1231),
    [anon_sym_new] = ACTIONS(1229),
    [anon_sym_class] = ACTIONS(1229),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_LBRACE] = ACTIONS(1231),
    [anon_sym_default] = ACTIONS(1229),
    [anon_sym_SEMI] = ACTIONS(1231),
    [anon_sym_assert] = ACTIONS(1229),
    [anon_sym_do] = ACTIONS(1229),
    [anon_sym_while] = ACTIONS(1229),
    [anon_sym_break] = ACTIONS(1229),
    [anon_sym_continue] = ACTIONS(1229),
    [anon_sym_return] = ACTIONS(1229),
    [anon_sym_yield] = ACTIONS(1229),
    [anon_sym_synchronized] = ACTIONS(1229),
    [anon_sym_throw] = ACTIONS(1229),
    [anon_sym_try] = ACTIONS(1229),
    [anon_sym_if] = ACTIONS(1229),
    [anon_sym_for] = ACTIONS(1229),
    [anon_sym_AT] = ACTIONS(1229),
    [anon_sym_open] = ACTIONS(1229),
    [anon_sym_module] = ACTIONS(1229),
    [anon_sym_static] = ACTIONS(1229),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_package] = ACTIONS(1229),
    [anon_sym_import] = ACTIONS(1229),
    [anon_sym_enum] = ACTIONS(1229),
    [anon_sym_public] = ACTIONS(1229),
    [anon_sym_protected] = ACTIONS(1229),
    [anon_sym_private] = ACTIONS(1229),
    [anon_sym_abstract] = ACTIONS(1229),
    [anon_sym_strictfp] = ACTIONS(1229),
    [anon_sym_native] = ACTIONS(1229),
    [anon_sym_transient] = ACTIONS(1229),
    [anon_sym_volatile] = ACTIONS(1229),
    [anon_sym_sealed] = ACTIONS(1229),
    [anon_sym_non_DASHsealed] = ACTIONS(1231),
    [anon_sym_record] = ACTIONS(1229),
    [anon_sym_ATinterface] = ACTIONS(1231),
    [anon_sym_interface] = ACTIONS(1229),
    [anon_sym_byte] = ACTIONS(1229),
    [anon_sym_short] = ACTIONS(1229),
    [anon_sym_int] = ACTIONS(1229),
    [anon_sym_long] = ACTIONS(1229),
    [anon_sym_char] = ACTIONS(1229),
    [anon_sym_float] = ACTIONS(1229),
    [anon_sym_double] = ACTIONS(1229),
    [sym_boolean_type] = ACTIONS(1229),
    [sym_void_type] = ACTIONS(1229),
    [sym_this] = ACTIONS(1229),
    [sym_super] = ACTIONS(1229),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [400] = {
    [sym_identifier] = ACTIONS(1233),
    [anon_sym_LPAREN] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_AMP_EQ] = ACTIONS(422),
    [anon_sym_PIPE_EQ] = ACTIONS(422),
    [anon_sym_CARET_EQ] = ACTIONS(422),
    [anon_sym_PERCENT_EQ] = ACTIONS(422),
    [anon_sym_LT_LT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_LT] = ACTIONS(1233),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_AMP_AMP] = ACTIONS(422),
    [anon_sym_PIPE_PIPE] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(420),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PIPE] = ACTIONS(420),
    [anon_sym_CARET] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(420),
    [anon_sym_LT_LT] = ACTIONS(420),
    [anon_sym_GT_GT] = ACTIONS(420),
    [anon_sym_GT_GT_GT] = ACTIONS(420),
    [anon_sym_instanceof] = ACTIONS(420),
    [anon_sym_final] = ACTIONS(1233),
    [anon_sym_DASH_GT] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_PLUS_PLUS] = ACTIONS(422),
    [anon_sym_DASH_DASH] = ACTIONS(422),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_class] = ACTIONS(1233),
    [anon_sym_COLON_COLON] = ACTIONS(422),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_synchronized] = ACTIONS(1233),
    [anon_sym_AT] = ACTIONS(1233),
    [anon_sym_static] = ACTIONS(1233),
    [anon_sym_enum] = ACTIONS(1233),
    [anon_sym_public] = ACTIONS(1233),
    [anon_sym_protected] = ACTIONS(1233),
    [anon_sym_private] = ACTIONS(1233),
    [anon_sym_abstract] = ACTIONS(1233),
    [anon_sym_strictfp] = ACTIONS(1233),
    [anon_sym_native] = ACTIONS(1233),
    [anon_sym_transient] = ACTIONS(1233),
    [anon_sym_volatile] = ACTIONS(1233),
    [anon_sym_sealed] = ACTIONS(1233),
    [anon_sym_non_DASHsealed] = ACTIONS(1235),
    [anon_sym_record] = ACTIONS(1233),
    [anon_sym_ATinterface] = ACTIONS(1235),
    [anon_sym_interface] = ACTIONS(1233),
    [anon_sym_byte] = ACTIONS(1233),
    [anon_sym_short] = ACTIONS(1233),
    [anon_sym_int] = ACTIONS(1233),
    [anon_sym_long] = ACTIONS(1233),
    [anon_sym_char] = ACTIONS(1233),
    [anon_sym_float] = ACTIONS(1233),
    [anon_sym_double] = ACTIONS(1233),
    [sym_boolean_type] = ACTIONS(1233),
    [sym_void_type] = ACTIONS(1233),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [401] = {
    [sym_identifier] = ACTIONS(1233),
    [anon_sym_LPAREN] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_AMP_EQ] = ACTIONS(422),
    [anon_sym_PIPE_EQ] = ACTIONS(422),
    [anon_sym_CARET_EQ] = ACTIONS(422),
    [anon_sym_PERCENT_EQ] = ACTIONS(422),
    [anon_sym_LT_LT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_LT] = ACTIONS(420),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_AMP_AMP] = ACTIONS(422),
    [anon_sym_PIPE_PIPE] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(420),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PIPE] = ACTIONS(420),
    [anon_sym_CARET] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(420),
    [anon_sym_LT_LT] = ACTIONS(420),
    [anon_sym_GT_GT] = ACTIONS(420),
    [anon_sym_GT_GT_GT] = ACTIONS(420),
    [anon_sym_instanceof] = ACTIONS(420),
    [anon_sym_final] = ACTIONS(1233),
    [anon_sym_DASH_GT] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_PLUS_PLUS] = ACTIONS(422),
    [anon_sym_DASH_DASH] = ACTIONS(422),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_class] = ACTIONS(1233),
    [anon_sym_COLON_COLON] = ACTIONS(422),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_synchronized] = ACTIONS(1233),
    [anon_sym_AT] = ACTIONS(1233),
    [anon_sym_static] = ACTIONS(1233),
    [anon_sym_enum] = ACTIONS(1233),
    [anon_sym_public] = ACTIONS(1233),
    [anon_sym_protected] = ACTIONS(1233),
    [anon_sym_private] = ACTIONS(1233),
    [anon_sym_abstract] = ACTIONS(1233),
    [anon_sym_strictfp] = ACTIONS(1233),
    [anon_sym_native] = ACTIONS(1233),
    [anon_sym_transient] = ACTIONS(1233),
    [anon_sym_volatile] = ACTIONS(1233),
    [anon_sym_sealed] = ACTIONS(1233),
    [anon_sym_non_DASHsealed] = ACTIONS(1235),
    [anon_sym_record] = ACTIONS(1233),
    [anon_sym_ATinterface] = ACTIONS(1235),
    [anon_sym_interface] = ACTIONS(1233),
    [anon_sym_byte] = ACTIONS(1233),
    [anon_sym_short] = ACTIONS(1233),
    [anon_sym_int] = ACTIONS(1233),
    [anon_sym_long] = ACTIONS(1233),
    [anon_sym_char] = ACTIONS(1233),
    [anon_sym_float] = ACTIONS(1233),
    [anon_sym_double] = ACTIONS(1233),
    [sym_boolean_type] = ACTIONS(1233),
    [sym_void_type] = ACTIONS(1233),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [402] = {
    [sym_identifier] = ACTIONS(1233),
    [anon_sym_LPAREN] = ACTIONS(422),
    [anon_sym_RPAREN] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_EQ] = ACTIONS(420),
    [anon_sym_PLUS_EQ] = ACTIONS(422),
    [anon_sym_DASH_EQ] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(422),
    [anon_sym_SLASH_EQ] = ACTIONS(422),
    [anon_sym_AMP_EQ] = ACTIONS(422),
    [anon_sym_PIPE_EQ] = ACTIONS(422),
    [anon_sym_CARET_EQ] = ACTIONS(422),
    [anon_sym_PERCENT_EQ] = ACTIONS(422),
    [anon_sym_LT_LT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(422),
    [anon_sym_GT] = ACTIONS(420),
    [anon_sym_LT] = ACTIONS(420),
    [anon_sym_GT_EQ] = ACTIONS(422),
    [anon_sym_LT_EQ] = ACTIONS(422),
    [anon_sym_EQ_EQ] = ACTIONS(422),
    [anon_sym_BANG_EQ] = ACTIONS(422),
    [anon_sym_AMP_AMP] = ACTIONS(422),
    [anon_sym_PIPE_PIPE] = ACTIONS(422),
    [anon_sym_PLUS] = ACTIONS(420),
    [anon_sym_DASH] = ACTIONS(420),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PIPE] = ACTIONS(420),
    [anon_sym_CARET] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(420),
    [anon_sym_LT_LT] = ACTIONS(420),
    [anon_sym_GT_GT] = ACTIONS(420),
    [anon_sym_GT_GT_GT] = ACTIONS(420),
    [anon_sym_instanceof] = ACTIONS(420),
    [anon_sym_final] = ACTIONS(1233),
    [anon_sym_DASH_GT] = ACTIONS(422),
    [anon_sym_COMMA] = ACTIONS(422),
    [anon_sym_QMARK] = ACTIONS(422),
    [anon_sym_PLUS_PLUS] = ACTIONS(422),
    [anon_sym_DASH_DASH] = ACTIONS(422),
    [anon_sym_LBRACK] = ACTIONS(422),
    [anon_sym_DOT] = ACTIONS(422),
    [anon_sym_COLON_COLON] = ACTIONS(422),
    [anon_sym_default] = ACTIONS(1233),
    [anon_sym_SEMI] = ACTIONS(422),
    [anon_sym_synchronized] = ACTIONS(1233),
    [anon_sym_AT] = ACTIONS(1235),
    [anon_sym_static] = ACTIONS(1233),
    [anon_sym_public] = ACTIONS(1233),
    [anon_sym_protected] = ACTIONS(1233),
    [anon_sym_private] = ACTIONS(1233),
    [anon_sym_abstract] = ACTIONS(1233),
    [anon_sym_strictfp] = ACTIONS(1233),
    [anon_sym_native] = ACTIONS(1233),
    [anon_sym_transient] = ACTIONS(1233),
    [anon_sym_volatile] = ACTIONS(1233),
    [anon_sym_sealed] = ACTIONS(1233),
    [anon_sym_non_DASHsealed] = ACTIONS(1235),
    [anon_sym_byte] = ACTIONS(1233),
    [anon_sym_short] = ACTIONS(1233),
    [anon_sym_int] = ACTIONS(1233),
    [anon_sym_long] = ACTIONS(1233),
    [anon_sym_char] = ACTIONS(1233),
    [anon_sym_float] = ACTIONS(1233),
    [anon_sym_double] = ACTIONS(1233),
    [sym_boolean_type] = ACTIONS(1233),
    [sym_void_type] = ACTIONS(1233),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [403] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_lambda_expression] = STATE(587),
    [sym_inferred_parameters] = STATE(1347),
    [sym_primary_expression] = STATE(519),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(558),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1347),
    [sym__reserved_identifier] = STATE(580),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(1237),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(1239),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(1241),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(1241),
    [anon_sym_module] = ACTIONS(1241),
    [anon_sym_with] = ACTIONS(1241),
    [anon_sym_sealed] = ACTIONS(1241),
    [anon_sym_record] = ACTIONS(1241),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(1243),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [404] = {
    [sym__literal] = STATE(558),
    [sym_string_literal] = STATE(571),
    [sym__string_literal] = STATE(550),
    [sym__multiline_string_literal] = STATE(550),
    [sym_lambda_expression] = STATE(587),
    [sym_inferred_parameters] = STATE(1363),
    [sym_primary_expression] = STATE(519),
    [sym_array_creation_expression] = STATE(558),
    [sym_parenthesized_expression] = STATE(558),
    [sym_class_literal] = STATE(558),
    [sym_object_creation_expression] = STATE(558),
    [sym__unqualified_object_creation_expression] = STATE(521),
    [sym_field_access] = STATE(558),
    [sym_template_expression] = STATE(558),
    [sym_array_access] = STATE(558),
    [sym_method_invocation] = STATE(558),
    [sym_method_reference] = STATE(558),
    [sym__annotation] = STATE(774),
    [sym_marker_annotation] = STATE(774),
    [sym_annotation] = STATE(774),
    [sym__type] = STATE(1361),
    [sym__unannotated_type] = STATE(895),
    [sym_annotated_type] = STATE(905),
    [sym_scoped_type_identifier] = STATE(816),
    [sym_generic_type] = STATE(827),
    [sym_array_type] = STATE(757),
    [sym_integral_type] = STATE(757),
    [sym_floating_point_type] = STATE(757),
    [sym_formal_parameters] = STATE(1363),
    [sym__reserved_identifier] = STATE(487),
    [aux_sym_array_creation_expression_repeat1] = STATE(774),
    [sym_identifier] = ACTIONS(1245),
    [sym_decimal_integer_literal] = ACTIONS(9),
    [sym_hex_integer_literal] = ACTIONS(9),
    [sym_octal_integer_literal] = ACTIONS(9),
    [sym_binary_integer_literal] = ACTIONS(11),
    [sym_decimal_floating_point_literal] = ACTIONS(11),
    [sym_hex_floating_point_literal] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_character_literal] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(15),
    [sym_null_literal] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(1239),
    [anon_sym_new] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(1241),
    [anon_sym_AT] = ACTIONS(424),
    [anon_sym_open] = ACTIONS(1241),
    [anon_sym_module] = ACTIONS(1241),
    [anon_sym_with] = ACTIONS(1241),
    [anon_sym_sealed] = ACTIONS(1241),
    [anon_sym_record] = ACTIONS(1241),
    [anon_sym_byte] = ACTIONS(87),
    [anon_sym_short] = ACTIONS(87),
    [anon_sym_int] = ACTIONS(87),
    [anon_sym_long] = ACTIONS(87),
    [anon_sym_char] = ACTIONS(87),
    [anon_sym_float] = ACTIONS(89),
    [anon_sym_double] = ACTIONS(89),
    [sym_boolean_type] = ACTIONS(91),
    [sym_void_type] = ACTIONS(91),
    [sym_this] = ACTIONS(93),
    [sym_super] = ACTIONS(1243),
    [sym_line_comment] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(422), 26,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(420), 35,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_final,
      anon_sym_COLON,
      anon_sym_default,
      anon_sym_when,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [70] = 28,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1247), 1,
      sym_identifier,
    ACTIONS(1249), 1,
      anon_sym_RBRACE,
    ACTIONS(1251), 1,
      anon_sym_SEMI,
    ACTIONS(1253), 1,
      anon_sym_static,
    ACTIONS(1255), 1,
      anon_sym_record,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(696), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(778), 1,
      sym__unannotated_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(1050), 1,
      sym__constructor_declarator,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(23), 12,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    STATE(407), 12,
      sym_block,
      sym_enum_declaration,
      sym_class_declaration,
      sym_static_initializer,
      sym_constructor_declaration,
      sym_field_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_method_declaration,
      sym_compact_constructor_declaration,
      aux_sym_enum_body_declarations_repeat1,
  [189] = 28,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1247), 1,
      sym_identifier,
    ACTIONS(1253), 1,
      anon_sym_static,
    ACTIONS(1255), 1,
      anon_sym_record,
    ACTIONS(1257), 1,
      anon_sym_RBRACE,
    ACTIONS(1259), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(696), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(778), 1,
      sym__unannotated_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(1050), 1,
      sym__constructor_declarator,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(23), 12,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    STATE(409), 12,
      sym_block,
      sym_enum_declaration,
      sym_class_declaration,
      sym_static_initializer,
      sym_constructor_declaration,
      sym_field_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_method_declaration,
      sym_compact_constructor_declaration,
      aux_sym_enum_body_declarations_repeat1,
  [308] = 28,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1247), 1,
      sym_identifier,
    ACTIONS(1253), 1,
      anon_sym_static,
    ACTIONS(1255), 1,
      anon_sym_record,
    ACTIONS(1261), 1,
      anon_sym_RBRACE,
    ACTIONS(1263), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(696), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(778), 1,
      sym__unannotated_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(1050), 1,
      sym__constructor_declarator,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(23), 12,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    STATE(410), 12,
      sym_block,
      sym_enum_declaration,
      sym_class_declaration,
      sym_static_initializer,
      sym_constructor_declaration,
      sym_field_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_method_declaration,
      sym_compact_constructor_declaration,
      aux_sym_enum_body_declarations_repeat1,
  [427] = 28,
    ACTIONS(1265), 1,
      sym_identifier,
    ACTIONS(1268), 1,
      anon_sym_RBRACE,
    ACTIONS(1270), 1,
      anon_sym_LT,
    ACTIONS(1276), 1,
      anon_sym_class,
    ACTIONS(1279), 1,
      anon_sym_LBRACE,
    ACTIONS(1282), 1,
      anon_sym_SEMI,
    ACTIONS(1285), 1,
      anon_sym_AT,
    ACTIONS(1288), 1,
      anon_sym_static,
    ACTIONS(1291), 1,
      anon_sym_enum,
    ACTIONS(1294), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1297), 1,
      anon_sym_record,
    ACTIONS(1300), 1,
      anon_sym_ATinterface,
    ACTIONS(1303), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(696), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(778), 1,
      sym__unannotated_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(1050), 1,
      sym__constructor_declarator,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1309), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(1312), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1306), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(1273), 12,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    STATE(409), 12,
      sym_block,
      sym_enum_declaration,
      sym_class_declaration,
      sym_static_initializer,
      sym_constructor_declaration,
      sym_field_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_method_declaration,
      sym_compact_constructor_declaration,
      aux_sym_enum_body_declarations_repeat1,
  [546] = 28,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1247), 1,
      sym_identifier,
    ACTIONS(1253), 1,
      anon_sym_static,
    ACTIONS(1255), 1,
      anon_sym_record,
    ACTIONS(1259), 1,
      anon_sym_SEMI,
    ACTIONS(1315), 1,
      anon_sym_RBRACE,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(696), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(778), 1,
      sym__unannotated_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(1050), 1,
      sym__constructor_declarator,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(23), 12,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    STATE(409), 12,
      sym_block,
      sym_enum_declaration,
      sym_class_declaration,
      sym_static_initializer,
      sym_constructor_declaration,
      sym_field_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_method_declaration,
      sym_compact_constructor_declaration,
      aux_sym_enum_body_declarations_repeat1,
  [665] = 14,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1319), 14,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
    ACTIONS(1323), 15,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
  [754] = 17,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1343), 1,
      anon_sym_RPAREN,
    ACTIONS(1346), 1,
      anon_sym_COMMA,
    ACTIONS(1348), 1,
      anon_sym_DOT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1089), 1,
      aux_sym_inferred_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1341), 2,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1317), 9,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1319), 9,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [847] = 18,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1346), 1,
      anon_sym_COMMA,
    ACTIONS(1348), 1,
      anon_sym_DOT,
    ACTIONS(1352), 1,
      anon_sym_RPAREN,
    ACTIONS(1356), 1,
      anon_sym_AMP,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1089), 1,
      aux_sym_inferred_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1341), 2,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1317), 9,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1319), 9,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 12,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [942] = 25,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1362), 1,
      anon_sym_RBRACE,
    ACTIONS(1364), 1,
      anon_sym_LT,
    ACTIONS(1370), 1,
      anon_sym_class,
    ACTIONS(1373), 1,
      anon_sym_SEMI,
    ACTIONS(1376), 1,
      anon_sym_AT,
    ACTIONS(1379), 1,
      anon_sym_enum,
    ACTIONS(1382), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1385), 1,
      anon_sym_record,
    ACTIONS(1388), 1,
      anon_sym_ATinterface,
    ACTIONS(1391), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(747), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(775), 1,
      sym_type_parameters,
    STATE(779), 1,
      sym__unannotated_type,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1397), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(1400), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1394), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(414), 8,
      sym_enum_declaration,
      sym_class_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      sym_method_declaration,
      aux_sym_interface_body_repeat1,
    ACTIONS(1367), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [1049] = 15,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1403), 1,
      anon_sym_LPAREN,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 10,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 15,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
  [1136] = 25,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1255), 1,
      anon_sym_record,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(1407), 1,
      anon_sym_RBRACE,
    ACTIONS(1409), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(747), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(775), 1,
      sym_type_parameters,
    STATE(779), 1,
      sym__unannotated_type,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(417), 8,
      sym_enum_declaration,
      sym_class_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      sym_method_declaration,
      aux_sym_interface_body_repeat1,
    ACTIONS(23), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [1243] = 25,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1255), 1,
      anon_sym_record,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(1411), 1,
      anon_sym_RBRACE,
    ACTIONS(1413), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(747), 1,
      sym_modifiers,
    STATE(758), 1,
      sym_generic_type,
    STATE(775), 1,
      sym_type_parameters,
    STATE(779), 1,
      sym__unannotated_type,
    STATE(1070), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(414), 8,
      sym_enum_declaration,
      sym_class_declaration,
      sym_record_declaration,
      sym_annotation_type_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      sym_method_declaration,
      aux_sym_interface_body_repeat1,
    ACTIONS(23), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [1350] = 15,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1403), 1,
      anon_sym_LPAREN,
    ACTIONS(1415), 1,
      anon_sym_EQ,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 10,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1417), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 15,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
  [1437] = 15,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1422), 1,
      anon_sym_COLON,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 10,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [1523] = 15,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1424), 1,
      anon_sym_LPAREN,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 11,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [1609] = 15,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 10,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [1695] = 15,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1428), 1,
      anon_sym_COLON,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1319), 10,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
  [1781] = 6,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1077), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
    ACTIONS(420), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
    ACTIONS(422), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [1846] = 21,
    ACTIONS(1432), 1,
      sym_identifier,
    ACTIONS(1435), 1,
      anon_sym_RBRACE,
    ACTIONS(1440), 1,
      anon_sym_class,
    ACTIONS(1443), 1,
      anon_sym_SEMI,
    ACTIONS(1446), 1,
      anon_sym_AT,
    ACTIONS(1449), 1,
      anon_sym_enum,
    ACTIONS(1452), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1455), 1,
      anon_sym_ATinterface,
    ACTIONS(1458), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(794), 1,
      sym_modifiers,
    STATE(803), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1464), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(1467), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1461), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(424), 7,
      sym_enum_declaration,
      sym_class_declaration,
      sym_annotation_type_declaration,
      sym_annotation_type_element_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      aux_sym_annotation_type_body_repeat1,
    ACTIONS(1437), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [1940] = 21,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      anon_sym_RBRACE,
    ACTIONS(1472), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(794), 1,
      sym_modifiers,
    STATE(803), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(426), 7,
      sym_enum_declaration,
      sym_class_declaration,
      sym_annotation_type_declaration,
      sym_annotation_type_element_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      aux_sym_annotation_type_body_repeat1,
    ACTIONS(23), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [2034] = 21,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(75), 1,
      anon_sym_enum,
    ACTIONS(79), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(83), 1,
      anon_sym_ATinterface,
    ACTIONS(85), 1,
      anon_sym_interface,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(1474), 1,
      anon_sym_RBRACE,
    ACTIONS(1476), 1,
      anon_sym_SEMI,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(794), 1,
      sym_modifiers,
    STATE(803), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(509), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    STATE(424), 7,
      sym_enum_declaration,
      sym_class_declaration,
      sym_annotation_type_declaration,
      sym_annotation_type_element_declaration,
      sym_interface_declaration,
      sym_constant_declaration,
      aux_sym_annotation_type_body_repeat1,
    ACTIONS(23), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [2128] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(533), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1480), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1478), 31,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2189] = 8,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 19,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2256] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(539), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1484), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1482), 31,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2317] = 7,
    ACTIONS(1490), 1,
      anon_sym_LBRACK,
    ACTIONS(1493), 1,
      anon_sym_AT,
    STATE(430), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(937), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1486), 18,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1488), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [2381] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1500), 1,
      anon_sym_LBRACK,
    STATE(430), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(937), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1496), 18,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1498), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [2445] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1500), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(475), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(937), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1502), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1504), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [2510] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1484), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1482), 31,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2565] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1508), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1506), 31,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2620] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1480), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1478), 31,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2675] = 13,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1415), 1,
      anon_sym_EQ,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1417), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1319), 12,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_when,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
  [2750] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1500), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(475), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(937), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1510), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1512), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [2815] = 9,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1403), 1,
      anon_sym_LPAREN,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 15,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [2881] = 5,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 19,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [2939] = 9,
    ACTIONS(1403), 1,
      anon_sym_LPAREN,
    ACTIONS(1415), 1,
      anon_sym_EQ,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1417), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 15,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [3005] = 13,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1514), 1,
      anon_sym_EQ,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1319), 11,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 12,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
  [3078] = 9,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1424), 1,
      anon_sym_LPAREN,
    STATE(531), 1,
      sym_argument_list,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
    ACTIONS(1319), 15,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
  [3143] = 8,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1415), 1,
      anon_sym_EQ,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1417), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 15,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [3206] = 11,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_EQ,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1343), 1,
      anon_sym_RPAREN,
    ACTIONS(1346), 1,
      anon_sym_COMMA,
    STATE(531), 1,
      sym_argument_list,
    STATE(1089), 1,
      aux_sym_inferred_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1327), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1319), 13,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    ACTIONS(1323), 13,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
  [3275] = 8,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    ACTIONS(1518), 1,
      anon_sym_LT,
    ACTIONS(1521), 1,
      anon_sym_DOT,
    STATE(459), 1,
      sym_type_arguments,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1317), 16,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1341), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [3338] = 6,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    ACTIONS(1527), 1,
      anon_sym_DOT,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1525), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [3396] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1533), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(547), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(956), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1531), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1529), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [3460] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1533), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(520), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(956), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1537), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1535), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [3524] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1533), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(538), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(956), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1541), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1539), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [3588] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1533), 1,
      anon_sym_LBRACK,
    STATE(431), 1,
      aux_sym_dimensions_repeat1,
    STATE(525), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(956), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1545), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1543), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [3652] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1547), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1549), 25,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [3703] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1551), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1553), 25,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [3754] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1486), 18,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1488), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
      anon_sym_AT,
  [3805] = 4,
    ACTIONS(1555), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(420), 15,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
    ACTIONS(422), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [3858] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1557), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1559), 25,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [3909] = 6,
    ACTIONS(1527), 1,
      anon_sym_DOT,
    ACTIONS(1561), 1,
      anon_sym_LT,
    STATE(461), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 16,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1525), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [3966] = 4,
    ACTIONS(1564), 1,
      anon_sym_module,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(420), 14,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
    ACTIONS(422), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [4019] = 5,
    ACTIONS(1415), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1417), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(1323), 14,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 16,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [4074] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1566), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1568), 25,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4125] = 6,
    ACTIONS(1518), 1,
      anon_sym_LT,
    ACTIONS(1521), 1,
      anon_sym_DOT,
    STATE(459), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1317), 16,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1341), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [4182] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1570), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1572), 25,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4233] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1574), 18,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1576), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
      anon_sym_AT,
  [4284] = 4,
    ACTIONS(1527), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1525), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [4336] = 7,
    ACTIONS(1582), 1,
      anon_sym_LBRACK,
    ACTIONS(1585), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(959), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1580), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1578), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [4394] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1588), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1590), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4444] = 19,
    ACTIONS(460), 1,
      anon_sym_RPAREN,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(624), 1,
      aux_sym_modifiers_repeat1,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(773), 1,
      sym__unannotated_type,
    STATE(777), 1,
      aux_sym_array_creation_expression_repeat1,
    STATE(834), 1,
      sym_modifiers,
    STATE(1187), 1,
      sym_receiver_parameter,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1072), 2,
      sym_formal_parameter,
      sym_spread_parameter,
    STATE(702), 3,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [4526] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1592), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1594), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4576] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(867), 11,
      sym_binary_integer_literal,
      sym_decimal_floating_point_literal,
      sym_character_literal,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_LPAREN,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(869), 30,
      sym_decimal_integer_literal,
      sym_hex_integer_literal,
      sym_octal_integer_literal,
      sym_hex_floating_point_literal,
      sym_true,
      sym_false,
      anon_sym_DQUOTE,
      sym_null_literal,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_new,
      anon_sym_switch,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_this,
      sym_super,
      sym_identifier,
  [4626] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1596), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1598), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4676] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1602), 8,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1600), 33,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_to,
      anon_sym_with,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [4726] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1051), 11,
      sym_binary_integer_literal,
      sym_decimal_floating_point_literal,
      sym_character_literal,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_LPAREN,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1053), 30,
      sym_decimal_integer_literal,
      sym_hex_integer_literal,
      sym_octal_integer_literal,
      sym_hex_floating_point_literal,
      sym_true,
      sym_false,
      anon_sym_DQUOTE,
      sym_null_literal,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_new,
      anon_sym_switch,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_this,
      sym_super,
      sym_identifier,
  [4776] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1604), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1606), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
  [4826] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1525), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [4875] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1608), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1610), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [4924] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1612), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1614), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [4973] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1616), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1618), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_SEMI,
      anon_sym_AT,
  [5022] = 16,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(1620), 1,
      anon_sym_RPAREN,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(812), 1,
      sym__unannotated_type,
    STATE(834), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1134), 2,
      sym_formal_parameter,
      sym_spread_parameter,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [5096] = 6,
    ACTIONS(1622), 1,
      sym_identifier,
    STATE(601), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
    ACTIONS(1626), 10,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
    ACTIONS(1624), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [5150] = 6,
    ACTIONS(1628), 1,
      sym_identifier,
    STATE(605), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
    ACTIONS(1632), 10,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
    ACTIONS(1630), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [5204] = 15,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(812), 1,
      sym__unannotated_type,
    STATE(834), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1267), 2,
      sym_formal_parameter,
      sym_spread_parameter,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [5275] = 11,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1323), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [5338] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1510), 17,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_instanceof,
      anon_sym_when,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
    ACTIONS(1512), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_SEMI,
  [5385] = 16,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(818), 1,
      sym__unannotated_type,
    STATE(825), 1,
      sym_modifiers,
    STATE(888), 1,
      sym_catch_type,
    STATE(1310), 1,
      sym_catch_formal_parameter,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [5458] = 6,
    ACTIONS(1636), 1,
      anon_sym_LPAREN,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    STATE(544), 1,
      sym_annotation_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1638), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1634), 31,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [5510] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(537), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1644), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1642), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5559] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(551), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1650), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1648), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5608] = 6,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1323), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5659] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(570), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1654), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1652), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5708] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(569), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1658), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1656), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5757] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(548), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1662), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1660), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5806] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(541), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1666), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1664), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5855] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(533), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1480), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1478), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5904] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(556), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1670), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1668), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [5953] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(530), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1674), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1672), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6002] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(527), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1678), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1676), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6051] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(539), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1484), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1482), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6100] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(552), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1682), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1680), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6149] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(549), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1686), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1684), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6198] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(559), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1690), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1688), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6247] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1694), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1692), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
      anon_sym_AT,
  [6291] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1698), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1696), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_when,
      anon_sym_SEMI,
  [6335] = 7,
    ACTIONS(1707), 1,
      anon_sym_AT,
    ACTIONS(1710), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1702), 2,
      anon_sym_LT,
      anon_sym_ATinterface,
    STATE(502), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1704), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    ACTIONS(1700), 14,
      anon_sym_class,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [6387] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1553), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1551), 23,
      anon_sym_new,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_this,
      sym_super,
      sym_identifier,
  [6431] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1559), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1557), 23,
      anon_sym_new,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_this,
      sym_super,
      sym_identifier,
  [6475] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1715), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1713), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_when,
      anon_sym_SEMI,
  [6519] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1719), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1717), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_when,
      anon_sym_SEMI,
  [6563] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1723), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1721), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
      anon_sym_AT,
  [6607] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1549), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1547), 23,
      anon_sym_new,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_this,
      sym_super,
      sym_identifier,
  [6651] = 7,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(1731), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1727), 2,
      anon_sym_LT,
      anon_sym_ATinterface,
    STATE(502), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1729), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
    ACTIONS(1725), 14,
      anon_sym_class,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [6703] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1735), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1733), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6746] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1739), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1737), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [6789] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1743), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1741), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6832] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1747), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1745), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [6875] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1751), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1749), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [6918] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1755), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1753), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [6961] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1759), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1757), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7004] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1763), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1761), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7047] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1508), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1506), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7090] = 6,
    ACTIONS(1769), 1,
      anon_sym_LBRACK,
    ACTIONS(1771), 1,
      anon_sym_DOT,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1767), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1765), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [7139] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1777), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1775), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7182] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1781), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1779), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7225] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1785), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1783), 31,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [7268] = 6,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(482), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(484), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [7317] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1793), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1791), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7360] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1797), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1795), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7403] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1801), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1799), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7446] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1805), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1803), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7489] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1809), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1807), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [7532] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1813), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1811), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7575] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1817), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1815), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7618] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1821), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1819), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7661] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1484), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1482), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7704] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1825), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1823), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7747] = 5,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1235), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1830), 3,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
    ACTIONS(1827), 11,
      anon_sym_AT,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
    ACTIONS(1233), 17,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
  [7794] = 6,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1834), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1832), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [7843] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1838), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1836), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7886] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1842), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1840), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7929] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1846), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1844), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [7972] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1850), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1848), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8015] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1854), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1852), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8058] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1858), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1856), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8101] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1862), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1860), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [8144] = 11,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(1323), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 17,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_when,
  [8203] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1866), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1864), 31,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [8246] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1870), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1868), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8289] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1874), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1872), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [8332] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1878), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1876), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8375] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1882), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1880), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8418] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1886), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1884), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8461] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1890), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1888), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8504] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1894), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1892), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8547] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1898), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1896), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8590] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1480), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1478), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8633] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1902), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1900), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8676] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1906), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1904), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8719] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1910), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1908), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8762] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1914), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1912), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8805] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1323), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8848] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1918), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1916), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8891] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1922), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1920), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [8934] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1926), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1924), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [8977] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1930), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1928), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9020] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1934), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1932), 31,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9063] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1938), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1936), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9106] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1942), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1940), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9149] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1946), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1944), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9192] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1950), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1948), 31,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_open,
      anon_sym_module,
      anon_sym_static,
      anon_sym_package,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9235] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1954), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1952), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9278] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1958), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1956), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9321] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1962), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1960), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9364] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1966), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1964), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9407] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1970), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1968), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9450] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1974), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1972), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9493] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1978), 6,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1976), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9536] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1982), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1980), 25,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
      anon_sym_SEMI,
  [9579] = 5,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(1191), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1235), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1233), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9625] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1986), 5,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1984), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9667] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1990), 5,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1988), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9709] = 5,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    STATE(565), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1235), 3,
      anon_sym_LT,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(1233), 28,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_record,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [9755] = 6,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1419), 1,
      anon_sym_DASH_GT,
    STATE(531), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1323), 9,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
      anon_sym_COLON,
    ACTIONS(1319), 20,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_when,
  [9802] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(582), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1498), 10,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1496), 15,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_throws,
      sym_this,
      sym_identifier,
  [9851] = 7,
    ACTIONS(1493), 1,
      anon_sym_AT,
    ACTIONS(1994), 1,
      anon_sym_LBRACK,
    STATE(582), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1488), 10,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1486), 15,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_throws,
      sym_this,
      sym_identifier,
  [9900] = 17,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1997), 1,
      sym_identifier,
    ACTIONS(1999), 1,
      anon_sym_final,
    STATE(437), 1,
      sym__unannotated_type,
    STATE(446), 1,
      sym_generic_type,
    STATE(456), 1,
      sym_scoped_type_identifier,
    STATE(479), 1,
      sym__type,
    STATE(482), 1,
      sym_annotated_type,
    STATE(594), 1,
      sym_record_pattern,
    STATE(1284), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2003), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2005), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(473), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(776), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2001), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [9969] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2009), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2007), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10009] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2013), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2011), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10049] = 4,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1834), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1832), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10091] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1767), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1765), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10131] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2019), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2017), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10171] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2023), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2021), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10211] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2027), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2025), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10251] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(482), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(484), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10291] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2031), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2029), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10331] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2035), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2033), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10371] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2039), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2037), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10411] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2043), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2041), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10451] = 16,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1997), 1,
      sym_identifier,
    STATE(437), 1,
      sym__unannotated_type,
    STATE(446), 1,
      sym_generic_type,
    STATE(456), 1,
      sym_scoped_type_identifier,
    STATE(478), 1,
      sym__type,
    STATE(482), 1,
      sym_annotated_type,
    STATE(608), 1,
      sym_record_pattern,
    STATE(1284), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2003), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2005), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(473), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(776), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2001), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [10517] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2047), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2045), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10557] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2051), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2049), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10597] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2055), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2053), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10637] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2059), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2057), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10677] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2063), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2061), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10717] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2067), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2065), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10757] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2071), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_non_DASHsealed,
      anon_sym_ATinterface,
    ACTIONS(2069), 27,
      anon_sym_final,
      anon_sym_class,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_AT,
      anon_sym_static,
      anon_sym_enum,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_interface,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [10797] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2013), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2011), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10837] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2075), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2073), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10877] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2079), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2077), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10917] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1834), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1832), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10957] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2083), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2081), 23,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [10997] = 4,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2087), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2085), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11039] = 15,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 10,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11102] = 16,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 9,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11167] = 15,
    ACTIONS(2087), 1,
      anon_sym_PIPE,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 10,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11230] = 6,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2087), 7,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2085), 18,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11275] = 5,
    ACTIONS(2118), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2115), 2,
      anon_sym_DASH_GT,
      anon_sym_when,
    ACTIONS(1715), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1713), 19,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
  [11318] = 12,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2087), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 13,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11375] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2121), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11444] = 14,
    ACTIONS(2087), 1,
      anon_sym_PIPE,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 11,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11505] = 7,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2087), 5,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2085), 18,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11552] = 9,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2087), 4,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
    ACTIONS(2085), 16,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_instanceof,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11603] = 13,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2087), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 11,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11662] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2033), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11731] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2127), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_when,
      anon_sym_SEMI,
  [11800] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(1323), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1323), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1319), 19,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
      anon_sym_SEMI,
  [11842] = 6,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2131), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(626), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1725), 10,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
    ACTIONS(2129), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [11886] = 22,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2161), 1,
      anon_sym_COMMA,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(2165), 1,
      anon_sym_when,
    STATE(963), 1,
      aux_sym_argument_list_repeat1,
    STATE(1268), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2159), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [11962] = 6,
    ACTIONS(2170), 1,
      anon_sym_AT,
    ACTIONS(2173), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(626), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(1700), 10,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
    ACTIONS(2167), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [12006] = 6,
    ACTIONS(2176), 1,
      anon_sym_LPAREN,
    ACTIONS(2178), 1,
      anon_sym_DOT,
    STATE(688), 1,
      sym_annotation_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1638), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1634), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [12050] = 22,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2159), 1,
      anon_sym_COLON,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    ACTIONS(2182), 1,
      anon_sym_when,
    STATE(996), 1,
      aux_sym_argument_list_repeat1,
    STATE(1268), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [12125] = 4,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2115), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1715), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(1713), 18,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
  [12164] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1602), 5,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1600), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [12201] = 14,
    ACTIONS(2087), 1,
      anon_sym_PIPE,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 8,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12259] = 6,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2087), 7,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2085), 15,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12301] = 18,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2033), 4,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_when,
  [12367] = 13,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2087), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 8,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12423] = 9,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2087), 4,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
    ACTIONS(2085), 13,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12471] = 18,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2127), 4,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_when,
  [12537] = 12,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2087), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 10,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12591] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1576), 12,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1574), 15,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_throws,
      sym_this,
      sym_identifier,
  [12627] = 18,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2121), 4,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_when,
  [12693] = 15,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 7,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [12753] = 18,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2184), 4,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_when,
  [12819] = 6,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(2186), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(482), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(484), 16,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
  [12861] = 14,
    ACTIONS(510), 1,
      sym_underscore_pattern,
    ACTIONS(2188), 1,
      sym_identifier,
    ACTIONS(2190), 1,
      anon_sym_RPAREN,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(835), 1,
      sym__unannotated_type,
    STATE(870), 1,
      sym_generic_type,
    STATE(1284), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1150), 2,
      sym_record_pattern,
      sym_record_pattern_component,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [12919] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2184), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_when,
  [12985] = 15,
    ACTIONS(2087), 1,
      anon_sym_PIPE,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 7,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [13045] = 7,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2087), 5,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(2085), 15,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [13089] = 16,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2085), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_DASH_GT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_when,
  [13151] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1488), 12,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1486), 15,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_default,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      anon_sym_throws,
      sym_this,
      sym_identifier,
  [13187] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2192), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [13253] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1950), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1948), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [13288] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2194), 1,
      anon_sym_RPAREN,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    STATE(1099), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13357] = 15,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2198), 1,
      anon_sym_GT,
    ACTIONS(2200), 1,
      anon_sym_QMARK,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1105), 2,
      sym_wildcard,
      sym__type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(768), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [13416] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(2204), 1,
      anon_sym_SEMI,
    STATE(1068), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13485] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2206), 1,
      anon_sym_RPAREN,
    STATE(1109), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13554] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2208), 1,
      anon_sym_RPAREN,
    STATE(1086), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13623] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2210), 1,
      anon_sym_RPAREN,
    STATE(1104), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13692] = 4,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(480), 2,
      anon_sym_while,
      anon_sym_else,
    ACTIONS(482), 8,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT_GT,
    ACTIONS(484), 16,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_instanceof,
      anon_sym_QMARK,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_SEMI,
  [13729] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2212), 1,
      anon_sym_RPAREN,
    STATE(1083), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13798] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2214), 1,
      anon_sym_RPAREN,
    STATE(1122), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13867] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(2216), 1,
      anon_sym_SEMI,
    STATE(1146), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [13936] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2218), 1,
      anon_sym_RPAREN,
    STATE(1094), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14005] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2220), 1,
      anon_sym_RPAREN,
    STATE(1080), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14074] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1785), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1783), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [14109] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2222), 1,
      anon_sym_RPAREN,
    STATE(1111), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14178] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2224), 1,
      anon_sym_RPAREN,
    STATE(1095), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14247] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2226), 1,
      anon_sym_RPAREN,
    STATE(1096), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14316] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2228), 1,
      anon_sym_RPAREN,
    STATE(1069), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14385] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2230), 1,
      anon_sym_RPAREN,
    STATE(1112), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14454] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1934), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1932), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [14489] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2232), 1,
      anon_sym_RPAREN,
    STATE(1088), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14558] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2234), 1,
      anon_sym_RPAREN,
    STATE(1093), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14627] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2236), 1,
      anon_sym_RPAREN,
    STATE(1127), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14696] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(2238), 1,
      sym_identifier,
    ACTIONS(2240), 1,
      anon_sym_RBRACE,
    ACTIONS(2242), 1,
      anon_sym_COMMA,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    STATE(990), 1,
      sym_enum_constant,
    STATE(1334), 1,
      sym_enum_body_declarations,
    STATE(1335), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [14749] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2246), 1,
      anon_sym_RPAREN,
    STATE(1116), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14818] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2248), 1,
      anon_sym_RPAREN,
    STATE(1118), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14887] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2250), 1,
      anon_sym_RPAREN,
    STATE(1084), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [14956] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(2252), 1,
      anon_sym_SEMI,
    STATE(1067), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15025] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2254), 1,
      anon_sym_RPAREN,
    STATE(1082), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15094] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2256), 1,
      anon_sym_RPAREN,
    STATE(1119), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15163] = 13,
    ACTIONS(510), 1,
      sym_underscore_pattern,
    ACTIONS(2188), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(835), 1,
      sym__unannotated_type,
    STATE(870), 1,
      sym_generic_type,
    STATE(1284), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1225), 2,
      sym_record_pattern,
      sym_record_pattern_component,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [15218] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2258), 1,
      anon_sym_RPAREN,
    STATE(1126), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15287] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2260), 1,
      anon_sym_RBRACE,
    ACTIONS(2262), 1,
      anon_sym_COMMA,
    STATE(1139), 1,
      aux_sym_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15356] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2264), 1,
      anon_sym_RPAREN,
    STATE(1108), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15425] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    ACTIONS(2266), 1,
      anon_sym_RPAREN,
    STATE(1154), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15494] = 15,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2200), 1,
      anon_sym_QMARK,
    ACTIONS(2268), 1,
      anon_sym_GT,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1173), 2,
      sym_wildcard,
      sym__type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(768), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [15553] = 20,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2270), 1,
      anon_sym_RPAREN,
    STATE(1098), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [15622] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2272), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [15687] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1866), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_non_DASHsealed,
    ACTIONS(1864), 23,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [15722] = 16,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2274), 1,
      sym_identifier,
    ACTIONS(2276), 1,
      anon_sym_DOT,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2280), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2282), 1,
      sym_this,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1100), 1,
      aux_sym_receiver_parameter_repeat1,
    STATE(1231), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1512), 3,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_COLON_COLON,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [15782] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1592), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1594), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [15816] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(2238), 1,
      sym_identifier,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    ACTIONS(2284), 1,
      anon_sym_RBRACE,
    STATE(1115), 1,
      sym_enum_constant,
    STATE(1330), 1,
      sym_enum_body_declarations,
    STATE(1335), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [15866] = 14,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2200), 1,
      anon_sym_QMARK,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1202), 2,
      sym_wildcard,
      sym__type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(768), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [15922] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1596), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1598), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [15956] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2286), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [16020] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2288), 1,
      anon_sym_DOT,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 11,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1525), 11,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [16060] = 18,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(2290), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_class,
    ACTIONS(2294), 1,
      anon_sym_enum,
    ACTIONS(2296), 1,
      anon_sym_record,
    ACTIONS(2298), 1,
      anon_sym_ATinterface,
    ACTIONS(2300), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(783), 1,
      sym_type_parameters,
    STATE(784), 1,
      sym__unannotated_type,
    STATE(1007), 1,
      sym__constructor_declarator,
    STATE(1079), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [16124] = 19,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2302), 1,
      anon_sym_COLON,
    ACTIONS(2304), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [16190] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(2238), 1,
      sym_identifier,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    ACTIONS(2306), 1,
      anon_sym_RBRACE,
    STATE(1115), 1,
      sym_enum_constant,
    STATE(1299), 1,
      sym_enum_body_declarations,
    STATE(1335), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [16240] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2308), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [16304] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2310), 1,
      anon_sym_DOT,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1317), 11,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1341), 11,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [16344] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2312), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [16408] = 5,
    ACTIONS(1235), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(2314), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1827), 10,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
    ACTIONS(1233), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [16446] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2317), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [16510] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2192), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [16574] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2319), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [16638] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1604), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1606), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [16672] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1588), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1590), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [16706] = 18,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2133), 1,
      anon_sym_AMP,
    ACTIONS(2141), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2143), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_SLASH,
    ACTIONS(2151), 1,
      anon_sym_PIPE,
    ACTIONS(2153), 1,
      anon_sym_CARET,
    ACTIONS(2157), 1,
      anon_sym_GT_GT,
    ACTIONS(2163), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2135), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2137), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2139), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2145), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2147), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2155), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(2321), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [16770] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2323), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [16833] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2325), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [16896] = 14,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1049), 1,
      sym__type,
    STATE(1318), 1,
      sym_type_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [16951] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1566), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1568), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [16984] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2327), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17047] = 14,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1049), 1,
      sym__type,
    STATE(1223), 1,
      sym_type_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [17102] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2329), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17165] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2331), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17228] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2333), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17291] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2335), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17354] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2337), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17417] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2339), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17480] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2341), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17543] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2343), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17606] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2345), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17669] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17732] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2349), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17795] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2351), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17858] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2353), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [17921] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1616), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1618), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [17954] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1608), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1610), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [17987] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2355), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18050] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2357), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18113] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2359), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18176] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2361), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18239] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2363), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18302] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2365), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18365] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2367), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18428] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2369), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18491] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2371), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18554] = 17,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_class,
    ACTIONS(2294), 1,
      anon_sym_enum,
    ACTIONS(2296), 1,
      anon_sym_record,
    ACTIONS(2298), 1,
      anon_sym_ATinterface,
    ACTIONS(2300), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(775), 1,
      sym_type_parameters,
    STATE(790), 1,
      sym__unannotated_type,
    STATE(1079), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [18615] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2321), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18678] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2373), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18741] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2375), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18804] = 14,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2377), 1,
      anon_sym_open,
    ACTIONS(2379), 1,
      anon_sym_module,
    ACTIONS(2381), 1,
      anon_sym_package,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(820), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [18859] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2383), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [18922] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1570), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1572), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [18955] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2385), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [19018] = 17,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_class,
    ACTIONS(2294), 1,
      anon_sym_enum,
    ACTIONS(2296), 1,
      anon_sym_record,
    ACTIONS(2298), 1,
      anon_sym_ATinterface,
    ACTIONS(2300), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(775), 1,
      sym_type_parameters,
    STATE(785), 1,
      sym__unannotated_type,
    STATE(1079), 1,
      sym__method_header,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19079] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2387), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [19142] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2389), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [19205] = 14,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1049), 1,
      sym__type,
    STATE(1248), 1,
      sym_type_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19260] = 18,
    ACTIONS(2089), 1,
      anon_sym_AMP,
    ACTIONS(2101), 1,
      anon_sym_SLASH,
    ACTIONS(2103), 1,
      anon_sym_PIPE,
    ACTIONS(2105), 1,
      anon_sym_CARET,
    ACTIONS(2109), 1,
      anon_sym_GT_GT,
    ACTIONS(2111), 1,
      anon_sym_instanceof,
    ACTIONS(2113), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_QMARK,
    ACTIONS(2391), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2015), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2091), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2093), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2095), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
  [19323] = 6,
    ACTIONS(2393), 1,
      anon_sym_LPAREN,
    ACTIONS(2395), 1,
      anon_sym_DOT,
    STATE(795), 1,
      sym_annotation_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1638), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1634), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [19361] = 16,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1338), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [19419] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1274), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19471] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1614), 11,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1612), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
  [19503] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1035), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19555] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1525), 11,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1523), 12,
      anon_sym_DOT,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
  [19587] = 4,
    ACTIONS(2288), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1523), 11,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_record,
      sym_this,
      sym_identifier,
    ACTIONS(1525), 11,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
  [19621] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1018), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19673] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1140), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19725] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1153), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19777] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1203), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19829] = 13,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(829), 1,
      sym__unannotated_type,
    STATE(905), 1,
      sym_annotated_type,
    STATE(1017), 1,
      sym__type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(774), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [19881] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(422), 9,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(420), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [19912] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1043), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1351), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [19965] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(468), 1,
      anon_sym_non_DASHsealed,
    ACTIONS(2238), 1,
      sym_identifier,
    STATE(1115), 1,
      sym_enum_constant,
    STATE(1335), 1,
      sym_modifiers,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(624), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_modifiers_repeat1,
    ACTIONS(462), 13,
      anon_sym_final,
      anon_sym_default,
      anon_sym_synchronized,
      anon_sym_static,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_private,
      anon_sym_abstract,
      anon_sym_strictfp,
      anon_sym_native,
      anon_sym_transient,
      anon_sym_volatile,
      anon_sym_sealed,
  [20006] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1338), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20059] = 12,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2401), 1,
      anon_sym_QMARK,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(820), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20108] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1040), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1351), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20161] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1602), 9,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1600), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [20192] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1046), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1351), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20245] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2403), 1,
      sym_identifier,
    STATE(808), 1,
      sym_type_arguments,
    STATE(999), 1,
      sym_scoped_type_identifier,
    STATE(1148), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2405), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1234), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20293] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2274), 1,
      sym_identifier,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2280), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2282), 1,
      sym_this,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1100), 1,
      aux_sym_receiver_parameter_repeat1,
    STATE(1231), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20345] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(820), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20391] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(823), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(791), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20437] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2407), 1,
      sym_identifier,
    STATE(432), 1,
      sym__unannotated_type,
    STATE(456), 1,
      sym_scoped_type_identifier,
    STATE(463), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2003), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2005), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(473), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2001), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20483] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(880), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20529] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1356), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20581] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1298), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20633] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(848), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20679] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2409), 1,
      sym_identifier,
    STATE(808), 1,
      sym_type_arguments,
    STATE(841), 1,
      sym_scoped_type_identifier,
    STATE(859), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2411), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(872), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20727] = 14,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_class,
    ACTIONS(2294), 1,
      anon_sym_enum,
    ACTIONS(2296), 1,
      anon_sym_record,
    ACTIONS(2298), 1,
      anon_sym_ATinterface,
    ACTIONS(2300), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(804), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20779] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2413), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(823), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(791), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20825] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1314), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20877] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1303), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [20929] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2415), 1,
      sym_identifier,
    STATE(806), 1,
      sym_type_arguments,
    STATE(992), 1,
      sym_scoped_type_identifier,
    STATE(1156), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2417), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1218), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(772), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [20977] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2419), 1,
      sym_identifier,
    STATE(806), 1,
      sym_type_arguments,
    STATE(845), 1,
      sym_scoped_type_identifier,
    STATE(851), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2421), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(864), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(788), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21025] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2423), 1,
      sym_identifier,
    STATE(808), 1,
      sym_type_arguments,
    STATE(842), 1,
      sym_scoped_type_identifier,
    STATE(856), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2425), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(863), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21073] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2427), 1,
      sym_identifier,
    STATE(806), 1,
      sym_type_arguments,
    STATE(839), 1,
      sym_scoped_type_identifier,
    STATE(855), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2429), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(874), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(781), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21121] = 14,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2397), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(854), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1034), 1,
      sym__method_declarator,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1309), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21173] = 11,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(822), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21219] = 5,
    ACTIONS(2435), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2433), 2,
      anon_sym_LT,
      anon_sym_QMARK,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2431), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [21252] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1950), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1948), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [21281] = 13,
    ACTIONS(1405), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_class,
    ACTIONS(2294), 1,
      anon_sym_enum,
    ACTIONS(2298), 1,
      anon_sym_ATinterface,
    ACTIONS(2300), 1,
      anon_sym_interface,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(798), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21330] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1866), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1864), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [21359] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1934), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1932), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [21388] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1057), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1365), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21435] = 13,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2438), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(869), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1303), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21484] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1785), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_SEMI,
      anon_sym_AT,
    ACTIONS(1783), 13,
      anon_sym_open,
      anon_sym_module,
      anon_sym_package,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [21513] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1321), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21560] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1041), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1365), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21607] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1052), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1365), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21654] = 13,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      sym_underscore_pattern,
    ACTIONS(2440), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(867), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1298), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21703] = 12,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1081), 1,
      sym_variable_declarator,
    STATE(1309), 1,
      sym__variable_declarator_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21750] = 10,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2442), 1,
      sym_identifier,
    STATE(985), 1,
      sym_scoped_type_identifier,
    STATE(1141), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2444), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1256), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21792] = 10,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2446), 1,
      sym_identifier,
    STATE(1000), 1,
      sym_scoped_type_identifier,
    STATE(1106), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2448), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1251), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(805), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21834] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2450), 1,
      sym_identifier,
    ACTIONS(2452), 1,
      anon_sym_new,
    ACTIONS(2454), 1,
      sym_this,
    ACTIONS(2456), 1,
      sym_super,
    STATE(427), 1,
      sym__reserved_identifier,
    STATE(554), 1,
      sym__unqualified_object_creation_expression,
    STATE(555), 1,
      sym_string_literal,
    STATE(924), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(550), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21884] = 10,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2458), 1,
      sym_identifier,
    STATE(981), 1,
      sym_scoped_type_identifier,
    STATE(1143), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2460), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1252), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(811), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [21926] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2462), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1276), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [21970] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2450), 1,
      sym_identifier,
    ACTIONS(2452), 1,
      anon_sym_new,
    ACTIONS(2454), 1,
      sym_this,
    ACTIONS(2464), 1,
      sym_super,
    STATE(427), 1,
      sym__reserved_identifier,
    STATE(554), 1,
      sym__unqualified_object_creation_expression,
    STATE(555), 1,
      sym_string_literal,
    STATE(902), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(550), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22020] = 10,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2466), 1,
      sym_identifier,
    STATE(998), 1,
      sym_scoped_type_identifier,
    STATE(1064), 1,
      sym_generic_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(2468), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(1194), 2,
      sym_integral_type,
      sym_floating_point_type,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22062] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2280), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1231), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22106] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2452), 1,
      anon_sym_new,
    ACTIONS(2470), 1,
      sym_identifier,
    ACTIONS(2472), 1,
      sym_this,
    ACTIONS(2474), 1,
      sym_super,
    STATE(492), 1,
      sym__reserved_identifier,
    STATE(554), 1,
      sym__unqualified_object_creation_expression,
    STATE(555), 1,
      sym_string_literal,
    STATE(924), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(550), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22156] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    ACTIONS(2476), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1132), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22199] = 11,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    ACTIONS(2478), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1296), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22242] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2480), 1,
      anon_sym_DOT,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1525), 6,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1523), 9,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_this,
      sym_identifier,
  [22275] = 10,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1337), 1,
      anon_sym_DOT,
    ACTIONS(1341), 1,
      anon_sym_AT,
    STATE(531), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1334), 2,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
    ACTIONS(2483), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [22316] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2487), 1,
      anon_sym_PIPE,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(886), 1,
      aux_sym_catch_type_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2485), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [22355] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1377), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22396] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1504), 9,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_implements,
      anon_sym_permits,
  [22430] = 10,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(515), 1,
      sym_block,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1193), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1341), 2,
      anon_sym_LBRACK,
      anon_sym_AT,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [22470] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2493), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1024), 1,
      sym__method_declarator,
    STATE(1282), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22510] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2493), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1062), 1,
      sym__method_declarator,
    STATE(1282), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22550] = 10,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(542), 1,
      sym_block,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1193), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1341), 2,
      anon_sym_LBRACK,
      anon_sym_AT,
    ACTIONS(1317), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [22590] = 10,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(818), 1,
      sym__unannotated_type,
    STATE(887), 1,
      sym_catch_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22630] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2497), 1,
      anon_sym_PIPE,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2495), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [22666] = 4,
    ACTIONS(2480), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1525), 6,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_AT,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1523), 9,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_this,
      sym_identifier,
  [22693] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(826), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22730] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(1512), 8,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_implements,
      anon_sym_permits,
  [22763] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2501), 3,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_AT,
    ACTIONS(2499), 13,
      anon_sym_extends,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [22788] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(819), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22825] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(801), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22862] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(802), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22899] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(809), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [22936] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2478), 1,
      sym_identifier,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1296), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [22973] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2505), 3,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_AT,
    ACTIONS(2503), 13,
      anon_sym_extends,
      anon_sym_implements,
      anon_sym_permits,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [22998] = 9,
    ACTIONS(1405), 1,
      sym_identifier,
    STATE(695), 1,
      sym_scoped_type_identifier,
    STATE(758), 1,
      sym_generic_type,
    STATE(797), 1,
      sym__unannotated_type,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(89), 2,
      anon_sym_float,
      anon_sym_double,
    ACTIONS(91), 2,
      sym_boolean_type,
      sym_void_type,
    STATE(757), 3,
      sym_array_type,
      sym_integral_type,
      sym_floating_point_type,
    ACTIONS(87), 5,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
  [23035] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(495), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1249), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(871), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23077] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(745), 1,
      sym_type_arguments,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(447), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23119] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(485), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1253), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(448), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23161] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(745), 1,
      sym_type_arguments,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(449), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23203] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(745), 1,
      sym_type_arguments,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(866), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23245] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(495), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1249), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(450), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23287] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(485), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1253), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(865), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23329] = 12,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(745), 1,
      sym_type_arguments,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(873), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23371] = 4,
    ACTIONS(2511), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2192), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(1830), 10,
      anon_sym_byte,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_char,
      anon_sym_float,
      anon_sym_double,
      sym_boolean_type,
      sym_void_type,
      sym_identifier,
  [23397] = 8,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(606), 1,
      sym_record_pattern_body,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1341), 2,
      anon_sym_LBRACK,
      anon_sym_AT,
    ACTIONS(1317), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [23430] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2513), 1,
      sym_identifier,
    ACTIONS(2515), 1,
      sym_this,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1135), 1,
      aux_sym_receiver_parameter_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1504), 3,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_COLON_COLON,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23467] = 8,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(712), 1,
      sym_type_arguments,
    STATE(1262), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1341), 2,
      anon_sym_LBRACK,
      anon_sym_AT,
    ACTIONS(1317), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [23500] = 9,
    ACTIONS(2517), 1,
      anon_sym_RBRACE,
    ACTIONS(2519), 1,
      anon_sym_requires,
    ACTIONS(2521), 1,
      anon_sym_exports,
    ACTIONS(2523), 1,
      anon_sym_opens,
    ACTIONS(2525), 1,
      anon_sym_uses,
    ACTIONS(2527), 1,
      anon_sym_provides,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(860), 2,
      sym_module_directive,
      aux_sym_module_body_repeat1,
    STATE(953), 5,
      sym_requires_module_directive,
      sym_exports_module_directive,
      sym_opens_module_directive,
      sym_uses_module_directive,
      sym_provides_module_directive,
  [23534] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(873), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23570] = 6,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    ACTIONS(2529), 1,
      anon_sym_DOT,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1525), 3,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_AT,
    ACTIONS(1523), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [23598] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(991), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
    ACTIONS(2532), 5,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
  [23628] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(875), 1,
      sym_formal_parameters,
    STATE(991), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2532), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23662] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(447), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23698] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(866), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23734] = 8,
    ACTIONS(2534), 1,
      sym_identifier,
    STATE(878), 1,
      aux_sym_requires_module_directive_repeat1,
    STATE(910), 1,
      sym_requires_modifier,
    STATE(1292), 1,
      sym_scoped_identifier,
    STATE(1293), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2536), 2,
      anon_sym_transitive,
      anon_sym_static,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [23766] = 7,
    ACTIONS(2538), 1,
      sym_identifier,
    STATE(857), 1,
      aux_sym_requires_module_directive_repeat1,
    STATE(910), 1,
      sym_requires_modifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2536), 2,
      anon_sym_transitive,
      anon_sym_static,
    STATE(1205), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [23796] = 10,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(449), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23832] = 9,
    ACTIONS(2540), 1,
      anon_sym_RBRACE,
    ACTIONS(2542), 1,
      anon_sym_requires,
    ACTIONS(2545), 1,
      anon_sym_exports,
    ACTIONS(2548), 1,
      anon_sym_opens,
    ACTIONS(2551), 1,
      anon_sym_uses,
    ACTIONS(2554), 1,
      anon_sym_provides,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(860), 2,
      sym_module_directive,
      aux_sym_module_body_repeat1,
    STATE(953), 5,
      sym_requires_module_directive,
      sym_exports_module_directive,
      sym_opens_module_directive,
      sym_uses_module_directive,
      sym_provides_module_directive,
  [23866] = 9,
    ACTIONS(2519), 1,
      anon_sym_requires,
    ACTIONS(2521), 1,
      anon_sym_exports,
    ACTIONS(2523), 1,
      anon_sym_opens,
    ACTIONS(2525), 1,
      anon_sym_uses,
    ACTIONS(2527), 1,
      anon_sym_provides,
    ACTIONS(2557), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(850), 2,
      sym_module_directive,
      aux_sym_module_body_repeat1,
    STATE(953), 5,
      sym_requires_module_directive,
      sym_exports_module_directive,
      sym_opens_module_directive,
      sym_uses_module_directive,
      sym_provides_module_directive,
  [23900] = 8,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2470), 1,
      sym_identifier,
    ACTIONS(2472), 1,
      sym_this,
    ACTIONS(2474), 1,
      sym_super,
    STATE(492), 1,
      sym__reserved_identifier,
    STATE(924), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [23931] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(866), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23964] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(873), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [23997] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(520), 1,
      sym_dimensions,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1535), 2,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24028] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(538), 1,
      sym_dimensions,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1539), 2,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24059] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2559), 1,
      anon_sym_LPAREN,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(991), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2532), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24090] = 8,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2450), 1,
      sym_identifier,
    ACTIONS(2454), 1,
      sym_this,
    ACTIONS(2456), 1,
      sym_super,
    STATE(427), 1,
      sym__reserved_identifier,
    STATE(924), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24121] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2561), 1,
      anon_sym_LPAREN,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(991), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2532), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24152] = 6,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1525), 2,
      anon_sym_LBRACK,
      anon_sym_AT,
    ACTIONS(1523), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [24179] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(525), 1,
      sym_dimensions,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1543), 2,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24210] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(491), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1254), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(449), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24243] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(547), 1,
      sym_dimensions,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1529), 2,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(464), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24274] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2507), 1,
      anon_sym_LBRACK,
    STATE(494), 1,
      sym_argument_list,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1247), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(447), 2,
      sym_dimensions_expr,
      aux_sym_array_creation_expression_repeat2,
    STATE(969), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24307] = 7,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1157), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2563), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_throws,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24335] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2565), 1,
      anon_sym_default,
    ACTIONS(2567), 1,
      anon_sym_SEMI,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1063), 1,
      sym_dimensions,
    STATE(1316), 1,
      sym__default_value,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24367] = 7,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2569), 1,
      sym_identifier,
    ACTIONS(2571), 1,
      sym_this,
    STATE(496), 1,
      sym__reserved_identifier,
    STATE(922), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24395] = 5,
    STATE(878), 1,
      aux_sym_requires_module_directive_repeat1,
    STATE(910), 1,
      sym_requires_modifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2575), 2,
      anon_sym_transitive,
      anon_sym_static,
    ACTIONS(2573), 7,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [24419] = 6,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1206), 1,
      sym_variable_declarator,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24445] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2513), 1,
      sym_identifier,
    ACTIONS(2515), 1,
      sym_this,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    STATE(1135), 1,
      aux_sym_receiver_parameter_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24477] = 7,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(2578), 1,
      sym_identifier,
    ACTIONS(2580), 1,
      sym_this,
    STATE(429), 1,
      sym__reserved_identifier,
    STATE(922), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24505] = 9,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2565), 1,
      anon_sym_default,
    ACTIONS(2582), 1,
      anon_sym_SEMI,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(1071), 1,
      sym_dimensions,
    STATE(1360), 1,
      sym__default_value,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24537] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2584), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(991), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2532), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24567] = 6,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1210), 1,
      sym_variable_declarator,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24593] = 6,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1031), 1,
      sym__variable_declarator_id,
    STATE(1272), 1,
      sym_variable_declarator,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24619] = 4,
    ACTIONS(2487), 1,
      anon_sym_PIPE,
    STATE(889), 1,
      aux_sym_catch_type_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2586), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [24640] = 5,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1328), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24663] = 5,
    STATE(853), 1,
      sym__reserved_identifier,
    STATE(1311), 1,
      sym__variable_declarator_id,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2278), 2,
      sym_underscore_pattern,
      sym_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24686] = 4,
    ACTIONS(2588), 1,
      anon_sym_PIPE,
    STATE(889), 1,
      aux_sym_catch_type_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2495), 8,
      sym_underscore_pattern,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [24707] = 5,
    ACTIONS(2591), 1,
      sym_identifier,
    ACTIONS(2593), 1,
      anon_sym_static,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1198), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24730] = 6,
    ACTIONS(2595), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2600), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2597), 2,
      aux_sym__multiline_string_fragment_token1,
      aux_sym__multiline_string_fragment_token2,
    ACTIONS(2603), 2,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(891), 4,
      sym__multiline_string_fragment,
      sym_string_interpolation,
      sym__escape_sequence,
      aux_sym__multiline_string_literal_repeat1,
  [24755] = 11,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2608), 1,
      anon_sym_extends,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(338), 1,
      sym_class_body,
    STATE(923), 1,
      sym_type_parameters,
    STATE(976), 1,
      sym_superclass,
    STATE(1027), 1,
      sym_super_interfaces,
    STATE(1216), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [24790] = 11,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2608), 1,
      anon_sym_extends,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(274), 1,
      sym_class_body,
    STATE(919), 1,
      sym_type_parameters,
    STATE(955), 1,
      sym_superclass,
    STATE(1051), 1,
      sym_super_interfaces,
    STATE(1260), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [24825] = 6,
    ACTIONS(2614), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2618), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2616), 2,
      aux_sym__multiline_string_fragment_token1,
      aux_sym__multiline_string_fragment_token2,
    ACTIONS(2620), 2,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
    STATE(891), 4,
      sym__multiline_string_fragment,
      sym_string_interpolation,
      sym__escape_sequence,
      aux_sym__multiline_string_literal_repeat1,
  [24850] = 8,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(1512), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1992), 1,
      anon_sym_LBRACK,
    ACTIONS(2399), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_dimensions_repeat1,
    STATE(755), 1,
      sym_dimensions,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(965), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [24879] = 6,
    ACTIONS(2618), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2622), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2616), 2,
      aux_sym__multiline_string_fragment_token1,
      aux_sym__multiline_string_fragment_token2,
    ACTIONS(2624), 2,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
    STATE(894), 4,
      sym__multiline_string_fragment,
      sym_string_interpolation,
      sym__escape_sequence,
      aux_sym__multiline_string_literal_repeat1,
  [24904] = 4,
    ACTIONS(2626), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1038), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24924] = 4,
    ACTIONS(2628), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1078), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24944] = 4,
    ACTIONS(2630), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1160), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24964] = 4,
    ACTIONS(2632), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1163), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [24984] = 4,
    ACTIONS(2634), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1207), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25004] = 5,
    ACTIONS(2636), 1,
      sym_identifier,
    ACTIONS(2638), 1,
      sym_super,
    STATE(1220), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25026] = 4,
    ACTIONS(2640), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1162), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25046] = 4,
    ACTIONS(2642), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(627), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(1241), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25066] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1512), 9,
      anon_sym_RPAREN,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_implements,
      anon_sym_permits,
  [25082] = 4,
    ACTIONS(2644), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1291), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25102] = 4,
    ACTIONS(2646), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1197), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25122] = 4,
    ACTIONS(2648), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1279), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25142] = 4,
    ACTIONS(2650), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1036), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25162] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2652), 9,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_transitive,
      anon_sym_static,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [25178] = 4,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1113), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25198] = 4,
    ACTIONS(2656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1074), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25218] = 4,
    ACTIONS(2658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1208), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25238] = 8,
    ACTIONS(2660), 1,
      anon_sym_RBRACE,
    ACTIONS(2662), 1,
      anon_sym_case,
    ACTIONS(2664), 1,
      anon_sym_default,
    STATE(4), 1,
      aux_sym_switch_block_statement_group_repeat1,
    STATE(1242), 1,
      sym_switch_label,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(935), 2,
      sym_switch_block_statement_group,
      aux_sym_switch_block_repeat1,
    STATE(952), 2,
      sym_switch_rule,
      aux_sym_switch_block_repeat2,
  [25266] = 4,
    ACTIONS(2666), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(1037), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25286] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2668), 9,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_transitive,
      anon_sym_static,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
      sym_identifier,
  [25302] = 4,
    ACTIONS(2670), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(484), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25322] = 4,
    ACTIONS(2672), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(752), 2,
      sym_scoped_identifier,
      sym__reserved_identifier,
    ACTIONS(2674), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25342] = 9,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2608), 1,
      anon_sym_extends,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(325), 1,
      sym_class_body,
    STATE(950), 1,
      sym_superclass,
    STATE(1047), 1,
      sym_super_interfaces,
    STATE(1246), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [25371] = 4,
    ACTIONS(2676), 1,
      sym_identifier,
    STATE(1278), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25390] = 9,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2678), 1,
      anon_sym_extends,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(311), 1,
      sym_interface_body,
    STATE(977), 1,
      sym_type_parameters,
    STATE(1020), 1,
      sym_extends_interfaces,
    STATE(1213), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [25419] = 4,
    ACTIONS(2682), 1,
      sym_identifier,
    STATE(1295), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25438] = 9,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2608), 1,
      anon_sym_extends,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(331), 1,
      sym_class_body,
    STATE(961), 1,
      sym_superclass,
    STATE(1033), 1,
      sym_super_interfaces,
    STATE(1236), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [25467] = 4,
    ACTIONS(2636), 1,
      sym_identifier,
    STATE(1220), 1,
      sym__reserved_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(69), 6,
      anon_sym_yield,
      anon_sym_open,
      anon_sym_module,
      anon_sym_with,
      anon_sym_sealed,
      anon_sym_record,
  [25486] = 9,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2678), 1,
      anon_sym_extends,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(304), 1,
      sym_interface_body,
    STATE(975), 1,
      sym_type_parameters,
    STATE(1058), 1,
      sym_extends_interfaces,
    STATE(1286), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [25515] = 6,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(993), 1,
      sym_argument_list,
    STATE(1155), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2684), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [25537] = 7,
    ACTIONS(2686), 1,
      anon_sym_RBRACE,
    ACTIONS(2688), 1,
      anon_sym_case,
    ACTIONS(2691), 1,
      anon_sym_default,
    STATE(4), 1,
      aux_sym_switch_block_statement_group_repeat1,
    STATE(1315), 1,
      sym_switch_label,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(927), 2,
      sym_switch_block_statement_group,
      aux_sym_switch_block_repeat1,
  [25561] = 5,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2694), 1,
      sym_identifier,
    STATE(1073), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(940), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25581] = 5,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2694), 1,
      sym_identifier,
    STATE(1261), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(940), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25601] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2696), 7,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_implements,
      anon_sym_throws,
  [25615] = 6,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(983), 1,
      sym_argument_list,
    STATE(1114), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2698), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [25637] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2700), 7,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_implements,
      anon_sym_throws,
  [25651] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2702), 7,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_implements,
      anon_sym_throws,
  [25665] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2704), 7,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_implements,
      anon_sym_throws,
  [25679] = 7,
    ACTIONS(2664), 1,
      anon_sym_default,
    ACTIONS(2706), 1,
      anon_sym_RBRACE,
    ACTIONS(2708), 1,
      anon_sym_case,
    STATE(4), 1,
      aux_sym_switch_block_statement_group_repeat1,
    STATE(1315), 1,
      sym_switch_label,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(927), 2,
      sym_switch_block_statement_group,
      aux_sym_switch_block_repeat1,
  [25703] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2710), 7,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_implements,
      anon_sym_throws,
  [25717] = 4,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2712), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25734] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2714), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25747] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2716), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25764] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2718), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25781] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2720), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25798] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2722), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25811] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2724), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25824] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2726), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25837] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2726), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25850] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2726), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25863] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2728), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25876] = 4,
    ACTIONS(2433), 1,
      anon_sym_LBRACK,
    ACTIONS(2730), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25893] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2733), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(951), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25910] = 7,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(362), 1,
      sym_class_body,
    STATE(1014), 1,
      sym_super_interfaces,
    STATE(1190), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [25933] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2735), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [25950] = 6,
    ACTIONS(2662), 1,
      anon_sym_case,
    ACTIONS(2664), 1,
      anon_sym_default,
    ACTIONS(2706), 1,
      anon_sym_RBRACE,
    STATE(1372), 1,
      sym_switch_label,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(962), 2,
      sym_switch_rule,
      aux_sym_switch_block_repeat2,
  [25971] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2737), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25984] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2739), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [25997] = 7,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(322), 1,
      sym_class_body,
    STATE(1045), 1,
      sym_super_interfaces,
    STATE(1245), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26020] = 4,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2741), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26037] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2743), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [26050] = 6,
    ACTIONS(2745), 1,
      anon_sym_DQUOTE,
    ACTIONS(2747), 1,
      sym_string_fragment,
    ACTIONS(2750), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2753), 1,
      sym_escape_sequence,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(958), 2,
      sym_string_interpolation,
      aux_sym__string_literal_repeat1,
  [26071] = 4,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2756), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26088] = 2,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2758), 6,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      aux_sym__multiline_string_fragment_token1,
      aux_sym__multiline_string_fragment_token2,
      anon_sym_BSLASH_LBRACE,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [26101] = 7,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(366), 1,
      sym_class_body,
    STATE(1030), 1,
      sym_super_interfaces,
    STATE(1277), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26124] = 6,
    ACTIONS(2760), 1,
      anon_sym_RBRACE,
    ACTIONS(2762), 1,
      anon_sym_case,
    ACTIONS(2765), 1,
      anon_sym_default,
    STATE(1372), 1,
      sym_switch_label,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(962), 2,
      sym_switch_rule,
      aux_sym_switch_block_repeat2,
  [26145] = 6,
    ACTIONS(2161), 1,
      anon_sym_COMMA,
    ACTIONS(2165), 1,
      anon_sym_when,
    STATE(982), 1,
      aux_sym_argument_list_repeat1,
    STATE(1217), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2768), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [26166] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2770), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(941), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26183] = 4,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2772), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26200] = 6,
    ACTIONS(2774), 1,
      anon_sym_DQUOTE,
    ACTIONS(2776), 1,
      sym_string_fragment,
    ACTIONS(2778), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2780), 1,
      sym_escape_sequence,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(958), 2,
      sym_string_interpolation,
      aux_sym__string_literal_repeat1,
  [26221] = 2,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2782), 6,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      aux_sym__multiline_string_fragment_token1,
      aux_sym__multiline_string_fragment_token2,
      anon_sym_BSLASH_LBRACE,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [26234] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2784), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [26247] = 4,
    ACTIONS(464), 1,
      anon_sym_AT,
    ACTIONS(2786), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(948), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26264] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2788), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [26277] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(939), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26294] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2792), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [26307] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2794), 6,
      anon_sym_RBRACE,
      anon_sym_requires,
      anon_sym_exports,
      anon_sym_opens,
      anon_sym_uses,
      anon_sym_provides,
  [26320] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2796), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(792), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26337] = 7,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2678), 1,
      anon_sym_extends,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym_interface_body,
    STATE(1029), 1,
      sym_extends_interfaces,
    STATE(1185), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26360] = 7,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(351), 1,
      sym_class_body,
    STATE(1032), 1,
      sym_super_interfaces,
    STATE(1238), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26383] = 7,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2678), 1,
      anon_sym_extends,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(370), 1,
      sym_interface_body,
    STATE(1019), 1,
      sym_extends_interfaces,
    STATE(1255), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26406] = 4,
    ACTIONS(424), 1,
      anon_sym_AT,
    ACTIONS(2798), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(974), 4,
      sym__annotation,
      sym_marker_annotation,
      sym_annotation,
      aux_sym_array_creation_expression_repeat1,
  [26423] = 6,
    ACTIONS(2778), 1,
      anon_sym_BSLASH_LBRACE,
    ACTIONS(2800), 1,
      anon_sym_DQUOTE,
    ACTIONS(2802), 1,
      sym_string_fragment,
    ACTIONS(2804), 1,
      sym_escape_sequence,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(966), 2,
      sym_string_interpolation,
      aux_sym__string_literal_repeat1,
  [26444] = 3,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2483), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(1319), 3,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
  [26458] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(497), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26478] = 4,
    ACTIONS(2806), 1,
      anon_sym_COMMA,
    STATE(982), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2184), 3,
      anon_sym_DASH_GT,
      anon_sym_COLON,
      anon_sym_when,
  [26494] = 4,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(1090), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2809), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [26510] = 5,
    ACTIONS(2811), 1,
      anon_sym_catch,
    ACTIONS(2813), 1,
      anon_sym_finally,
    STATE(272), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    STATE(185), 2,
      sym_catch_clause,
      aux_sym_try_statement_repeat1,
  [26528] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(486), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26548] = 4,
    ACTIONS(2815), 1,
      anon_sym_COMMA,
    STATE(986), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2818), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_permits,
  [26564] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(499), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26584] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(495), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26604] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(531), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(1319), 3,
      anon_sym_LBRACK,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
  [26620] = 6,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    ACTIONS(2820), 1,
      anon_sym_RBRACE,
    ACTIONS(2822), 1,
      anon_sym_COMMA,
    STATE(994), 1,
      aux_sym_enum_body_repeat1,
    STATE(1337), 1,
      sym_enum_body_declarations,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26640] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2824), 5,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
  [26652] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26672] = 4,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(1117), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2826), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [26688] = 6,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    ACTIONS(2306), 1,
      anon_sym_RBRACE,
    ACTIONS(2828), 1,
      anon_sym_COMMA,
    STATE(1059), 1,
      aux_sym_enum_body_repeat1,
    STATE(1299), 1,
      sym_enum_body_declarations,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26708] = 4,
    STATE(1258), 1,
      sym__wildcard_bounds,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2830), 2,
      anon_sym_GT,
      anon_sym_COMMA,
    ACTIONS(2832), 2,
      anon_sym_extends,
      sym_super,
  [26724] = 6,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    ACTIONS(2182), 1,
      anon_sym_when,
    ACTIONS(2768), 1,
      anon_sym_COLON,
    STATE(1004), 1,
      aux_sym_argument_list_repeat1,
    STATE(1217), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26744] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(493), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26764] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(489), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26784] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26804] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(498), 1,
      sym_argument_list,
    STATE(745), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26824] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(490), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26844] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(488), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26864] = 6,
    ACTIONS(252), 1,
      anon_sym_LT,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2491), 1,
      anon_sym_DOT,
    STATE(485), 1,
      sym_argument_list,
    STATE(712), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26884] = 4,
    ACTIONS(2834), 1,
      anon_sym_COMMA,
    STATE(1004), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2184), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_when,
  [26900] = 4,
    STATE(1200), 1,
      sym__wildcard_bounds,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2832), 2,
      anon_sym_extends,
      sym_super,
    ACTIONS(2837), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [26916] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    STATE(282), 1,
      sym_class_body,
    STATE(1222), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26933] = 5,
    ACTIONS(2839), 1,
      anon_sym_LBRACE,
    ACTIONS(2841), 1,
      anon_sym_throws,
    STATE(572), 1,
      sym_constructor_body,
    STATE(1289), 1,
      sym_throws,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26950] = 4,
    ACTIONS(2843), 1,
      anon_sym_AMP,
    STATE(1008), 1,
      aux_sym_type_bound_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2846), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [26965] = 4,
    ACTIONS(252), 1,
      anon_sym_LT,
    STATE(1285), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2848), 2,
      anon_sym_new,
      sym_identifier,
  [26980] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    STATE(385), 1,
      sym_class_body,
    STATE(1196), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [26997] = 5,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2850), 1,
      anon_sym_DOT,
    STATE(1323), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27014] = 4,
    ACTIONS(2852), 1,
      anon_sym_COMMA,
    STATE(986), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2854), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [27029] = 4,
    ACTIONS(2852), 1,
      anon_sym_COMMA,
    STATE(986), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2856), 2,
      anon_sym_LBRACE,
      anon_sym_permits,
  [27044] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(363), 1,
      sym_class_body,
    STATE(1266), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27061] = 5,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(1055), 1,
      sym_formal_parameters,
    STATE(1287), 1,
      sym_type_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27078] = 5,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2858), 1,
      anon_sym_LBRACE,
    STATE(292), 1,
      sym_enum_body,
    STATE(1288), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27095] = 4,
    ACTIONS(2852), 1,
      anon_sym_COMMA,
    STATE(1012), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2860), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [27110] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2818), 4,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_permits,
  [27121] = 5,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(340), 1,
      sym_interface_body,
    STATE(1177), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27138] = 5,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(357), 1,
      sym_interface_body,
    STATE(1176), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27155] = 4,
    ACTIONS(2862), 1,
      anon_sym_AMP,
    STATE(1008), 1,
      aux_sym_type_bound_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2864), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [27170] = 4,
    ACTIONS(2868), 1,
      anon_sym_extends,
    STATE(1235), 1,
      sym_type_bound,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2866), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [27185] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    STATE(349), 1,
      sym_class_body,
    STATE(1240), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27202] = 4,
    ACTIONS(2841), 1,
      anon_sym_throws,
    STATE(1257), 1,
      sym_throws,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2870), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [27217] = 5,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2872), 1,
      anon_sym_RPAREN,
    ACTIONS(2874), 1,
      anon_sym_AMP,
    STATE(1091), 1,
      aux_sym_cast_expression_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27234] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2876), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27245] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(365), 1,
      sym_class_body,
    STATE(1239), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27262] = 3,
    ACTIONS(2878), 1,
      sym_string_fragment,
    ACTIONS(2606), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2758), 3,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_LBRACE,
      sym_escape_sequence,
  [27275] = 5,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(267), 1,
      sym_interface_body,
    STATE(1230), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27292] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(321), 1,
      sym_class_body,
    STATE(1219), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27309] = 3,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27322] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(356), 1,
      sym_class_body,
    STATE(1241), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27339] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(364), 1,
      sym_class_body,
    STATE(1259), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27356] = 4,
    ACTIONS(2841), 1,
      anon_sym_throws,
    STATE(1280), 1,
      sym_throws,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2884), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [27371] = 4,
    ACTIONS(2862), 1,
      anon_sym_AMP,
    STATE(1021), 1,
      aux_sym_type_bound_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2886), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [27386] = 5,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2888), 1,
      anon_sym_COMMA,
    ACTIONS(2890), 1,
      anon_sym_SEMI,
    STATE(1065), 1,
      aux_sym_provides_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27403] = 5,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    ACTIONS(2894), 1,
      anon_sym_SEMI,
    STATE(1075), 1,
      aux_sym_exports_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27420] = 5,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    ACTIONS(2896), 1,
      anon_sym_SEMI,
    STATE(1066), 1,
      aux_sym_exports_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27437] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2898), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27448] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2900), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27463] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2902), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27478] = 4,
    ACTIONS(2868), 1,
      anon_sym_extends,
    STATE(1250), 1,
      sym_type_bound,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2904), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [27493] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2906), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27508] = 4,
    ACTIONS(2165), 1,
      anon_sym_when,
    STATE(1268), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2159), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [27523] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(386), 1,
      sym_class_body,
    STATE(1186), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27540] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2908), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27555] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(377), 1,
      sym_class_body,
    STATE(1189), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27572] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2910), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27583] = 4,
    ACTIONS(2852), 1,
      anon_sym_COMMA,
    STATE(1013), 1,
      aux_sym_type_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2912), 2,
      anon_sym_LBRACE,
      anon_sym_permits,
  [27598] = 5,
    ACTIONS(2839), 1,
      anon_sym_LBRACE,
    ACTIONS(2841), 1,
      anon_sym_throws,
    STATE(513), 1,
      sym_constructor_body,
    STATE(1192), 1,
      sym_throws,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27615] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2612), 1,
      anon_sym_permits,
    STATE(319), 1,
      sym_class_body,
    STATE(1244), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27632] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2914), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27647] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2916), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27658] = 5,
    ACTIONS(2918), 1,
      anon_sym_LPAREN,
    ACTIONS(2920), 1,
      anon_sym_LBRACE,
    STATE(984), 1,
      sym_block,
    STATE(1195), 1,
      sym_resource_specification,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27675] = 5,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(2610), 1,
      anon_sym_implements,
    STATE(334), 1,
      sym_class_body,
    STATE(1224), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27692] = 5,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2874), 1,
      anon_sym_AMP,
    ACTIONS(2922), 1,
      anon_sym_RPAREN,
    STATE(1128), 1,
      aux_sym_cast_expression_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27709] = 4,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    ACTIONS(2924), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2880), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27724] = 5,
    ACTIONS(2612), 1,
      anon_sym_permits,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(376), 1,
      sym_interface_body,
    STATE(1221), 1,
      sym_permits,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27741] = 4,
    ACTIONS(2928), 1,
      anon_sym_COMMA,
    STATE(1059), 1,
      aux_sym_enum_body_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2926), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [27756] = 5,
    ACTIONS(2610), 1,
      anon_sym_implements,
    ACTIONS(2858), 1,
      anon_sym_LBRACE,
    STATE(336), 1,
      sym_enum_body,
    STATE(1215), 1,
      sym_super_interfaces,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27773] = 5,
    ACTIONS(19), 1,
      anon_sym_LT,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(1010), 1,
      sym_formal_parameters,
    STATE(1214), 1,
      sym_type_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27790] = 4,
    ACTIONS(2841), 1,
      anon_sym_throws,
    STATE(1212), 1,
      sym_throws,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2931), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [27805] = 4,
    ACTIONS(2565), 1,
      anon_sym_default,
    ACTIONS(2933), 1,
      anon_sym_SEMI,
    STATE(1350), 1,
      sym__default_value,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27819] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(489), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27833] = 4,
    ACTIONS(2888), 1,
      anon_sym_COMMA,
    ACTIONS(2935), 1,
      anon_sym_SEMI,
    STATE(1142), 1,
      aux_sym_provides_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27847] = 4,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    ACTIONS(2937), 1,
      anon_sym_SEMI,
    STATE(1076), 1,
      aux_sym_exports_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27861] = 4,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(2939), 1,
      anon_sym_SEMI,
    STATE(1171), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27875] = 4,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(2941), 1,
      anon_sym_SEMI,
    STATE(1171), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27889] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2943), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27903] = 4,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(2945), 1,
      anon_sym_SEMI,
    STATE(389), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27917] = 4,
    ACTIONS(2565), 1,
      anon_sym_default,
    ACTIONS(2947), 1,
      anon_sym_SEMI,
    STATE(1362), 1,
      sym__default_value,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27931] = 4,
    ACTIONS(2949), 1,
      anon_sym_RPAREN,
    ACTIONS(2951), 1,
      anon_sym_COMMA,
    STATE(1101), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27945] = 4,
    ACTIONS(2953), 1,
      anon_sym_GT,
    ACTIONS(2955), 1,
      anon_sym_COMMA,
    STATE(1103), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27959] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2957), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [27971] = 4,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    ACTIONS(2959), 1,
      anon_sym_SEMI,
    STATE(1076), 1,
      aux_sym_exports_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27985] = 4,
    ACTIONS(2961), 1,
      anon_sym_COMMA,
    ACTIONS(2964), 1,
      anon_sym_SEMI,
    STATE(1076), 1,
      aux_sym_exports_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [27999] = 4,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2966), 1,
      anon_sym_LBRACE,
    STATE(286), 1,
      sym_module_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28013] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2968), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [28025] = 4,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    ACTIONS(2970), 1,
      anon_sym_SEMI,
    STATE(394), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28039] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2972), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28053] = 4,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    ACTIONS(2976), 1,
      anon_sym_SEMI,
    STATE(1123), 1,
      aux_sym__variable_declarator_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28067] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28081] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2980), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28095] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2982), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28109] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2984), 1,
      anon_sym_DOT,
    STATE(1357), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28123] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2986), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28137] = 4,
    ACTIONS(2988), 1,
      anon_sym_RPAREN,
    ACTIONS(2990), 1,
      anon_sym_COMMA,
    STATE(1087), 1,
      aux_sym_record_pattern_body_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28151] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(2993), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28165] = 4,
    ACTIONS(1346), 1,
      anon_sym_COMMA,
    ACTIONS(2995), 1,
      anon_sym_RPAREN,
    STATE(1124), 1,
      aux_sym_inferred_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28179] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2997), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [28189] = 4,
    ACTIONS(2874), 1,
      anon_sym_AMP,
    ACTIONS(2999), 1,
      anon_sym_RPAREN,
    STATE(1129), 1,
      aux_sym_cast_expression_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28203] = 4,
    ACTIONS(3001), 1,
      anon_sym_RBRACE,
    ACTIONS(3003), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_element_value_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28217] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3006), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28231] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3008), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28245] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3010), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28259] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3012), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28273] = 4,
    ACTIONS(3014), 1,
      anon_sym_RPAREN,
    ACTIONS(3016), 1,
      anon_sym_COMMA,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28287] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3019), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28301] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3021), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28315] = 4,
    ACTIONS(2513), 1,
      sym_identifier,
    ACTIONS(2515), 1,
      sym_this,
    STATE(1130), 1,
      aux_sym_receiver_parameter_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28329] = 4,
    ACTIONS(1620), 1,
      anon_sym_RPAREN,
    ACTIONS(2951), 1,
      anon_sym_COMMA,
    STATE(1133), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28343] = 4,
    ACTIONS(2317), 1,
      anon_sym_RBRACE,
    ACTIONS(3023), 1,
      anon_sym_COMMA,
    STATE(1102), 1,
      aux_sym_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28357] = 4,
    ACTIONS(2955), 1,
      anon_sym_COMMA,
    ACTIONS(3026), 1,
      anon_sym_GT,
    STATE(1136), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28371] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3028), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28385] = 4,
    ACTIONS(3030), 1,
      anon_sym_GT,
    ACTIONS(3032), 1,
      anon_sym_COMMA,
    STATE(1138), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28399] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(498), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28413] = 4,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1787), 1,
      anon_sym_LBRACK,
    ACTIONS(1789), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28427] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3034), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28441] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3036), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28455] = 4,
    ACTIONS(3038), 1,
      anon_sym_RPAREN,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    STATE(1087), 1,
      aux_sym_record_pattern_body_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28469] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28483] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3044), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28497] = 4,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2966), 1,
      anon_sym_LBRACE,
    STATE(275), 1,
      sym_module_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28511] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3046), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [28521] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2926), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [28531] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3048), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28545] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3050), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [28555] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3052), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28569] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3054), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28583] = 4,
    ACTIONS(3056), 1,
      sym_identifier,
    ACTIONS(3058), 1,
      anon_sym_STAR,
    STATE(1327), 1,
      sym_asterisk,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28597] = 4,
    ACTIONS(3060), 1,
      anon_sym_RPAREN,
    ACTIONS(3062), 1,
      anon_sym_COMMA,
    STATE(1121), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28611] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3065), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28625] = 4,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    ACTIONS(3067), 1,
      anon_sym_SEMI,
    STATE(1158), 1,
      aux_sym__variable_declarator_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28639] = 4,
    ACTIONS(3069), 1,
      anon_sym_RPAREN,
    ACTIONS(3071), 1,
      anon_sym_COMMA,
    STATE(1124), 1,
      aux_sym_inferred_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28653] = 4,
    ACTIONS(518), 1,
      anon_sym_RBRACE,
    ACTIONS(3074), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_element_value_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28667] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3076), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28681] = 4,
    ACTIONS(2196), 1,
      anon_sym_COMMA,
    ACTIONS(3078), 1,
      anon_sym_RPAREN,
    STATE(1097), 1,
      aux_sym_for_statement_repeat2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28695] = 4,
    ACTIONS(2874), 1,
      anon_sym_AMP,
    ACTIONS(3080), 1,
      anon_sym_RPAREN,
    STATE(1129), 1,
      aux_sym_cast_expression_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28709] = 4,
    ACTIONS(3082), 1,
      anon_sym_RPAREN,
    ACTIONS(3084), 1,
      anon_sym_AMP,
    STATE(1129), 1,
      aux_sym_cast_expression_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28723] = 4,
    ACTIONS(3087), 1,
      sym_identifier,
    ACTIONS(3090), 1,
      sym_this,
    STATE(1130), 1,
      aux_sym_receiver_parameter_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28737] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3092), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [28747] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3094), 3,
      anon_sym_DASH_GT,
      anon_sym_COLON,
      anon_sym_when,
  [28757] = 4,
    ACTIONS(3096), 1,
      anon_sym_RPAREN,
    ACTIONS(3098), 1,
      anon_sym_COMMA,
    STATE(1133), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28771] = 4,
    ACTIONS(2951), 1,
      anon_sym_COMMA,
    ACTIONS(3101), 1,
      anon_sym_RPAREN,
    STATE(1161), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28785] = 4,
    ACTIONS(2513), 1,
      sym_identifier,
    ACTIONS(3103), 1,
      sym_this,
    STATE(1130), 1,
      aux_sym_receiver_parameter_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28799] = 4,
    ACTIONS(3105), 1,
      anon_sym_GT,
    ACTIONS(3107), 1,
      anon_sym_COMMA,
    STATE(1136), 1,
      aux_sym_type_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28813] = 4,
    ACTIONS(3110), 1,
      anon_sym_RPAREN,
    ACTIONS(3112), 1,
      anon_sym_SEMI,
    STATE(1144), 1,
      aux_sym_resource_specification_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28827] = 4,
    ACTIONS(3032), 1,
      anon_sym_COMMA,
    ACTIONS(3114), 1,
      anon_sym_GT,
    STATE(1164), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28841] = 4,
    ACTIONS(524), 1,
      anon_sym_RBRACE,
    ACTIONS(3116), 1,
      anon_sym_COMMA,
    STATE(1102), 1,
      aux_sym_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28855] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2846), 3,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_COMMA,
  [28865] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(486), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28879] = 4,
    ACTIONS(3118), 1,
      anon_sym_COMMA,
    ACTIONS(3121), 1,
      anon_sym_SEMI,
    STATE(1142), 1,
      aux_sym_provides_module_directive_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28893] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(497), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28907] = 4,
    ACTIONS(657), 1,
      anon_sym_RPAREN,
    ACTIONS(3123), 1,
      anon_sym_SEMI,
    STATE(1175), 1,
      aux_sym_resource_specification_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28921] = 4,
    ACTIONS(3125), 1,
      anon_sym_RPAREN,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    STATE(1121), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28935] = 4,
    ACTIONS(2202), 1,
      anon_sym_COMMA,
    ACTIONS(3129), 1,
      anon_sym_SEMI,
    STATE(1171), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28949] = 4,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    ACTIONS(3131), 1,
      anon_sym_RPAREN,
    STATE(1145), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28963] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(491), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28977] = 4,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    ACTIONS(3133), 1,
      anon_sym_RPAREN,
    STATE(1165), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [28991] = 4,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3135), 1,
      anon_sym_RPAREN,
    STATE(1110), 1,
      aux_sym_record_pattern_body_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29005] = 4,
    ACTIONS(3056), 1,
      sym_identifier,
    ACTIONS(3058), 1,
      anon_sym_STAR,
    STATE(1341), 1,
      sym_asterisk,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29019] = 4,
    ACTIONS(2244), 1,
      anon_sym_SEMI,
    ACTIONS(2820), 1,
      anon_sym_RBRACE,
    STATE(1337), 1,
      sym_enum_body_declarations,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29033] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3137), 3,
      anon_sym_LBRACE,
      anon_sym_implements,
      anon_sym_permits,
  [29043] = 4,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    ACTIONS(3139), 1,
      anon_sym_RPAREN,
    STATE(1004), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29057] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3141), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [29067] = 4,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    ACTIONS(2509), 1,
      anon_sym_DOT,
    STATE(494), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29081] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3143), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_throws,
  [29091] = 4,
    ACTIONS(3145), 1,
      anon_sym_COMMA,
    ACTIONS(3148), 1,
      anon_sym_SEMI,
    STATE(1158), 1,
      aux_sym__variable_declarator_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29105] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2272), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [29115] = 4,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(2966), 1,
      anon_sym_LBRACE,
    STATE(328), 1,
      sym_module_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29129] = 4,
    ACTIONS(2951), 1,
      anon_sym_COMMA,
    ACTIONS(3150), 1,
      anon_sym_RPAREN,
    STATE(1133), 1,
      aux_sym_formal_parameters_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29143] = 4,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3152), 1,
      anon_sym_SEMI,
    ACTIONS(3154), 1,
      anon_sym_to,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29157] = 4,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3156), 1,
      anon_sym_SEMI,
    ACTIONS(3158), 1,
      anon_sym_to,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29171] = 4,
    ACTIONS(3160), 1,
      anon_sym_GT,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    STATE(1164), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29185] = 4,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
    STATE(1121), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29199] = 4,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    ACTIONS(3167), 1,
      anon_sym_RPAREN,
    STATE(1121), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29213] = 4,
    ACTIONS(3169), 1,
      anon_sym_RBRACE,
    ACTIONS(3171), 1,
      anon_sym_COMMA,
    STATE(1125), 1,
      aux_sym_element_value_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29227] = 4,
    ACTIONS(2260), 1,
      anon_sym_RBRACE,
    ACTIONS(2262), 1,
      anon_sym_COMMA,
    STATE(1139), 1,
      aux_sym_array_initializer_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29241] = 4,
    ACTIONS(2159), 1,
      anon_sym_COLON,
    ACTIONS(2182), 1,
      anon_sym_when,
    STATE(1268), 1,
      sym_guard,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29255] = 4,
    ACTIONS(3032), 1,
      anon_sym_COMMA,
    ACTIONS(3173), 1,
      anon_sym_GT,
    STATE(1164), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29269] = 4,
    ACTIONS(3175), 1,
      anon_sym_COMMA,
    ACTIONS(3178), 1,
      anon_sym_SEMI,
    STATE(1171), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29283] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3180), 3,
      anon_sym_DASH_GT,
      anon_sym_COLON,
      anon_sym_when,
  [29293] = 4,
    ACTIONS(3032), 1,
      anon_sym_COMMA,
    ACTIONS(3182), 1,
      anon_sym_GT,
    STATE(1170), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29307] = 4,
    ACTIONS(3127), 1,
      anon_sym_COMMA,
    ACTIONS(3184), 1,
      anon_sym_RPAREN,
    STATE(1166), 1,
      aux_sym_annotation_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29321] = 4,
    ACTIONS(3186), 1,
      anon_sym_RPAREN,
    ACTIONS(3188), 1,
      anon_sym_SEMI,
    STATE(1175), 1,
      aux_sym_resource_specification_repeat1,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29335] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(337), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29346] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(310), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29357] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(1188), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29368] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(105), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29379] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3186), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [29388] = 3,
    ACTIONS(3191), 1,
      sym_identifier,
    ACTIONS(3193), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29399] = 3,
    ACTIONS(3195), 1,
      sym_identifier,
    ACTIONS(3197), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29410] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(91), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29421] = 3,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2850), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29432] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(271), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29443] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(347), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29454] = 3,
    ACTIONS(2949), 1,
      anon_sym_RPAREN,
    ACTIONS(3199), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29465] = 3,
    ACTIONS(3201), 1,
      anon_sym_LBRACE,
    STATE(113), 1,
      sym_switch_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29476] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(352), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29487] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29498] = 3,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    STATE(261), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29509] = 3,
    ACTIONS(2839), 1,
      anon_sym_LBRACE,
    STATE(511), 1,
      sym_constructor_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29520] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3203), 2,
      anon_sym_LBRACE,
      anon_sym_throws,
  [29529] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(489), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29540] = 3,
    ACTIONS(2920), 1,
      anon_sym_LBRACE,
    STATE(179), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29551] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(344), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29562] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3205), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29573] = 3,
    ACTIONS(3207), 1,
      anon_sym_DOT,
    ACTIONS(3209), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29584] = 3,
    ACTIONS(3211), 1,
      anon_sym_LBRACE,
    STATE(298), 1,
      sym_annotation_type_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29595] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3213), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [29604] = 3,
    ACTIONS(3215), 1,
      sym_identifier,
    STATE(1227), 1,
      sym_element_value_pair,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29615] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3160), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [29624] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3217), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [29633] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3219), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29642] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3221), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29653] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3223), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29662] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3225), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29673] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3227), 1,
      anon_sym_with,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29684] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(1359), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29695] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3229), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [29704] = 3,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3231), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29715] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3233), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [29724] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(359), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29735] = 3,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(1023), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29746] = 3,
    ACTIONS(2858), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym_enum_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29757] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29768] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3235), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [29777] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(494), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29788] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(256), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29799] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(561), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29810] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(265), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29821] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(382), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29832] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3237), 2,
      anon_sym_LBRACE,
      anon_sym_permits,
  [29841] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(281), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29852] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2988), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29861] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3001), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [29870] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3060), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29879] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3239), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29888] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(1336), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29899] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(372), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29910] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3241), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29919] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2317), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [29928] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3243), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [29937] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(491), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29948] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3245), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [29957] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(361), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29968] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(101), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29979] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(255), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [29990] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30001] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(312), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30012] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(314), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30023] = 3,
    ACTIONS(3247), 1,
      anon_sym_DASH_GT,
    ACTIONS(3249), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30034] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3251), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [30043] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(374), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30054] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(383), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30065] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(380), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30076] = 3,
    ACTIONS(516), 1,
      anon_sym_LBRACE,
    STATE(529), 1,
      sym_array_initializer,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30087] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3253), 2,
      anon_sym_LBRACE,
      anon_sym_permits,
  [30096] = 3,
    ACTIONS(516), 1,
      anon_sym_LBRACE,
    STATE(526), 1,
      sym_array_initializer,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30107] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3255), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [30116] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(498), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30127] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(497), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30138] = 3,
    ACTIONS(516), 1,
      anon_sym_LBRACE,
    STATE(536), 1,
      sym_array_initializer,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30149] = 3,
    ACTIONS(516), 1,
      anon_sym_LBRACE,
    STATE(540), 1,
      sym_array_initializer,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30160] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(342), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30171] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(486), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30182] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3257), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [30191] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2837), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [30200] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(315), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30211] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(318), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30222] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3105), 2,
      anon_sym_GT,
      anon_sym_COMMA,
  [30231] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3259), 2,
      anon_sym_LBRACE,
      anon_sym_throws,
  [30240] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3261), 2,
      sym_this,
      sym_super,
  [30249] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(32), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30260] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(34), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30271] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(268), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30282] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3096), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30291] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(2768), 2,
      anon_sym_DASH_GT,
      anon_sym_COLON,
  [30300] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(1319), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30311] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3263), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30320] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3090), 2,
      sym_this,
      sym_identifier,
  [30329] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3265), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30338] = 3,
    ACTIONS(1197), 1,
      anon_sym_while,
    ACTIONS(3267), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30349] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3269), 2,
      anon_sym_RPAREN,
      anon_sym_AMP,
  [30358] = 3,
    ACTIONS(2920), 1,
      anon_sym_LBRACE,
    STATE(248), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30369] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3271), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30378] = 3,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    STATE(317), 1,
      sym_class_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30389] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3069), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30398] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3273), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30409] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3275), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [30418] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3277), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30427] = 3,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(875), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30438] = 3,
    ACTIONS(3211), 1,
      anon_sym_LBRACE,
    STATE(320), 1,
      sym_annotation_type_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30449] = 3,
    ACTIONS(1516), 1,
      anon_sym_LPAREN,
    STATE(606), 1,
      sym_record_pattern_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30460] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3279), 2,
      anon_sym_new,
      sym_identifier,
  [30469] = 3,
    ACTIONS(2680), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym_interface_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30480] = 3,
    ACTIONS(2489), 1,
      anon_sym_LPAREN,
    STATE(1006), 1,
      sym_formal_parameters,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30491] = 3,
    ACTIONS(2858), 1,
      anon_sym_LBRACE,
    STATE(333), 1,
      sym_enum_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30502] = 3,
    ACTIONS(2839), 1,
      anon_sym_LBRACE,
    STATE(574), 1,
      sym_constructor_body,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30513] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3281), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30524] = 3,
    ACTIONS(3283), 1,
      anon_sym_DOT,
    ACTIONS(3285), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30535] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3287), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30546] = 3,
    ACTIONS(1640), 1,
      anon_sym_DOT,
    ACTIONS(3289), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30557] = 3,
    ACTIONS(35), 1,
      anon_sym_LBRACE,
    STATE(305), 1,
      sym_block,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30568] = 3,
    ACTIONS(1321), 1,
      anon_sym_LPAREN,
    STATE(516), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30579] = 2,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
    ACTIONS(3291), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [30588] = 3,
    ACTIONS(655), 1,
      anon_sym_LPAREN,
    STATE(103), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30599] = 2,
    ACTIONS(3293), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30607] = 2,
    ACTIONS(2284), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30615] = 2,
    ACTIONS(3056), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30623] = 2,
    ACTIONS(3295), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30631] = 2,
    ACTIONS(3297), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30639] = 2,
    ACTIONS(3299), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30647] = 2,
    ACTIONS(3301), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30655] = 2,
    ACTIONS(2984), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30663] = 2,
    ACTIONS(3303), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30671] = 2,
    ACTIONS(598), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30679] = 2,
    ACTIONS(3305), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30687] = 2,
    ACTIONS(3307), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30695] = 2,
    ACTIONS(3309), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30703] = 2,
    ACTIONS(3311), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30711] = 2,
    ACTIONS(3313), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30719] = 2,
    ACTIONS(2584), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30727] = 2,
    ACTIONS(3315), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30735] = 2,
    ACTIONS(3249), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30743] = 2,
    ACTIONS(3317), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30751] = 2,
    ACTIONS(3319), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30759] = 2,
    ACTIONS(3321), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30767] = 2,
    ACTIONS(3323), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30775] = 2,
    ACTIONS(3325), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30783] = 2,
    ACTIONS(3327), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30791] = 2,
    ACTIONS(3131), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30799] = 2,
    ACTIONS(3329), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30807] = 2,
    ACTIONS(3331), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30815] = 2,
    ACTIONS(3133), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30823] = 2,
    ACTIONS(3333), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30831] = 2,
    ACTIONS(3335), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30839] = 2,
    ACTIONS(3337), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30847] = 2,
    ACTIONS(3169), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30855] = 2,
    ACTIONS(3339), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30863] = 2,
    ACTIONS(3341), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30871] = 2,
    ACTIONS(3343), 1,
      anon_sym_module,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30879] = 2,
    ACTIONS(3345), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30887] = 2,
    ACTIONS(2820), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30895] = 2,
    ACTIONS(3347), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30903] = 2,
    ACTIONS(3349), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30911] = 2,
    ACTIONS(2306), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30919] = 2,
    ACTIONS(3351), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30927] = 2,
    ACTIONS(3353), 1,
      anon_sym_class,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30935] = 2,
    ACTIONS(542), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30943] = 2,
    ACTIONS(3355), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30951] = 2,
    ACTIONS(3357), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30959] = 2,
    ACTIONS(3359), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30967] = 2,
    ACTIONS(3361), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30975] = 2,
    ACTIONS(3363), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30983] = 2,
    ACTIONS(3365), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30991] = 2,
    ACTIONS(3367), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [30999] = 2,
    ACTIONS(620), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31007] = 2,
    ACTIONS(2260), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31015] = 2,
    ACTIONS(3369), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31023] = 2,
    ACTIONS(3371), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31031] = 2,
    ACTIONS(3184), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31039] = 2,
    ACTIONS(3373), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31047] = 2,
    ACTIONS(3375), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31055] = 2,
    ACTIONS(3377), 1,
      anon_sym_while,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31063] = 2,
    ACTIONS(3379), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31071] = 2,
    ACTIONS(3381), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31079] = 2,
    ACTIONS(592), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31087] = 2,
    ACTIONS(3383), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31095] = 2,
    ACTIONS(3385), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31103] = 2,
    ACTIONS(1773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31111] = 2,
    ACTIONS(3387), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31119] = 2,
    ACTIONS(1332), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31127] = 2,
    ACTIONS(3389), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31135] = 2,
    ACTIONS(3391), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31143] = 2,
    ACTIONS(3393), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31151] = 2,
    ACTIONS(3395), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31159] = 2,
    ACTIONS(3397), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31167] = 2,
    ACTIONS(3399), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31175] = 2,
    ACTIONS(3401), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31183] = 2,
    ACTIONS(3403), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31191] = 2,
    ACTIONS(3247), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31199] = 2,
    ACTIONS(3405), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31207] = 2,
    ACTIONS(3407), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31215] = 2,
    ACTIONS(3409), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31223] = 2,
    ACTIONS(3411), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
  [31231] = 2,
    ACTIONS(3413), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_line_comment,
      sym_block_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(405)] = 0,
  [SMALL_STATE(406)] = 70,
  [SMALL_STATE(407)] = 189,
  [SMALL_STATE(408)] = 308,
  [SMALL_STATE(409)] = 427,
  [SMALL_STATE(410)] = 546,
  [SMALL_STATE(411)] = 665,
  [SMALL_STATE(412)] = 754,
  [SMALL_STATE(413)] = 847,
  [SMALL_STATE(414)] = 942,
  [SMALL_STATE(415)] = 1049,
  [SMALL_STATE(416)] = 1136,
  [SMALL_STATE(417)] = 1243,
  [SMALL_STATE(418)] = 1350,
  [SMALL_STATE(419)] = 1437,
  [SMALL_STATE(420)] = 1523,
  [SMALL_STATE(421)] = 1609,
  [SMALL_STATE(422)] = 1695,
  [SMALL_STATE(423)] = 1781,
  [SMALL_STATE(424)] = 1846,
  [SMALL_STATE(425)] = 1940,
  [SMALL_STATE(426)] = 2034,
  [SMALL_STATE(427)] = 2128,
  [SMALL_STATE(428)] = 2189,
  [SMALL_STATE(429)] = 2256,
  [SMALL_STATE(430)] = 2317,
  [SMALL_STATE(431)] = 2381,
  [SMALL_STATE(432)] = 2445,
  [SMALL_STATE(433)] = 2510,
  [SMALL_STATE(434)] = 2565,
  [SMALL_STATE(435)] = 2620,
  [SMALL_STATE(436)] = 2675,
  [SMALL_STATE(437)] = 2750,
  [SMALL_STATE(438)] = 2815,
  [SMALL_STATE(439)] = 2881,
  [SMALL_STATE(440)] = 2939,
  [SMALL_STATE(441)] = 3005,
  [SMALL_STATE(442)] = 3078,
  [SMALL_STATE(443)] = 3143,
  [SMALL_STATE(444)] = 3206,
  [SMALL_STATE(445)] = 3275,
  [SMALL_STATE(446)] = 3338,
  [SMALL_STATE(447)] = 3396,
  [SMALL_STATE(448)] = 3460,
  [SMALL_STATE(449)] = 3524,
  [SMALL_STATE(450)] = 3588,
  [SMALL_STATE(451)] = 3652,
  [SMALL_STATE(452)] = 3703,
  [SMALL_STATE(453)] = 3754,
  [SMALL_STATE(454)] = 3805,
  [SMALL_STATE(455)] = 3858,
  [SMALL_STATE(456)] = 3909,
  [SMALL_STATE(457)] = 3966,
  [SMALL_STATE(458)] = 4019,
  [SMALL_STATE(459)] = 4074,
  [SMALL_STATE(460)] = 4125,
  [SMALL_STATE(461)] = 4182,
  [SMALL_STATE(462)] = 4233,
  [SMALL_STATE(463)] = 4284,
  [SMALL_STATE(464)] = 4336,
  [SMALL_STATE(465)] = 4394,
  [SMALL_STATE(466)] = 4444,
  [SMALL_STATE(467)] = 4526,
  [SMALL_STATE(468)] = 4576,
  [SMALL_STATE(469)] = 4626,
  [SMALL_STATE(470)] = 4676,
  [SMALL_STATE(471)] = 4726,
  [SMALL_STATE(472)] = 4776,
  [SMALL_STATE(473)] = 4826,
  [SMALL_STATE(474)] = 4875,
  [SMALL_STATE(475)] = 4924,
  [SMALL_STATE(476)] = 4973,
  [SMALL_STATE(477)] = 5022,
  [SMALL_STATE(478)] = 5096,
  [SMALL_STATE(479)] = 5150,
  [SMALL_STATE(480)] = 5204,
  [SMALL_STATE(481)] = 5275,
  [SMALL_STATE(482)] = 5338,
  [SMALL_STATE(483)] = 5385,
  [SMALL_STATE(484)] = 5458,
  [SMALL_STATE(485)] = 5510,
  [SMALL_STATE(486)] = 5559,
  [SMALL_STATE(487)] = 5608,
  [SMALL_STATE(488)] = 5659,
  [SMALL_STATE(489)] = 5708,
  [SMALL_STATE(490)] = 5757,
  [SMALL_STATE(491)] = 5806,
  [SMALL_STATE(492)] = 5855,
  [SMALL_STATE(493)] = 5904,
  [SMALL_STATE(494)] = 5953,
  [SMALL_STATE(495)] = 6002,
  [SMALL_STATE(496)] = 6051,
  [SMALL_STATE(497)] = 6100,
  [SMALL_STATE(498)] = 6149,
  [SMALL_STATE(499)] = 6198,
  [SMALL_STATE(500)] = 6247,
  [SMALL_STATE(501)] = 6291,
  [SMALL_STATE(502)] = 6335,
  [SMALL_STATE(503)] = 6387,
  [SMALL_STATE(504)] = 6431,
  [SMALL_STATE(505)] = 6475,
  [SMALL_STATE(506)] = 6519,
  [SMALL_STATE(507)] = 6563,
  [SMALL_STATE(508)] = 6607,
  [SMALL_STATE(509)] = 6651,
  [SMALL_STATE(510)] = 6703,
  [SMALL_STATE(511)] = 6746,
  [SMALL_STATE(512)] = 6789,
  [SMALL_STATE(513)] = 6832,
  [SMALL_STATE(514)] = 6875,
  [SMALL_STATE(515)] = 6918,
  [SMALL_STATE(516)] = 6961,
  [SMALL_STATE(517)] = 7004,
  [SMALL_STATE(518)] = 7047,
  [SMALL_STATE(519)] = 7090,
  [SMALL_STATE(520)] = 7139,
  [SMALL_STATE(521)] = 7182,
  [SMALL_STATE(522)] = 7225,
  [SMALL_STATE(523)] = 7268,
  [SMALL_STATE(524)] = 7317,
  [SMALL_STATE(525)] = 7360,
  [SMALL_STATE(526)] = 7403,
  [SMALL_STATE(527)] = 7446,
  [SMALL_STATE(528)] = 7489,
  [SMALL_STATE(529)] = 7532,
  [SMALL_STATE(530)] = 7575,
  [SMALL_STATE(531)] = 7618,
  [SMALL_STATE(532)] = 7661,
  [SMALL_STATE(533)] = 7704,
  [SMALL_STATE(534)] = 7747,
  [SMALL_STATE(535)] = 7794,
  [SMALL_STATE(536)] = 7843,
  [SMALL_STATE(537)] = 7886,
  [SMALL_STATE(538)] = 7929,
  [SMALL_STATE(539)] = 7972,
  [SMALL_STATE(540)] = 8015,
  [SMALL_STATE(541)] = 8058,
  [SMALL_STATE(542)] = 8101,
  [SMALL_STATE(543)] = 8144,
  [SMALL_STATE(544)] = 8203,
  [SMALL_STATE(545)] = 8246,
  [SMALL_STATE(546)] = 8289,
  [SMALL_STATE(547)] = 8332,
  [SMALL_STATE(548)] = 8375,
  [SMALL_STATE(549)] = 8418,
  [SMALL_STATE(550)] = 8461,
  [SMALL_STATE(551)] = 8504,
  [SMALL_STATE(552)] = 8547,
  [SMALL_STATE(553)] = 8590,
  [SMALL_STATE(554)] = 8633,
  [SMALL_STATE(555)] = 8676,
  [SMALL_STATE(556)] = 8719,
  [SMALL_STATE(557)] = 8762,
  [SMALL_STATE(558)] = 8805,
  [SMALL_STATE(559)] = 8848,
  [SMALL_STATE(560)] = 8891,
  [SMALL_STATE(561)] = 8934,
  [SMALL_STATE(562)] = 8977,
  [SMALL_STATE(563)] = 9020,
  [SMALL_STATE(564)] = 9063,
  [SMALL_STATE(565)] = 9106,
  [SMALL_STATE(566)] = 9149,
  [SMALL_STATE(567)] = 9192,
  [SMALL_STATE(568)] = 9235,
  [SMALL_STATE(569)] = 9278,
  [SMALL_STATE(570)] = 9321,
  [SMALL_STATE(571)] = 9364,
  [SMALL_STATE(572)] = 9407,
  [SMALL_STATE(573)] = 9450,
  [SMALL_STATE(574)] = 9493,
  [SMALL_STATE(575)] = 9536,
  [SMALL_STATE(576)] = 9579,
  [SMALL_STATE(577)] = 9625,
  [SMALL_STATE(578)] = 9667,
  [SMALL_STATE(579)] = 9709,
  [SMALL_STATE(580)] = 9755,
  [SMALL_STATE(581)] = 9802,
  [SMALL_STATE(582)] = 9851,
  [SMALL_STATE(583)] = 9900,
  [SMALL_STATE(584)] = 9969,
  [SMALL_STATE(585)] = 10009,
  [SMALL_STATE(586)] = 10049,
  [SMALL_STATE(587)] = 10091,
  [SMALL_STATE(588)] = 10131,
  [SMALL_STATE(589)] = 10171,
  [SMALL_STATE(590)] = 10211,
  [SMALL_STATE(591)] = 10251,
  [SMALL_STATE(592)] = 10291,
  [SMALL_STATE(593)] = 10331,
  [SMALL_STATE(594)] = 10371,
  [SMALL_STATE(595)] = 10411,
  [SMALL_STATE(596)] = 10451,
  [SMALL_STATE(597)] = 10517,
  [SMALL_STATE(598)] = 10557,
  [SMALL_STATE(599)] = 10597,
  [SMALL_STATE(600)] = 10637,
  [SMALL_STATE(601)] = 10677,
  [SMALL_STATE(602)] = 10717,
  [SMALL_STATE(603)] = 10757,
  [SMALL_STATE(604)] = 10797,
  [SMALL_STATE(605)] = 10837,
  [SMALL_STATE(606)] = 10877,
  [SMALL_STATE(607)] = 10917,
  [SMALL_STATE(608)] = 10957,
  [SMALL_STATE(609)] = 10997,
  [SMALL_STATE(610)] = 11039,
  [SMALL_STATE(611)] = 11102,
  [SMALL_STATE(612)] = 11167,
  [SMALL_STATE(613)] = 11230,
  [SMALL_STATE(614)] = 11275,
  [SMALL_STATE(615)] = 11318,
  [SMALL_STATE(616)] = 11375,
  [SMALL_STATE(617)] = 11444,
  [SMALL_STATE(618)] = 11505,
  [SMALL_STATE(619)] = 11552,
  [SMALL_STATE(620)] = 11603,
  [SMALL_STATE(621)] = 11662,
  [SMALL_STATE(622)] = 11731,
  [SMALL_STATE(623)] = 11800,
  [SMALL_STATE(624)] = 11842,
  [SMALL_STATE(625)] = 11886,
  [SMALL_STATE(626)] = 11962,
  [SMALL_STATE(627)] = 12006,
  [SMALL_STATE(628)] = 12050,
  [SMALL_STATE(629)] = 12125,
  [SMALL_STATE(630)] = 12164,
  [SMALL_STATE(631)] = 12201,
  [SMALL_STATE(632)] = 12259,
  [SMALL_STATE(633)] = 12301,
  [SMALL_STATE(634)] = 12367,
  [SMALL_STATE(635)] = 12423,
  [SMALL_STATE(636)] = 12471,
  [SMALL_STATE(637)] = 12537,
  [SMALL_STATE(638)] = 12591,
  [SMALL_STATE(639)] = 12627,
  [SMALL_STATE(640)] = 12693,
  [SMALL_STATE(641)] = 12753,
  [SMALL_STATE(642)] = 12819,
  [SMALL_STATE(643)] = 12861,
  [SMALL_STATE(644)] = 12919,
  [SMALL_STATE(645)] = 12985,
  [SMALL_STATE(646)] = 13045,
  [SMALL_STATE(647)] = 13089,
  [SMALL_STATE(648)] = 13151,
  [SMALL_STATE(649)] = 13187,
  [SMALL_STATE(650)] = 13253,
  [SMALL_STATE(651)] = 13288,
  [SMALL_STATE(652)] = 13357,
  [SMALL_STATE(653)] = 13416,
  [SMALL_STATE(654)] = 13485,
  [SMALL_STATE(655)] = 13554,
  [SMALL_STATE(656)] = 13623,
  [SMALL_STATE(657)] = 13692,
  [SMALL_STATE(658)] = 13729,
  [SMALL_STATE(659)] = 13798,
  [SMALL_STATE(660)] = 13867,
  [SMALL_STATE(661)] = 13936,
  [SMALL_STATE(662)] = 14005,
  [SMALL_STATE(663)] = 14074,
  [SMALL_STATE(664)] = 14109,
  [SMALL_STATE(665)] = 14178,
  [SMALL_STATE(666)] = 14247,
  [SMALL_STATE(667)] = 14316,
  [SMALL_STATE(668)] = 14385,
  [SMALL_STATE(669)] = 14454,
  [SMALL_STATE(670)] = 14489,
  [SMALL_STATE(671)] = 14558,
  [SMALL_STATE(672)] = 14627,
  [SMALL_STATE(673)] = 14696,
  [SMALL_STATE(674)] = 14749,
  [SMALL_STATE(675)] = 14818,
  [SMALL_STATE(676)] = 14887,
  [SMALL_STATE(677)] = 14956,
  [SMALL_STATE(678)] = 15025,
  [SMALL_STATE(679)] = 15094,
  [SMALL_STATE(680)] = 15163,
  [SMALL_STATE(681)] = 15218,
  [SMALL_STATE(682)] = 15287,
  [SMALL_STATE(683)] = 15356,
  [SMALL_STATE(684)] = 15425,
  [SMALL_STATE(685)] = 15494,
  [SMALL_STATE(686)] = 15553,
  [SMALL_STATE(687)] = 15622,
  [SMALL_STATE(688)] = 15687,
  [SMALL_STATE(689)] = 15722,
  [SMALL_STATE(690)] = 15782,
  [SMALL_STATE(691)] = 15816,
  [SMALL_STATE(692)] = 15866,
  [SMALL_STATE(693)] = 15922,
  [SMALL_STATE(694)] = 15956,
  [SMALL_STATE(695)] = 16020,
  [SMALL_STATE(696)] = 16060,
  [SMALL_STATE(697)] = 16124,
  [SMALL_STATE(698)] = 16190,
  [SMALL_STATE(699)] = 16240,
  [SMALL_STATE(700)] = 16304,
  [SMALL_STATE(701)] = 16344,
  [SMALL_STATE(702)] = 16408,
  [SMALL_STATE(703)] = 16446,
  [SMALL_STATE(704)] = 16510,
  [SMALL_STATE(705)] = 16574,
  [SMALL_STATE(706)] = 16638,
  [SMALL_STATE(707)] = 16672,
  [SMALL_STATE(708)] = 16706,
  [SMALL_STATE(709)] = 16770,
  [SMALL_STATE(710)] = 16833,
  [SMALL_STATE(711)] = 16896,
  [SMALL_STATE(712)] = 16951,
  [SMALL_STATE(713)] = 16984,
  [SMALL_STATE(714)] = 17047,
  [SMALL_STATE(715)] = 17102,
  [SMALL_STATE(716)] = 17165,
  [SMALL_STATE(717)] = 17228,
  [SMALL_STATE(718)] = 17291,
  [SMALL_STATE(719)] = 17354,
  [SMALL_STATE(720)] = 17417,
  [SMALL_STATE(721)] = 17480,
  [SMALL_STATE(722)] = 17543,
  [SMALL_STATE(723)] = 17606,
  [SMALL_STATE(724)] = 17669,
  [SMALL_STATE(725)] = 17732,
  [SMALL_STATE(726)] = 17795,
  [SMALL_STATE(727)] = 17858,
  [SMALL_STATE(728)] = 17921,
  [SMALL_STATE(729)] = 17954,
  [SMALL_STATE(730)] = 17987,
  [SMALL_STATE(731)] = 18050,
  [SMALL_STATE(732)] = 18113,
  [SMALL_STATE(733)] = 18176,
  [SMALL_STATE(734)] = 18239,
  [SMALL_STATE(735)] = 18302,
  [SMALL_STATE(736)] = 18365,
  [SMALL_STATE(737)] = 18428,
  [SMALL_STATE(738)] = 18491,
  [SMALL_STATE(739)] = 18554,
  [SMALL_STATE(740)] = 18615,
  [SMALL_STATE(741)] = 18678,
  [SMALL_STATE(742)] = 18741,
  [SMALL_STATE(743)] = 18804,
  [SMALL_STATE(744)] = 18859,
  [SMALL_STATE(745)] = 18922,
  [SMALL_STATE(746)] = 18955,
  [SMALL_STATE(747)] = 19018,
  [SMALL_STATE(748)] = 19079,
  [SMALL_STATE(749)] = 19142,
  [SMALL_STATE(750)] = 19205,
  [SMALL_STATE(751)] = 19260,
  [SMALL_STATE(752)] = 19323,
  [SMALL_STATE(753)] = 19361,
  [SMALL_STATE(754)] = 19419,
  [SMALL_STATE(755)] = 19471,
  [SMALL_STATE(756)] = 19503,
  [SMALL_STATE(757)] = 19555,
  [SMALL_STATE(758)] = 19587,
  [SMALL_STATE(759)] = 19621,
  [SMALL_STATE(760)] = 19673,
  [SMALL_STATE(761)] = 19725,
  [SMALL_STATE(762)] = 19777,
  [SMALL_STATE(763)] = 19829,
  [SMALL_STATE(764)] = 19881,
  [SMALL_STATE(765)] = 19912,
  [SMALL_STATE(766)] = 19965,
  [SMALL_STATE(767)] = 20006,
  [SMALL_STATE(768)] = 20059,
  [SMALL_STATE(769)] = 20108,
  [SMALL_STATE(770)] = 20161,
  [SMALL_STATE(771)] = 20192,
  [SMALL_STATE(772)] = 20245,
  [SMALL_STATE(773)] = 20293,
  [SMALL_STATE(774)] = 20345,
  [SMALL_STATE(775)] = 20391,
  [SMALL_STATE(776)] = 20437,
  [SMALL_STATE(777)] = 20483,
  [SMALL_STATE(778)] = 20529,
  [SMALL_STATE(779)] = 20581,
  [SMALL_STATE(780)] = 20633,
  [SMALL_STATE(781)] = 20679,
  [SMALL_STATE(782)] = 20727,
  [SMALL_STATE(783)] = 20779,
  [SMALL_STATE(784)] = 20825,
  [SMALL_STATE(785)] = 20877,
  [SMALL_STATE(786)] = 20929,
  [SMALL_STATE(787)] = 20977,
  [SMALL_STATE(788)] = 21025,
  [SMALL_STATE(789)] = 21073,
  [SMALL_STATE(790)] = 21121,
  [SMALL_STATE(791)] = 21173,
  [SMALL_STATE(792)] = 21219,
  [SMALL_STATE(793)] = 21252,
  [SMALL_STATE(794)] = 21281,
  [SMALL_STATE(795)] = 21330,
  [SMALL_STATE(796)] = 21359,
  [SMALL_STATE(797)] = 21388,
  [SMALL_STATE(798)] = 21435,
  [SMALL_STATE(799)] = 21484,
  [SMALL_STATE(800)] = 21513,
  [SMALL_STATE(801)] = 21560,
  [SMALL_STATE(802)] = 21607,
  [SMALL_STATE(803)] = 21654,
  [SMALL_STATE(804)] = 21703,
  [SMALL_STATE(805)] = 21750,
  [SMALL_STATE(806)] = 21792,
  [SMALL_STATE(807)] = 21834,
  [SMALL_STATE(808)] = 21884,
  [SMALL_STATE(809)] = 21926,
  [SMALL_STATE(810)] = 21970,
  [SMALL_STATE(811)] = 22020,
  [SMALL_STATE(812)] = 22062,
  [SMALL_STATE(813)] = 22106,
  [SMALL_STATE(814)] = 22156,
  [SMALL_STATE(815)] = 22199,
  [SMALL_STATE(816)] = 22242,
  [SMALL_STATE(817)] = 22275,
  [SMALL_STATE(818)] = 22316,
  [SMALL_STATE(819)] = 22355,
  [SMALL_STATE(820)] = 22396,
  [SMALL_STATE(821)] = 22430,
  [SMALL_STATE(822)] = 22470,
  [SMALL_STATE(823)] = 22510,
  [SMALL_STATE(824)] = 22550,
  [SMALL_STATE(825)] = 22590,
  [SMALL_STATE(826)] = 22630,
  [SMALL_STATE(827)] = 22666,
  [SMALL_STATE(828)] = 22693,
  [SMALL_STATE(829)] = 22730,
  [SMALL_STATE(830)] = 22763,
  [SMALL_STATE(831)] = 22788,
  [SMALL_STATE(832)] = 22825,
  [SMALL_STATE(833)] = 22862,
  [SMALL_STATE(834)] = 22899,
  [SMALL_STATE(835)] = 22936,
  [SMALL_STATE(836)] = 22973,
  [SMALL_STATE(837)] = 22998,
  [SMALL_STATE(838)] = 23035,
  [SMALL_STATE(839)] = 23077,
  [SMALL_STATE(840)] = 23119,
  [SMALL_STATE(841)] = 23161,
  [SMALL_STATE(842)] = 23203,
  [SMALL_STATE(843)] = 23245,
  [SMALL_STATE(844)] = 23287,
  [SMALL_STATE(845)] = 23329,
  [SMALL_STATE(846)] = 23371,
  [SMALL_STATE(847)] = 23397,
  [SMALL_STATE(848)] = 23430,
  [SMALL_STATE(849)] = 23467,
  [SMALL_STATE(850)] = 23500,
  [SMALL_STATE(851)] = 23534,
  [SMALL_STATE(852)] = 23570,
  [SMALL_STATE(853)] = 23598,
  [SMALL_STATE(854)] = 23628,
  [SMALL_STATE(855)] = 23662,
  [SMALL_STATE(856)] = 23698,
  [SMALL_STATE(857)] = 23734,
  [SMALL_STATE(858)] = 23766,
  [SMALL_STATE(859)] = 23796,
  [SMALL_STATE(860)] = 23832,
  [SMALL_STATE(861)] = 23866,
  [SMALL_STATE(862)] = 23900,
  [SMALL_STATE(863)] = 23931,
  [SMALL_STATE(864)] = 23964,
  [SMALL_STATE(865)] = 23997,
  [SMALL_STATE(866)] = 24028,
  [SMALL_STATE(867)] = 24059,
  [SMALL_STATE(868)] = 24090,
  [SMALL_STATE(869)] = 24121,
  [SMALL_STATE(870)] = 24152,
  [SMALL_STATE(871)] = 24179,
  [SMALL_STATE(872)] = 24210,
  [SMALL_STATE(873)] = 24243,
  [SMALL_STATE(874)] = 24274,
  [SMALL_STATE(875)] = 24307,
  [SMALL_STATE(876)] = 24335,
  [SMALL_STATE(877)] = 24367,
  [SMALL_STATE(878)] = 24395,
  [SMALL_STATE(879)] = 24419,
  [SMALL_STATE(880)] = 24445,
  [SMALL_STATE(881)] = 24477,
  [SMALL_STATE(882)] = 24505,
  [SMALL_STATE(883)] = 24537,
  [SMALL_STATE(884)] = 24567,
  [SMALL_STATE(885)] = 24593,
  [SMALL_STATE(886)] = 24619,
  [SMALL_STATE(887)] = 24640,
  [SMALL_STATE(888)] = 24663,
  [SMALL_STATE(889)] = 24686,
  [SMALL_STATE(890)] = 24707,
  [SMALL_STATE(891)] = 24730,
  [SMALL_STATE(892)] = 24755,
  [SMALL_STATE(893)] = 24790,
  [SMALL_STATE(894)] = 24825,
  [SMALL_STATE(895)] = 24850,
  [SMALL_STATE(896)] = 24879,
  [SMALL_STATE(897)] = 24904,
  [SMALL_STATE(898)] = 24924,
  [SMALL_STATE(899)] = 24944,
  [SMALL_STATE(900)] = 24964,
  [SMALL_STATE(901)] = 24984,
  [SMALL_STATE(902)] = 25004,
  [SMALL_STATE(903)] = 25026,
  [SMALL_STATE(904)] = 25046,
  [SMALL_STATE(905)] = 25066,
  [SMALL_STATE(906)] = 25082,
  [SMALL_STATE(907)] = 25102,
  [SMALL_STATE(908)] = 25122,
  [SMALL_STATE(909)] = 25142,
  [SMALL_STATE(910)] = 25162,
  [SMALL_STATE(911)] = 25178,
  [SMALL_STATE(912)] = 25198,
  [SMALL_STATE(913)] = 25218,
  [SMALL_STATE(914)] = 25238,
  [SMALL_STATE(915)] = 25266,
  [SMALL_STATE(916)] = 25286,
  [SMALL_STATE(917)] = 25302,
  [SMALL_STATE(918)] = 25322,
  [SMALL_STATE(919)] = 25342,
  [SMALL_STATE(920)] = 25371,
  [SMALL_STATE(921)] = 25390,
  [SMALL_STATE(922)] = 25419,
  [SMALL_STATE(923)] = 25438,
  [SMALL_STATE(924)] = 25467,
  [SMALL_STATE(925)] = 25486,
  [SMALL_STATE(926)] = 25515,
  [SMALL_STATE(927)] = 25537,
  [SMALL_STATE(928)] = 25561,
  [SMALL_STATE(929)] = 25581,
  [SMALL_STATE(930)] = 25601,
  [SMALL_STATE(931)] = 25615,
  [SMALL_STATE(932)] = 25637,
  [SMALL_STATE(933)] = 25651,
  [SMALL_STATE(934)] = 25665,
  [SMALL_STATE(935)] = 25679,
  [SMALL_STATE(936)] = 25703,
  [SMALL_STATE(937)] = 25717,
  [SMALL_STATE(938)] = 25734,
  [SMALL_STATE(939)] = 25747,
  [SMALL_STATE(940)] = 25764,
  [SMALL_STATE(941)] = 25781,
  [SMALL_STATE(942)] = 25798,
  [SMALL_STATE(943)] = 25811,
  [SMALL_STATE(944)] = 25824,
  [SMALL_STATE(945)] = 25837,
  [SMALL_STATE(946)] = 25850,
  [SMALL_STATE(947)] = 25863,
  [SMALL_STATE(948)] = 25876,
  [SMALL_STATE(949)] = 25893,
  [SMALL_STATE(950)] = 25910,
  [SMALL_STATE(951)] = 25933,
  [SMALL_STATE(952)] = 25950,
  [SMALL_STATE(953)] = 25971,
  [SMALL_STATE(954)] = 25984,
  [SMALL_STATE(955)] = 25997,
  [SMALL_STATE(956)] = 26020,
  [SMALL_STATE(957)] = 26037,
  [SMALL_STATE(958)] = 26050,
  [SMALL_STATE(959)] = 26071,
  [SMALL_STATE(960)] = 26088,
  [SMALL_STATE(961)] = 26101,
  [SMALL_STATE(962)] = 26124,
  [SMALL_STATE(963)] = 26145,
  [SMALL_STATE(964)] = 26166,
  [SMALL_STATE(965)] = 26183,
  [SMALL_STATE(966)] = 26200,
  [SMALL_STATE(967)] = 26221,
  [SMALL_STATE(968)] = 26234,
  [SMALL_STATE(969)] = 26247,
  [SMALL_STATE(970)] = 26264,
  [SMALL_STATE(971)] = 26277,
  [SMALL_STATE(972)] = 26294,
  [SMALL_STATE(973)] = 26307,
  [SMALL_STATE(974)] = 26320,
  [SMALL_STATE(975)] = 26337,
  [SMALL_STATE(976)] = 26360,
  [SMALL_STATE(977)] = 26383,
  [SMALL_STATE(978)] = 26406,
  [SMALL_STATE(979)] = 26423,
  [SMALL_STATE(980)] = 26444,
  [SMALL_STATE(981)] = 26458,
  [SMALL_STATE(982)] = 26478,
  [SMALL_STATE(983)] = 26494,
  [SMALL_STATE(984)] = 26510,
  [SMALL_STATE(985)] = 26528,
  [SMALL_STATE(986)] = 26548,
  [SMALL_STATE(987)] = 26564,
  [SMALL_STATE(988)] = 26584,
  [SMALL_STATE(989)] = 26604,
  [SMALL_STATE(990)] = 26620,
  [SMALL_STATE(991)] = 26640,
  [SMALL_STATE(992)] = 26652,
  [SMALL_STATE(993)] = 26672,
  [SMALL_STATE(994)] = 26688,
  [SMALL_STATE(995)] = 26708,
  [SMALL_STATE(996)] = 26724,
  [SMALL_STATE(997)] = 26744,
  [SMALL_STATE(998)] = 26764,
  [SMALL_STATE(999)] = 26784,
  [SMALL_STATE(1000)] = 26804,
  [SMALL_STATE(1001)] = 26824,
  [SMALL_STATE(1002)] = 26844,
  [SMALL_STATE(1003)] = 26864,
  [SMALL_STATE(1004)] = 26884,
  [SMALL_STATE(1005)] = 26900,
  [SMALL_STATE(1006)] = 26916,
  [SMALL_STATE(1007)] = 26933,
  [SMALL_STATE(1008)] = 26950,
  [SMALL_STATE(1009)] = 26965,
  [SMALL_STATE(1010)] = 26980,
  [SMALL_STATE(1011)] = 26997,
  [SMALL_STATE(1012)] = 27014,
  [SMALL_STATE(1013)] = 27029,
  [SMALL_STATE(1014)] = 27044,
  [SMALL_STATE(1015)] = 27061,
  [SMALL_STATE(1016)] = 27078,
  [SMALL_STATE(1017)] = 27095,
  [SMALL_STATE(1018)] = 27110,
  [SMALL_STATE(1019)] = 27121,
  [SMALL_STATE(1020)] = 27138,
  [SMALL_STATE(1021)] = 27155,
  [SMALL_STATE(1022)] = 27170,
  [SMALL_STATE(1023)] = 27185,
  [SMALL_STATE(1024)] = 27202,
  [SMALL_STATE(1025)] = 27217,
  [SMALL_STATE(1026)] = 27234,
  [SMALL_STATE(1027)] = 27245,
  [SMALL_STATE(1028)] = 27262,
  [SMALL_STATE(1029)] = 27275,
  [SMALL_STATE(1030)] = 27292,
  [SMALL_STATE(1031)] = 27309,
  [SMALL_STATE(1032)] = 27322,
  [SMALL_STATE(1033)] = 27339,
  [SMALL_STATE(1034)] = 27356,
  [SMALL_STATE(1035)] = 27371,
  [SMALL_STATE(1036)] = 27386,
  [SMALL_STATE(1037)] = 27403,
  [SMALL_STATE(1038)] = 27420,
  [SMALL_STATE(1039)] = 27437,
  [SMALL_STATE(1040)] = 27448,
  [SMALL_STATE(1041)] = 27463,
  [SMALL_STATE(1042)] = 27478,
  [SMALL_STATE(1043)] = 27493,
  [SMALL_STATE(1044)] = 27508,
  [SMALL_STATE(1045)] = 27523,
  [SMALL_STATE(1046)] = 27540,
  [SMALL_STATE(1047)] = 27555,
  [SMALL_STATE(1048)] = 27572,
  [SMALL_STATE(1049)] = 27583,
  [SMALL_STATE(1050)] = 27598,
  [SMALL_STATE(1051)] = 27615,
  [SMALL_STATE(1052)] = 27632,
  [SMALL_STATE(1053)] = 27647,
  [SMALL_STATE(1054)] = 27658,
  [SMALL_STATE(1055)] = 27675,
  [SMALL_STATE(1056)] = 27692,
  [SMALL_STATE(1057)] = 27709,
  [SMALL_STATE(1058)] = 27724,
  [SMALL_STATE(1059)] = 27741,
  [SMALL_STATE(1060)] = 27756,
  [SMALL_STATE(1061)] = 27773,
  [SMALL_STATE(1062)] = 27790,
  [SMALL_STATE(1063)] = 27805,
  [SMALL_STATE(1064)] = 27819,
  [SMALL_STATE(1065)] = 27833,
  [SMALL_STATE(1066)] = 27847,
  [SMALL_STATE(1067)] = 27861,
  [SMALL_STATE(1068)] = 27875,
  [SMALL_STATE(1069)] = 27889,
  [SMALL_STATE(1070)] = 27903,
  [SMALL_STATE(1071)] = 27917,
  [SMALL_STATE(1072)] = 27931,
  [SMALL_STATE(1073)] = 27945,
  [SMALL_STATE(1074)] = 27959,
  [SMALL_STATE(1075)] = 27971,
  [SMALL_STATE(1076)] = 27985,
  [SMALL_STATE(1077)] = 27999,
  [SMALL_STATE(1078)] = 28013,
  [SMALL_STATE(1079)] = 28025,
  [SMALL_STATE(1080)] = 28039,
  [SMALL_STATE(1081)] = 28053,
  [SMALL_STATE(1082)] = 28067,
  [SMALL_STATE(1083)] = 28081,
  [SMALL_STATE(1084)] = 28095,
  [SMALL_STATE(1085)] = 28109,
  [SMALL_STATE(1086)] = 28123,
  [SMALL_STATE(1087)] = 28137,
  [SMALL_STATE(1088)] = 28151,
  [SMALL_STATE(1089)] = 28165,
  [SMALL_STATE(1090)] = 28179,
  [SMALL_STATE(1091)] = 28189,
  [SMALL_STATE(1092)] = 28203,
  [SMALL_STATE(1093)] = 28217,
  [SMALL_STATE(1094)] = 28231,
  [SMALL_STATE(1095)] = 28245,
  [SMALL_STATE(1096)] = 28259,
  [SMALL_STATE(1097)] = 28273,
  [SMALL_STATE(1098)] = 28287,
  [SMALL_STATE(1099)] = 28301,
  [SMALL_STATE(1100)] = 28315,
  [SMALL_STATE(1101)] = 28329,
  [SMALL_STATE(1102)] = 28343,
  [SMALL_STATE(1103)] = 28357,
  [SMALL_STATE(1104)] = 28371,
  [SMALL_STATE(1105)] = 28385,
  [SMALL_STATE(1106)] = 28399,
  [SMALL_STATE(1107)] = 28413,
  [SMALL_STATE(1108)] = 28427,
  [SMALL_STATE(1109)] = 28441,
  [SMALL_STATE(1110)] = 28455,
  [SMALL_STATE(1111)] = 28469,
  [SMALL_STATE(1112)] = 28483,
  [SMALL_STATE(1113)] = 28497,
  [SMALL_STATE(1114)] = 28511,
  [SMALL_STATE(1115)] = 28521,
  [SMALL_STATE(1116)] = 28531,
  [SMALL_STATE(1117)] = 28545,
  [SMALL_STATE(1118)] = 28555,
  [SMALL_STATE(1119)] = 28569,
  [SMALL_STATE(1120)] = 28583,
  [SMALL_STATE(1121)] = 28597,
  [SMALL_STATE(1122)] = 28611,
  [SMALL_STATE(1123)] = 28625,
  [SMALL_STATE(1124)] = 28639,
  [SMALL_STATE(1125)] = 28653,
  [SMALL_STATE(1126)] = 28667,
  [SMALL_STATE(1127)] = 28681,
  [SMALL_STATE(1128)] = 28695,
  [SMALL_STATE(1129)] = 28709,
  [SMALL_STATE(1130)] = 28723,
  [SMALL_STATE(1131)] = 28737,
  [SMALL_STATE(1132)] = 28747,
  [SMALL_STATE(1133)] = 28757,
  [SMALL_STATE(1134)] = 28771,
  [SMALL_STATE(1135)] = 28785,
  [SMALL_STATE(1136)] = 28799,
  [SMALL_STATE(1137)] = 28813,
  [SMALL_STATE(1138)] = 28827,
  [SMALL_STATE(1139)] = 28841,
  [SMALL_STATE(1140)] = 28855,
  [SMALL_STATE(1141)] = 28865,
  [SMALL_STATE(1142)] = 28879,
  [SMALL_STATE(1143)] = 28893,
  [SMALL_STATE(1144)] = 28907,
  [SMALL_STATE(1145)] = 28921,
  [SMALL_STATE(1146)] = 28935,
  [SMALL_STATE(1147)] = 28949,
  [SMALL_STATE(1148)] = 28963,
  [SMALL_STATE(1149)] = 28977,
  [SMALL_STATE(1150)] = 28991,
  [SMALL_STATE(1151)] = 29005,
  [SMALL_STATE(1152)] = 29019,
  [SMALL_STATE(1153)] = 29033,
  [SMALL_STATE(1154)] = 29043,
  [SMALL_STATE(1155)] = 29057,
  [SMALL_STATE(1156)] = 29067,
  [SMALL_STATE(1157)] = 29081,
  [SMALL_STATE(1158)] = 29091,
  [SMALL_STATE(1159)] = 29105,
  [SMALL_STATE(1160)] = 29115,
  [SMALL_STATE(1161)] = 29129,
  [SMALL_STATE(1162)] = 29143,
  [SMALL_STATE(1163)] = 29157,
  [SMALL_STATE(1164)] = 29171,
  [SMALL_STATE(1165)] = 29185,
  [SMALL_STATE(1166)] = 29199,
  [SMALL_STATE(1167)] = 29213,
  [SMALL_STATE(1168)] = 29227,
  [SMALL_STATE(1169)] = 29241,
  [SMALL_STATE(1170)] = 29255,
  [SMALL_STATE(1171)] = 29269,
  [SMALL_STATE(1172)] = 29283,
  [SMALL_STATE(1173)] = 29293,
  [SMALL_STATE(1174)] = 29307,
  [SMALL_STATE(1175)] = 29321,
  [SMALL_STATE(1176)] = 29335,
  [SMALL_STATE(1177)] = 29346,
  [SMALL_STATE(1178)] = 29357,
  [SMALL_STATE(1179)] = 29368,
  [SMALL_STATE(1180)] = 29379,
  [SMALL_STATE(1181)] = 29388,
  [SMALL_STATE(1182)] = 29399,
  [SMALL_STATE(1183)] = 29410,
  [SMALL_STATE(1184)] = 29421,
  [SMALL_STATE(1185)] = 29432,
  [SMALL_STATE(1186)] = 29443,
  [SMALL_STATE(1187)] = 29454,
  [SMALL_STATE(1188)] = 29465,
  [SMALL_STATE(1189)] = 29476,
  [SMALL_STATE(1190)] = 29487,
  [SMALL_STATE(1191)] = 29498,
  [SMALL_STATE(1192)] = 29509,
  [SMALL_STATE(1193)] = 29520,
  [SMALL_STATE(1194)] = 29529,
  [SMALL_STATE(1195)] = 29540,
  [SMALL_STATE(1196)] = 29551,
  [SMALL_STATE(1197)] = 29562,
  [SMALL_STATE(1198)] = 29573,
  [SMALL_STATE(1199)] = 29584,
  [SMALL_STATE(1200)] = 29595,
  [SMALL_STATE(1201)] = 29604,
  [SMALL_STATE(1202)] = 29615,
  [SMALL_STATE(1203)] = 29624,
  [SMALL_STATE(1204)] = 29633,
  [SMALL_STATE(1205)] = 29642,
  [SMALL_STATE(1206)] = 29653,
  [SMALL_STATE(1207)] = 29662,
  [SMALL_STATE(1208)] = 29673,
  [SMALL_STATE(1209)] = 29684,
  [SMALL_STATE(1210)] = 29695,
  [SMALL_STATE(1211)] = 29704,
  [SMALL_STATE(1212)] = 29715,
  [SMALL_STATE(1213)] = 29724,
  [SMALL_STATE(1214)] = 29735,
  [SMALL_STATE(1215)] = 29746,
  [SMALL_STATE(1216)] = 29757,
  [SMALL_STATE(1217)] = 29768,
  [SMALL_STATE(1218)] = 29777,
  [SMALL_STATE(1219)] = 29788,
  [SMALL_STATE(1220)] = 29799,
  [SMALL_STATE(1221)] = 29810,
  [SMALL_STATE(1222)] = 29821,
  [SMALL_STATE(1223)] = 29832,
  [SMALL_STATE(1224)] = 29841,
  [SMALL_STATE(1225)] = 29852,
  [SMALL_STATE(1226)] = 29861,
  [SMALL_STATE(1227)] = 29870,
  [SMALL_STATE(1228)] = 29879,
  [SMALL_STATE(1229)] = 29888,
  [SMALL_STATE(1230)] = 29899,
  [SMALL_STATE(1231)] = 29910,
  [SMALL_STATE(1232)] = 29919,
  [SMALL_STATE(1233)] = 29928,
  [SMALL_STATE(1234)] = 29937,
  [SMALL_STATE(1235)] = 29948,
  [SMALL_STATE(1236)] = 29957,
  [SMALL_STATE(1237)] = 29968,
  [SMALL_STATE(1238)] = 29979,
  [SMALL_STATE(1239)] = 29990,
  [SMALL_STATE(1240)] = 30001,
  [SMALL_STATE(1241)] = 30012,
  [SMALL_STATE(1242)] = 30023,
  [SMALL_STATE(1243)] = 30034,
  [SMALL_STATE(1244)] = 30043,
  [SMALL_STATE(1245)] = 30054,
  [SMALL_STATE(1246)] = 30065,
  [SMALL_STATE(1247)] = 30076,
  [SMALL_STATE(1248)] = 30087,
  [SMALL_STATE(1249)] = 30096,
  [SMALL_STATE(1250)] = 30107,
  [SMALL_STATE(1251)] = 30116,
  [SMALL_STATE(1252)] = 30127,
  [SMALL_STATE(1253)] = 30138,
  [SMALL_STATE(1254)] = 30149,
  [SMALL_STATE(1255)] = 30160,
  [SMALL_STATE(1256)] = 30171,
  [SMALL_STATE(1257)] = 30182,
  [SMALL_STATE(1258)] = 30191,
  [SMALL_STATE(1259)] = 30200,
  [SMALL_STATE(1260)] = 30211,
  [SMALL_STATE(1261)] = 30222,
  [SMALL_STATE(1262)] = 30231,
  [SMALL_STATE(1263)] = 30240,
  [SMALL_STATE(1264)] = 30249,
  [SMALL_STATE(1265)] = 30260,
  [SMALL_STATE(1266)] = 30271,
  [SMALL_STATE(1267)] = 30282,
  [SMALL_STATE(1268)] = 30291,
  [SMALL_STATE(1269)] = 30300,
  [SMALL_STATE(1270)] = 30311,
  [SMALL_STATE(1271)] = 30320,
  [SMALL_STATE(1272)] = 30329,
  [SMALL_STATE(1273)] = 30338,
  [SMALL_STATE(1274)] = 30349,
  [SMALL_STATE(1275)] = 30358,
  [SMALL_STATE(1276)] = 30369,
  [SMALL_STATE(1277)] = 30378,
  [SMALL_STATE(1278)] = 30389,
  [SMALL_STATE(1279)] = 30398,
  [SMALL_STATE(1280)] = 30409,
  [SMALL_STATE(1281)] = 30418,
  [SMALL_STATE(1282)] = 30427,
  [SMALL_STATE(1283)] = 30438,
  [SMALL_STATE(1284)] = 30449,
  [SMALL_STATE(1285)] = 30460,
  [SMALL_STATE(1286)] = 30469,
  [SMALL_STATE(1287)] = 30480,
  [SMALL_STATE(1288)] = 30491,
  [SMALL_STATE(1289)] = 30502,
  [SMALL_STATE(1290)] = 30513,
  [SMALL_STATE(1291)] = 30524,
  [SMALL_STATE(1292)] = 30535,
  [SMALL_STATE(1293)] = 30546,
  [SMALL_STATE(1294)] = 30557,
  [SMALL_STATE(1295)] = 30568,
  [SMALL_STATE(1296)] = 30579,
  [SMALL_STATE(1297)] = 30588,
  [SMALL_STATE(1298)] = 30599,
  [SMALL_STATE(1299)] = 30607,
  [SMALL_STATE(1300)] = 30615,
  [SMALL_STATE(1301)] = 30623,
  [SMALL_STATE(1302)] = 30631,
  [SMALL_STATE(1303)] = 30639,
  [SMALL_STATE(1304)] = 30647,
  [SMALL_STATE(1305)] = 30655,
  [SMALL_STATE(1306)] = 30663,
  [SMALL_STATE(1307)] = 30671,
  [SMALL_STATE(1308)] = 30679,
  [SMALL_STATE(1309)] = 30687,
  [SMALL_STATE(1310)] = 30695,
  [SMALL_STATE(1311)] = 30703,
  [SMALL_STATE(1312)] = 30711,
  [SMALL_STATE(1313)] = 30719,
  [SMALL_STATE(1314)] = 30727,
  [SMALL_STATE(1315)] = 30735,
  [SMALL_STATE(1316)] = 30743,
  [SMALL_STATE(1317)] = 30751,
  [SMALL_STATE(1318)] = 30759,
  [SMALL_STATE(1319)] = 30767,
  [SMALL_STATE(1320)] = 30775,
  [SMALL_STATE(1321)] = 30783,
  [SMALL_STATE(1322)] = 30791,
  [SMALL_STATE(1323)] = 30799,
  [SMALL_STATE(1324)] = 30807,
  [SMALL_STATE(1325)] = 30815,
  [SMALL_STATE(1326)] = 30823,
  [SMALL_STATE(1327)] = 30831,
  [SMALL_STATE(1328)] = 30839,
  [SMALL_STATE(1329)] = 30847,
  [SMALL_STATE(1330)] = 30855,
  [SMALL_STATE(1331)] = 30863,
  [SMALL_STATE(1332)] = 30871,
  [SMALL_STATE(1333)] = 30879,
  [SMALL_STATE(1334)] = 30887,
  [SMALL_STATE(1335)] = 30895,
  [SMALL_STATE(1336)] = 30903,
  [SMALL_STATE(1337)] = 30911,
  [SMALL_STATE(1338)] = 30919,
  [SMALL_STATE(1339)] = 30927,
  [SMALL_STATE(1340)] = 30935,
  [SMALL_STATE(1341)] = 30943,
  [SMALL_STATE(1342)] = 30951,
  [SMALL_STATE(1343)] = 30959,
  [SMALL_STATE(1344)] = 30967,
  [SMALL_STATE(1345)] = 30975,
  [SMALL_STATE(1346)] = 30983,
  [SMALL_STATE(1347)] = 30991,
  [SMALL_STATE(1348)] = 30999,
  [SMALL_STATE(1349)] = 31007,
  [SMALL_STATE(1350)] = 31015,
  [SMALL_STATE(1351)] = 31023,
  [SMALL_STATE(1352)] = 31031,
  [SMALL_STATE(1353)] = 31039,
  [SMALL_STATE(1354)] = 31047,
  [SMALL_STATE(1355)] = 31055,
  [SMALL_STATE(1356)] = 31063,
  [SMALL_STATE(1357)] = 31071,
  [SMALL_STATE(1358)] = 31079,
  [SMALL_STATE(1359)] = 31087,
  [SMALL_STATE(1360)] = 31095,
  [SMALL_STATE(1361)] = 31103,
  [SMALL_STATE(1362)] = 31111,
  [SMALL_STATE(1363)] = 31119,
  [SMALL_STATE(1364)] = 31127,
  [SMALL_STATE(1365)] = 31135,
  [SMALL_STATE(1366)] = 31143,
  [SMALL_STATE(1367)] = 31151,
  [SMALL_STATE(1368)] = 31159,
  [SMALL_STATE(1369)] = 31167,
  [SMALL_STATE(1370)] = 31175,
  [SMALL_STATE(1371)] = 31183,
  [SMALL_STATE(1372)] = 31191,
  [SMALL_STATE(1373)] = 31199,
  [SMALL_STATE(1374)] = 31207,
  [SMALL_STATE(1375)] = 31215,
  [SMALL_STATE(1376)] = 31223,
  [SMALL_STATE(1377)] = 31231,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(509),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(576),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1366),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2),
  [99] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(421),
  [102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(571),
  [105] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(571),
  [108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(979),
  [111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(896),
  [114] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(117),
  [117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(928),
  [120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(242),
  [123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(509),
  [126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(242),
  [129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(238),
  [132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(789),
  [135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1346),
  [138] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1178),
  [141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(13),
  [144] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(284),
  [147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(217),
  [150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(24),
  [153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1179),
  [156] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1181),
  [159] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1182),
  [162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(152),
  [165] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(106),
  [168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(576),
  [171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(211),
  [174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1054),
  [177] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1183),
  [180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1371),
  [183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(917),
  [186] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(457),
  [189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(423),
  [192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(138),
  [195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(907),
  [198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(890),
  [201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1369),
  [204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(400),
  [207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(509),
  [210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(454),
  [213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1368),
  [216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1366),
  [219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(728),
  [222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(729),
  [225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(757),
  [228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(558),
  [231] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(1184),
  [234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 1),
  [236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_block_statement_group, 1),
  [240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_block_statement_group, 1),
  [242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(422),
  [261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(571),
  [264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(571),
  [267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(979),
  [270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(896),
  [273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2),
  [275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(117),
  [278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(242),
  [281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(509),
  [284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(242),
  [287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(238),
  [290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(789),
  [293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1346),
  [296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1178),
  [299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(13),
  [302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(284),
  [307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(217),
  [310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(24),
  [313] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1264),
  [316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1181),
  [319] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1182),
  [322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(152),
  [325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(106),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(576),
  [331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(211),
  [334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1054),
  [337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1265),
  [340] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1370),
  [343] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(917),
  [346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(457),
  [349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(423),
  [352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(138),
  [355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(907),
  [358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(890),
  [361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1369),
  [364] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(401),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(509),
  [370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(454),
  [373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1368),
  [376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1366),
  [379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(728),
  [382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(729),
  [385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(757),
  [388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(558),
  [391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat2, 2), SHIFT_REPEAT(1184),
  [394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_block_statement_group, 2),
  [396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_block_statement_group, 2),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1373),
  [418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, .production_id = 1),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__reserved_identifier, 1, .production_id = 1),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 2),
  [428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body, 2),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 3),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_body, 3),
  [434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_block, 2),
  [436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_block, 2),
  [438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3),
  [440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression, 3, .production_id = 21),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_expression, 3, .production_id = 21),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_block, 3),
  [456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_block, 3),
  [458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1),
  [480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1),
  [482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1),
  [484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1),
  [486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1), REDUCE(sym_statement, 1),
  [489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1), REDUCE(sym_statement, 1),
  [492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_with_resources_statement, 4, .production_id = 24),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_with_resources_statement, 4, .production_id = 24),
  [568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_with_resources_statement, 3, .production_id = 24),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_with_resources_statement, 3, .production_id = 24),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, .production_id = 23),
  [630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, .production_id = 23),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(1302),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 5, .production_id = 149),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 5, .production_id = 149),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 140),
  [665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 140),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 8, .production_id = 179),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 8, .production_id = 179),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 3),
  [673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 3),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 3),
  [677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 3),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3),
  [681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3),
  [683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_statement, 3),
  [685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yield_statement, 3),
  [687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_synchronized_statement, 3, .production_id = 22),
  [689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_synchronized_statement, 3, .production_id = 22),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3),
  [693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3),
  [695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2),
  [697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2),
  [699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 126),
  [701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 126),
  [703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 103),
  [705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 103),
  [707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 155),
  [709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 155),
  [711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 102),
  [713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 102),
  [715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, .production_id = 147),
  [717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, .production_id = 147),
  [719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 6),
  [721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 6),
  [723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 3),
  [725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_statement, 3),
  [727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 91),
  [729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 91),
  [731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 2),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_body, 2),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 3, .production_id = 20),
  [737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 3, .production_id = 20),
  [739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_declaration, 4, .production_id = 62),
  [741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_declaration, 4, .production_id = 62),
  [743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_body, 3),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_body, 3),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 175),
  [749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 175),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 174),
  [753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 174),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_body, 3),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_body, 3),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 151),
  [761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 151),
  [763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, .production_id = 101),
  [765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, .production_id = 101),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, .production_id = 100),
  [769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, .production_id = 100),
  [771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_declaration, 4),
  [773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_declaration, 4),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enhanced_for_statement, 8, .production_id = 173),
  [777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enhanced_for_statement, 8, .production_id = 173),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_declaration, 3, .production_id = 20),
  [781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_declaration, 3, .production_id = 20),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_declaration, 3),
  [785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_declaration, 3),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 171),
  [793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 171),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 3),
  [797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_declaration, 3),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3),
  [801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 3),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 3, .production_id = 20),
  [805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 3, .production_id = 20),
  [807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 170),
  [809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 170),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 5),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_declaration, 5),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 169),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 169),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_declaration, 3, .production_id = 20),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_declaration, 3, .production_id = 20),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, .production_id = 201),
  [829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, .production_id = 201),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, .production_id = 23),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, .production_id = 23),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, .production_id = 200),
  [837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, .production_id = 200),
  [839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, .production_id = 199),
  [841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, .production_id = 199),
  [843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 3),
  [845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_body, 3),
  [847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 3, .production_id = 20),
  [849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 3, .production_id = 20),
  [851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2),
  [853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 2),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 154),
  [857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 154),
  [859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 168),
  [861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 168),
  [863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 11, .production_id = 206),
  [865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 11, .production_id = 206),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_variable_declaration, 4, .production_id = 71),
  [869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_variable_declaration, 4, .production_id = 71),
  [871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, .production_id = 166),
  [873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, .production_id = 166),
  [875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, .production_id = 62),
  [877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, .production_id = 62),
  [879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, .production_id = 165),
  [881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, .production_id = 165),
  [883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 127),
  [885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 127),
  [887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, .production_id = 164),
  [889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, .production_id = 164),
  [891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, .production_id = 163),
  [893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, .production_id = 163),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3),
  [897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3),
  [899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, .production_id = 162),
  [901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, .production_id = 162),
  [903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, .production_id = 60),
  [905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, .production_id = 60),
  [907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, .production_id = 59),
  [909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, .production_id = 59),
  [911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_declaration, 4, .production_id = 62),
  [913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_declaration, 4, .production_id = 62),
  [915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, .production_id = 161),
  [917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, .production_id = 161),
  [919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, .production_id = 58),
  [921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, .production_id = 58),
  [923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 96),
  [925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 96),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_with_resources_statement, 5, .production_id = 24),
  [929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_with_resources_statement, 5, .production_id = 24),
  [931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, .production_id = 57),
  [933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, .production_id = 57),
  [935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 172),
  [937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 172),
  [939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2),
  [941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2),
  [943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_declaration, 5, .production_id = 114),
  [945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_declaration, 5, .production_id = 114),
  [947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2),
  [949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2),
  [953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 2),
  [955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 108),
  [957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 108),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 4),
  [961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_declaration, 4),
  [963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, .production_id = 59),
  [965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 4, .production_id = 59),
  [967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 4, .production_id = 63),
  [969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 4, .production_id = 63),
  [971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 5, .production_id = 95),
  [973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 5, .production_id = 95),
  [975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, .production_id = 62),
  [977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 4, .production_id = 62),
  [979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, .production_id = 145),
  [981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, .production_id = 145),
  [983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, .production_id = 62),
  [985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, .production_id = 62),
  [987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_body, 2),
  [989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_body, 2),
  [991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, .production_id = 144),
  [993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, .production_id = 144),
  [995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 5),
  [997] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assert_statement, 5),
  [999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, .production_id = 138),
  [1001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, .production_id = 138),
  [1003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 181),
  [1005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 181),
  [1007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, .production_id = 143),
  [1009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, .production_id = 143),
  [1011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 187),
  [1013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 187),
  [1015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 5),
  [1017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 5),
  [1019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 123),
  [1021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 123),
  [1023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 182),
  [1025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 182),
  [1027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, .production_id = 142),
  [1029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, .production_id = 142),
  [1031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_body, 2),
  [1033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_body, 2),
  [1035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 109),
  [1037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 109),
  [1039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 122),
  [1041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 122),
  [1043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 141),
  [1045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 141),
  [1047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 121),
  [1049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 121),
  [1051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_variable_declaration, 3, .production_id = 40),
  [1053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_variable_declaration, 3, .production_id = 40),
  [1055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 139),
  [1057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 139),
  [1059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 113),
  [1061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 113),
  [1063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 183),
  [1065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 183),
  [1067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 111),
  [1069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 111),
  [1071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 6),
  [1073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_declaration, 6),
  [1075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 138),
  [1077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 138),
  [1079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 89),
  [1081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 89),
  [1083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 120),
  [1085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 120),
  [1087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 137),
  [1089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 137),
  [1091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 110),
  [1093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 110),
  [1095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, .production_id = 136),
  [1097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, .production_id = 136),
  [1099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 111),
  [1101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 111),
  [1103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, .production_id = 110),
  [1105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 5, .production_id = 110),
  [1107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 3, .production_id = 21),
  [1109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, .production_id = 21),
  [1111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, .production_id = 108),
  [1113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, .production_id = 108),
  [1115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enhanced_for_statement, 9, .production_id = 186),
  [1117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enhanced_for_statement, 9, .production_id = 186),
  [1119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, .production_id = 134),
  [1121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, .production_id = 134),
  [1123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4),
  [1125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_body, 4),
  [1127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 94),
  [1129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 94),
  [1131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 185),
  [1133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 185),
  [1135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, .production_id = 64),
  [1137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, .production_id = 64),
  [1139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 90),
  [1141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 90),
  [1143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 157),
  [1145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 157),
  [1147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 184),
  [1149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 184),
  [1151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 91),
  [1153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 91),
  [1155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, .production_id = 57),
  [1157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, .production_id = 57),
  [1159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, .production_id = 133),
  [1161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, .production_id = 133),
  [1163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 93),
  [1165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 93),
  [1167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 156),
  [1169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 156),
  [1171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, .production_id = 112),
  [1173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, .production_id = 112),
  [1175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, .production_id = 92),
  [1177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, .production_id = 92),
  [1179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, .production_id = 60),
  [1181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, .production_id = 60),
  [1183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat1, 2),
  [1185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_block_statement_group_repeat1, 2),
  [1187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat1, 2), SHIFT_REPEAT(140),
  [1190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_switch_block_statement_group_repeat1, 2), SHIFT_REPEAT(1243),
  [1193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 2, .production_id = 13),
  [1195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 2, .production_id = 13),
  [1197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, .production_id = 25),
  [1199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, .production_id = 25),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [1203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 2, .production_id = 12),
  [1205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 2, .production_id = 12),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [1209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 3, .production_id = 35),
  [1211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 3, .production_id = 35),
  [1213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 3, .production_id = 36),
  [1215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 3, .production_id = 36),
  [1217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_constructor_invocation, 3, .production_id = 167),
  [1219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_constructor_invocation, 3, .production_id = 167),
  [1221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_constructor_invocation, 4, .production_id = 180),
  [1223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_constructor_invocation, 4, .production_id = 180),
  [1225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_constructor_invocation, 6, .production_id = 205),
  [1227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_constructor_invocation, 6, .production_id = 205),
  [1229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_constructor_invocation, 5, .production_id = 198),
  [1231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_constructor_invocation, 5, .production_id = 198),
  [1233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 1),
  [1235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 1),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_declarations, 1),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [1265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(824),
  [1268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2),
  [1270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(928),
  [1273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(509),
  [1276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(1346),
  [1279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(13),
  [1282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(409),
  [1285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(917),
  [1288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(579),
  [1291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(1369),
  [1294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(509),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(1317),
  [1300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(1368),
  [1303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(1366),
  [1306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(728),
  [1309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(729),
  [1312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_declarations_repeat1, 2), SHIFT_REPEAT(757),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_declarations, 2),
  [1317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unannotated_type, 1, .production_id = 2),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [1323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1), SHIFT(652),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1), REDUCE(sym__unannotated_type, 1, .production_id = 2),
  [1337] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1), REDUCE(sym__unannotated_type, 1, .production_id = 2), SHIFT(978),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unannotated_type, 1, .production_id = 2),
  [1343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1), SHIFT(1331),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [1348] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_primary_expression, 1), REDUCE(sym__unannotated_type, 1, .production_id = 2), SHIFT(978),
  [1352] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_primary_expression, 1), REDUCE(sym__unannotated_type, 1, .production_id = 2), SHIFT(1331),
  [1356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1), REDUCE(sym__unannotated_type, 1, .production_id = 2),
  [1359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(700),
  [1362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interface_body_repeat1, 2),
  [1364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(928),
  [1367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(509),
  [1370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(1346),
  [1373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(414),
  [1376] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(917),
  [1379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(1369),
  [1382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(509),
  [1385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(1317),
  [1388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(1368),
  [1391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(1366),
  [1394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(728),
  [1397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(729),
  [1400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_body_repeat1, 2), SHIFT_REPEAT(757),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1), SHIFT(144),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [1428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [1432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(700),
  [1435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2),
  [1437] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(509),
  [1440] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(1346),
  [1443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(424),
  [1446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(917),
  [1449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(1369),
  [1452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(509),
  [1455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(1368),
  [1458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(1366),
  [1461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(728),
  [1464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(729),
  [1467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_annotation_type_body_repeat1, 2), SHIFT_REPEAT(757),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_access, 3, .production_id = 27),
  [1480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_access, 3, .production_id = 27),
  [1482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_access, 5, .production_id = 104),
  [1484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_access, 5, .production_id = 104),
  [1486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_dimensions_repeat1, 2),
  [1488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2),
  [1490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2), SHIFT_REPEAT(1348),
  [1493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2), SHIFT_REPEAT(904),
  [1496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 1),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 1),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [1502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotated_type, 2),
  [1504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotated_type, 2),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_access, 4, .production_id = 70),
  [1508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_access, 4, .production_id = 70),
  [1510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type, 1),
  [1512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1),
  [1514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [1518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__unannotated_type, 1, .production_id = 2), SHIFT(685),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unannotated_type, 1),
  [1525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unannotated_type, 1),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [1529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 3, .production_id = 17),
  [1531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 3, .production_id = 17),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 56),
  [1537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 56),
  [1539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 54),
  [1541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 54),
  [1543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 3, .production_id = 19),
  [1545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 3, .production_id = 19),
  [1547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4),
  [1549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4),
  [1551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3),
  [1553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [1557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 2),
  [1559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 2),
  [1561] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__unannotated_type, 1), SHIFT(685),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, .dynamic_precedence = 10, .production_id = 2),
  [1568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, .dynamic_precedence = 10, .production_id = 2),
  [1570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, .dynamic_precedence = 10),
  [1572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, .dynamic_precedence = 10),
  [1574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_dimensions_repeat1, 3),
  [1576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 3),
  [1578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat2, 2),
  [1580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_creation_expression_repeat2, 2),
  [1582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat2, 2), SHIFT_REPEAT(212),
  [1585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat2, 2), SHIFT_REPEAT(904),
  [1588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_type_identifier, 4, .production_id = 77),
  [1590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 4, .production_id = 77),
  [1592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_type_identifier, 3, .production_id = 30),
  [1594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 3, .production_id = 30),
  [1596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_type_identifier, 4, .production_id = 66),
  [1598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 4, .production_id = 66),
  [1600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 3, .production_id = 61),
  [1602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, .production_id = 61),
  [1604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_type_identifier, 3, .production_id = 42),
  [1606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 3, .production_id = 42),
  [1608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_floating_point_type, 1),
  [1610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_floating_point_type, 1),
  [1612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 2, .production_id = 8),
  [1614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 2, .production_id = 8),
  [1616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integral_type, 1),
  [1618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integral_type, 1),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 4, .production_id = 68),
  [1626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 4, .production_id = 68),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 3, .production_id = 32),
  [1632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 3, .production_id = 32),
  [1634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_marker_annotation, 2, .production_id = 5),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_marker_annotation, 2, .production_id = 5),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [1642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 55),
  [1644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 55),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 79),
  [1650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 79),
  [1652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 116),
  [1654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 116),
  [1656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 115),
  [1658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 115),
  [1660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 52),
  [1662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 52),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 53),
  [1666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 53),
  [1668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 86),
  [1670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 86),
  [1672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 3, .production_id = 16),
  [1674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 3, .production_id = 16),
  [1676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 3, .production_id = 18),
  [1678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 3, .production_id = 18),
  [1680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 85),
  [1682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 85),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 51),
  [1686] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 51),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 80),
  [1690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 80),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions_expr, 4),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions_expr, 4),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4),
  [1698] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4),
  [1700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2),
  [1702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2),
  [1704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(502),
  [1707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(917),
  [1710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(502),
  [1713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2),
  [1715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3),
  [1719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3),
  [1721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions_expr, 3),
  [1723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions_expr, 3),
  [1725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifiers, 1),
  [1727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifiers, 1),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(502),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_reference, 4),
  [1735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_reference, 4),
  [1737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, .production_id = 119),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, .production_id = 119),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_initializer, 3),
  [1743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_initializer, 3),
  [1745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 2, .production_id = 88),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 2, .production_id = 88),
  [1749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 3),
  [1751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 3),
  [1753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compact_constructor_declaration, 3, .production_id = 20),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compact_constructor_declaration, 3, .production_id = 20),
  [1757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 7, .production_id = 160),
  [1759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 7, .production_id = 160),
  [1761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiline_string_literal, 3),
  [1763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__multiline_string_literal, 3),
  [1765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 5, .production_id = 78),
  [1767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 5, .production_id = 78),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 5, .production_id = 84),
  [1777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 5, .production_id = 84),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 1, .production_id = 3),
  [1781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 1, .production_id = 3),
  [1783] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_argument_list, 4),
  [1785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_argument_list, 4),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [1791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 2),
  [1793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 2),
  [1795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 50),
  [1797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 50),
  [1799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 49),
  [1801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 49),
  [1803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 18),
  [1805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 18),
  [1807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_body, 3),
  [1809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_body, 3),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 47),
  [1813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 47),
  [1815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 16),
  [1817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 4, .production_id = 16),
  [1819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 2, .production_id = 6),
  [1821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 2, .production_id = 6),
  [1823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 4, .production_id = 65),
  [1825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 4, .production_id = 65),
  [1827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_creation_expression_repeat1, 1), REDUCE(aux_sym_modifiers_repeat1, 1),
  [1830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_creation_expression_repeat1, 1),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, .production_id = 44),
  [1834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, .production_id = 44),
  [1836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 5, .production_id = 83),
  [1838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 5, .production_id = 83),
  [1840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 55),
  [1842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 55),
  [1844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 5, .production_id = 82),
  [1846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 5, .production_id = 82),
  [1848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 6, .production_id = 135),
  [1850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 6, .production_id = 135),
  [1852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 5, .production_id = 81),
  [1854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 5, .production_id = 81),
  [1856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 53),
  [1858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 53),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compact_constructor_declaration, 2, .production_id = 87),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compact_constructor_declaration, 2, .production_id = 87),
  [1864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 3, .production_id = 26),
  [1866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 3, .production_id = 26),
  [1868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_literal, 3, .dynamic_precedence = 17),
  [1870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_literal, 3, .dynamic_precedence = 17),
  [1872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, .production_id = 40),
  [1874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, .production_id = 40),
  [1876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 4, .production_id = 48),
  [1878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 4, .production_id = 48),
  [1880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 52),
  [1882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 52),
  [1884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 51),
  [1886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 5, .production_id = 51),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 1),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 1),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 79),
  [1894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 79),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 85),
  [1898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 85),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 3, .production_id = 34),
  [1902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 3, .production_id = 34),
  [1904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_expression, 3, .production_id = 33),
  [1906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_expression, 3, .production_id = 33),
  [1908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 86),
  [1910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 86),
  [1912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_initializer, 4),
  [1914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_initializer, 4),
  [1916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 80),
  [1918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 6, .production_id = 80),
  [1920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_body, 2),
  [1922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_body, 2),
  [1924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_invocation, 5, .production_id = 105),
  [1926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_invocation, 5, .production_id = 105),
  [1928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_initializer, 2),
  [1930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_initializer, 2),
  [1932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_argument_list, 3),
  [1934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_argument_list, 3),
  [1936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiline_string_literal, 2),
  [1938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__multiline_string_literal, 2),
  [1940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_initializer, 2),
  [1942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_initializer, 2),
  [1944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_reference, 3),
  [1946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_reference, 3),
  [1948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_argument_list, 2),
  [1950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_argument_list, 2),
  [1952] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, .production_id = 71),
  [1954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, .production_id = 71),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 7, .production_id = 115),
  [1958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 7, .production_id = 115),
  [1960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unqualified_object_creation_expression, 7, .production_id = 116),
  [1962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unqualified_object_creation_expression, 7, .production_id = 116),
  [1964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1),
  [1966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1),
  [1968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, .production_id = 117),
  [1970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, .production_id = 117),
  [1972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_body, 4),
  [1974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_body, 4),
  [1976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, .production_id = 146),
  [1978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, .production_id = 146),
  [1980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_initializer, 5),
  [1982] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_initializer, 5),
  [1984] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_declaration, 3, .production_id = 40),
  [1986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_declaration, 3, .production_id = 40),
  [1988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_declaration, 4, .production_id = 71),
  [1990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_declaration, 4, .production_id = 71),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [1994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2), SHIFT_REPEAT(1340),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [1999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(596),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [2003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [2005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [2007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern_body, 3),
  [2009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern_body, 3),
  [2011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2),
  [2013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [2017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 203),
  [2019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 203),
  [2021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 202),
  [2023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 202),
  [2025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 204),
  [2027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 7, .production_id = 204),
  [2029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern_body, 4),
  [2031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern_body, 4),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, .production_id = 29),
  [2035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, .production_id = 29),
  [2037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 3, .production_id = 31),
  [2039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 3, .production_id = 31),
  [2041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 8, .production_id = 207),
  [2043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 8, .production_id = 207),
  [2045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 5, .production_id = 178),
  [2047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 5, .production_id = 178),
  [2049] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern_body, 2),
  [2051] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern_body, 2),
  [2053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 197),
  [2055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 197),
  [2057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 196),
  [2059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 196),
  [2061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 5, .production_id = 106),
  [2063] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 5, .production_id = 106),
  [2065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, .production_id = 4),
  [2067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, .production_id = 4),
  [2069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 194),
  [2071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_type_element_declaration, 6, .production_id = 194),
  [2073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 4, .production_id = 69),
  [2075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 4, .production_id = 69),
  [2077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern, 2),
  [2079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_pattern, 2),
  [2081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instanceof_expression, 4, .production_id = 67),
  [2083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instanceof_expression, 4, .production_id = 67),
  [2085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, .production_id = 28),
  [2087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, .production_id = 28),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(234),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [2103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_argument_list, 2), REDUCE(sym_record_pattern_body, 2),
  [2118] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_argument_list, 2), REDUCE(sym_record_pattern_body, 2),
  [2121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, .production_id = 107),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, .production_id = 28),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [2151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [2159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_label, 2),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [2167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(626),
  [2170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(904),
  [2173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(626),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [2192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__element_value, 1),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [2238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [2240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [2244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [2248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, .production_id = 76),
  [2274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, .production_id = 97),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [2294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1344),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [2308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource, 4, .production_id = 124),
  [2310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [2312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat2, 2, .production_id = 152),
  [2314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat1, 1), REDUCE(aux_sym_modifiers_repeat1, 1),
  [2317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_initializer_repeat1, 2),
  [2319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource, 5, .production_id = 148),
  [2321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guard, 2),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [2365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [2367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [2377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [2379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [2397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [2403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [2405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [2407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [2409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [2411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [2417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [2419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [2421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [2429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [2431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_creation_expression_repeat1, 2),
  [2433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat1, 2),
  [2435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat1, 2), SHIFT_REPEAT(918),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [2442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(987),
  [2444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [2446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [2448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [2450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [2460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [2466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [2480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__unannotated_type, 1), SHIFT(964),
  [2483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource, 1),
  [2485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_type, 1),
  [2487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [2495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_catch_type_repeat1, 2),
  [2497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_catch_type_repeat1, 2),
  [2499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameters, 3),
  [2501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3),
  [2503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameters, 4),
  [2505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [2511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat1, 1),
  [2513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [2515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [2527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__unannotated_type, 1), SHIFT(964),
  [2532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_declarator_id, 1, .production_id = 7),
  [2534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [2540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2),
  [2542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2), SHIFT_REPEAT(858),
  [2545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2), SHIFT_REPEAT(900),
  [2548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2), SHIFT_REPEAT(903),
  [2551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2), SHIFT_REPEAT(901),
  [2554] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2), SHIFT_REPEAT(913),
  [2557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [2563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_declarator, 2, .production_id = 39),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [2571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(532),
  [2573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_requires_module_directive_repeat1, 2, .production_id = 130),
  [2575] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requires_module_directive_repeat1, 2, .production_id = 130), SHIFT_REPEAT(916),
  [2578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [2580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [2584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2586] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_type, 2),
  [2588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_catch_type_repeat1, 2), SHIFT_REPEAT(828),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [2595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__multiline_string_literal_repeat1, 2),
  [2597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__multiline_string_literal_repeat1, 2), SHIFT_REPEAT(967),
  [2600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__multiline_string_literal_repeat1, 2), SHIFT_REPEAT(192),
  [2603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__multiline_string_literal_repeat1, 2), SHIFT_REPEAT(891),
  [2606] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [2608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [2612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [2614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [2616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [2618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [2620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [2622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(564),
  [2624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [2626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [2628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [2630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [2632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [2634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [2636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [2638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [2640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [2642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [2644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [2646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [2648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [2650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [2652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_requires_module_directive_repeat1, 1, .production_id = 99),
  [2654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [2656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [2658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [2666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [2668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_modifier, 1),
  [2670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [2672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [2674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [2676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [2678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [2680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [2682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [2684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 1, .production_id = 7),
  [2686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat1, 2),
  [2688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat1, 2), SHIFT_REPEAT(140),
  [2691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat1, 2), SHIFT_REPEAT(1243),
  [2694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 2),
  [2698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 2, .production_id = 5),
  [2700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 3),
  [2702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 5),
  [2704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 4),
  [2706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [2708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameters, 6),
  [2712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [2714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_provides_module_directive, 5, .production_id = 177),
  [2716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [2720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [2722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_provides_module_directive, 6, .production_id = 192),
  [2724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opens_module_directive, 6, .production_id = 189),
  [2726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_module_directive, 4, .production_id = 158),
  [2728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exports_module_directive, 6, .production_id = 189),
  [2730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_creation_expression_repeat1, 2), SHIFT_REPEAT(904),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [2737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_directive, 1),
  [2739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uses_module_directive, 3, .production_id = 45),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [2743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_module_directive, 3, .production_id = 129),
  [2745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2),
  [2747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal_repeat1, 2), SHIFT_REPEAT(958),
  [2750] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2), SHIFT_REPEAT(239),
  [2753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2), SHIFT_REPEAT(958),
  [2756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_interpolation, 3),
  [2760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat2, 2),
  [2762] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat2, 2), SHIFT_REPEAT(139),
  [2765] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_block_repeat2, 2), SHIFT_REPEAT(1243),
  [2768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_label, 3),
  [2770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [2774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [2776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [2778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [2780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [2782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__multiline_string_fragment, 1),
  [2784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opens_module_directive, 3, .production_id = 131),
  [2786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exports_module_directive, 3, .production_id = 131),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opens_module_directive, 5, .production_id = 176),
  [2794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exports_module_directive, 5, .production_id = 176),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [2798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [2800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [2802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [2806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2), SHIFT_REPEAT(199),
  [2809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 3, .production_id = 26),
  [2811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [2815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_list_repeat1, 2), SHIFT_REPEAT(759),
  [2818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_list_repeat1, 2),
  [2820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_declarator_id, 2, .production_id = 38),
  [2826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 2, .production_id = 6),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [2830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard, 1),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [2834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2), SHIFT_REPEAT(246),
  [2837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard, 2),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [2843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_bound_repeat1, 2), SHIFT_REPEAT(760),
  [2846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_bound_repeat1, 2),
  [2848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [2854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throws, 3),
  [2856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 2),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [2860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throws, 2),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [2864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_bound, 3),
  [2866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 1, .production_id = 2),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [2870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 4, .production_id = 72),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [2876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_value_array_initializer, 5),
  [2878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_interpolation, 3),
  [2880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, .production_id = 10),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [2884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 2, .production_id = 11),
  [2886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_bound, 2),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [2896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [2898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_value_array_initializer, 4),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, .production_id = 15),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_value_array_initializer, 3),
  [2912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_list, 1),
  [2914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_value_array_initializer, 2),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2),
  [2928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2), SHIFT_REPEAT(766),
  [2931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 3, .production_id = 37),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exports_module_directive_repeat1, 2, .production_id = 188),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_exports_module_directive_repeat1, 2, .production_id = 190), SHIFT_REPEAT(912),
  [2964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_exports_module_directive_repeat1, 2, .production_id = 190),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_provides_module_directive_repeat1, 2, .production_id = 191),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [2972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_declarator_list, 1, .production_id = 9),
  [2978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [2982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_pattern_body_repeat1, 2),
  [2990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_pattern_body_repeat1, 2), SHIFT_REPEAT(680),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 4, .production_id = 159),
  [2999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [3001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_element_value_array_initializer_repeat1, 2),
  [3003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_element_value_array_initializer_repeat1, 2), SHIFT_REPEAT(135),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [3008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [3010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [3012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [3014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat2, 2, .production_id = 153),
  [3016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat2, 2, .production_id = 153), SHIFT_REPEAT(209),
  [3019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [3021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [3023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_initializer_repeat1, 2), SHIFT_REPEAT(142),
  [3026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [3028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [3038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [3046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 3, .production_id = 20),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [3050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 3, .production_id = 132),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [3060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_argument_list_repeat1, 2),
  [3062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_argument_list_repeat1, 2), SHIFT_REPEAT(1201),
  [3065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [3067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_declarator_list, 2, .production_id = 41),
  [3069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_inferred_parameters_repeat1, 2),
  [3071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_inferred_parameters_repeat1, 2), SHIFT_REPEAT(920),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [3082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_cast_expression_repeat1, 2, .production_id = 46),
  [3084] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_cast_expression_repeat1, 2, .production_id = 46), SHIFT_REPEAT(754),
  [3087] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_receiver_parameter_repeat1, 2), SHIFT_REPEAT(1313),
  [3090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_receiver_parameter_repeat1, 2),
  [3092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_rule, 3),
  [3094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_pattern, 2),
  [3096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_formal_parameters_repeat1, 2),
  [3098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_formal_parameters_repeat1, 2), SHIFT_REPEAT(480),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [3105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2),
  [3107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2), SHIFT_REPEAT(929),
  [3110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [3112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [3118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_provides_module_directive_repeat1, 2, .production_id = 193), SHIFT_REPEAT(898),
  [3121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_provides_module_directive_repeat1, 2, .production_id = 193),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [3131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [3137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_superclass, 2),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [3141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_constant, 2, .production_id = 87),
  [3143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_declarator, 3, .production_id = 73),
  [3145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__variable_declarator_list_repeat1, 2, .production_id = 75), SHIFT_REPEAT(884),
  [3148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_declarator_list_repeat1, 2, .production_id = 75),
  [3150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [3152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [3154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [3156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [3158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [3160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2),
  [3162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2), SHIFT_REPEAT(692),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [3175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, .production_id = 98), SHIFT_REPEAT(214),
  [3178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, .production_id = 98),
  [3180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1),
  [3182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [3184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [3186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_resource_specification_repeat1, 2),
  [3188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_resource_specification_repeat1, 2), SHIFT_REPEAT(254),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [3193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [3195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [3199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [3203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_declarator, 2, .production_id = 39),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [3213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard, 3),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [3217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__wildcard_bounds, 2),
  [3219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receiver_parameter, 4),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [3223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_parameter, 4),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [3229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_declarator_list_repeat1, 2, .production_id = 74),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [3233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 4, .production_id = 37),
  [3235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_label, 4),
  [3237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_interfaces, 2),
  [3239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receiver_parameter, 2),
  [3241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameter, 2, .production_id = 14),
  [3243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern_component, 1),
  [3245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, .production_id = 2),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [3251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_label, 1),
  [3253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_super_interfaces, 2),
  [3255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, .production_id = 15),
  [3257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 5, .production_id = 72),
  [3259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_declarator, 3, .production_id = 118),
  [3261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [3263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receiver_parameter, 3),
  [3265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_parameter, 3),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [3269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_cast_expression_repeat1, 2, .production_id = 45),
  [3271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_parameter, 3, .production_id = 43),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [3275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_header, 3, .production_id = 11),
  [3277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_value_pair, 3, .production_id = 128),
  [3279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [3281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [3287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [3291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_pattern_component, 2),
  [3293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [3295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [3297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [3299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [3301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [3303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [3305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inferred_parameters, 4),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [3309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [3311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_formal_parameter, 2, .production_id = 125),
  [3313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_specification, 5),
  [3315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [3319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [3321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permits, 2),
  [3323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [3325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_specification, 3),
  [3327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [3329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [3331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [3333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_asterisk, 1),
  [3335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [3337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_formal_parameter, 3, .production_id = 150),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [3341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inferred_parameters, 3),
  [3343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [3345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [3347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [3349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [3351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [3389] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [3395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__default_value, 2, .production_id = 195),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [3411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_specification, 4),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_java() {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
